/*****************************************************************************
 *
 * \file
 *
 * \brief FIR coefficients for the dsp16_resampling function from the DPSLib.
 *        These coefficients have the following caracterizations:
 *          - Input sampling frequency: 44100 Hz
 *          - Output sampling frequency: 48000 Hz
 *          - Re-sampling order: 20
 *          - Coefficients are normalized
 *          - Memory foot print: 6400 bytes
 *         It matches the following parameters:
 *         (dsp16_resampling_options_t::dsp16_custom_filter)
 *          - Cut-off frequency (fc_hz): 22050
 *          - Sampling frequency (fs_hz): 7056000
 *          - Actual FIR filter order (order): 3200
 *
 * Copyright (c) 2010 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/

A_ALIGNED static const dsp16_t dsp16_resampling_fircoef_ord20_44100_48000_norm[] = {
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00000388),
  DSP16_Q(-0.00001705),
  DSP16_Q(0.00004205),
  DSP16_Q(-0.00008224),
  DSP16_Q(0.00014283),
  DSP16_Q(-0.00023373),
  DSP16_Q(0.00037808),
  DSP16_Q(-0.00064641),
  DSP16_Q(0.00139636),
  DSP16_Q(0.45654937),
  DSP16_Q(-0.00138723),
  DSP16_Q(0.00064399),
  DSP16_Q(-0.00037692),
  DSP16_Q(0.00023303),
  DSP16_Q(-0.00014237),
  DSP16_Q(0.00008193),
  DSP16_Q(-0.00004185),
  DSP16_Q(0.00001693),
  DSP16_Q(-0.00000383),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00001180),
  DSP16_Q(-0.00005148),
  DSP16_Q(0.00012674),
  DSP16_Q(-0.00024761),
  DSP16_Q(0.00042982),
  DSP16_Q(-0.00070321),
  DSP16_Q(0.00113760),
  DSP16_Q(-0.00194632),
  DSP16_Q(0.00421627),
  DSP16_Q(0.45648982),
  DSP16_Q(-0.00413409),
  DSP16_Q(0.00192447),
  DSP16_Q(-0.00112712),
  DSP16_Q(0.00069693),
  DSP16_Q(-0.00042569),
  DSP16_Q(0.00024485),
  DSP16_Q(-0.00012494),
  DSP16_Q(0.00005044),
  DSP16_Q(-0.00001135),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00001992),
  DSP16_Q(-0.00008637),
  DSP16_Q(0.00021218),
  DSP16_Q(-0.00041413),
  DSP16_Q(0.00071848),
  DSP16_Q(-0.00117522),
  DSP16_Q(0.00190137),
  DSP16_Q(-0.00325531),
  DSP16_Q(0.00707210),
  DSP16_Q(0.45637074),
  DSP16_Q(-0.00684384),
  DSP16_Q(0.00319462),
  DSP16_Q(-0.00187227),
  DSP16_Q(0.00115778),
  DSP16_Q(-0.00070702),
  DSP16_Q(0.00040644),
  DSP16_Q(-0.00020720),
  DSP16_Q(0.00008347),
  DSP16_Q(-0.00001865),
  DSP16_Q(-0.00000001),
  DSP16_Q(0.00002824),
  DSP16_Q(-0.00012169),
  DSP16_Q(0.00029834),
  DSP16_Q(-0.00058173),
  DSP16_Q(0.00100872),
  DSP16_Q(-0.00164959),
  DSP16_Q(0.00266913),
  DSP16_Q(-0.00457295),
  DSP16_Q(0.00996340),
  DSP16_Q(0.45619215),
  DSP16_Q(-0.00951608),
  DSP16_Q(0.00445405),
  DSP16_Q(-0.00261212),
  DSP16_Q(0.00161542),
  DSP16_Q(-0.00098627),
  DSP16_Q(0.00056667),
  DSP16_Q(-0.00028858),
  DSP16_Q(0.00011601),
  DSP16_Q(-0.00002576),
  DSP16_Q(-0.00000002),
  DSP16_Q(0.00003676),
  DSP16_Q(-0.00015744),
  DSP16_Q(0.00038519),
  DSP16_Q(-0.00075034),
  DSP16_Q(0.00130042),
  DSP16_Q(-0.00212616),
  DSP16_Q(0.00344060),
  DSP16_Q(-0.00589883),
  DSP16_Q(0.01288974),
  DSP16_Q(0.45595409),
  DSP16_Q(-0.01215045),
  DSP16_Q(0.00570237),
  DSP16_Q(-0.00334640),
  DSP16_Q(0.00206970),
  DSP16_Q(-0.00126333),
  DSP16_Q(0.00072546),
  DSP16_Q(-0.00036907),
  DSP16_Q(0.00014805),
  DSP16_Q(-0.00003266),
  DSP16_Q(-0.00000004),
  DSP16_Q(0.00004547),
  DSP16_Q(-0.00019360),
  DSP16_Q(0.00047271),
  DSP16_Q(-0.00091991),
  DSP16_Q(0.00159347),
  DSP16_Q(-0.00260473),
  DSP16_Q(0.00421550),
  DSP16_Q(-0.00723250),
  DSP16_Q(0.01585068),
  DSP16_Q(0.45565662),
  DSP16_Q(-0.01474660),
  DSP16_Q(0.00693918),
  DSP16_Q(-0.00407486),
  DSP16_Q(0.00252045),
  DSP16_Q(-0.00153810),
  DSP16_Q(0.00088277),
  DSP16_Q(-0.00044864),
  DSP16_Q(0.00017958),
  DSP16_Q(-0.00003935),
  DSP16_Q(-0.00000006),
  DSP16_Q(0.00005438),
  DSP16_Q(-0.00023017),
  DSP16_Q(0.00056086),
  DSP16_Q(-0.00109038),
  DSP16_Q(0.00188778),
  DSP16_Q(-0.00308515),
  DSP16_Q(0.00499354),
  DSP16_Q(-0.00857351),
  DSP16_Q(0.01884576),
  DSP16_Q(0.45529982),
  DSP16_Q(-0.01730417),
  DSP16_Q(0.00816410),
  DSP16_Q(-0.00479727),
  DSP16_Q(0.00296752),
  DSP16_Q(-0.00181050),
  DSP16_Q(0.00103854),
  DSP16_Q(-0.00052726),
  DSP16_Q(0.00021060),
  DSP16_Q(-0.00004585),
  DSP16_Q(-0.00000010),
  DSP16_Q(0.00006349),
  DSP16_Q(-0.00026712),
  DSP16_Q(0.00064960),
  DSP16_Q(-0.00126168),
  DSP16_Q(0.00218321),
  DSP16_Q(-0.00356722),
  DSP16_Q(0.00577446),
  DSP16_Q(-0.00992141),
  DSP16_Q(0.02187449),
  DSP16_Q(0.45488377),
  DSP16_Q(-0.01982284),
  DSP16_Q(0.00937677),
  DSP16_Q(-0.00551336),
  DSP16_Q(0.00341076),
  DSP16_Q(-0.00208042),
  DSP16_Q(0.00119272),
  DSP16_Q(-0.00060491),
  DSP16_Q(0.00024109),
  DSP16_Q(-0.00005213),
  DSP16_Q(-0.00000015),
  DSP16_Q(0.00007279),
  DSP16_Q(-0.00030446),
  DSP16_Q(0.00073891),
  DSP16_Q(-0.00143374),
  DSP16_Q(0.00247968),
  DSP16_Q(-0.00405077),
  DSP16_Q(0.00655795),
  DSP16_Q(-0.01127576),
  DSP16_Q(0.02493641),
  DSP16_Q(0.45440857),
  DSP16_Q(-0.02230227),
  DSP16_Q(0.01057682),
  DSP16_Q(-0.00622291),
  DSP16_Q(0.00385000),
  DSP16_Q(-0.00234778),
  DSP16_Q(0.00134526),
  DSP16_Q(-0.00068157),
  DSP16_Q(0.00027105),
  DSP16_Q(-0.00005821),
  DSP16_Q(-0.00000021),
  DSP16_Q(0.00008227),
  DSP16_Q(-0.00034215),
  DSP16_Q(0.00082875),
  DSP16_Q(-0.00160650),
  DSP16_Q(0.00277705),
  DSP16_Q(-0.00453561),
  DSP16_Q(0.00734373),
  DSP16_Q(-0.01263608),
  DSP16_Q(0.02803101),
  DSP16_Q(0.45387432),
  DSP16_Q(-0.02474217),
  DSP16_Q(0.01176389),
  DSP16_Q(-0.00692568),
  DSP16_Q(0.00428510),
  DSP16_Q(-0.00261248),
  DSP16_Q(0.00149611),
  DSP16_Q(-0.00075721),
  DSP16_Q(0.00030048),
  DSP16_Q(-0.00006409),
  DSP16_Q(-0.00000029),
  DSP16_Q(0.00009195),
  DSP16_Q(-0.00038020),
  DSP16_Q(0.00091908),
  DSP16_Q(-0.00177990),
  DSP16_Q(0.00307522),
  DSP16_Q(-0.00502156),
  DSP16_Q(0.00813151),
  DSP16_Q(-0.01400192),
  DSP16_Q(0.03115780),
  DSP16_Q(0.45328117),
  DSP16_Q(-0.02714223),
  DSP16_Q(0.01293762),
  DSP16_Q(-0.00762144),
  DSP16_Q(0.00471592),
  DSP16_Q(-0.00287444),
  DSP16_Q(0.00164521),
  DSP16_Q(-0.00083180),
  DSP16_Q(0.00032935),
  DSP16_Q(-0.00006976),
  DSP16_Q(-0.00000038),
  DSP16_Q(0.00010181),
  DSP16_Q(-0.00041858),
  DSP16_Q(0.00100988),
  DSP16_Q(-0.00195387),
  DSP16_Q(0.00337408),
  DSP16_Q(-0.00550843),
  DSP16_Q(0.00892100),
  DSP16_Q(-0.01537280),
  DSP16_Q(0.03431626),
  DSP16_Q(0.45262925),
  DSP16_Q(-0.02950216),
  DSP16_Q(0.01409767),
  DSP16_Q(-0.00830996),
  DSP16_Q(0.00514230),
  DSP16_Q(-0.00313356),
  DSP16_Q(0.00179253),
  DSP16_Q(-0.00090533),
  DSP16_Q(0.00035768),
  DSP16_Q(-0.00007523),
  DSP16_Q(-0.00000049),
  DSP16_Q(0.00011185),
  DSP16_Q(-0.00045729),
  DSP16_Q(0.00110111),
  DSP16_Q(-0.00212833),
  DSP16_Q(0.00367350),
  DSP16_Q(-0.00599603),
  DSP16_Q(0.00971188),
  DSP16_Q(-0.01674824),
  DSP16_Q(0.03750586),
  DSP16_Q(0.45191872),
  DSP16_Q(-0.03182169),
  DSP16_Q(0.01524372),
  DSP16_Q(-0.00899101),
  DSP16_Q(0.00556411),
  DSP16_Q(-0.00338976),
  DSP16_Q(0.00193800),
  DSP16_Q(-0.00097777),
  DSP16_Q(0.00038544),
  DSP16_Q(-0.00008050),
  DSP16_Q(-0.00000063),
  DSP16_Q(0.00012208),
  DSP16_Q(-0.00049630),
  DSP16_Q(0.00119273),
  DSP16_Q(-0.00230322),
  DSP16_Q(0.00397337),
  DSP16_Q(-0.00648418),
  DSP16_Q(0.01050388),
  DSP16_Q(-0.01812775),
  DSP16_Q(0.04072608),
  DSP16_Q(0.45114975),
  DSP16_Q(-0.03410057),
  DSP16_Q(0.01637542),
  DSP16_Q(-0.00966438),
  DSP16_Q(0.00598121),
  DSP16_Q(-0.00364296),
  DSP16_Q(0.00208160),
  DSP16_Q(-0.00104911),
  DSP16_Q(0.00041263),
  DSP16_Q(-0.00008557),
  DSP16_Q(-0.00000078),
  DSP16_Q(0.00013248),
  DSP16_Q(-0.00053561),
  DSP16_Q(0.00128471),
  DSP16_Q(-0.00247848),
  DSP16_Q(0.00427356),
  DSP16_Q(-0.00697268),
  DSP16_Q(0.01129667),
  DSP16_Q(-0.01951086),
  DSP16_Q(0.04397636),
  DSP16_Q(0.45032251),
  DSP16_Q(-0.03633853),
  DSP16_Q(0.01749245),
  DSP16_Q(-0.01032985),
  DSP16_Q(0.00639346),
  DSP16_Q(-0.00389308),
  DSP16_Q(0.00222326),
  DSP16_Q(-0.00111931),
  DSP16_Q(0.00043926),
  DSP16_Q(-0.00009043),
  DSP16_Q(-0.00000095),
  DSP16_Q(0.00014306),
  DSP16_Q(-0.00057520),
  DSP16_Q(0.00137700),
  DSP16_Q(-0.00265403),
  DSP16_Q(0.00457398),
  DSP16_Q(-0.00746135),
  DSP16_Q(0.01208997),
  DSP16_Q(-0.02089707),
  DSP16_Q(0.04725615),
  DSP16_Q(0.44943722),
  DSP16_Q(-0.03853535),
  DSP16_Q(0.01859451),
  DSP16_Q(-0.01098722),
  DSP16_Q(0.00680072),
  DSP16_Q(-0.00414002),
  DSP16_Q(0.00236295),
  DSP16_Q(-0.00118837),
  DSP16_Q(0.00046531),
  DSP16_Q(-0.00009510),
  DSP16_Q(-0.00000115),
  DSP16_Q(0.00015380),
  DSP16_Q(-0.00061505),
  DSP16_Q(0.00146958),
  DSP16_Q(-0.00282980),
  DSP16_Q(0.00487448),
  DSP16_Q(-0.00794999),
  DSP16_Q(0.01288346),
  DSP16_Q(-0.02228589),
  DSP16_Q(0.05056489),
  DSP16_Q(0.44849408),
  DSP16_Q(-0.04069079),
  DSP16_Q(0.01968128),
  DSP16_Q(-0.01163626),
  DSP16_Q(0.00720287),
  DSP16_Q(-0.00438372),
  DSP16_Q(0.00250062),
  DSP16_Q(-0.00125626),
  DSP16_Q(0.00049078),
  DSP16_Q(-0.00009957),
  DSP16_Q(-0.00000138),
  DSP16_Q(0.00016472),
  DSP16_Q(-0.00065515),
  DSP16_Q(0.00156241),
  DSP16_Q(-0.00300573),
  DSP16_Q(0.00517495),
  DSP16_Q(-0.00843841),
  DSP16_Q(0.01367684),
  DSP16_Q(-0.02367680),
  DSP16_Q(0.05390200),
  DSP16_Q(0.44749331),
  DSP16_Q(-0.04280464),
  DSP16_Q(0.02075247),
  DSP16_Q(-0.01227680),
  DSP16_Q(0.00759978),
  DSP16_Q(-0.00462410),
  DSP16_Q(0.00263624),
  DSP16_Q(-0.00132297),
  DSP16_Q(0.00051566),
  DSP16_Q(-0.00010384),
  DSP16_Q(-0.00000163),
  DSP16_Q(0.00017580),
  DSP16_Q(-0.00069548),
  DSP16_Q(0.00165544),
  DSP16_Q(-0.00318173),
  DSP16_Q(0.00547528),
  DSP16_Q(-0.00892640),
  DSP16_Q(0.01446979),
  DSP16_Q(-0.02506931),
  DSP16_Q(0.05726690),
  DSP16_Q(0.44643516),
  DSP16_Q(-0.04487670),
  DSP16_Q(0.02180778),
  DSP16_Q(-0.01290861),
  DSP16_Q(0.00799131),
  DSP16_Q(-0.00486108),
  DSP16_Q(0.00276976),
  DSP16_Q(-0.00138847),
  DSP16_Q(0.00053994),
  DSP16_Q(-0.00010792),
  DSP16_Q(-0.00000191),
  DSP16_Q(0.00018704),
  DSP16_Q(-0.00073602),
  DSP16_Q(0.00174864),
  DSP16_Q(-0.00335774),
  DSP16_Q(0.00577533),
  DSP16_Q(-0.00941378),
  DSP16_Q(0.01526201),
  DSP16_Q(-0.02646290),
  DSP16_Q(0.06065898),
  DSP16_Q(0.44531987),
  DSP16_Q(-0.04690679),
  DSP16_Q(0.02284693),
  DSP16_Q(-0.01353153),
  DSP16_Q(0.00837735),
  DSP16_Q(-0.00509459),
  DSP16_Q(0.00290114),
  DSP16_Q(-0.00145275),
  DSP16_Q(0.00056364),
  DSP16_Q(-0.00011180),
  DSP16_Q(-0.00000222),
  DSP16_Q(0.00019843),
  DSP16_Q(-0.00077676),
  DSP16_Q(0.00184198),
  DSP16_Q(-0.00353369),
  DSP16_Q(0.00607499),
  DSP16_Q(-0.00990036),
  DSP16_Q(0.01605318),
  DSP16_Q(-0.02785706),
  DSP16_Q(0.06407766),
  DSP16_Q(0.44414772),
  DSP16_Q(-0.04889471),
  DSP16_Q(0.02386965),
  DSP16_Q(-0.01414534),
  DSP16_Q(0.00875778),
  DSP16_Q(-0.00532455),
  DSP16_Q(0.00303035),
  DSP16_Q(-0.00151580),
  DSP16_Q(0.00058674),
  DSP16_Q(-0.00011549),
  DSP16_Q(-0.00000257),
  DSP16_Q(0.00020998),
  DSP16_Q(-0.00081769),
  DSP16_Q(0.00193541),
  DSP16_Q(-0.00370949),
  DSP16_Q(0.00637413),
  DSP16_Q(-0.01038592),
  DSP16_Q(0.01684299),
  DSP16_Q(-0.02925127),
  DSP16_Q(0.06752231),
  DSP16_Q(0.44291898),
  DSP16_Q(-0.05084032),
  DSP16_Q(0.02487566),
  DSP16_Q(-0.01474988),
  DSP16_Q(0.00913248),
  DSP16_Q(-0.00555091),
  DSP16_Q(0.00315734),
  DSP16_Q(-0.00157760),
  DSP16_Q(0.00060923),
  DSP16_Q(-0.00011899),
  DSP16_Q(-0.00000294),
  DSP16_Q(0.00022168),
  DSP16_Q(-0.00085878),
  DSP16_Q(0.00202889),
  DSP16_Q(-0.00388509),
  DSP16_Q(0.00667263),
  DSP16_Q(-0.01087028),
  DSP16_Q(0.01763112),
  DSP16_Q(-0.03064501),
  DSP16_Q(0.07099231),
  DSP16_Q(0.44163395),
  DSP16_Q(-0.05274346),
  DSP16_Q(0.02586471),
  DSP16_Q(-0.01534496),
  DSP16_Q(0.00950134),
  DSP16_Q(-0.00577358),
  DSP16_Q(0.00328209),
  DSP16_Q(-0.00163813),
  DSP16_Q(0.00063112),
  DSP16_Q(-0.00012231),
  DSP16_Q(-0.00000335),
  DSP16_Q(0.00023352),
  DSP16_Q(-0.00090001),
  DSP16_Q(0.00212238),
  DSP16_Q(-0.00406040),
  DSP16_Q(0.00697037),
  DSP16_Q(-0.01135323),
  DSP16_Q(0.01841726),
  DSP16_Q(-0.03203775),
  DSP16_Q(0.07448704),
  DSP16_Q(0.44029293),
  DSP16_Q(-0.05460398),
  DSP16_Q(0.02683655),
  DSP16_Q(-0.01593041),
  DSP16_Q(0.00986424),
  DSP16_Q(-0.00599251),
  DSP16_Q(0.00340455),
  DSP16_Q(-0.00169738),
  DSP16_Q(0.00065241),
  DSP16_Q(-0.00012543),
  DSP16_Q(-0.00000379),
  DSP16_Q(0.00024550),
  DSP16_Q(-0.00094138),
  DSP16_Q(0.00221585),
  DSP16_Q(-0.00423536),
  DSP16_Q(0.00726721),
  DSP16_Q(-0.01183458),
  DSP16_Q(0.01920108),
  DSP16_Q(-0.03342896),
  DSP16_Q(0.07800584),
  DSP16_Q(0.43889624),
  DSP16_Q(-0.05642176),
  DSP16_Q(0.02779093),
  DSP16_Q(-0.01650605),
  DSP16_Q(0.01022108),
  DSP16_Q(-0.00620762),
  DSP16_Q(0.00352470),
  DSP16_Q(-0.00175533),
  DSP16_Q(0.00067308),
  DSP16_Q(-0.00012838),
  DSP16_Q(-0.00000427),
  DSP16_Q(0.00025761),
  DSP16_Q(-0.00098286),
  DSP16_Q(0.00230925),
  DSP16_Q(-0.00440988),
  DSP16_Q(0.00756304),
  DSP16_Q(-0.01231412),
  DSP16_Q(0.01998226),
  DSP16_Q(-0.03481811),
  DSP16_Q(0.08154809),
  DSP16_Q(0.43744422),
  DSP16_Q(-0.05819669),
  DSP16_Q(0.02872761),
  DSP16_Q(-0.01707173),
  DSP16_Q(0.01057176),
  DSP16_Q(-0.00641887),
  DSP16_Q(0.00364250),
  DSP16_Q(-0.00181198),
  DSP16_Q(0.00069314),
  DSP16_Q(-0.00013114),
  DSP16_Q(-0.00000479),
  DSP16_Q(0.00026985),
  DSP16_Q(-0.00102443),
  DSP16_Q(0.00240255),
  DSP16_Q(-0.00458389),
  DSP16_Q(0.00785774),
  DSP16_Q(-0.01279165),
  DSP16_Q(0.02076049),
  DSP16_Q(-0.03620466),
  DSP16_Q(0.08511310),
  DSP16_Q(0.43593720),
  DSP16_Q(-0.05992865),
  DSP16_Q(0.02964637),
  DSP16_Q(-0.01762728),
  DSP16_Q(0.01091616),
  DSP16_Q(-0.00662618),
  DSP16_Q(0.00375792),
  DSP16_Q(-0.00186731),
  DSP16_Q(0.00071259),
  DSP16_Q(-0.00013372),
  DSP16_Q(-0.00000534),
  DSP16_Q(0.00028222),
  DSP16_Q(-0.00106608),
  DSP16_Q(0.00249569),
  DSP16_Q(-0.00475732),
  DSP16_Q(0.00815116),
  DSP16_Q(-0.01326698),
  DSP16_Q(0.02153545),
  DSP16_Q(-0.03758807),
  DSP16_Q(0.08870023),
  DSP16_Q(0.43437556),
  DSP16_Q(-0.06161756),
  DSP16_Q(0.03054698),
  DSP16_Q(-0.01817256),
  DSP16_Q(0.01125419),
  DSP16_Q(-0.00682950),
  DSP16_Q(0.00387093),
  DSP16_Q(-0.00192131),
  DSP16_Q(0.00073143),
  DSP16_Q(-0.00013612),
  DSP16_Q(-0.00000594),
  DSP16_Q(0.00029471),
  DSP16_Q(-0.00110779),
  DSP16_Q(0.00258865),
  DSP16_Q(-0.00493008),
  DSP16_Q(0.00844319),
  DSP16_Q(-0.01373990),
  DSP16_Q(0.02230681),
  DSP16_Q(-0.03896780),
  DSP16_Q(0.09230880),
  DSP16_Q(0.43275965),
  DSP16_Q(-0.06326335),
  DSP16_Q(0.03142924),
  DSP16_Q(-0.01870740),
  DSP16_Q(0.01158576),
  DSP16_Q(-0.00702878),
  DSP16_Q(0.00398150),
  DSP16_Q(-0.00197396),
  DSP16_Q(0.00074965),
  DSP16_Q(-0.00013835),
  DSP16_Q(-0.00000657),
  DSP16_Q(0.00030731),
  DSP16_Q(-0.00114953),
  DSP16_Q(0.00268138),
  DSP16_Q(-0.00510212),
  DSP16_Q(0.00873371),
  DSP16_Q(-0.01421021),
  DSP16_Q(0.02307425),
  DSP16_Q(-0.04034331),
  DSP16_Q(0.09593812),
  DSP16_Q(0.43108987),
  DSP16_Q(-0.06486593),
  DSP16_Q(0.03229295),
  DSP16_Q(-0.01923166),
  DSP16_Q(0.01191078),
  DSP16_Q(-0.00722395),
  DSP16_Q(0.00408962),
  DSP16_Q(-0.00202527),
  DSP16_Q(0.00076726),
  DSP16_Q(-0.00014040),
  DSP16_Q(-0.00000725),
  DSP16_Q(0.00032003),
  DSP16_Q(-0.00119129),
  DSP16_Q(0.00277383),
  DSP16_Q(-0.00527334),
  DSP16_Q(0.00902258),
  DSP16_Q(-0.01467771),
  DSP16_Q(0.02383744),
  DSP16_Q(-0.04171403),
  DSP16_Q(0.09958750),
  DSP16_Q(0.42936661),
  DSP16_Q(-0.06642526),
  DSP16_Q(0.03313790),
  DSP16_Q(-0.01974521),
  DSP16_Q(0.01222914),
  DSP16_Q(-0.00741498),
  DSP16_Q(0.00419524),
  DSP16_Q(-0.00207522),
  DSP16_Q(0.00078425),
  DSP16_Q(-0.00014229),
  DSP16_Q(-0.00000796),
  DSP16_Q(0.00033284),
  DSP16_Q(-0.00123305),
  DSP16_Q(0.00286597),
  DSP16_Q(-0.00544367),
  DSP16_Q(0.00930968),
  DSP16_Q(-0.01514219),
  DSP16_Q(0.02459607),
  DSP16_Q(-0.04307944),
  DSP16_Q(0.10325626),
  DSP16_Q(0.42759029),
  DSP16_Q(-0.06794129),
  DSP16_Q(0.03396390),
  DSP16_Q(-0.02024790),
  DSP16_Q(0.01254078),
  DSP16_Q(-0.00760180),
  DSP16_Q(0.00429834),
  DSP16_Q(-0.00212380),
  DSP16_Q(0.00080063),
  DSP16_Q(-0.00014401),
  DSP16_Q(-0.00000872),
  DSP16_Q(0.00034575),
  DSP16_Q(-0.00127479),
  DSP16_Q(0.00295775),
  DSP16_Q(-0.00561304),
  DSP16_Q(0.00959488),
  DSP16_Q(-0.01560346),
  DSP16_Q(0.02534980),
  DSP16_Q(-0.04443896),
  DSP16_Q(0.10694367),
  DSP16_Q(0.42576131),
  DSP16_Q(-0.06941400),
  DSP16_Q(0.03477079),
  DSP16_Q(-0.02073961),
  DSP16_Q(0.01284560),
  DSP16_Q(-0.00778437),
  DSP16_Q(0.00439891),
  DSP16_Q(-0.00217100),
  DSP16_Q(0.00081639),
  DSP16_Q(-0.00014557),
  DSP16_Q(-0.00000953),
  DSP16_Q(0.00035875),
  DSP16_Q(-0.00131649),
  DSP16_Q(0.00304913),
  DSP16_Q(-0.00578137),
  DSP16_Q(0.00987806),
  DSP16_Q(-0.01606132),
  DSP16_Q(0.02609832),
  DSP16_Q(-0.04579204),
  DSP16_Q(0.11064904),
  DSP16_Q(0.42388012),
  DSP16_Q(-0.07084336),
  DSP16_Q(0.03555839),
  DSP16_Q(-0.02122022),
  DSP16_Q(0.01314352),
  DSP16_Q(-0.00796265),
  DSP16_Q(0.00449692),
  DSP16_Q(-0.00221682),
  DSP16_Q(0.00083154),
  DSP16_Q(-0.00014696),
  DSP16_Q(-0.00001038),
  DSP16_Q(0.00037184),
  DSP16_Q(-0.00135813),
  DSP16_Q(0.00314007),
  DSP16_Q(-0.00594858),
  DSP16_Q(0.01015908),
  DSP16_Q(-0.01651555),
  DSP16_Q(0.02684131),
  DSP16_Q(-0.04713814),
  DSP16_Q(0.11437164),
  DSP16_Q(0.42194716),
  DSP16_Q(-0.07222936),
  DSP16_Q(0.03632654),
  DSP16_Q(-0.02168959),
  DSP16_Q(0.01343447),
  DSP16_Q(-0.00813659),
  DSP16_Q(0.00459235),
  DSP16_Q(-0.00226124),
  DSP16_Q(0.00084607),
  DSP16_Q(-0.00014820),
  DSP16_Q(-0.00001127),
  DSP16_Q(0.00038501),
  DSP16_Q(-0.00139969),
  DSP16_Q(0.00323052),
  DSP16_Q(-0.00611460),
  DSP16_Q(0.01043783),
  DSP16_Q(-0.01696597),
  DSP16_Q(0.02757843),
  DSP16_Q(-0.04847668),
  DSP16_Q(0.11811074),
  DSP16_Q(0.41996289),
  DSP16_Q(-0.07357202),
  DSP16_Q(0.03707507),
  DSP16_Q(-0.02214763),
  DSP16_Q(0.01371837),
  DSP16_Q(-0.00830614),
  DSP16_Q(0.00468518),
  DSP16_Q(-0.00230428),
  DSP16_Q(0.00085999),
  DSP16_Q(-0.00014928),
  DSP16_Q(-0.00001221),
  DSP16_Q(0.00039825),
  DSP16_Q(-0.00144116),
  DSP16_Q(0.00332045),
  DSP16_Q(-0.00627935),
  DSP16_Q(0.01071418),
  DSP16_Q(-0.01741236),
  DSP16_Q(0.02830936),
  DSP16_Q(-0.04980711),
  DSP16_Q(0.12186562),
  DSP16_Q(0.41792778),
  DSP16_Q(-0.07487135),
  DSP16_Q(0.03780386),
  DSP16_Q(-0.02259420),
  DSP16_Q(0.01399516),
  DSP16_Q(-0.00847128),
  DSP16_Q(0.00477538),
  DSP16_Q(-0.00234591),
  DSP16_Q(0.00087330),
  DSP16_Q(-0.00015021),
  DSP16_Q(-0.00001319),
  DSP16_Q(0.00041155),
  DSP16_Q(-0.00148249),
  DSP16_Q(0.00340981),
  DSP16_Q(-0.00644275),
  DSP16_Q(0.01098800),
  DSP16_Q(-0.01785454),
  DSP16_Q(0.02903379),
  DSP16_Q(-0.05112887),
  DSP16_Q(0.12563552),
  DSP16_Q(0.41584232),
  DSP16_Q(-0.07612738),
  DSP16_Q(0.03851275),
  DSP16_Q(-0.02302922),
  DSP16_Q(0.01426476),
  DSP16_Q(-0.00863195),
  DSP16_Q(0.00486295),
  DSP16_Q(-0.00238613),
  DSP16_Q(0.00088601),
  DSP16_Q(-0.00015098),
  DSP16_Q(-0.00001422),
  DSP16_Q(0.00042492),
  DSP16_Q(-0.00152369),
  DSP16_Q(0.00349855),
  DSP16_Q(-0.00660472),
  DSP16_Q(0.01125916),
  DSP16_Q(-0.01829229),
  DSP16_Q(0.02975139),
  DSP16_Q(-0.05244139),
  DSP16_Q(0.12941971),
  DSP16_Q(0.41370699),
  DSP16_Q(-0.07734014),
  DSP16_Q(0.03920162),
  DSP16_Q(-0.02345258),
  DSP16_Q(0.01452711),
  DSP16_Q(-0.00878813),
  DSP16_Q(0.00494787),
  DSP16_Q(-0.00242495),
  DSP16_Q(0.00089810),
  DSP16_Q(-0.00015162),
  DSP16_Q(-0.00001530),
  DSP16_Q(0.00043833),
  DSP16_Q(-0.00156473),
  DSP16_Q(0.00358664),
  DSP16_Q(-0.00676520),
  DSP16_Q(0.01152754),
  DSP16_Q(-0.01872543),
  DSP16_Q(0.03046183),
  DSP16_Q(-0.05374411),
  DSP16_Q(0.13321744),
  DSP16_Q(0.41152229),
  DSP16_Q(-0.07850969),
  DSP16_Q(0.03987034),
  DSP16_Q(-0.02386419),
  DSP16_Q(0.01478216),
  DSP16_Q(-0.00893979),
  DSP16_Q(0.00503012),
  DSP16_Q(-0.00246235),
  DSP16_Q(0.00090960),
  DSP16_Q(-0.00015211),
  DSP16_Q(-0.00001642),
  DSP16_Q(0.00045179),
  DSP16_Q(-0.00160558),
  DSP16_Q(0.00367402),
  DSP16_Q(-0.00692410),
  DSP16_Q(0.01179302),
  DSP16_Q(-0.01915374),
  DSP16_Q(0.03116480),
  DSP16_Q(-0.05503646),
  DSP16_Q(0.13702793),
  DSP16_Q(0.40928876),
  DSP16_Q(-0.07963610),
  DSP16_Q(0.04051881),
  DSP16_Q(-0.02426395),
  DSP16_Q(0.01502984),
  DSP16_Q(-0.00908688),
  DSP16_Q(0.00510969),
  DSP16_Q(-0.00249834),
  DSP16_Q(0.00092049),
  DSP16_Q(-0.00015246),
  DSP16_Q(-0.00001759),
  DSP16_Q(0.00046529),
  DSP16_Q(-0.00164623),
  DSP16_Q(0.00376066),
  DSP16_Q(-0.00708134),
  DSP16_Q(0.01205546),
  DSP16_Q(-0.01957704),
  DSP16_Q(0.03185997),
  DSP16_Q(-0.05631787),
  DSP16_Q(0.14085044),
  DSP16_Q(0.40700690),
  DSP16_Q(-0.08071943),
  DSP16_Q(0.04114692),
  DSP16_Q(-0.02465178),
  DSP16_Q(0.01527010),
  DSP16_Q(-0.00922938),
  DSP16_Q(0.00518657),
  DSP16_Q(-0.00253291),
  DSP16_Q(0.00093078),
  DSP16_Q(-0.00015267),
  DSP16_Q(-0.00001881),
  DSP16_Q(0.00047882),
  DSP16_Q(-0.00168665),
  DSP16_Q(0.00384652),
  DSP16_Q(-0.00723686),
  DSP16_Q(0.01231475),
  DSP16_Q(-0.01999513),
  DSP16_Q(0.03254702),
  DSP16_Q(-0.05758778),
  DSP16_Q(0.14468418),
  DSP16_Q(0.40467727),
  DSP16_Q(-0.08175978),
  DSP16_Q(0.04175456),
  DSP16_Q(-0.02502761),
  DSP16_Q(0.01550289),
  DSP16_Q(-0.00936727),
  DSP16_Q(0.00526074),
  DSP16_Q(-0.00256607),
  DSP16_Q(0.00094048),
  DSP16_Q(-0.00015275),
  DSP16_Q(-0.00002007),
  DSP16_Q(0.00049237),
  DSP16_Q(-0.00172682),
  DSP16_Q(0.00393154),
  DSP16_Q(-0.00739057),
  DSP16_Q(0.01257076),
  DSP16_Q(-0.02040780),
  DSP16_Q(0.03322565),
  DSP16_Q(-0.05884562),
  DSP16_Q(0.14852839),
  DSP16_Q(0.40230041),
  DSP16_Q(-0.08275724),
  DSP16_Q(0.04234166),
  DSP16_Q(-0.02539135),
  DSP16_Q(0.01572817),
  DSP16_Q(-0.00950052),
  DSP16_Q(0.00533220),
  DSP16_Q(-0.00259780),
  DSP16_Q(0.00094959),
  DSP16_Q(-0.00015270),
  DSP16_Q(-0.00002139),
  DSP16_Q(0.00050594),
  DSP16_Q(-0.00176673),
  DSP16_Q(0.00401569),
  DSP16_Q(-0.00754240),
  DSP16_Q(0.01282337),
  DSP16_Q(-0.02081487),
  DSP16_Q(0.03389552),
  DSP16_Q(-0.06009083),
  DSP16_Q(0.15238228),
  DSP16_Q(0.39987687),
  DSP16_Q(-0.08371193),
  DSP16_Q(0.04290814),
  DSP16_Q(-0.02574294),
  DSP16_Q(0.01594588),
  DSP16_Q(-0.00962910),
  DSP16_Q(0.00540093),
  DSP16_Q(-0.00262812),
  DSP16_Q(0.00095811),
  DSP16_Q(-0.00015253),
  DSP16_Q(-0.00002275),
  DSP16_Q(0.00051952),
  DSP16_Q(-0.00180634),
  DSP16_Q(0.00409892),
  DSP16_Q(-0.00769227),
  DSP16_Q(0.01307245),
  DSP16_Q(-0.02121614),
  DSP16_Q(0.03455633),
  DSP16_Q(-0.06132283),
  DSP16_Q(0.15624506),
  DSP16_Q(0.39740724),
  DSP16_Q(-0.08462396),
  DSP16_Q(0.04345391),
  DSP16_Q(-0.02608231),
  DSP16_Q(0.01615598),
  DSP16_Q(-0.00975299),
  DSP16_Q(0.00546694),
  DSP16_Q(-0.00265702),
  DSP16_Q(0.00096605),
  DSP16_Q(-0.00015223),
  DSP16_Q(-0.00002416),
  DSP16_Q(0.00053309),
  DSP16_Q(-0.00184564),
  DSP16_Q(0.00418119),
  DSP16_Q(-0.00784011),
  DSP16_Q(0.01331789),
  DSP16_Q(-0.02161141),
  DSP16_Q(0.03520776),
  DSP16_Q(-0.06254105),
  DSP16_Q(0.16011595),
  DSP16_Q(0.39489209),
  DSP16_Q(-0.08549347),
  DSP16_Q(0.04397891),
  DSP16_Q(-0.02640941),
  DSP16_Q(0.01635845),
  DSP16_Q(-0.00987218),
  DSP16_Q(0.00553020),
  DSP16_Q(-0.00268450),
  DSP16_Q(0.00097341),
  DSP16_Q(-0.00015182),
  DSP16_Q(-0.00002561),
  DSP16_Q(0.00054666),
  DSP16_Q(-0.00188461),
  DSP16_Q(0.00426246),
  DSP16_Q(-0.00798584),
  DSP16_Q(0.01355956),
  DSP16_Q(-0.02200050),
  DSP16_Q(0.03584949),
  DSP16_Q(-0.06374494),
  DSP16_Q(0.16399414),
  DSP16_Q(0.39233201),
  DSP16_Q(-0.08632059),
  DSP16_Q(0.04448310),
  DSP16_Q(-0.02672418),
  DSP16_Q(0.01655324),
  DSP16_Q(-0.00998664),
  DSP16_Q(0.00559073),
  DSP16_Q(-0.00271057),
  DSP16_Q(0.00098020),
  DSP16_Q(-0.00015128),
  DSP16_Q(-0.00002711),
  DSP16_Q(0.00056021),
  DSP16_Q(-0.00192323),
  DSP16_Q(0.00434268),
  DSP16_Q(-0.00812939),
  DSP16_Q(0.01379734),
  DSP16_Q(-0.02238322),
  DSP16_Q(0.03648122),
  DSP16_Q(-0.06493392),
  DSP16_Q(0.16787885),
  DSP16_Q(0.38972760),
  DSP16_Q(-0.08710549),
  DSP16_Q(0.04496641),
  DSP16_Q(-0.02702657),
  DSP16_Q(0.01674033),
  DSP16_Q(-0.01009637),
  DSP16_Q(0.00564851),
  DSP16_Q(-0.00273523),
  DSP16_Q(0.00098641),
  DSP16_Q(-0.00015064),
  DSP16_Q(-0.00002866),
  DSP16_Q(0.00057374),
  DSP16_Q(-0.00196146),
  DSP16_Q(0.00442181),
  DSP16_Q(-0.00827068),
  DSP16_Q(0.01403112),
  DSP16_Q(-0.02275937),
  DSP16_Q(0.03710264),
  DSP16_Q(-0.06610742),
  DSP16_Q(0.17176926),
  DSP16_Q(0.38707947),
  DSP16_Q(-0.08784833),
  DSP16_Q(0.04542881),
  DSP16_Q(-0.02731653),
  DSP16_Q(0.01691968),
  DSP16_Q(-0.01020135),
  DSP16_Q(0.00570355),
  DSP16_Q(-0.00275848),
  DSP16_Q(0.00099207),
  DSP16_Q(-0.00014988),
  DSP16_Q(-0.00003026),
  DSP16_Q(0.00058724),
  DSP16_Q(-0.00199930),
  DSP16_Q(0.00449981),
  DSP16_Q(-0.00840965),
  DSP16_Q(0.01426077),
  DSP16_Q(-0.02312877),
  DSP16_Q(0.03771344),
  DSP16_Q(-0.06726489),
  DSP16_Q(0.17566457),
  DSP16_Q(0.38438825),
  DSP16_Q(-0.08854928),
  DSP16_Q(0.04587027),
  DSP16_Q(-0.02759404),
  DSP16_Q(0.01709127),
  DSP16_Q(-0.01030156),
  DSP16_Q(0.00575583),
  DSP16_Q(-0.00278033),
  DSP16_Q(0.00099716),
  DSP16_Q(-0.00014903),
  DSP16_Q(-0.00003190),
  DSP16_Q(0.00060070),
  DSP16_Q(-0.00203672),
  DSP16_Q(0.00457663),
  DSP16_Q(-0.00854621),
  DSP16_Q(0.01448617),
  DSP16_Q(-0.02349123),
  DSP16_Q(0.03831331),
  DSP16_Q(-0.06840575),
  DSP16_Q(0.17956396),
  DSP16_Q(0.38165455),
  DSP16_Q(-0.08920853),
  DSP16_Q(0.04629077),
  DSP16_Q(-0.02785905),
  DSP16_Q(0.01725508),
  DSP16_Q(-0.01039700),
  DSP16_Q(0.00580537),
  DSP16_Q(-0.00280077),
  DSP16_Q(0.00100170),
  DSP16_Q(-0.00014807),
  DSP16_Q(-0.00003358),
  DSP16_Q(0.00061410),
  DSP16_Q(-0.00207369),
  DSP16_Q(0.00465223),
  DSP16_Q(-0.00868029),
  DSP16_Q(0.01470722),
  DSP16_Q(-0.02384657),
  DSP16_Q(0.03890196),
  DSP16_Q(-0.06952944),
  DSP16_Q(0.18346662),
  DSP16_Q(0.37887904),
  DSP16_Q(-0.08982629),
  DSP16_Q(0.04669028),
  DSP16_Q(-0.02811154),
  DSP16_Q(0.01741109),
  DSP16_Q(-0.01048766),
  DSP16_Q(0.00585215),
  DSP16_Q(-0.00281982),
  DSP16_Q(0.00100569),
  DSP16_Q(-0.00014701),
  DSP16_Q(-0.00003531),
  DSP16_Q(0.00062745),
  DSP16_Q(-0.00211019),
  DSP16_Q(0.00472657),
  DSP16_Q(-0.00881183),
  DSP16_Q(0.01492378),
  DSP16_Q(-0.02419461),
  DSP16_Q(0.03947908),
  DSP16_Q(-0.07063540),
  DSP16_Q(0.18737173),
  DSP16_Q(0.37606234),
  DSP16_Q(-0.09040274),
  DSP16_Q(0.04706879),
  DSP16_Q(-0.02835147),
  DSP16_Q(0.01755929),
  DSP16_Q(-0.01057354),
  DSP16_Q(0.00589619),
  DSP16_Q(-0.00283749),
  DSP16_Q(0.00100914),
  DSP16_Q(-0.00014586),
  DSP16_Q(-0.00003708),
  DSP16_Q(0.00064073),
  DSP16_Q(-0.00214621),
  DSP16_Q(0.00479960),
  DSP16_Q(-0.00894074),
  DSP16_Q(0.01513576),
  DSP16_Q(-0.02453516),
  DSP16_Q(0.04004437),
  DSP16_Q(-0.07172307),
  DSP16_Q(0.19127846),
  DSP16_Q(0.37320512),
  DSP16_Q(-0.09093812),
  DSP16_Q(0.04742632),
  DSP16_Q(-0.02857885),
  DSP16_Q(0.01769966),
  DSP16_Q(-0.01065464),
  DSP16_Q(0.00593749),
  DSP16_Q(-0.00285377),
  DSP16_Q(0.00101206),
  DSP16_Q(-0.00014461),
  DSP16_Q(-0.00003890),
  DSP16_Q(0.00065394),
  DSP16_Q(-0.00218172),
  DSP16_Q(0.00487129),
  DSP16_Q(-0.00906697),
  DSP16_Q(0.01534303),
  DSP16_Q(-0.02486804),
  DSP16_Q(0.04059754),
  DSP16_Q(-0.07279189),
  DSP16_Q(0.19518600),
  DSP16_Q(0.37030805),
  DSP16_Q(-0.09143265),
  DSP16_Q(0.04776286),
  DSP16_Q(-0.02879364),
  DSP16_Q(0.01783219),
  DSP16_Q(-0.01073094),
  DSP16_Q(0.00597605),
  DSP16_Q(-0.00286867),
  DSP16_Q(0.00101445),
  DSP16_Q(-0.00014328),
  DSP16_Q(-0.00004076),
  DSP16_Q(0.00066706),
  DSP16_Q(-0.00221670),
  DSP16_Q(0.00494160),
  DSP16_Q(-0.00919043),
  DSP16_Q(0.01554549),
  DSP16_Q(-0.02519308),
  DSP16_Q(0.04113830),
  DSP16_Q(-0.07384131),
  DSP16_Q(0.19909351),
  DSP16_Q(0.36737179),
  DSP16_Q(-0.09188658),
  DSP16_Q(0.04807842),
  DSP16_Q(-0.02899584),
  DSP16_Q(0.01795689),
  DSP16_Q(-0.01080246),
  DSP16_Q(0.00601187),
  DSP16_Q(-0.00288221),
  DSP16_Q(0.00101631),
  DSP16_Q(-0.00014187),
  DSP16_Q(-0.00004266),
  DSP16_Q(0.00068009),
  DSP16_Q(-0.00225112),
  DSP16_Q(0.00501047),
  DSP16_Q(-0.00931106),
  DSP16_Q(0.01574302),
  DSP16_Q(-0.02551010),
  DSP16_Q(0.04166635),
  DSP16_Q(-0.07487077),
  DSP16_Q(0.20300017),
  DSP16_Q(0.36439704),
  DSP16_Q(-0.09230014),
  DSP16_Q(0.04837304),
  DSP16_Q(-0.02918545),
  DSP16_Q(0.01807374),
  DSP16_Q(-0.01086920),
  DSP16_Q(0.00604497),
  DSP16_Q(-0.00289438),
  DSP16_Q(0.00101766),
  DSP16_Q(-0.00014037),
  DSP16_Q(-0.00004459),
  DSP16_Q(0.00069302),
  DSP16_Q(-0.00228497),
  DSP16_Q(0.00507787),
  DSP16_Q(-0.00942880),
  DSP16_Q(0.01593551),
  DSP16_Q(-0.02581894),
  DSP16_Q(0.04218142),
  DSP16_Q(-0.07587971),
  DSP16_Q(0.20690514),
  DSP16_Q(0.36138447),
  DSP16_Q(-0.09267360),
  DSP16_Q(0.04864674),
  DSP16_Q(-0.02936247),
  DSP16_Q(0.01818275),
  DSP16_Q(-0.01093115),
  DSP16_Q(0.00607535),
  DSP16_Q(-0.00290521),
  DSP16_Q(0.00101850),
  DSP16_Q(-0.00013880),
  DSP16_Q(-0.00004657),
  DSP16_Q(0.00070584),
  DSP16_Q(-0.00231821),
  DSP16_Q(0.00514376),
  DSP16_Q(-0.00954356),
  DSP16_Q(0.01612286),
  DSP16_Q(-0.02611941),
  DSP16_Q(0.04268321),
  DSP16_Q(-0.07686759),
  DSP16_Q(0.21080758),
  DSP16_Q(0.35833481),
  DSP16_Q(-0.09300723),
  DSP16_Q(0.04889956),
  DSP16_Q(-0.02952691),
  DSP16_Q(0.01828393),
  DSP16_Q(-0.01098834),
  DSP16_Q(0.00610301),
  DSP16_Q(-0.00291469),
  DSP16_Q(0.00101884),
  DSP16_Q(-0.00013716),
  DSP16_Q(-0.00004859),
  DSP16_Q(0.00071854),
  DSP16_Q(-0.00235084),
  DSP16_Q(0.00520810),
  DSP16_Q(-0.00965529),
  DSP16_Q(0.01630495),
  DSP16_Q(-0.02641136),
  DSP16_Q(0.04317145),
  DSP16_Q(-0.07783386),
  DSP16_Q(0.21470666),
  DSP16_Q(0.35524874),
  DSP16_Q(-0.09330130),
  DSP16_Q(0.04913154),
  DSP16_Q(-0.02967877),
  DSP16_Q(0.01837727),
  DSP16_Q(-0.01104076),
  DSP16_Q(0.00612798),
  DSP16_Q(-0.00292284),
  DSP16_Q(0.00101869),
  DSP16_Q(-0.00013544),
  DSP16_Q(-0.00005064),
  DSP16_Q(0.00073110),
  DSP16_Q(-0.00238283),
  DSP16_Q(0.00527084),
  DSP16_Q(-0.00976391),
  DSP16_Q(0.01648169),
  DSP16_Q(-0.02669461),
  DSP16_Q(0.04364586),
  DSP16_Q(-0.07877798),
  DSP16_Q(0.21860155),
  DSP16_Q(0.35212698),
  DSP16_Q(-0.09355610),
  DSP16_Q(0.04934273),
  DSP16_Q(-0.02981807),
  DSP16_Q(0.01846279),
  DSP16_Q(-0.01108842),
  DSP16_Q(0.00615026),
  DSP16_Q(-0.00292966),
  DSP16_Q(0.00101804),
  DSP16_Q(-0.00013366),
  DSP16_Q(-0.00005272),
  DSP16_Q(0.00074353),
  DSP16_Q(-0.00241415),
  DSP16_Q(0.00533196),
  DSP16_Q(-0.00986937),
  DSP16_Q(0.01665296),
  DSP16_Q(-0.02696900),
  DSP16_Q(0.04410616),
  DSP16_Q(-0.07969940),
  DSP16_Q(0.22249139),
  DSP16_Q(0.34897027),
  DSP16_Q(-0.09377194),
  DSP16_Q(0.04953320),
  DSP16_Q(-0.02994483),
  DSP16_Q(0.01854051),
  DSP16_Q(-0.01113135),
  DSP16_Q(0.00616986),
  DSP16_Q(-0.00293517),
  DSP16_Q(0.00101692),
  DSP16_Q(-0.00013182),
  DSP16_Q(-0.00005484),
  DSP16_Q(0.00075581),
  DSP16_Q(-0.00244479),
  DSP16_Q(0.00539140),
  DSP16_Q(-0.00997159),
  DSP16_Q(0.01681867),
  DSP16_Q(-0.02723437),
  DSP16_Q(0.04455210),
  DSP16_Q(-0.08059758),
  DSP16_Q(0.22637536),
  DSP16_Q(0.34577932),
  DSP16_Q(-0.09394911),
  DSP16_Q(0.04970302),
  DSP16_Q(-0.03005907),
  DSP16_Q(0.01861043),
  DSP16_Q(-0.01116955),
  DSP16_Q(0.00618679),
  DSP16_Q(-0.00293938),
  DSP16_Q(0.00101533),
  DSP16_Q(-0.00012992),
  DSP16_Q(-0.00005700),
  DSP16_Q(0.00076793),
  DSP16_Q(-0.00247472),
  DSP16_Q(0.00544912),
  DSP16_Q(-0.01007051),
  DSP16_Q(0.01697872),
  DSP16_Q(-0.02749057),
  DSP16_Q(0.04498339),
  DSP16_Q(-0.08147200),
  DSP16_Q(0.23025261),
  DSP16_Q(0.34255487),
  DSP16_Q(-0.09408793),
  DSP16_Q(0.04985225),
  DSP16_Q(-0.03016084),
  DSP16_Q(0.01867258),
  DSP16_Q(-0.01120303),
  DSP16_Q(0.00620108),
  DSP16_Q(-0.00294229),
  DSP16_Q(0.00101327),
  DSP16_Q(-0.00012797),
  DSP16_Q(-0.00005918),
  DSP16_Q(0.00077989),
  DSP16_Q(-0.00250393),
  DSP16_Q(0.00550510),
  DSP16_Q(-0.01016607),
  DSP16_Q(0.01713301),
  DSP16_Q(-0.02773743),
  DSP16_Q(0.04539978),
  DSP16_Q(-0.08232211),
  DSP16_Q(0.23412229),
  DSP16_Q(0.33929766),
  DSP16_Q(-0.09418873),
  DSP16_Q(0.04998097),
  DSP16_Q(-0.03025015),
  DSP16_Q(0.01872698),
  DSP16_Q(-0.01123183),
  DSP16_Q(0.00621273),
  DSP16_Q(-0.00294393),
  DSP16_Q(0.00101076),
  DSP16_Q(-0.00012596),
  DSP16_Q(-0.00006139),
  DSP16_Q(0.00079167),
  DSP16_Q(-0.00253238),
  DSP16_Q(0.00555929),
  DSP16_Q(-0.01025821),
  DSP16_Q(0.01728143),
  DSP16_Q(-0.02797480),
  DSP16_Q(0.04580101),
  DSP16_Q(-0.08314740),
  DSP16_Q(0.23798357),
  DSP16_Q(0.33600845),
  DSP16_Q(-0.09425184),
  DSP16_Q(0.05008929),
  DSP16_Q(-0.03032706),
  DSP16_Q(0.01877365),
  DSP16_Q(-0.01125595),
  DSP16_Q(0.00622176),
  DSP16_Q(-0.00294431),
  DSP16_Q(0.00100780),
  DSP16_Q(-0.00012390),
  DSP16_Q(-0.00006363),
  DSP16_Q(0.00080326),
  DSP16_Q(-0.00256006),
  DSP16_Q(0.00561165),
  DSP16_Q(-0.01034686),
  DSP16_Q(0.01742390),
  DSP16_Q(-0.02820254),
  DSP16_Q(0.04618683),
  DSP16_Q(-0.08394734),
  DSP16_Q(0.24183560),
  DSP16_Q(0.33268799),
  DSP16_Q(-0.09427760),
  DSP16_Q(0.05017728),
  DSP16_Q(-0.03039160),
  DSP16_Q(0.01881263),
  DSP16_Q(-0.01127542),
  DSP16_Q(0.00622819),
  DSP16_Q(-0.00294343),
  DSP16_Q(0.00100441),
  DSP16_Q(-0.00012180),
  DSP16_Q(-0.00006589),
  DSP16_Q(0.00081465),
  DSP16_Q(-0.00258695),
  DSP16_Q(0.00566215),
  DSP16_Q(-0.01043197),
  DSP16_Q(0.01756032),
  DSP16_Q(-0.02842050),
  DSP16_Q(0.04655699),
  DSP16_Q(-0.08472140),
  DSP16_Q(0.24567754),
  DSP16_Q(0.32933704),
  DSP16_Q(-0.09426637),
  DSP16_Q(0.05024507),
  DSP16_Q(-0.03044382),
  DSP16_Q(0.01884395),
  DSP16_Q(-0.01129025),
  DSP16_Q(0.00623203),
  DSP16_Q(-0.00294131),
  DSP16_Q(0.00100058),
  DSP16_Q(-0.00011966),
  DSP16_Q(-0.00006818),
  DSP16_Q(0.00082584),
  DSP16_Q(-0.00261303),
  DSP16_Q(0.00571075),
  DSP16_Q(-0.01051347),
  DSP16_Q(0.01769060),
  DSP16_Q(-0.02862852),
  DSP16_Q(0.04691124),
  DSP16_Q(-0.08546908),
  DSP16_Q(0.24950855),
  DSP16_Q(0.32595638),
  DSP16_Q(-0.09421850),
  DSP16_Q(0.05029274),
  DSP16_Q(-0.03048378),
  DSP16_Q(0.01886763),
  DSP16_Q(-0.01130049),
  DSP16_Q(0.00623331),
  DSP16_Q(-0.00293796),
  DSP16_Q(0.00099633),
  DSP16_Q(-0.00011748),
  DSP16_Q(-0.00007049),
  DSP16_Q(0.00083682),
  DSP16_Q(-0.00263827),
  DSP16_Q(0.00575741),
  DSP16_Q(-0.01059131),
  DSP16_Q(0.01781464),
  DSP16_Q(-0.02882648),
  DSP16_Q(0.04724934),
  DSP16_Q(-0.08618987),
  DSP16_Q(0.25332778),
  DSP16_Q(0.32254677),
  DSP16_Q(-0.09413436),
  DSP16_Q(0.05032043),
  DSP16_Q(-0.03051153),
  DSP16_Q(0.01888371),
  DSP16_Q(-0.01130615),
  DSP16_Q(0.00623205),
  DSP16_Q(-0.00293340),
  DSP16_Q(0.00099167),
  DSP16_Q(-0.00011526),
  DSP16_Q(-0.00007281),
  DSP16_Q(0.00084757),
  DSP16_Q(-0.00266266),
  DSP16_Q(0.00580210),
  DSP16_Q(-0.01066544),
  DSP16_Q(0.01793237),
  DSP16_Q(-0.02901423),
  DSP16_Q(0.04757105),
  DSP16_Q(-0.08688325),
  DSP16_Q(0.25713439),
  DSP16_Q(0.31910899),
  DSP16_Q(-0.09401433),
  DSP16_Q(0.05032824),
  DSP16_Q(-0.03052713),
  DSP16_Q(0.01889224),
  DSP16_Q(-0.01130726),
  DSP16_Q(0.00622826),
  DSP16_Q(-0.00292765),
  DSP16_Q(0.00098660),
  DSP16_Q(-0.00011301),
  DSP16_Q(-0.00007516),
  DSP16_Q(0.00085809),
  DSP16_Q(-0.00268617),
  DSP16_Q(0.00584478),
  DSP16_Q(-0.01073578),
  DSP16_Q(0.01804369),
  DSP16_Q(-0.02919164),
  DSP16_Q(0.04787614),
  DSP16_Q(-0.08754873),
  DSP16_Q(0.26092755),
  DSP16_Q(0.31564383),
  DSP16_Q(-0.09385879),
  DSP16_Q(0.05031632),
  DSP16_Q(-0.03053066),
  DSP16_Q(0.01889326),
  DSP16_Q(-0.01130385),
  DSP16_Q(0.00622197),
  DSP16_Q(-0.00292071),
  DSP16_Q(0.00098114),
  DSP16_Q(-0.00011074),
  DSP16_Q(-0.00007752),
  DSP16_Q(0.00086836),
  DSP16_Q(-0.00270879),
  DSP16_Q(0.00588541),
  DSP16_Q(-0.01080230),
  DSP16_Q(0.01814853),
  DSP16_Q(-0.02935858),
  DSP16_Q(0.04816439),
  DSP16_Q(-0.08818581),
  DSP16_Q(0.26470640),
  DSP16_Q(0.31215208),
  DSP16_Q(-0.09366814),
  DSP16_Q(0.05028480),
  DSP16_Q(-0.03052217),
  DSP16_Q(0.01888680),
  DSP16_Q(-0.01129596),
  DSP16_Q(0.00621320),
  DSP16_Q(-0.00291261),
  DSP16_Q(0.00097529),
  DSP16_Q(-0.00010844),
  DSP16_Q(-0.00007989),
  DSP16_Q(0.00087838),
  DSP16_Q(-0.00273050),
  DSP16_Q(0.00592397),
  DSP16_Q(-0.01086493),
  DSP16_Q(0.01824679),
  DSP16_Q(-0.02951491),
  DSP16_Q(0.04843557),
  DSP16_Q(-0.08879400),
  DSP16_Q(0.26847013),
  DSP16_Q(0.30863453),
  DSP16_Q(-0.09344277),
  DSP16_Q(0.05023382),
  DSP16_Q(-0.03050175),
  DSP16_Q(0.01887293),
  DSP16_Q(-0.01128361),
  DSP16_Q(0.00620197),
  DSP16_Q(-0.00290336),
  DSP16_Q(0.00096907),
  DSP16_Q(-0.00010611),
  DSP16_Q(-0.00008227),
  DSP16_Q(0.00088813),
  DSP16_Q(-0.00275126),
  DSP16_Q(0.00596042),
  DSP16_Q(-0.01092362),
  DSP16_Q(0.01833841),
  DSP16_Q(-0.02966052),
  DSP16_Q(0.04868946),
  DSP16_Q(-0.08937282),
  DSP16_Q(0.27221788),
  DSP16_Q(0.30509198),
  DSP16_Q(-0.09318309),
  DSP16_Q(0.05016353),
  DSP16_Q(-0.03046948),
  DSP16_Q(0.01885168),
  DSP16_Q(-0.01126684),
  DSP16_Q(0.00618832),
  DSP16_Q(-0.00289297),
  DSP16_Q(0.00096248),
  DSP16_Q(-0.00010377),
  DSP16_Q(-0.00008466),
  DSP16_Q(0.00089761),
  DSP16_Q(-0.00277108),
  DSP16_Q(0.00599473),
  DSP16_Q(-0.01097833),
  DSP16_Q(0.01842329),
  DSP16_Q(-0.02979528),
  DSP16_Q(0.04892586),
  DSP16_Q(-0.08992178),
  DSP16_Q(0.27594882),
  DSP16_Q(0.30152523),
  DSP16_Q(-0.09288951),
  DSP16_Q(0.05007408),
  DSP16_Q(-0.03042543),
  DSP16_Q(0.01882312),
  DSP16_Q(-0.01124569),
  DSP16_Q(0.00617225),
  DSP16_Q(-0.00288146),
  DSP16_Q(0.00095553),
  DSP16_Q(-0.00010141),
  DSP16_Q(-0.00008706),
  DSP16_Q(0.00090681),
  DSP16_Q(-0.00278992),
  DSP16_Q(0.00602686),
  DSP16_Q(-0.01102901),
  DSP16_Q(0.01850138),
  DSP16_Q(-0.02991907),
  DSP16_Q(0.04914456),
  DSP16_Q(-0.09044041),
  DSP16_Q(0.27966212),
  DSP16_Q(0.29793510),
  DSP16_Q(-0.09256247),
  DSP16_Q(0.04996564),
  DSP16_Q(-0.03036969),
  DSP16_Q(0.01878730),
  DSP16_Q(-0.01122020),
  DSP16_Q(0.00615381),
  DSP16_Q(-0.00286885),
  DSP16_Q(0.00094823),
  DSP16_Q(-0.00009903),
  DSP16_Q(-0.00008946),
  DSP16_Q(0.00091572),
  DSP16_Q(-0.00280777),
  DSP16_Q(0.00605678),
  DSP16_Q(-0.01107560),
  DSP16_Q(0.01857259),
  DSP16_Q(-0.03003179),
  DSP16_Q(0.04934535),
  DSP16_Q(-0.09092825),
  DSP16_Q(0.28335696),
  DSP16_Q(0.29432238),
  DSP16_Q(-0.09220238),
  DSP16_Q(0.04983837),
  DSP16_Q(-0.03030237),
  DSP16_Q(0.01874427),
  DSP16_Q(-0.01119040),
  DSP16_Q(0.00613301),
  DSP16_Q(-0.00285516),
  DSP16_Q(0.00094058),
  DSP16_Q(-0.00009665),
  DSP16_Q(-0.00009186),
  DSP16_Q(0.00092432),
  DSP16_Q(-0.00282460),
  DSP16_Q(0.00608447),
  DSP16_Q(-0.01111806),
  DSP16_Q(0.01863685),
  DSP16_Q(-0.03013331),
  DSP16_Q(0.04952804),
  DSP16_Q(-0.09138482),
  DSP16_Q(0.28703250),
  DSP16_Q(0.29068791),
  DSP16_Q(-0.09180968),
  DSP16_Q(0.04969244),
  DSP16_Q(-0.03022354),
  DSP16_Q(0.01869410),
  DSP16_Q(-0.01115634),
  DSP16_Q(0.00610989),
  DSP16_Q(-0.00284041),
  DSP16_Q(0.00093261),
  DSP16_Q(-0.00009425),
  DSP16_Q(-0.00009425),
  DSP16_Q(0.00093261),
  DSP16_Q(-0.00284041),
  DSP16_Q(0.00610989),
  DSP16_Q(-0.01115634),
  DSP16_Q(0.01869410),
  DSP16_Q(-0.03022354),
  DSP16_Q(0.04969244),
  DSP16_Q(-0.09180968),
  DSP16_Q(0.29068791),
  DSP16_Q(0.28703250),
  DSP16_Q(-0.09138482),
  DSP16_Q(0.04952804),
  DSP16_Q(-0.03013331),
  DSP16_Q(0.01863685),
  DSP16_Q(-0.01111806),
  DSP16_Q(0.00608447),
  DSP16_Q(-0.00282460),
  DSP16_Q(0.00092432),
  DSP16_Q(-0.00009186),
  DSP16_Q(-0.00009665),
  DSP16_Q(0.00094058),
  DSP16_Q(-0.00285516),
  DSP16_Q(0.00613301),
  DSP16_Q(-0.01119040),
  DSP16_Q(0.01874427),
  DSP16_Q(-0.03030237),
  DSP16_Q(0.04983837),
  DSP16_Q(-0.09220238),
  DSP16_Q(0.29432238),
  DSP16_Q(0.28335696),
  DSP16_Q(-0.09092825),
  DSP16_Q(0.04934535),
  DSP16_Q(-0.03003179),
  DSP16_Q(0.01857259),
  DSP16_Q(-0.01107560),
  DSP16_Q(0.00605678),
  DSP16_Q(-0.00280777),
  DSP16_Q(0.00091572),
  DSP16_Q(-0.00008946),
  DSP16_Q(-0.00009903),
  DSP16_Q(0.00094823),
  DSP16_Q(-0.00286885),
  DSP16_Q(0.00615381),
  DSP16_Q(-0.01122020),
  DSP16_Q(0.01878730),
  DSP16_Q(-0.03036969),
  DSP16_Q(0.04996564),
  DSP16_Q(-0.09256247),
  DSP16_Q(0.29793510),
  DSP16_Q(0.27966212),
  DSP16_Q(-0.09044041),
  DSP16_Q(0.04914456),
  DSP16_Q(-0.02991907),
  DSP16_Q(0.01850138),
  DSP16_Q(-0.01102901),
  DSP16_Q(0.00602686),
  DSP16_Q(-0.00278992),
  DSP16_Q(0.00090681),
  DSP16_Q(-0.00008706),
  DSP16_Q(-0.00010141),
  DSP16_Q(0.00095553),
  DSP16_Q(-0.00288146),
  DSP16_Q(0.00617225),
  DSP16_Q(-0.01124569),
  DSP16_Q(0.01882312),
  DSP16_Q(-0.03042543),
  DSP16_Q(0.05007408),
  DSP16_Q(-0.09288951),
  DSP16_Q(0.30152523),
  DSP16_Q(0.27594882),
  DSP16_Q(-0.08992178),
  DSP16_Q(0.04892586),
  DSP16_Q(-0.02979528),
  DSP16_Q(0.01842329),
  DSP16_Q(-0.01097833),
  DSP16_Q(0.00599473),
  DSP16_Q(-0.00277108),
  DSP16_Q(0.00089761),
  DSP16_Q(-0.00008466),
  DSP16_Q(-0.00010377),
  DSP16_Q(0.00096248),
  DSP16_Q(-0.00289297),
  DSP16_Q(0.00618832),
  DSP16_Q(-0.01126684),
  DSP16_Q(0.01885168),
  DSP16_Q(-0.03046948),
  DSP16_Q(0.05016353),
  DSP16_Q(-0.09318309),
  DSP16_Q(0.30509198),
  DSP16_Q(0.27221788),
  DSP16_Q(-0.08937282),
  DSP16_Q(0.04868946),
  DSP16_Q(-0.02966052),
  DSP16_Q(0.01833841),
  DSP16_Q(-0.01092362),
  DSP16_Q(0.00596042),
  DSP16_Q(-0.00275126),
  DSP16_Q(0.00088813),
  DSP16_Q(-0.00008227),
  DSP16_Q(-0.00010611),
  DSP16_Q(0.00096907),
  DSP16_Q(-0.00290336),
  DSP16_Q(0.00620197),
  DSP16_Q(-0.01128361),
  DSP16_Q(0.01887293),
  DSP16_Q(-0.03050175),
  DSP16_Q(0.05023382),
  DSP16_Q(-0.09344277),
  DSP16_Q(0.30863453),
  DSP16_Q(0.26847013),
  DSP16_Q(-0.08879400),
  DSP16_Q(0.04843557),
  DSP16_Q(-0.02951491),
  DSP16_Q(0.01824679),
  DSP16_Q(-0.01086493),
  DSP16_Q(0.00592397),
  DSP16_Q(-0.00273050),
  DSP16_Q(0.00087838),
  DSP16_Q(-0.00007989),
  DSP16_Q(-0.00010844),
  DSP16_Q(0.00097529),
  DSP16_Q(-0.00291261),
  DSP16_Q(0.00621320),
  DSP16_Q(-0.01129596),
  DSP16_Q(0.01888680),
  DSP16_Q(-0.03052217),
  DSP16_Q(0.05028480),
  DSP16_Q(-0.09366814),
  DSP16_Q(0.31215208),
  DSP16_Q(0.26470640),
  DSP16_Q(-0.08818581),
  DSP16_Q(0.04816439),
  DSP16_Q(-0.02935858),
  DSP16_Q(0.01814853),
  DSP16_Q(-0.01080230),
  DSP16_Q(0.00588541),
  DSP16_Q(-0.00270879),
  DSP16_Q(0.00086836),
  DSP16_Q(-0.00007752),
  DSP16_Q(-0.00011074),
  DSP16_Q(0.00098114),
  DSP16_Q(-0.00292071),
  DSP16_Q(0.00622197),
  DSP16_Q(-0.01130385),
  DSP16_Q(0.01889326),
  DSP16_Q(-0.03053066),
  DSP16_Q(0.05031632),
  DSP16_Q(-0.09385879),
  DSP16_Q(0.31564383),
  DSP16_Q(0.26092755),
  DSP16_Q(-0.08754873),
  DSP16_Q(0.04787614),
  DSP16_Q(-0.02919164),
  DSP16_Q(0.01804369),
  DSP16_Q(-0.01073578),
  DSP16_Q(0.00584478),
  DSP16_Q(-0.00268617),
  DSP16_Q(0.00085809),
  DSP16_Q(-0.00007516),
  DSP16_Q(-0.00011301),
  DSP16_Q(0.00098660),
  DSP16_Q(-0.00292765),
  DSP16_Q(0.00622826),
  DSP16_Q(-0.01130726),
  DSP16_Q(0.01889224),
  DSP16_Q(-0.03052713),
  DSP16_Q(0.05032824),
  DSP16_Q(-0.09401433),
  DSP16_Q(0.31910899),
  DSP16_Q(0.25713439),
  DSP16_Q(-0.08688325),
  DSP16_Q(0.04757105),
  DSP16_Q(-0.02901423),
  DSP16_Q(0.01793237),
  DSP16_Q(-0.01066544),
  DSP16_Q(0.00580210),
  DSP16_Q(-0.00266266),
  DSP16_Q(0.00084757),
  DSP16_Q(-0.00007281),
  DSP16_Q(-0.00011526),
  DSP16_Q(0.00099167),
  DSP16_Q(-0.00293340),
  DSP16_Q(0.00623205),
  DSP16_Q(-0.01130615),
  DSP16_Q(0.01888371),
  DSP16_Q(-0.03051153),
  DSP16_Q(0.05032043),
  DSP16_Q(-0.09413436),
  DSP16_Q(0.32254677),
  DSP16_Q(0.25332778),
  DSP16_Q(-0.08618987),
  DSP16_Q(0.04724934),
  DSP16_Q(-0.02882648),
  DSP16_Q(0.01781464),
  DSP16_Q(-0.01059131),
  DSP16_Q(0.00575741),
  DSP16_Q(-0.00263827),
  DSP16_Q(0.00083682),
  DSP16_Q(-0.00007049),
  DSP16_Q(-0.00011748),
  DSP16_Q(0.00099633),
  DSP16_Q(-0.00293796),
  DSP16_Q(0.00623331),
  DSP16_Q(-0.01130049),
  DSP16_Q(0.01886763),
  DSP16_Q(-0.03048378),
  DSP16_Q(0.05029274),
  DSP16_Q(-0.09421850),
  DSP16_Q(0.32595638),
  DSP16_Q(0.24950855),
  DSP16_Q(-0.08546908),
  DSP16_Q(0.04691124),
  DSP16_Q(-0.02862852),
  DSP16_Q(0.01769060),
  DSP16_Q(-0.01051347),
  DSP16_Q(0.00571075),
  DSP16_Q(-0.00261303),
  DSP16_Q(0.00082584),
  DSP16_Q(-0.00006818),
  DSP16_Q(-0.00011966),
  DSP16_Q(0.00100058),
  DSP16_Q(-0.00294131),
  DSP16_Q(0.00623203),
  DSP16_Q(-0.01129025),
  DSP16_Q(0.01884395),
  DSP16_Q(-0.03044382),
  DSP16_Q(0.05024507),
  DSP16_Q(-0.09426637),
  DSP16_Q(0.32933704),
  DSP16_Q(0.24567754),
  DSP16_Q(-0.08472140),
  DSP16_Q(0.04655699),
  DSP16_Q(-0.02842050),
  DSP16_Q(0.01756032),
  DSP16_Q(-0.01043197),
  DSP16_Q(0.00566215),
  DSP16_Q(-0.00258695),
  DSP16_Q(0.00081465),
  DSP16_Q(-0.00006589),
  DSP16_Q(-0.00012180),
  DSP16_Q(0.00100441),
  DSP16_Q(-0.00294343),
  DSP16_Q(0.00622819),
  DSP16_Q(-0.01127542),
  DSP16_Q(0.01881263),
  DSP16_Q(-0.03039160),
  DSP16_Q(0.05017728),
  DSP16_Q(-0.09427760),
  DSP16_Q(0.33268799),
  DSP16_Q(0.24183560),
  DSP16_Q(-0.08394734),
  DSP16_Q(0.04618683),
  DSP16_Q(-0.02820254),
  DSP16_Q(0.01742390),
  DSP16_Q(-0.01034686),
  DSP16_Q(0.00561165),
  DSP16_Q(-0.00256006),
  DSP16_Q(0.00080326),
  DSP16_Q(-0.00006363),
  DSP16_Q(-0.00012390),
  DSP16_Q(0.00100780),
  DSP16_Q(-0.00294431),
  DSP16_Q(0.00622176),
  DSP16_Q(-0.01125595),
  DSP16_Q(0.01877365),
  DSP16_Q(-0.03032706),
  DSP16_Q(0.05008929),
  DSP16_Q(-0.09425184),
  DSP16_Q(0.33600845),
  DSP16_Q(0.23798357),
  DSP16_Q(-0.08314740),
  DSP16_Q(0.04580101),
  DSP16_Q(-0.02797480),
  DSP16_Q(0.01728143),
  DSP16_Q(-0.01025821),
  DSP16_Q(0.00555929),
  DSP16_Q(-0.00253238),
  DSP16_Q(0.00079167),
  DSP16_Q(-0.00006139),
  DSP16_Q(-0.00012596),
  DSP16_Q(0.00101076),
  DSP16_Q(-0.00294393),
  DSP16_Q(0.00621273),
  DSP16_Q(-0.01123183),
  DSP16_Q(0.01872698),
  DSP16_Q(-0.03025015),
  DSP16_Q(0.04998097),
  DSP16_Q(-0.09418873),
  DSP16_Q(0.33929766),
  DSP16_Q(0.23412229),
  DSP16_Q(-0.08232211),
  DSP16_Q(0.04539978),
  DSP16_Q(-0.02773743),
  DSP16_Q(0.01713301),
  DSP16_Q(-0.01016607),
  DSP16_Q(0.00550510),
  DSP16_Q(-0.00250393),
  DSP16_Q(0.00077989),
  DSP16_Q(-0.00005918),
  DSP16_Q(-0.00012797),
  DSP16_Q(0.00101327),
  DSP16_Q(-0.00294229),
  DSP16_Q(0.00620108),
  DSP16_Q(-0.01120303),
  DSP16_Q(0.01867258),
  DSP16_Q(-0.03016084),
  DSP16_Q(0.04985225),
  DSP16_Q(-0.09408793),
  DSP16_Q(0.34255487),
  DSP16_Q(0.23025261),
  DSP16_Q(-0.08147200),
  DSP16_Q(0.04498339),
  DSP16_Q(-0.02749057),
  DSP16_Q(0.01697872),
  DSP16_Q(-0.01007051),
  DSP16_Q(0.00544912),
  DSP16_Q(-0.00247472),
  DSP16_Q(0.00076793),
  DSP16_Q(-0.00005700),
  DSP16_Q(-0.00012992),
  DSP16_Q(0.00101533),
  DSP16_Q(-0.00293938),
  DSP16_Q(0.00618679),
  DSP16_Q(-0.01116955),
  DSP16_Q(0.01861043),
  DSP16_Q(-0.03005907),
  DSP16_Q(0.04970302),
  DSP16_Q(-0.09394911),
  DSP16_Q(0.34577932),
  DSP16_Q(0.22637536),
  DSP16_Q(-0.08059758),
  DSP16_Q(0.04455210),
  DSP16_Q(-0.02723437),
  DSP16_Q(0.01681867),
  DSP16_Q(-0.00997159),
  DSP16_Q(0.00539140),
  DSP16_Q(-0.00244479),
  DSP16_Q(0.00075581),
  DSP16_Q(-0.00005484),
  DSP16_Q(-0.00013182),
  DSP16_Q(0.00101692),
  DSP16_Q(-0.00293517),
  DSP16_Q(0.00616986),
  DSP16_Q(-0.01113135),
  DSP16_Q(0.01854051),
  DSP16_Q(-0.02994483),
  DSP16_Q(0.04953320),
  DSP16_Q(-0.09377194),
  DSP16_Q(0.34897027),
  DSP16_Q(0.22249139),
  DSP16_Q(-0.07969940),
  DSP16_Q(0.04410616),
  DSP16_Q(-0.02696900),
  DSP16_Q(0.01665296),
  DSP16_Q(-0.00986937),
  DSP16_Q(0.00533196),
  DSP16_Q(-0.00241415),
  DSP16_Q(0.00074353),
  DSP16_Q(-0.00005272),
  DSP16_Q(-0.00013366),
  DSP16_Q(0.00101804),
  DSP16_Q(-0.00292966),
  DSP16_Q(0.00615026),
  DSP16_Q(-0.01108842),
  DSP16_Q(0.01846279),
  DSP16_Q(-0.02981807),
  DSP16_Q(0.04934273),
  DSP16_Q(-0.09355610),
  DSP16_Q(0.35212698),
  DSP16_Q(0.21860155),
  DSP16_Q(-0.07877798),
  DSP16_Q(0.04364586),
  DSP16_Q(-0.02669461),
  DSP16_Q(0.01648169),
  DSP16_Q(-0.00976391),
  DSP16_Q(0.00527084),
  DSP16_Q(-0.00238283),
  DSP16_Q(0.00073110),
  DSP16_Q(-0.00005064),
  DSP16_Q(-0.00013544),
  DSP16_Q(0.00101869),
  DSP16_Q(-0.00292284),
  DSP16_Q(0.00612798),
  DSP16_Q(-0.01104076),
  DSP16_Q(0.01837727),
  DSP16_Q(-0.02967877),
  DSP16_Q(0.04913154),
  DSP16_Q(-0.09330130),
  DSP16_Q(0.35524874),
  DSP16_Q(0.21470666),
  DSP16_Q(-0.07783386),
  DSP16_Q(0.04317145),
  DSP16_Q(-0.02641136),
  DSP16_Q(0.01630495),
  DSP16_Q(-0.00965529),
  DSP16_Q(0.00520810),
  DSP16_Q(-0.00235084),
  DSP16_Q(0.00071854),
  DSP16_Q(-0.00004859),
  DSP16_Q(-0.00013716),
  DSP16_Q(0.00101884),
  DSP16_Q(-0.00291469),
  DSP16_Q(0.00610301),
  DSP16_Q(-0.01098834),
  DSP16_Q(0.01828393),
  DSP16_Q(-0.02952691),
  DSP16_Q(0.04889956),
  DSP16_Q(-0.09300723),
  DSP16_Q(0.35833481),
  DSP16_Q(0.21080758),
  DSP16_Q(-0.07686759),
  DSP16_Q(0.04268321),
  DSP16_Q(-0.02611941),
  DSP16_Q(0.01612286),
  DSP16_Q(-0.00954356),
  DSP16_Q(0.00514376),
  DSP16_Q(-0.00231821),
  DSP16_Q(0.00070584),
  DSP16_Q(-0.00004657),
  DSP16_Q(-0.00013880),
  DSP16_Q(0.00101850),
  DSP16_Q(-0.00290521),
  DSP16_Q(0.00607535),
  DSP16_Q(-0.01093115),
  DSP16_Q(0.01818275),
  DSP16_Q(-0.02936247),
  DSP16_Q(0.04864674),
  DSP16_Q(-0.09267360),
  DSP16_Q(0.36138447),
  DSP16_Q(0.20690514),
  DSP16_Q(-0.07587971),
  DSP16_Q(0.04218142),
  DSP16_Q(-0.02581894),
  DSP16_Q(0.01593551),
  DSP16_Q(-0.00942880),
  DSP16_Q(0.00507787),
  DSP16_Q(-0.00228497),
  DSP16_Q(0.00069302),
  DSP16_Q(-0.00004459),
  DSP16_Q(-0.00014037),
  DSP16_Q(0.00101766),
  DSP16_Q(-0.00289438),
  DSP16_Q(0.00604497),
  DSP16_Q(-0.01086920),
  DSP16_Q(0.01807374),
  DSP16_Q(-0.02918545),
  DSP16_Q(0.04837304),
  DSP16_Q(-0.09230014),
  DSP16_Q(0.36439704),
  DSP16_Q(0.20300017),
  DSP16_Q(-0.07487077),
  DSP16_Q(0.04166635),
  DSP16_Q(-0.02551010),
  DSP16_Q(0.01574302),
  DSP16_Q(-0.00931106),
  DSP16_Q(0.00501047),
  DSP16_Q(-0.00225112),
  DSP16_Q(0.00068009),
  DSP16_Q(-0.00004266),
  DSP16_Q(-0.00014187),
  DSP16_Q(0.00101631),
  DSP16_Q(-0.00288221),
  DSP16_Q(0.00601187),
  DSP16_Q(-0.01080246),
  DSP16_Q(0.01795689),
  DSP16_Q(-0.02899584),
  DSP16_Q(0.04807842),
  DSP16_Q(-0.09188658),
  DSP16_Q(0.36737179),
  DSP16_Q(0.19909351),
  DSP16_Q(-0.07384131),
  DSP16_Q(0.04113830),
  DSP16_Q(-0.02519308),
  DSP16_Q(0.01554549),
  DSP16_Q(-0.00919043),
  DSP16_Q(0.00494160),
  DSP16_Q(-0.00221670),
  DSP16_Q(0.00066706),
  DSP16_Q(-0.00004076),
  DSP16_Q(-0.00014328),
  DSP16_Q(0.00101445),
  DSP16_Q(-0.00286867),
  DSP16_Q(0.00597605),
  DSP16_Q(-0.01073094),
  DSP16_Q(0.01783219),
  DSP16_Q(-0.02879364),
  DSP16_Q(0.04776286),
  DSP16_Q(-0.09143265),
  DSP16_Q(0.37030805),
  DSP16_Q(0.19518600),
  DSP16_Q(-0.07279189),
  DSP16_Q(0.04059754),
  DSP16_Q(-0.02486804),
  DSP16_Q(0.01534303),
  DSP16_Q(-0.00906697),
  DSP16_Q(0.00487129),
  DSP16_Q(-0.00218172),
  DSP16_Q(0.00065394),
  DSP16_Q(-0.00003890),
  DSP16_Q(-0.00014461),
  DSP16_Q(0.00101206),
  DSP16_Q(-0.00285377),
  DSP16_Q(0.00593749),
  DSP16_Q(-0.01065464),
  DSP16_Q(0.01769966),
  DSP16_Q(-0.02857885),
  DSP16_Q(0.04742632),
  DSP16_Q(-0.09093812),
  DSP16_Q(0.37320512),
  DSP16_Q(0.19127846),
  DSP16_Q(-0.07172307),
  DSP16_Q(0.04004437),
  DSP16_Q(-0.02453516),
  DSP16_Q(0.01513576),
  DSP16_Q(-0.00894074),
  DSP16_Q(0.00479960),
  DSP16_Q(-0.00214621),
  DSP16_Q(0.00064073),
  DSP16_Q(-0.00003708),
  DSP16_Q(-0.00014586),
  DSP16_Q(0.00100914),
  DSP16_Q(-0.00283749),
  DSP16_Q(0.00589619),
  DSP16_Q(-0.01057354),
  DSP16_Q(0.01755929),
  DSP16_Q(-0.02835147),
  DSP16_Q(0.04706879),
  DSP16_Q(-0.09040274),
  DSP16_Q(0.37606234),
  DSP16_Q(0.18737173),
  DSP16_Q(-0.07063540),
  DSP16_Q(0.03947908),
  DSP16_Q(-0.02419461),
  DSP16_Q(0.01492378),
  DSP16_Q(-0.00881183),
  DSP16_Q(0.00472657),
  DSP16_Q(-0.00211019),
  DSP16_Q(0.00062745),
  DSP16_Q(-0.00003531),
  DSP16_Q(-0.00014701),
  DSP16_Q(0.00100569),
  DSP16_Q(-0.00281982),
  DSP16_Q(0.00585215),
  DSP16_Q(-0.01048766),
  DSP16_Q(0.01741109),
  DSP16_Q(-0.02811154),
  DSP16_Q(0.04669028),
  DSP16_Q(-0.08982629),
  DSP16_Q(0.37887904),
  DSP16_Q(0.18346662),
  DSP16_Q(-0.06952944),
  DSP16_Q(0.03890196),
  DSP16_Q(-0.02384657),
  DSP16_Q(0.01470722),
  DSP16_Q(-0.00868029),
  DSP16_Q(0.00465223),
  DSP16_Q(-0.00207369),
  DSP16_Q(0.00061410),
  DSP16_Q(-0.00003358),
  DSP16_Q(-0.00014807),
  DSP16_Q(0.00100170),
  DSP16_Q(-0.00280077),
  DSP16_Q(0.00580537),
  DSP16_Q(-0.01039700),
  DSP16_Q(0.01725508),
  DSP16_Q(-0.02785905),
  DSP16_Q(0.04629077),
  DSP16_Q(-0.08920853),
  DSP16_Q(0.38165455),
  DSP16_Q(0.17956396),
  DSP16_Q(-0.06840575),
  DSP16_Q(0.03831331),
  DSP16_Q(-0.02349123),
  DSP16_Q(0.01448617),
  DSP16_Q(-0.00854621),
  DSP16_Q(0.00457663),
  DSP16_Q(-0.00203672),
  DSP16_Q(0.00060070),
  DSP16_Q(-0.00003190),
  DSP16_Q(-0.00014903),
  DSP16_Q(0.00099716),
  DSP16_Q(-0.00278033),
  DSP16_Q(0.00575583),
  DSP16_Q(-0.01030156),
  DSP16_Q(0.01709127),
  DSP16_Q(-0.02759404),
  DSP16_Q(0.04587027),
  DSP16_Q(-0.08854928),
  DSP16_Q(0.38438825),
  DSP16_Q(0.17566457),
  DSP16_Q(-0.06726489),
  DSP16_Q(0.03771344),
  DSP16_Q(-0.02312877),
  DSP16_Q(0.01426077),
  DSP16_Q(-0.00840965),
  DSP16_Q(0.00449981),
  DSP16_Q(-0.00199930),
  DSP16_Q(0.00058724),
  DSP16_Q(-0.00003026),
  DSP16_Q(-0.00014988),
  DSP16_Q(0.00099207),
  DSP16_Q(-0.00275848),
  DSP16_Q(0.00570355),
  DSP16_Q(-0.01020135),
  DSP16_Q(0.01691968),
  DSP16_Q(-0.02731653),
  DSP16_Q(0.04542881),
  DSP16_Q(-0.08784833),
  DSP16_Q(0.38707947),
  DSP16_Q(0.17176926),
  DSP16_Q(-0.06610742),
  DSP16_Q(0.03710264),
  DSP16_Q(-0.02275937),
  DSP16_Q(0.01403112),
  DSP16_Q(-0.00827068),
  DSP16_Q(0.00442181),
  DSP16_Q(-0.00196146),
  DSP16_Q(0.00057374),
  DSP16_Q(-0.00002866),
  DSP16_Q(-0.00015064),
  DSP16_Q(0.00098641),
  DSP16_Q(-0.00273523),
  DSP16_Q(0.00564851),
  DSP16_Q(-0.01009637),
  DSP16_Q(0.01674033),
  DSP16_Q(-0.02702657),
  DSP16_Q(0.04496641),
  DSP16_Q(-0.08710549),
  DSP16_Q(0.38972760),
  DSP16_Q(0.16787885),
  DSP16_Q(-0.06493392),
  DSP16_Q(0.03648122),
  DSP16_Q(-0.02238322),
  DSP16_Q(0.01379734),
  DSP16_Q(-0.00812939),
  DSP16_Q(0.00434268),
  DSP16_Q(-0.00192323),
  DSP16_Q(0.00056021),
  DSP16_Q(-0.00002711),
  DSP16_Q(-0.00015128),
  DSP16_Q(0.00098020),
  DSP16_Q(-0.00271057),
  DSP16_Q(0.00559073),
  DSP16_Q(-0.00998664),
  DSP16_Q(0.01655324),
  DSP16_Q(-0.02672418),
  DSP16_Q(0.04448310),
  DSP16_Q(-0.08632059),
  DSP16_Q(0.39233201),
  DSP16_Q(0.16399414),
  DSP16_Q(-0.06374494),
  DSP16_Q(0.03584949),
  DSP16_Q(-0.02200050),
  DSP16_Q(0.01355956),
  DSP16_Q(-0.00798584),
  DSP16_Q(0.00426246),
  DSP16_Q(-0.00188461),
  DSP16_Q(0.00054666),
  DSP16_Q(-0.00002561),
  DSP16_Q(-0.00015182),
  DSP16_Q(0.00097341),
  DSP16_Q(-0.00268450),
  DSP16_Q(0.00553020),
  DSP16_Q(-0.00987218),
  DSP16_Q(0.01635845),
  DSP16_Q(-0.02640941),
  DSP16_Q(0.04397891),
  DSP16_Q(-0.08549347),
  DSP16_Q(0.39489209),
  DSP16_Q(0.16011595),
  DSP16_Q(-0.06254105),
  DSP16_Q(0.03520776),
  DSP16_Q(-0.02161141),
  DSP16_Q(0.01331789),
  DSP16_Q(-0.00784011),
  DSP16_Q(0.00418119),
  DSP16_Q(-0.00184564),
  DSP16_Q(0.00053309),
  DSP16_Q(-0.00002416),
  DSP16_Q(-0.00015223),
  DSP16_Q(0.00096605),
  DSP16_Q(-0.00265702),
  DSP16_Q(0.00546694),
  DSP16_Q(-0.00975299),
  DSP16_Q(0.01615598),
  DSP16_Q(-0.02608231),
  DSP16_Q(0.04345391),
  DSP16_Q(-0.08462396),
  DSP16_Q(0.39740724),
  DSP16_Q(0.15624506),
  DSP16_Q(-0.06132283),
  DSP16_Q(0.03455633),
  DSP16_Q(-0.02121614),
  DSP16_Q(0.01307245),
  DSP16_Q(-0.00769227),
  DSP16_Q(0.00409892),
  DSP16_Q(-0.00180634),
  DSP16_Q(0.00051952),
  DSP16_Q(-0.00002275),
  DSP16_Q(-0.00015253),
  DSP16_Q(0.00095811),
  DSP16_Q(-0.00262812),
  DSP16_Q(0.00540093),
  DSP16_Q(-0.00962910),
  DSP16_Q(0.01594588),
  DSP16_Q(-0.02574294),
  DSP16_Q(0.04290814),
  DSP16_Q(-0.08371193),
  DSP16_Q(0.39987687),
  DSP16_Q(0.15238228),
  DSP16_Q(-0.06009083),
  DSP16_Q(0.03389552),
  DSP16_Q(-0.02081487),
  DSP16_Q(0.01282337),
  DSP16_Q(-0.00754240),
  DSP16_Q(0.00401569),
  DSP16_Q(-0.00176673),
  DSP16_Q(0.00050594),
  DSP16_Q(-0.00002139),
  DSP16_Q(-0.00015270),
  DSP16_Q(0.00094959),
  DSP16_Q(-0.00259780),
  DSP16_Q(0.00533220),
  DSP16_Q(-0.00950052),
  DSP16_Q(0.01572817),
  DSP16_Q(-0.02539135),
  DSP16_Q(0.04234166),
  DSP16_Q(-0.08275724),
  DSP16_Q(0.40230041),
  DSP16_Q(0.14852839),
  DSP16_Q(-0.05884562),
  DSP16_Q(0.03322565),
  DSP16_Q(-0.02040780),
  DSP16_Q(0.01257076),
  DSP16_Q(-0.00739057),
  DSP16_Q(0.00393154),
  DSP16_Q(-0.00172682),
  DSP16_Q(0.00049237),
  DSP16_Q(-0.00002007),
  DSP16_Q(-0.00015275),
  DSP16_Q(0.00094048),
  DSP16_Q(-0.00256607),
  DSP16_Q(0.00526074),
  DSP16_Q(-0.00936727),
  DSP16_Q(0.01550289),
  DSP16_Q(-0.02502761),
  DSP16_Q(0.04175456),
  DSP16_Q(-0.08175978),
  DSP16_Q(0.40467727),
  DSP16_Q(0.14468418),
  DSP16_Q(-0.05758778),
  DSP16_Q(0.03254702),
  DSP16_Q(-0.01999513),
  DSP16_Q(0.01231475),
  DSP16_Q(-0.00723686),
  DSP16_Q(0.00384652),
  DSP16_Q(-0.00168665),
  DSP16_Q(0.00047882),
  DSP16_Q(-0.00001881),
  DSP16_Q(-0.00015267),
  DSP16_Q(0.00093078),
  DSP16_Q(-0.00253291),
  DSP16_Q(0.00518657),
  DSP16_Q(-0.00922938),
  DSP16_Q(0.01527010),
  DSP16_Q(-0.02465178),
  DSP16_Q(0.04114692),
  DSP16_Q(-0.08071943),
  DSP16_Q(0.40700690),
  DSP16_Q(0.14085044),
  DSP16_Q(-0.05631787),
  DSP16_Q(0.03185997),
  DSP16_Q(-0.01957704),
  DSP16_Q(0.01205546),
  DSP16_Q(-0.00708134),
  DSP16_Q(0.00376066),
  DSP16_Q(-0.00164623),
  DSP16_Q(0.00046529),
  DSP16_Q(-0.00001759),
  DSP16_Q(-0.00015246),
  DSP16_Q(0.00092049),
  DSP16_Q(-0.00249834),
  DSP16_Q(0.00510969),
  DSP16_Q(-0.00908688),
  DSP16_Q(0.01502984),
  DSP16_Q(-0.02426395),
  DSP16_Q(0.04051881),
  DSP16_Q(-0.07963610),
  DSP16_Q(0.40928876),
  DSP16_Q(0.13702793),
  DSP16_Q(-0.05503646),
  DSP16_Q(0.03116480),
  DSP16_Q(-0.01915374),
  DSP16_Q(0.01179302),
  DSP16_Q(-0.00692410),
  DSP16_Q(0.00367402),
  DSP16_Q(-0.00160558),
  DSP16_Q(0.00045179),
  DSP16_Q(-0.00001642),
  DSP16_Q(-0.00015211),
  DSP16_Q(0.00090960),
  DSP16_Q(-0.00246235),
  DSP16_Q(0.00503012),
  DSP16_Q(-0.00893979),
  DSP16_Q(0.01478216),
  DSP16_Q(-0.02386419),
  DSP16_Q(0.03987034),
  DSP16_Q(-0.07850969),
  DSP16_Q(0.41152229),
  DSP16_Q(0.13321744),
  DSP16_Q(-0.05374411),
  DSP16_Q(0.03046183),
  DSP16_Q(-0.01872543),
  DSP16_Q(0.01152754),
  DSP16_Q(-0.00676520),
  DSP16_Q(0.00358664),
  DSP16_Q(-0.00156473),
  DSP16_Q(0.00043833),
  DSP16_Q(-0.00001530),
  DSP16_Q(-0.00015162),
  DSP16_Q(0.00089810),
  DSP16_Q(-0.00242495),
  DSP16_Q(0.00494787),
  DSP16_Q(-0.00878813),
  DSP16_Q(0.01452711),
  DSP16_Q(-0.02345258),
  DSP16_Q(0.03920162),
  DSP16_Q(-0.07734014),
  DSP16_Q(0.41370699),
  DSP16_Q(0.12941971),
  DSP16_Q(-0.05244139),
  DSP16_Q(0.02975139),
  DSP16_Q(-0.01829229),
  DSP16_Q(0.01125916),
  DSP16_Q(-0.00660472),
  DSP16_Q(0.00349855),
  DSP16_Q(-0.00152369),
  DSP16_Q(0.00042492),
  DSP16_Q(-0.00001422),
  DSP16_Q(-0.00015098),
  DSP16_Q(0.00088601),
  DSP16_Q(-0.00238613),
  DSP16_Q(0.00486295),
  DSP16_Q(-0.00863195),
  DSP16_Q(0.01426476),
  DSP16_Q(-0.02302922),
  DSP16_Q(0.03851275),
  DSP16_Q(-0.07612738),
  DSP16_Q(0.41584232),
  DSP16_Q(0.12563552),
  DSP16_Q(-0.05112887),
  DSP16_Q(0.02903379),
  DSP16_Q(-0.01785454),
  DSP16_Q(0.01098800),
  DSP16_Q(-0.00644275),
  DSP16_Q(0.00340981),
  DSP16_Q(-0.00148249),
  DSP16_Q(0.00041155),
  DSP16_Q(-0.00001319),
  DSP16_Q(-0.00015021),
  DSP16_Q(0.00087330),
  DSP16_Q(-0.00234591),
  DSP16_Q(0.00477538),
  DSP16_Q(-0.00847128),
  DSP16_Q(0.01399516),
  DSP16_Q(-0.02259420),
  DSP16_Q(0.03780386),
  DSP16_Q(-0.07487135),
  DSP16_Q(0.41792778),
  DSP16_Q(0.12186562),
  DSP16_Q(-0.04980711),
  DSP16_Q(0.02830936),
  DSP16_Q(-0.01741236),
  DSP16_Q(0.01071418),
  DSP16_Q(-0.00627935),
  DSP16_Q(0.00332045),
  DSP16_Q(-0.00144116),
  DSP16_Q(0.00039825),
  DSP16_Q(-0.00001221),
  DSP16_Q(-0.00014928),
  DSP16_Q(0.00085999),
  DSP16_Q(-0.00230428),
  DSP16_Q(0.00468518),
  DSP16_Q(-0.00830614),
  DSP16_Q(0.01371837),
  DSP16_Q(-0.02214763),
  DSP16_Q(0.03707507),
  DSP16_Q(-0.07357202),
  DSP16_Q(0.41996289),
  DSP16_Q(0.11811074),
  DSP16_Q(-0.04847668),
  DSP16_Q(0.02757843),
  DSP16_Q(-0.01696597),
  DSP16_Q(0.01043783),
  DSP16_Q(-0.00611460),
  DSP16_Q(0.00323052),
  DSP16_Q(-0.00139969),
  DSP16_Q(0.00038501),
  DSP16_Q(-0.00001127),
  DSP16_Q(-0.00014820),
  DSP16_Q(0.00084607),
  DSP16_Q(-0.00226124),
  DSP16_Q(0.00459235),
  DSP16_Q(-0.00813659),
  DSP16_Q(0.01343447),
  DSP16_Q(-0.02168959),
  DSP16_Q(0.03632654),
  DSP16_Q(-0.07222936),
  DSP16_Q(0.42194716),
  DSP16_Q(0.11437164),
  DSP16_Q(-0.04713814),
  DSP16_Q(0.02684131),
  DSP16_Q(-0.01651555),
  DSP16_Q(0.01015908),
  DSP16_Q(-0.00594858),
  DSP16_Q(0.00314007),
  DSP16_Q(-0.00135813),
  DSP16_Q(0.00037184),
  DSP16_Q(-0.00001038),
  DSP16_Q(-0.00014696),
  DSP16_Q(0.00083154),
  DSP16_Q(-0.00221682),
  DSP16_Q(0.00449692),
  DSP16_Q(-0.00796265),
  DSP16_Q(0.01314352),
  DSP16_Q(-0.02122022),
  DSP16_Q(0.03555839),
  DSP16_Q(-0.07084336),
  DSP16_Q(0.42388012),
  DSP16_Q(0.11064904),
  DSP16_Q(-0.04579204),
  DSP16_Q(0.02609832),
  DSP16_Q(-0.01606132),
  DSP16_Q(0.00987806),
  DSP16_Q(-0.00578137),
  DSP16_Q(0.00304913),
  DSP16_Q(-0.00131649),
  DSP16_Q(0.00035875),
  DSP16_Q(-0.00000953),
  DSP16_Q(-0.00014557),
  DSP16_Q(0.00081639),
  DSP16_Q(-0.00217100),
  DSP16_Q(0.00439891),
  DSP16_Q(-0.00778437),
  DSP16_Q(0.01284560),
  DSP16_Q(-0.02073961),
  DSP16_Q(0.03477079),
  DSP16_Q(-0.06941400),
  DSP16_Q(0.42576131),
  DSP16_Q(0.10694367),
  DSP16_Q(-0.04443896),
  DSP16_Q(0.02534980),
  DSP16_Q(-0.01560346),
  DSP16_Q(0.00959488),
  DSP16_Q(-0.00561304),
  DSP16_Q(0.00295775),
  DSP16_Q(-0.00127479),
  DSP16_Q(0.00034575),
  DSP16_Q(-0.00000872),
  DSP16_Q(-0.00014401),
  DSP16_Q(0.00080063),
  DSP16_Q(-0.00212380),
  DSP16_Q(0.00429834),
  DSP16_Q(-0.00760180),
  DSP16_Q(0.01254078),
  DSP16_Q(-0.02024790),
  DSP16_Q(0.03396390),
  DSP16_Q(-0.06794129),
  DSP16_Q(0.42759029),
  DSP16_Q(0.10325626),
  DSP16_Q(-0.04307944),
  DSP16_Q(0.02459607),
  DSP16_Q(-0.01514219),
  DSP16_Q(0.00930968),
  DSP16_Q(-0.00544367),
  DSP16_Q(0.00286597),
  DSP16_Q(-0.00123305),
  DSP16_Q(0.00033284),
  DSP16_Q(-0.00000796),
  DSP16_Q(-0.00014229),
  DSP16_Q(0.00078425),
  DSP16_Q(-0.00207522),
  DSP16_Q(0.00419524),
  DSP16_Q(-0.00741498),
  DSP16_Q(0.01222914),
  DSP16_Q(-0.01974521),
  DSP16_Q(0.03313790),
  DSP16_Q(-0.06642526),
  DSP16_Q(0.42936661),
  DSP16_Q(0.09958750),
  DSP16_Q(-0.04171403),
  DSP16_Q(0.02383744),
  DSP16_Q(-0.01467771),
  DSP16_Q(0.00902258),
  DSP16_Q(-0.00527334),
  DSP16_Q(0.00277383),
  DSP16_Q(-0.00119129),
  DSP16_Q(0.00032003),
  DSP16_Q(-0.00000725),
  DSP16_Q(-0.00014040),
  DSP16_Q(0.00076726),
  DSP16_Q(-0.00202527),
  DSP16_Q(0.00408962),
  DSP16_Q(-0.00722395),
  DSP16_Q(0.01191078),
  DSP16_Q(-0.01923166),
  DSP16_Q(0.03229295),
  DSP16_Q(-0.06486593),
  DSP16_Q(0.43108987),
  DSP16_Q(0.09593812),
  DSP16_Q(-0.04034331),
  DSP16_Q(0.02307425),
  DSP16_Q(-0.01421021),
  DSP16_Q(0.00873371),
  DSP16_Q(-0.00510212),
  DSP16_Q(0.00268138),
  DSP16_Q(-0.00114953),
  DSP16_Q(0.00030731),
  DSP16_Q(-0.00000657),
  DSP16_Q(-0.00013835),
  DSP16_Q(0.00074965),
  DSP16_Q(-0.00197396),
  DSP16_Q(0.00398150),
  DSP16_Q(-0.00702878),
  DSP16_Q(0.01158576),
  DSP16_Q(-0.01870740),
  DSP16_Q(0.03142924),
  DSP16_Q(-0.06326335),
  DSP16_Q(0.43275965),
  DSP16_Q(0.09230880),
  DSP16_Q(-0.03896780),
  DSP16_Q(0.02230681),
  DSP16_Q(-0.01373990),
  DSP16_Q(0.00844319),
  DSP16_Q(-0.00493008),
  DSP16_Q(0.00258865),
  DSP16_Q(-0.00110779),
  DSP16_Q(0.00029471),
  DSP16_Q(-0.00000594),
  DSP16_Q(-0.00013612),
  DSP16_Q(0.00073143),
  DSP16_Q(-0.00192131),
  DSP16_Q(0.00387093),
  DSP16_Q(-0.00682950),
  DSP16_Q(0.01125419),
  DSP16_Q(-0.01817256),
  DSP16_Q(0.03054698),
  DSP16_Q(-0.06161756),
  DSP16_Q(0.43437556),
  DSP16_Q(0.08870023),
  DSP16_Q(-0.03758807),
  DSP16_Q(0.02153545),
  DSP16_Q(-0.01326698),
  DSP16_Q(0.00815116),
  DSP16_Q(-0.00475732),
  DSP16_Q(0.00249569),
  DSP16_Q(-0.00106608),
  DSP16_Q(0.00028222),
  DSP16_Q(-0.00000534),
  DSP16_Q(-0.00013372),
  DSP16_Q(0.00071259),
  DSP16_Q(-0.00186731),
  DSP16_Q(0.00375792),
  DSP16_Q(-0.00662618),
  DSP16_Q(0.01091616),
  DSP16_Q(-0.01762728),
  DSP16_Q(0.02964637),
  DSP16_Q(-0.05992865),
  DSP16_Q(0.43593720),
  DSP16_Q(0.08511310),
  DSP16_Q(-0.03620466),
  DSP16_Q(0.02076049),
  DSP16_Q(-0.01279165),
  DSP16_Q(0.00785774),
  DSP16_Q(-0.00458389),
  DSP16_Q(0.00240255),
  DSP16_Q(-0.00102443),
  DSP16_Q(0.00026985),
  DSP16_Q(-0.00000479),
  DSP16_Q(-0.00013114),
  DSP16_Q(0.00069314),
  DSP16_Q(-0.00181198),
  DSP16_Q(0.00364250),
  DSP16_Q(-0.00641887),
  DSP16_Q(0.01057176),
  DSP16_Q(-0.01707173),
  DSP16_Q(0.02872761),
  DSP16_Q(-0.05819669),
  DSP16_Q(0.43744422),
  DSP16_Q(0.08154809),
  DSP16_Q(-0.03481811),
  DSP16_Q(0.01998226),
  DSP16_Q(-0.01231412),
  DSP16_Q(0.00756304),
  DSP16_Q(-0.00440988),
  DSP16_Q(0.00230925),
  DSP16_Q(-0.00098286),
  DSP16_Q(0.00025761),
  DSP16_Q(-0.00000427),
  DSP16_Q(-0.00012838),
  DSP16_Q(0.00067308),
  DSP16_Q(-0.00175533),
  DSP16_Q(0.00352470),
  DSP16_Q(-0.00620762),
  DSP16_Q(0.01022108),
  DSP16_Q(-0.01650605),
  DSP16_Q(0.02779093),
  DSP16_Q(-0.05642176),
  DSP16_Q(0.43889624),
  DSP16_Q(0.07800584),
  DSP16_Q(-0.03342896),
  DSP16_Q(0.01920108),
  DSP16_Q(-0.01183458),
  DSP16_Q(0.00726721),
  DSP16_Q(-0.00423536),
  DSP16_Q(0.00221585),
  DSP16_Q(-0.00094138),
  DSP16_Q(0.00024550),
  DSP16_Q(-0.00000379),
  DSP16_Q(-0.00012543),
  DSP16_Q(0.00065241),
  DSP16_Q(-0.00169738),
  DSP16_Q(0.00340455),
  DSP16_Q(-0.00599251),
  DSP16_Q(0.00986424),
  DSP16_Q(-0.01593041),
  DSP16_Q(0.02683655),
  DSP16_Q(-0.05460398),
  DSP16_Q(0.44029293),
  DSP16_Q(0.07448704),
  DSP16_Q(-0.03203775),
  DSP16_Q(0.01841726),
  DSP16_Q(-0.01135323),
  DSP16_Q(0.00697037),
  DSP16_Q(-0.00406040),
  DSP16_Q(0.00212238),
  DSP16_Q(-0.00090001),
  DSP16_Q(0.00023352),
  DSP16_Q(-0.00000335),
  DSP16_Q(-0.00012231),
  DSP16_Q(0.00063112),
  DSP16_Q(-0.00163813),
  DSP16_Q(0.00328209),
  DSP16_Q(-0.00577358),
  DSP16_Q(0.00950134),
  DSP16_Q(-0.01534496),
  DSP16_Q(0.02586471),
  DSP16_Q(-0.05274346),
  DSP16_Q(0.44163395),
  DSP16_Q(0.07099231),
  DSP16_Q(-0.03064501),
  DSP16_Q(0.01763112),
  DSP16_Q(-0.01087028),
  DSP16_Q(0.00667263),
  DSP16_Q(-0.00388509),
  DSP16_Q(0.00202889),
  DSP16_Q(-0.00085878),
  DSP16_Q(0.00022168),
  DSP16_Q(-0.00000294),
  DSP16_Q(-0.00011899),
  DSP16_Q(0.00060923),
  DSP16_Q(-0.00157760),
  DSP16_Q(0.00315734),
  DSP16_Q(-0.00555091),
  DSP16_Q(0.00913248),
  DSP16_Q(-0.01474988),
  DSP16_Q(0.02487566),
  DSP16_Q(-0.05084032),
  DSP16_Q(0.44291898),
  DSP16_Q(0.06752231),
  DSP16_Q(-0.02925127),
  DSP16_Q(0.01684299),
  DSP16_Q(-0.01038592),
  DSP16_Q(0.00637413),
  DSP16_Q(-0.00370949),
  DSP16_Q(0.00193541),
  DSP16_Q(-0.00081769),
  DSP16_Q(0.00020998),
  DSP16_Q(-0.00000257),
  DSP16_Q(-0.00011549),
  DSP16_Q(0.00058674),
  DSP16_Q(-0.00151580),
  DSP16_Q(0.00303035),
  DSP16_Q(-0.00532455),
  DSP16_Q(0.00875778),
  DSP16_Q(-0.01414534),
  DSP16_Q(0.02386965),
  DSP16_Q(-0.04889471),
  DSP16_Q(0.44414772),
  DSP16_Q(0.06407766),
  DSP16_Q(-0.02785706),
  DSP16_Q(0.01605318),
  DSP16_Q(-0.00990036),
  DSP16_Q(0.00607499),
  DSP16_Q(-0.00353369),
  DSP16_Q(0.00184198),
  DSP16_Q(-0.00077676),
  DSP16_Q(0.00019843),
  DSP16_Q(-0.00000222),
  DSP16_Q(-0.00011180),
  DSP16_Q(0.00056364),
  DSP16_Q(-0.00145275),
  DSP16_Q(0.00290114),
  DSP16_Q(-0.00509459),
  DSP16_Q(0.00837735),
  DSP16_Q(-0.01353153),
  DSP16_Q(0.02284693),
  DSP16_Q(-0.04690679),
  DSP16_Q(0.44531987),
  DSP16_Q(0.06065898),
  DSP16_Q(-0.02646290),
  DSP16_Q(0.01526201),
  DSP16_Q(-0.00941378),
  DSP16_Q(0.00577533),
  DSP16_Q(-0.00335774),
  DSP16_Q(0.00174864),
  DSP16_Q(-0.00073602),
  DSP16_Q(0.00018704),
  DSP16_Q(-0.00000191),
  DSP16_Q(-0.00010792),
  DSP16_Q(0.00053994),
  DSP16_Q(-0.00138847),
  DSP16_Q(0.00276976),
  DSP16_Q(-0.00486108),
  DSP16_Q(0.00799131),
  DSP16_Q(-0.01290861),
  DSP16_Q(0.02180778),
  DSP16_Q(-0.04487670),
  DSP16_Q(0.44643516),
  DSP16_Q(0.05726690),
  DSP16_Q(-0.02506931),
  DSP16_Q(0.01446979),
  DSP16_Q(-0.00892640),
  DSP16_Q(0.00547528),
  DSP16_Q(-0.00318173),
  DSP16_Q(0.00165544),
  DSP16_Q(-0.00069548),
  DSP16_Q(0.00017580),
  DSP16_Q(-0.00000163),
  DSP16_Q(-0.00010384),
  DSP16_Q(0.00051566),
  DSP16_Q(-0.00132297),
  DSP16_Q(0.00263624),
  DSP16_Q(-0.00462410),
  DSP16_Q(0.00759978),
  DSP16_Q(-0.01227680),
  DSP16_Q(0.02075247),
  DSP16_Q(-0.04280464),
  DSP16_Q(0.44749331),
  DSP16_Q(0.05390200),
  DSP16_Q(-0.02367680),
  DSP16_Q(0.01367684),
  DSP16_Q(-0.00843841),
  DSP16_Q(0.00517495),
  DSP16_Q(-0.00300573),
  DSP16_Q(0.00156241),
  DSP16_Q(-0.00065515),
  DSP16_Q(0.00016472),
  DSP16_Q(-0.00000138),
  DSP16_Q(-0.00009957),
  DSP16_Q(0.00049078),
  DSP16_Q(-0.00125626),
  DSP16_Q(0.00250062),
  DSP16_Q(-0.00438372),
  DSP16_Q(0.00720287),
  DSP16_Q(-0.01163626),
  DSP16_Q(0.01968128),
  DSP16_Q(-0.04069079),
  DSP16_Q(0.44849408),
  DSP16_Q(0.05056489),
  DSP16_Q(-0.02228589),
  DSP16_Q(0.01288346),
  DSP16_Q(-0.00794999),
  DSP16_Q(0.00487448),
  DSP16_Q(-0.00282980),
  DSP16_Q(0.00146958),
  DSP16_Q(-0.00061505),
  DSP16_Q(0.00015380),
  DSP16_Q(-0.00000115),
  DSP16_Q(-0.00009510),
  DSP16_Q(0.00046531),
  DSP16_Q(-0.00118837),
  DSP16_Q(0.00236295),
  DSP16_Q(-0.00414002),
  DSP16_Q(0.00680072),
  DSP16_Q(-0.01098722),
  DSP16_Q(0.01859451),
  DSP16_Q(-0.03853535),
  DSP16_Q(0.44943722),
  DSP16_Q(0.04725615),
  DSP16_Q(-0.02089707),
  DSP16_Q(0.01208997),
  DSP16_Q(-0.00746135),
  DSP16_Q(0.00457398),
  DSP16_Q(-0.00265403),
  DSP16_Q(0.00137700),
  DSP16_Q(-0.00057520),
  DSP16_Q(0.00014306),
  DSP16_Q(-0.00000095),
  DSP16_Q(-0.00009043),
  DSP16_Q(0.00043926),
  DSP16_Q(-0.00111931),
  DSP16_Q(0.00222326),
  DSP16_Q(-0.00389308),
  DSP16_Q(0.00639346),
  DSP16_Q(-0.01032985),
  DSP16_Q(0.01749245),
  DSP16_Q(-0.03633853),
  DSP16_Q(0.45032251),
  DSP16_Q(0.04397636),
  DSP16_Q(-0.01951086),
  DSP16_Q(0.01129667),
  DSP16_Q(-0.00697268),
  DSP16_Q(0.00427356),
  DSP16_Q(-0.00247848),
  DSP16_Q(0.00128471),
  DSP16_Q(-0.00053561),
  DSP16_Q(0.00013248),
  DSP16_Q(-0.00000078),
  DSP16_Q(-0.00008557),
  DSP16_Q(0.00041263),
  DSP16_Q(-0.00104911),
  DSP16_Q(0.00208160),
  DSP16_Q(-0.00364296),
  DSP16_Q(0.00598121),
  DSP16_Q(-0.00966438),
  DSP16_Q(0.01637542),
  DSP16_Q(-0.03410057),
  DSP16_Q(0.45114975),
  DSP16_Q(0.04072608),
  DSP16_Q(-0.01812775),
  DSP16_Q(0.01050388),
  DSP16_Q(-0.00648418),
  DSP16_Q(0.00397337),
  DSP16_Q(-0.00230322),
  DSP16_Q(0.00119273),
  DSP16_Q(-0.00049630),
  DSP16_Q(0.00012208),
  DSP16_Q(-0.00000063),
  DSP16_Q(-0.00008050),
  DSP16_Q(0.00038544),
  DSP16_Q(-0.00097777),
  DSP16_Q(0.00193800),
  DSP16_Q(-0.00338976),
  DSP16_Q(0.00556411),
  DSP16_Q(-0.00899101),
  DSP16_Q(0.01524372),
  DSP16_Q(-0.03182169),
  DSP16_Q(0.45191872),
  DSP16_Q(0.03750586),
  DSP16_Q(-0.01674824),
  DSP16_Q(0.00971188),
  DSP16_Q(-0.00599603),
  DSP16_Q(0.00367350),
  DSP16_Q(-0.00212833),
  DSP16_Q(0.00110111),
  DSP16_Q(-0.00045729),
  DSP16_Q(0.00011185),
  DSP16_Q(-0.00000049),
  DSP16_Q(-0.00007523),
  DSP16_Q(0.00035768),
  DSP16_Q(-0.00090533),
  DSP16_Q(0.00179253),
  DSP16_Q(-0.00313356),
  DSP16_Q(0.00514230),
  DSP16_Q(-0.00830996),
  DSP16_Q(0.01409767),
  DSP16_Q(-0.02950216),
  DSP16_Q(0.45262925),
  DSP16_Q(0.03431626),
  DSP16_Q(-0.01537280),
  DSP16_Q(0.00892100),
  DSP16_Q(-0.00550843),
  DSP16_Q(0.00337408),
  DSP16_Q(-0.00195387),
  DSP16_Q(0.00100988),
  DSP16_Q(-0.00041858),
  DSP16_Q(0.00010181),
  DSP16_Q(-0.00000038),
  DSP16_Q(-0.00006976),
  DSP16_Q(0.00032935),
  DSP16_Q(-0.00083180),
  DSP16_Q(0.00164521),
  DSP16_Q(-0.00287444),
  DSP16_Q(0.00471592),
  DSP16_Q(-0.00762144),
  DSP16_Q(0.01293762),
  DSP16_Q(-0.02714223),
  DSP16_Q(0.45328117),
  DSP16_Q(0.03115780),
  DSP16_Q(-0.01400192),
  DSP16_Q(0.00813151),
  DSP16_Q(-0.00502156),
  DSP16_Q(0.00307522),
  DSP16_Q(-0.00177990),
  DSP16_Q(0.00091908),
  DSP16_Q(-0.00038020),
  DSP16_Q(0.00009195),
  DSP16_Q(-0.00000029),
  DSP16_Q(-0.00006409),
  DSP16_Q(0.00030048),
  DSP16_Q(-0.00075721),
  DSP16_Q(0.00149611),
  DSP16_Q(-0.00261248),
  DSP16_Q(0.00428510),
  DSP16_Q(-0.00692568),
  DSP16_Q(0.01176389),
  DSP16_Q(-0.02474217),
  DSP16_Q(0.45387432),
  DSP16_Q(0.02803101),
  DSP16_Q(-0.01263608),
  DSP16_Q(0.00734373),
  DSP16_Q(-0.00453561),
  DSP16_Q(0.00277705),
  DSP16_Q(-0.00160650),
  DSP16_Q(0.00082875),
  DSP16_Q(-0.00034215),
  DSP16_Q(0.00008227),
  DSP16_Q(-0.00000021),
  DSP16_Q(-0.00005821),
  DSP16_Q(0.00027105),
  DSP16_Q(-0.00068157),
  DSP16_Q(0.00134526),
  DSP16_Q(-0.00234778),
  DSP16_Q(0.00385000),
  DSP16_Q(-0.00622291),
  DSP16_Q(0.01057682),
  DSP16_Q(-0.02230227),
  DSP16_Q(0.45440857),
  DSP16_Q(0.02493641),
  DSP16_Q(-0.01127576),
  DSP16_Q(0.00655795),
  DSP16_Q(-0.00405077),
  DSP16_Q(0.00247968),
  DSP16_Q(-0.00143374),
  DSP16_Q(0.00073891),
  DSP16_Q(-0.00030446),
  DSP16_Q(0.00007279),
  DSP16_Q(-0.00000015),
  DSP16_Q(-0.00005213),
  DSP16_Q(0.00024109),
  DSP16_Q(-0.00060491),
  DSP16_Q(0.00119272),
  DSP16_Q(-0.00208042),
  DSP16_Q(0.00341076),
  DSP16_Q(-0.00551336),
  DSP16_Q(0.00937677),
  DSP16_Q(-0.01982284),
  DSP16_Q(0.45488377),
  DSP16_Q(0.02187449),
  DSP16_Q(-0.00992141),
  DSP16_Q(0.00577446),
  DSP16_Q(-0.00356722),
  DSP16_Q(0.00218321),
  DSP16_Q(-0.00126168),
  DSP16_Q(0.00064960),
  DSP16_Q(-0.00026712),
  DSP16_Q(0.00006349),
  DSP16_Q(-0.00000010),
  DSP16_Q(-0.00004585),
  DSP16_Q(0.00021060),
  DSP16_Q(-0.00052726),
  DSP16_Q(0.00103854),
  DSP16_Q(-0.00181050),
  DSP16_Q(0.00296752),
  DSP16_Q(-0.00479727),
  DSP16_Q(0.00816410),
  DSP16_Q(-0.01730417),
  DSP16_Q(0.45529982),
  DSP16_Q(0.01884576),
  DSP16_Q(-0.00857351),
  DSP16_Q(0.00499354),
  DSP16_Q(-0.00308515),
  DSP16_Q(0.00188778),
  DSP16_Q(-0.00109038),
  DSP16_Q(0.00056086),
  DSP16_Q(-0.00023017),
  DSP16_Q(0.00005438),
  DSP16_Q(-0.00000006),
  DSP16_Q(-0.00003935),
  DSP16_Q(0.00017958),
  DSP16_Q(-0.00044864),
  DSP16_Q(0.00088277),
  DSP16_Q(-0.00153810),
  DSP16_Q(0.00252045),
  DSP16_Q(-0.00407486),
  DSP16_Q(0.00693918),
  DSP16_Q(-0.01474660),
  DSP16_Q(0.45565662),
  DSP16_Q(0.01585068),
  DSP16_Q(-0.00723250),
  DSP16_Q(0.00421550),
  DSP16_Q(-0.00260473),
  DSP16_Q(0.00159347),
  DSP16_Q(-0.00091991),
  DSP16_Q(0.00047271),
  DSP16_Q(-0.00019360),
  DSP16_Q(0.00004547),
  DSP16_Q(-0.00000004),
  DSP16_Q(-0.00003266),
  DSP16_Q(0.00014805),
  DSP16_Q(-0.00036907),
  DSP16_Q(0.00072546),
  DSP16_Q(-0.00126333),
  DSP16_Q(0.00206970),
  DSP16_Q(-0.00334640),
  DSP16_Q(0.00570237),
  DSP16_Q(-0.01215045),
  DSP16_Q(0.45595409),
  DSP16_Q(0.01288974),
  DSP16_Q(-0.00589883),
  DSP16_Q(0.00344060),
  DSP16_Q(-0.00212616),
  DSP16_Q(0.00130042),
  DSP16_Q(-0.00075034),
  DSP16_Q(0.00038519),
  DSP16_Q(-0.00015744),
  DSP16_Q(0.00003676),
  DSP16_Q(-0.00000002),
  DSP16_Q(-0.00002576),
  DSP16_Q(0.00011601),
  DSP16_Q(-0.00028858),
  DSP16_Q(0.00056667),
  DSP16_Q(-0.00098627),
  DSP16_Q(0.00161542),
  DSP16_Q(-0.00261212),
  DSP16_Q(0.00445405),
  DSP16_Q(-0.00951608),
  DSP16_Q(0.45619215),
  DSP16_Q(0.00996340),
  DSP16_Q(-0.00457295),
  DSP16_Q(0.00266913),
  DSP16_Q(-0.00164959),
  DSP16_Q(0.00100872),
  DSP16_Q(-0.00058173),
  DSP16_Q(0.00029834),
  DSP16_Q(-0.00012169),
  DSP16_Q(0.00002824),
  DSP16_Q(-0.00000001),
  DSP16_Q(-0.00001865),
  DSP16_Q(0.00008347),
  DSP16_Q(-0.00020720),
  DSP16_Q(0.00040644),
  DSP16_Q(-0.00070702),
  DSP16_Q(0.00115778),
  DSP16_Q(-0.00187227),
  DSP16_Q(0.00319462),
  DSP16_Q(-0.00684384),
  DSP16_Q(0.45637074),
  DSP16_Q(0.00707210),
  DSP16_Q(-0.00325531),
  DSP16_Q(0.00190137),
  DSP16_Q(-0.00117522),
  DSP16_Q(0.00071848),
  DSP16_Q(-0.00041413),
  DSP16_Q(0.00021218),
  DSP16_Q(-0.00008637),
  DSP16_Q(0.00001992),
  DSP16_Q(-0.00000000),
  DSP16_Q(-0.00001135),
  DSP16_Q(0.00005044),
  DSP16_Q(-0.00012494),
  DSP16_Q(0.00024485),
  DSP16_Q(-0.00042569),
  DSP16_Q(0.00069693),
  DSP16_Q(-0.00112712),
  DSP16_Q(0.00192447),
  DSP16_Q(-0.00413409),
  DSP16_Q(0.45648982),
  DSP16_Q(0.00421627),
  DSP16_Q(-0.00194632),
  DSP16_Q(0.00113760),
  DSP16_Q(-0.00070321),
  DSP16_Q(0.00042982),
  DSP16_Q(-0.00024761),
  DSP16_Q(0.00012674),
  DSP16_Q(-0.00005148),
  DSP16_Q(0.00001180),
  DSP16_Q(-0.00000000),
  DSP16_Q(-0.00000383),
  DSP16_Q(0.00001693),
  DSP16_Q(-0.00004185),
  DSP16_Q(0.00008193),
  DSP16_Q(-0.00014237),
  DSP16_Q(0.00023303),
  DSP16_Q(-0.00037692),
  DSP16_Q(0.00064399),
  DSP16_Q(-0.00138723),
  DSP16_Q(0.45654937),
  DSP16_Q(0.00139636),
  DSP16_Q(-0.00064641),
  DSP16_Q(0.00037808),
  DSP16_Q(-0.00023373),
  DSP16_Q(0.00014283),
  DSP16_Q(-0.00008224),
  DSP16_Q(0.00004205),
  DSP16_Q(-0.00001705),
  DSP16_Q(0.00000388),
  DSP16_Q(-0.00000000)
};
