/*****************************************************************************
 *
 * \file
 *
 * \brief FIR coefficients for the dsp16_resampling function from the DPSLib.
 *        These coefficients have the following caracterizations:
 *          - Input sampling frequency: 44100 Hz
 *          - Output sampling frequency: 48000 Hz
 *          - Re-sampling order: 30
 *          - Coefficients are normalized
 *          - Memory foot print: 9600 bytes
 *         It matches the following parameters:
 *         (dsp16_resampling_options_t::dsp16_custom_filter)
 *          - Cut-off frequency (fc_hz): 22050
 *          - Sampling frequency (fs_hz): 7056000
 *          - Actual FIR filter order (order): 4800
 *
 * Copyright (c) 2010 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/

A_ALIGNED static const dsp16_t dsp16_resampling_fircoef_ord30_44100_48000_norm[] = {
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000100),
  DSP16_Q(0.00000425),
  DSP16_Q(-0.00001016),
  DSP16_Q(0.00001920),
  DSP16_Q(-0.00003192),
  DSP16_Q(0.00004902),
  DSP16_Q(-0.00007147),
  DSP16_Q(0.00010075),
  DSP16_Q(-0.00013931),
  DSP16_Q(0.00019158),
  DSP16_Q(-0.00026651),
  DSP16_Q(0.00038521),
  DSP16_Q(-0.00061149),
  DSP16_Q(0.00126618),
  DSP16_Q(0.40834756),
  DSP16_Q(-0.00125812),
  DSP16_Q(0.00060941),
  DSP16_Q(-0.00038425),
  DSP16_Q(0.00026594),
  DSP16_Q(-0.00019120),
  DSP16_Q(0.00013904),
  DSP16_Q(-0.00010054),
  DSP16_Q(0.00007131),
  DSP16_Q(-0.00004890),
  DSP16_Q(0.00003183),
  DSP16_Q(-0.00001914),
  DSP16_Q(0.00001012),
  DSP16_Q(-0.00000422),
  DSP16_Q(0.00000098),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000303),
  DSP16_Q(0.00001282),
  DSP16_Q(-0.00003062),
  DSP16_Q(0.00005781),
  DSP16_Q(-0.00009604),
  DSP16_Q(0.00014741),
  DSP16_Q(-0.00021486),
  DSP16_Q(0.00030285),
  DSP16_Q(-0.00041872),
  DSP16_Q(0.00057582),
  DSP16_Q(-0.00080114),
  DSP16_Q(0.00115839),
  DSP16_Q(-0.00184051),
  DSP16_Q(0.00382254),
  DSP16_Q(0.40829473),
  DSP16_Q(-0.00374999),
  DSP16_Q(0.00182181),
  DSP16_Q(-0.00114970),
  DSP16_Q(0.00079600),
  DSP16_Q(-0.00057237),
  DSP16_Q(0.00041623),
  DSP16_Q(-0.00030097),
  DSP16_Q(0.00021343),
  DSP16_Q(-0.00014631),
  DSP16_Q(0.00009521),
  DSP16_Q(-0.00005720),
  DSP16_Q(0.00003020),
  DSP16_Q(-0.00001257),
  DSP16_Q(0.00000291),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000511),
  DSP16_Q(0.00002150),
  DSP16_Q(-0.00005125),
  DSP16_Q(0.00009666),
  DSP16_Q(-0.00016048),
  DSP16_Q(0.00024624),
  DSP16_Q(-0.00035882),
  DSP16_Q(0.00050566),
  DSP16_Q(-0.00069908),
  DSP16_Q(0.00096139),
  DSP16_Q(-0.00133777),
  DSP16_Q(0.00193501),
  DSP16_Q(-0.00307723),
  DSP16_Q(0.00641057),
  DSP16_Q(0.40818909),
  DSP16_Q(-0.00620905),
  DSP16_Q(0.00302531),
  DSP16_Q(-0.00191089),
  DSP16_Q(0.00132349),
  DSP16_Q(-0.00095179),
  DSP16_Q(0.00069215),
  DSP16_Q(-0.00050045),
  DSP16_Q(0.00035483),
  DSP16_Q(-0.00024318),
  DSP16_Q(0.00015818),
  DSP16_Q(-0.00009498),
  DSP16_Q(0.00005010),
  DSP16_Q(-0.00002080),
  DSP16_Q(0.00000479),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000724),
  DSP16_Q(0.00003029),
  DSP16_Q(-0.00007205),
  DSP16_Q(0.00013575),
  DSP16_Q(-0.00022524),
  DSP16_Q(0.00034546),
  DSP16_Q(-0.00050327),
  DSP16_Q(0.00070912),
  DSP16_Q(-0.00098029),
  DSP16_Q(0.00134812),
  DSP16_Q(-0.00187618),
  DSP16_Q(0.00271481),
  DSP16_Q(-0.00432126),
  DSP16_Q(0.00902989),
  DSP16_Q(0.40803067),
  DSP16_Q(-0.00863496),
  DSP16_Q(0.00421953),
  DSP16_Q(-0.00266754),
  DSP16_Q(0.00184821),
  DSP16_Q(-0.00132933),
  DSP16_Q(0.00096671),
  DSP16_Q(-0.00069891),
  DSP16_Q(0.00049546),
  DSP16_Q(-0.00033947),
  DSP16_Q(0.00022072),
  DSP16_Q(-0.00013245),
  DSP16_Q(0.00006979),
  DSP16_Q(-0.00002892),
  DSP16_Q(0.00000662),
  DSP16_Q(0.00000001),
  DSP16_Q(-0.00000943),
  DSP16_Q(0.00003919),
  DSP16_Q(-0.00009301),
  DSP16_Q(0.00017505),
  DSP16_Q(-0.00029028),
  DSP16_Q(0.00044504),
  DSP16_Q(-0.00064817),
  DSP16_Q(0.00091315),
  DSP16_Q(-0.00126223),
  DSP16_Q(0.00173589),
  DSP16_Q(-0.00241619),
  DSP16_Q(0.00349748),
  DSP16_Q(-0.00557219),
  DSP16_Q(0.01168008),
  DSP16_Q(0.40781949),
  DSP16_Q(-0.01102738),
  DSP16_Q(0.00540409),
  DSP16_Q(-0.00341939),
  DSP16_Q(0.00236998),
  DSP16_Q(-0.00170483),
  DSP16_Q(0.00123979),
  DSP16_Q(-0.00089627),
  DSP16_Q(0.00063526),
  DSP16_Q(-0.00043515),
  DSP16_Q(0.00028282),
  DSP16_Q(-0.00016961),
  DSP16_Q(0.00008927),
  DSP16_Q(-0.00003691),
  DSP16_Q(0.00000839),
  DSP16_Q(0.00000001),
  DSP16_Q(-0.00001166),
  DSP16_Q(0.00004818),
  DSP16_Q(-0.00011411),
  DSP16_Q(0.00021456),
  DSP16_Q(-0.00035558),
  DSP16_Q(0.00054494),
  DSP16_Q(-0.00079347),
  DSP16_Q(0.00111766),
  DSP16_Q(-0.00154481),
  DSP16_Q(0.00212455),
  DSP16_Q(-0.00295758),
  DSP16_Q(0.00428276),
  DSP16_Q(-0.00682958),
  DSP16_Q(0.01436073),
  DSP16_Q(0.40755561),
  DSP16_Q(-0.01338596),
  DSP16_Q(0.00657861),
  DSP16_Q(-0.00416618),
  DSP16_Q(0.00288859),
  DSP16_Q(-0.00207818),
  DSP16_Q(0.00151131),
  DSP16_Q(-0.00109247),
  DSP16_Q(0.00077419),
  DSP16_Q(-0.00053017),
  DSP16_Q(0.00034444),
  DSP16_Q(-0.00020643),
  DSP16_Q(0.00010854),
  DSP16_Q(-0.00004478),
  DSP16_Q(0.00001011),
  DSP16_Q(0.00000002),
  DSP16_Q(-0.00001394),
  DSP16_Q(0.00005727),
  DSP16_Q(-0.00013537),
  DSP16_Q(0.00025426),
  DSP16_Q(-0.00042112),
  DSP16_Q(0.00064512),
  DSP16_Q(-0.00093910),
  DSP16_Q(0.00132258),
  DSP16_Q(-0.00182792),
  DSP16_Q(0.00251394),
  DSP16_Q(-0.00350015),
  DSP16_Q(0.00507034),
  DSP16_Q(-0.00809304),
  DSP16_Q(0.01707142),
  DSP16_Q(0.40723910),
  DSP16_Q(-0.01571038),
  DSP16_Q(0.00774273),
  DSP16_Q(-0.00490763),
  DSP16_Q(0.00340387),
  DSP16_Q(-0.00244922),
  DSP16_Q(0.00178116),
  DSP16_Q(-0.00128743),
  DSP16_Q(0.00091220),
  DSP16_Q(-0.00062451),
  DSP16_Q(0.00040557),
  DSP16_Q(-0.00024292),
  DSP16_Q(0.00012758),
  DSP16_Q(-0.00005252),
  DSP16_Q(0.00001178),
  DSP16_Q(0.00000003),
  DSP16_Q(-0.00001627),
  DSP16_Q(0.00006645),
  DSP16_Q(-0.00015675),
  DSP16_Q(0.00029414),
  DSP16_Q(-0.00048686),
  DSP16_Q(0.00074555),
  DSP16_Q(-0.00108502),
  DSP16_Q(0.00152784),
  DSP16_Q(-0.00211144),
  DSP16_Q(0.00290391),
  DSP16_Q(-0.00404371),
  DSP16_Q(0.00585995),
  DSP16_Q(-0.00936211),
  DSP16_Q(0.01981171),
  DSP16_Q(0.40687001),
  DSP16_Q(-0.01800033),
  DSP16_Q(0.00889609),
  DSP16_Q(-0.00564351),
  DSP16_Q(0.00391564),
  DSP16_Q(-0.00281783),
  DSP16_Q(0.00204924),
  DSP16_Q(-0.00148108),
  DSP16_Q(0.00104923),
  DSP16_Q(-0.00071814),
  DSP16_Q(0.00046618),
  DSP16_Q(-0.00027905),
  DSP16_Q(0.00014640),
  DSP16_Q(-0.00006014),
  DSP16_Q(0.00001340),
  DSP16_Q(0.00000004),
  DSP16_Q(-0.00001865),
  DSP16_Q(0.00007572),
  DSP16_Q(-0.00017827),
  DSP16_Q(0.00033417),
  DSP16_Q(-0.00055280),
  DSP16_Q(0.00084619),
  DSP16_Q(-0.00123116),
  DSP16_Q(0.00173334),
  DSP16_Q(-0.00239527),
  DSP16_Q(0.00329433),
  DSP16_Q(-0.00458804),
  DSP16_Q(0.00665130),
  DSP16_Q(-0.01063638),
  DSP16_Q(0.02258117),
  DSP16_Q(0.40644845),
  DSP16_Q(-0.02025550),
  DSP16_Q(0.01003833),
  DSP16_Q(-0.00637356),
  DSP16_Q(0.00442370),
  DSP16_Q(-0.00318387),
  DSP16_Q(0.00231546),
  DSP16_Q(-0.00167335),
  DSP16_Q(0.00118524),
  DSP16_Q(-0.00081101),
  DSP16_Q(0.00052626),
  DSP16_Q(-0.00031481),
  DSP16_Q(0.00016499),
  DSP16_Q(-0.00006763),
  DSP16_Q(0.00001497),
  DSP16_Q(0.00000006),
  DSP16_Q(-0.00002108),
  DSP16_Q(0.00008508),
  DSP16_Q(-0.00019990),
  DSP16_Q(0.00037435),
  DSP16_Q(-0.00061889),
  DSP16_Q(0.00094699),
  DSP16_Q(-0.00137747),
  DSP16_Q(0.00193902),
  DSP16_Q(-0.00267929),
  DSP16_Q(0.00368503),
  DSP16_Q(-0.00513294),
  DSP16_Q(0.00744407),
  DSP16_Q(-0.01191542),
  DSP16_Q(0.02537934),
  DSP16_Q(0.40597452),
  DSP16_Q(-0.02247560),
  DSP16_Q(0.01116911),
  DSP16_Q(-0.00709752),
  DSP16_Q(0.00492789),
  DSP16_Q(-0.00354721),
  DSP16_Q(0.00257972),
  DSP16_Q(-0.00186417),
  DSP16_Q(0.00132018),
  DSP16_Q(-0.00090310),
  DSP16_Q(0.00058578),
  DSP16_Q(-0.00035019),
  DSP16_Q(0.00018333),
  DSP16_Q(-0.00007498),
  DSP16_Q(0.00001648),
  DSP16_Q(0.00000008),
  DSP16_Q(-0.00002355),
  DSP16_Q(0.00009452),
  DSP16_Q(-0.00022165),
  DSP16_Q(0.00041465),
  DSP16_Q(-0.00068511),
  DSP16_Q(0.00104791),
  DSP16_Q(-0.00152389),
  DSP16_Q(0.00214480),
  DSP16_Q(-0.00296340),
  DSP16_Q(0.00407587),
  DSP16_Q(-0.00567820),
  DSP16_Q(0.00823800),
  DSP16_Q(-0.01319876),
  DSP16_Q(0.02820576),
  DSP16_Q(0.40544831),
  DSP16_Q(-0.02466035),
  DSP16_Q(0.01228807),
  DSP16_Q(-0.00781515),
  DSP16_Q(0.00542802),
  DSP16_Q(-0.00390772),
  DSP16_Q(0.00284192),
  DSP16_Q(-0.00205347),
  DSP16_Q(0.00145399),
  DSP16_Q(-0.00099437),
  DSP16_Q(0.00064471),
  DSP16_Q(-0.00038518),
  DSP16_Q(0.00020143),
  DSP16_Q(-0.00008220),
  DSP16_Q(0.00001794),
  DSP16_Q(0.00000010),
  DSP16_Q(-0.00002607),
  DSP16_Q(0.00010405),
  DSP16_Q(-0.00024350),
  DSP16_Q(0.00045507),
  DSP16_Q(-0.00075144),
  DSP16_Q(0.00114893),
  DSP16_Q(-0.00167036),
  DSP16_Q(0.00235058),
  DSP16_Q(-0.00324749),
  DSP16_Q(0.00446670),
  DSP16_Q(-0.00622360),
  DSP16_Q(0.00903276),
  DSP16_Q(-0.01448599),
  DSP16_Q(0.03105995),
  DSP16_Q(0.40486996),
  DSP16_Q(-0.02680947),
  DSP16_Q(0.01339489),
  DSP16_Q(-0.00852621),
  DSP16_Q(0.00592391),
  DSP16_Q(-0.00426527),
  DSP16_Q(0.00310197),
  DSP16_Q(-0.00224118),
  DSP16_Q(0.00158663),
  DSP16_Q(-0.00108480),
  DSP16_Q(0.00070305),
  DSP16_Q(-0.00041977),
  DSP16_Q(0.00021928),
  DSP16_Q(-0.00008929),
  DSP16_Q(0.00001935),
  DSP16_Q(0.00000013),
  DSP16_Q(-0.00002864),
  DSP16_Q(0.00011365),
  DSP16_Q(-0.00026544),
  DSP16_Q(0.00049559),
  DSP16_Q(-0.00081786),
  DSP16_Q(0.00124999),
  DSP16_Q(-0.00181683),
  DSP16_Q(0.00255629),
  DSP16_Q(-0.00353145),
  DSP16_Q(0.00485736),
  DSP16_Q(-0.00676895),
  DSP16_Q(0.00982807),
  DSP16_Q(-0.01577663),
  DSP16_Q(0.03394145),
  DSP16_Q(0.40423960),
  DSP16_Q(-0.02892271),
  DSP16_Q(0.01448924),
  DSP16_Q(-0.00923047),
  DSP16_Q(0.00641540),
  DSP16_Q(-0.00461974),
  DSP16_Q(0.00335978),
  DSP16_Q(-0.00242724),
  DSP16_Q(0.00171806),
  DSP16_Q(-0.00117434),
  DSP16_Q(0.00076077),
  DSP16_Q(-0.00045394),
  DSP16_Q(0.00023687),
  DSP16_Q(-0.00009623),
  DSP16_Q(0.00002071),
  DSP16_Q(0.00000017),
  DSP16_Q(-0.00003125),
  DSP16_Q(0.00012332),
  DSP16_Q(-0.00028747),
  DSP16_Q(0.00053618),
  DSP16_Q(-0.00088433),
  DSP16_Q(0.00135106),
  DSP16_Q(-0.00196324),
  DSP16_Q(0.00276186),
  DSP16_Q(-0.00381515),
  DSP16_Q(0.00524770),
  DSP16_Q(-0.00731402),
  DSP16_Q(0.01062363),
  DSP16_Q(-0.01707025),
  DSP16_Q(0.03684977),
  DSP16_Q(0.40355737),
  DSP16_Q(-0.03099980),
  DSP16_Q(0.01557078),
  DSP16_Q(-0.00992768),
  DSP16_Q(0.00690231),
  DSP16_Q(-0.00497100),
  DSP16_Q(0.00361526),
  DSP16_Q(-0.00261158),
  DSP16_Q(0.00184823),
  DSP16_Q(-0.00126297),
  DSP16_Q(0.00081785),
  DSP16_Q(-0.00048769),
  DSP16_Q(0.00025421),
  DSP16_Q(-0.00010304),
  DSP16_Q(0.00002202),
  DSP16_Q(0.00000021),
  DSP16_Q(-0.00003391),
  DSP16_Q(0.00013306),
  DSP16_Q(-0.00030958),
  DSP16_Q(0.00057684),
  DSP16_Q(-0.00095082),
  DSP16_Q(0.00145210),
  DSP16_Q(-0.00210953),
  DSP16_Q(0.00296719),
  DSP16_Q(-0.00409850),
  DSP16_Q(0.00563757),
  DSP16_Q(-0.00785862),
  DSP16_Q(0.01141912),
  DSP16_Q(-0.01836637),
  DSP16_Q(0.03978440),
  DSP16_Q(0.40282345),
  DSP16_Q(-0.03304052),
  DSP16_Q(0.01663921),
  DSP16_Q(-0.01061761),
  DSP16_Q(0.00738448),
  DSP16_Q(-0.00531892),
  DSP16_Q(0.00386831),
  DSP16_Q(-0.00279414),
  DSP16_Q(0.00197708),
  DSP16_Q(-0.00135065),
  DSP16_Q(0.00087428),
  DSP16_Q(-0.00052100),
  DSP16_Q(0.00027127),
  DSP16_Q(-0.00010971),
  DSP16_Q(0.00002328),
  DSP16_Q(0.00000025),
  DSP16_Q(-0.00003661),
  DSP16_Q(0.00014287),
  DSP16_Q(-0.00033175),
  DSP16_Q(0.00061755),
  DSP16_Q(-0.00101732),
  DSP16_Q(0.00155307),
  DSP16_Q(-0.00225564),
  DSP16_Q(0.00317222),
  DSP16_Q(-0.00438138),
  DSP16_Q(0.00602681),
  DSP16_Q(-0.00840251),
  DSP16_Q(0.01221425),
  DSP16_Q(-0.01966455),
  DSP16_Q(0.04274484),
  DSP16_Q(0.40203800),
  DSP16_Q(-0.03504462),
  DSP16_Q(0.01769421),
  DSP16_Q(-0.01130005),
  DSP16_Q(0.00786174),
  DSP16_Q(-0.00566339),
  DSP16_Q(0.00411884),
  DSP16_Q(-0.00297484),
  DSP16_Q(0.00210459),
  DSP16_Q(-0.00143737),
  DSP16_Q(0.00093002),
  DSP16_Q(-0.00055386),
  DSP16_Q(0.00028806),
  DSP16_Q(-0.00011624),
  DSP16_Q(0.00002448),
  DSP16_Q(0.00000030),
  DSP16_Q(-0.00003935),
  DSP16_Q(0.00015274),
  DSP16_Q(-0.00035399),
  DSP16_Q(0.00065829),
  DSP16_Q(-0.00108380),
  DSP16_Q(0.00165392),
  DSP16_Q(-0.00240152),
  DSP16_Q(0.00337684),
  DSP16_Q(-0.00466368),
  DSP16_Q(0.00641527),
  DSP16_Q(-0.00894550),
  DSP16_Q(0.01300872),
  DSP16_Q(-0.02096431),
  DSP16_Q(0.04573058),
  DSP16_Q(0.40120121),
  DSP16_Q(-0.03701189),
  DSP16_Q(0.01873548),
  DSP16_Q(-0.01197475),
  DSP16_Q(0.00833393),
  DSP16_Q(-0.00600428),
  DSP16_Q(0.00436678),
  DSP16_Q(-0.00315364),
  DSP16_Q(0.00223069),
  DSP16_Q(-0.00152308),
  DSP16_Q(0.00098507),
  DSP16_Q(-0.00058626),
  DSP16_Q(0.00030458),
  DSP16_Q(-0.00012263),
  DSP16_Q(0.00002564),
  DSP16_Q(0.00000036),
  DSP16_Q(-0.00004214),
  DSP16_Q(0.00016267),
  DSP16_Q(-0.00037627),
  DSP16_Q(0.00069905),
  DSP16_Q(-0.00115022),
  DSP16_Q(0.00175462),
  DSP16_Q(-0.00254710),
  DSP16_Q(0.00358099),
  DSP16_Q(-0.00494528),
  DSP16_Q(0.00680280),
  DSP16_Q(-0.00948736),
  DSP16_Q(0.01380221),
  DSP16_Q(-0.02226519),
  DSP16_Q(0.04874110),
  DSP16_Q(0.40031326),
  DSP16_Q(-0.03894212),
  DSP16_Q(0.01976272),
  DSP16_Q(-0.01264151),
  DSP16_Q(0.00880088),
  DSP16_Q(-0.00634149),
  DSP16_Q(0.00461203),
  DSP16_Q(-0.00333046),
  DSP16_Q(0.00235536),
  DSP16_Q(-0.00160776),
  DSP16_Q(0.00103941),
  DSP16_Q(-0.00061820),
  DSP16_Q(0.00032081),
  DSP16_Q(-0.00012887),
  DSP16_Q(0.00002674),
  DSP16_Q(0.00000043),
  DSP16_Q(-0.00004496),
  DSP16_Q(0.00017265),
  DSP16_Q(-0.00039860),
  DSP16_Q(0.00073980),
  DSP16_Q(-0.00121657),
  DSP16_Q(0.00185513),
  DSP16_Q(-0.00269233),
  DSP16_Q(0.00378459),
  DSP16_Q(-0.00522608),
  DSP16_Q(0.00718925),
  DSP16_Q(-0.01002789),
  DSP16_Q(0.01459441),
  DSP16_Q(-0.02356671),
  DSP16_Q(0.05177587),
  DSP16_Q(0.39937438),
  DSP16_Q(-0.04083512),
  DSP16_Q(0.02077565),
  DSP16_Q(-0.01330011),
  DSP16_Q(0.00926244),
  DSP16_Q(-0.00667488),
  DSP16_Q(0.00485450),
  DSP16_Q(-0.00350525),
  DSP16_Q(0.00247854),
  DSP16_Q(-0.00169138),
  DSP16_Q(0.00109302),
  DSP16_Q(-0.00064966),
  DSP16_Q(0.00033676),
  DSP16_Q(-0.00013496),
  DSP16_Q(0.00002780),
  DSP16_Q(0.00000050),
  DSP16_Q(-0.00004783),
  DSP16_Q(0.00018268),
  DSP16_Q(-0.00042096),
  DSP16_Q(0.00078053),
  DSP16_Q(-0.00128280),
  DSP16_Q(0.00195539),
  DSP16_Q(-0.00283714),
  DSP16_Q(0.00398754),
  DSP16_Q(-0.00550595),
  DSP16_Q(0.00757445),
  DSP16_Q(-0.01056687),
  DSP16_Q(0.01538502),
  DSP16_Q(-0.02486840),
  DSP16_Q(0.05483434),
  DSP16_Q(0.39838477),
  DSP16_Q(-0.04269068),
  DSP16_Q(0.02177397),
  DSP16_Q(-0.01395034),
  DSP16_Q(0.00971845),
  DSP16_Q(-0.00700435),
  DSP16_Q(0.00509412),
  DSP16_Q(-0.00367795),
  DSP16_Q(0.00260020),
  DSP16_Q(-0.00177391),
  DSP16_Q(0.00114587),
  DSP16_Q(-0.00068063),
  DSP16_Q(0.00035242),
  DSP16_Q(-0.00014091),
  DSP16_Q(0.00002880),
  DSP16_Q(0.00000059),
  DSP16_Q(-0.00005073),
  DSP16_Q(0.00019276),
  DSP16_Q(-0.00044334),
  DSP16_Q(0.00082123),
  DSP16_Q(-0.00134891),
  DSP16_Q(0.00205539),
  DSP16_Q(-0.00298148),
  DSP16_Q(0.00418977),
  DSP16_Q(-0.00578479),
  DSP16_Q(0.00795825),
  DSP16_Q(-0.01110408),
  DSP16_Q(0.01617373),
  DSP16_Q(-0.02616977),
  DSP16_Q(0.05791598),
  DSP16_Q(0.39734468),
  DSP16_Q(-0.04450865),
  DSP16_Q(0.02275742),
  DSP16_Q(-0.01459199),
  DSP16_Q(0.01016876),
  DSP16_Q(-0.00732978),
  DSP16_Q(0.00533081),
  DSP16_Q(-0.00384849),
  DSP16_Q(0.00272029),
  DSP16_Q(-0.00185533),
  DSP16_Q(0.00119797),
  DSP16_Q(-0.00071111),
  DSP16_Q(0.00036779),
  DSP16_Q(-0.00014671),
  DSP16_Q(0.00002976),
  DSP16_Q(0.00000068),
  DSP16_Q(-0.00005367),
  DSP16_Q(0.00020288),
  DSP16_Q(-0.00046573),
  DSP16_Q(0.00086188),
  DSP16_Q(-0.00141485),
  DSP16_Q(0.00215506),
  DSP16_Q(-0.00312529),
  DSP16_Q(0.00439119),
  DSP16_Q(-0.00606249),
  DSP16_Q(0.00834050),
  DSP16_Q(-0.01163930),
  DSP16_Q(0.01696022),
  DSP16_Q(-0.02747035),
  DSP16_Q(0.06102022),
  DSP16_Q(0.39625434),
  DSP16_Q(-0.04628885),
  DSP16_Q(0.02372572),
  DSP16_Q(-0.01522486),
  DSP16_Q(0.01061323),
  DSP16_Q(-0.00765107),
  DSP16_Q(0.00556447),
  DSP16_Q(-0.00401682),
  DSP16_Q(0.00283878),
  DSP16_Q(-0.00193560),
  DSP16_Q(0.00124927),
  DSP16_Q(-0.00074108),
  DSP16_Q(0.00038286),
  DSP16_Q(-0.00015236),
  DSP16_Q(0.00003067),
  DSP16_Q(0.00000078),
  DSP16_Q(-0.00005665),
  DSP16_Q(0.00021303),
  DSP16_Q(-0.00048813),
  DSP16_Q(0.00090246),
  DSP16_Q(-0.00148061),
  DSP16_Q(0.00225437),
  DSP16_Q(-0.00326851),
  DSP16_Q(0.00459173),
  DSP16_Q(-0.00633892),
  DSP16_Q(0.00872105),
  DSP16_Q(-0.01217233),
  DSP16_Q(0.01774419),
  DSP16_Q(-0.02876965),
  DSP16_Q(0.06414650),
  DSP16_Q(0.39511402),
  DSP16_Q(-0.04803112),
  DSP16_Q(0.02467861),
  DSP16_Q(-0.01584875),
  DSP16_Q(0.01105170),
  DSP16_Q(-0.00796811),
  DSP16_Q(0.00579504),
  DSP16_Q(-0.00418288),
  DSP16_Q(0.00295562),
  DSP16_Q(-0.00201471),
  DSP16_Q(0.00129979),
  DSP16_Q(-0.00077053),
  DSP16_Q(0.00039762),
  DSP16_Q(-0.00015787),
  DSP16_Q(0.00003153),
  DSP16_Q(0.00000088),
  DSP16_Q(-0.00005967),
  DSP16_Q(0.00022322),
  DSP16_Q(-0.00051052),
  DSP16_Q(0.00094295),
  DSP16_Q(-0.00154615),
  DSP16_Q(0.00235329),
  DSP16_Q(-0.00341108),
  DSP16_Q(0.00479129),
  DSP16_Q(-0.00661398),
  DSP16_Q(0.00909973),
  DSP16_Q(-0.01270295),
  DSP16_Q(0.01852532),
  DSP16_Q(-0.03006718),
  DSP16_Q(0.06729426),
  DSP16_Q(0.39392397),
  DSP16_Q(-0.04973532),
  DSP16_Q(0.02561584),
  DSP16_Q(-0.01646346),
  DSP16_Q(0.01148403),
  DSP16_Q(-0.00828078),
  DSP16_Q(0.00602244),
  DSP16_Q(-0.00434662),
  DSP16_Q(0.00307077),
  DSP16_Q(-0.00209263),
  DSP16_Q(0.00134948),
  DSP16_Q(-0.00079947),
  DSP16_Q(0.00041209),
  DSP16_Q(-0.00016322),
  DSP16_Q(0.00003234),
  DSP16_Q(0.00000100),
  DSP16_Q(-0.00006272),
  DSP16_Q(0.00023343),
  DSP16_Q(-0.00053289),
  DSP16_Q(0.00098334),
  DSP16_Q(-0.00161145),
  DSP16_Q(0.00245176),
  DSP16_Q(-0.00355295),
  DSP16_Q(0.00498980),
  DSP16_Q(-0.00688756),
  DSP16_Q(0.00947640),
  DSP16_Q(-0.01323094),
  DSP16_Q(0.01930330),
  DSP16_Q(-0.03136245),
  DSP16_Q(0.07046292),
  DSP16_Q(0.39268447),
  DSP16_Q(-0.05140132),
  DSP16_Q(0.02653715),
  DSP16_Q(-0.01706881),
  DSP16_Q(0.01191008),
  DSP16_Q(-0.00858900),
  DSP16_Q(0.00624658),
  DSP16_Q(-0.00450798),
  DSP16_Q(0.00318420),
  DSP16_Q(-0.00216932),
  DSP16_Q(0.00139835),
  DSP16_Q(-0.00082787),
  DSP16_Q(0.00042624),
  DSP16_Q(-0.00016843),
  DSP16_Q(0.00003310),
  DSP16_Q(0.00000113),
  DSP16_Q(-0.00006580),
  DSP16_Q(0.00024367),
  DSP16_Q(-0.00055524),
  DSP16_Q(0.00102361),
  DSP16_Q(-0.00167648),
  DSP16_Q(0.00254975),
  DSP16_Q(-0.00369404),
  DSP16_Q(0.00518718),
  DSP16_Q(-0.00715953),
  DSP16_Q(0.00985089),
  DSP16_Q(-0.01375609),
  DSP16_Q(0.02007782),
  DSP16_Q(-0.03265497),
  DSP16_Q(0.07365189),
  DSP16_Q(0.39139582),
  DSP16_Q(-0.05302900),
  DSP16_Q(0.02744231),
  DSP16_Q(-0.01766460),
  DSP16_Q(0.01232971),
  DSP16_Q(-0.00889265),
  DSP16_Q(0.00646740),
  DSP16_Q(-0.00466690),
  DSP16_Q(0.00329588),
  DSP16_Q(-0.00224478),
  DSP16_Q(0.00144638),
  DSP16_Q(-0.00085573),
  DSP16_Q(0.00044008),
  DSP16_Q(-0.00017348),
  DSP16_Q(0.00003382),
  DSP16_Q(0.00000126),
  DSP16_Q(-0.00006891),
  DSP16_Q(0.00025393),
  DSP16_Q(-0.00057756),
  DSP16_Q(0.00106374),
  DSP16_Q(-0.00174121),
  DSP16_Q(0.00264721),
  DSP16_Q(-0.00383431),
  DSP16_Q(0.00538334),
  DSP16_Q(-0.00742980),
  DSP16_Q(0.01022306),
  DSP16_Q(-0.01427817),
  DSP16_Q(0.02084856),
  DSP16_Q(-0.03394423),
  DSP16_Q(0.07686058),
  DSP16_Q(0.39005832),
  DSP16_Q(-0.05461823),
  DSP16_Q(0.02833108),
  DSP16_Q(-0.01825067),
  DSP16_Q(0.01274280),
  DSP16_Q(-0.00919163),
  DSP16_Q(0.00668482),
  DSP16_Q(-0.00482335),
  DSP16_Q(0.00340576),
  DSP16_Q(-0.00231896),
  DSP16_Q(0.00149354),
  DSP16_Q(-0.00088305),
  DSP16_Q(0.00045361),
  DSP16_Q(-0.00017838),
  DSP16_Q(0.00003449),
  DSP16_Q(0.00000141),
  DSP16_Q(-0.00007206),
  DSP16_Q(0.00026421),
  DSP16_Q(-0.00059983),
  DSP16_Q(0.00110371),
  DSP16_Q(-0.00180561),
  DSP16_Q(0.00274411),
  DSP16_Q(-0.00397370),
  DSP16_Q(0.00557821),
  DSP16_Q(-0.00769824),
  DSP16_Q(0.01059275),
  DSP16_Q(-0.01479699),
  DSP16_Q(0.02161521),
  DSP16_Q(-0.03522975),
  DSP16_Q(0.08008839),
  DSP16_Q(0.38867228),
  DSP16_Q(-0.05616893),
  DSP16_Q(0.02920324),
  DSP16_Q(-0.01882683),
  DSP16_Q(0.01314920),
  DSP16_Q(-0.00948585),
  DSP16_Q(0.00689877),
  DSP16_Q(-0.00497726),
  DSP16_Q(0.00351380),
  DSP16_Q(-0.00239186),
  DSP16_Q(0.00153984),
  DSP16_Q(-0.00090981),
  DSP16_Q(0.00046681),
  DSP16_Q(-0.00018313),
  DSP16_Q(0.00003512),
  DSP16_Q(0.00000156),
  DSP16_Q(-0.00007523),
  DSP16_Q(0.00027449),
  DSP16_Q(-0.00062205),
  DSP16_Q(0.00114351),
  DSP16_Q(-0.00186965),
  DSP16_Q(0.00284040),
  DSP16_Q(-0.00411214),
  DSP16_Q(0.00577169),
  DSP16_Q(-0.00796475),
  DSP16_Q(0.01095981),
  DSP16_Q(-0.01531231),
  DSP16_Q(0.02237745),
  DSP16_Q(-0.03651101),
  DSP16_Q(0.08333471),
  DSP16_Q(0.38723802),
  DSP16_Q(-0.05768099),
  DSP16_Q(0.03005857),
  DSP16_Q(-0.01939290),
  DSP16_Q(0.01354878),
  DSP16_Q(-0.00977522),
  DSP16_Q(0.00710918),
  DSP16_Q(-0.00512859),
  DSP16_Q(0.00361999),
  DSP16_Q(-0.00246345),
  DSP16_Q(0.00158525),
  DSP16_Q(-0.00093601),
  DSP16_Q(0.00047970),
  DSP16_Q(-0.00018773),
  DSP16_Q(0.00003570),
  DSP16_Q(0.00000173),
  DSP16_Q(-0.00007844),
  DSP16_Q(0.00028478),
  DSP16_Q(-0.00064420),
  DSP16_Q(0.00118312),
  DSP16_Q(-0.00193332),
  DSP16_Q(0.00293604),
  DSP16_Q(-0.00424957),
  DSP16_Q(0.00596371),
  DSP16_Q(-0.00822921),
  DSP16_Q(0.01132408),
  DSP16_Q(-0.01582393),
  DSP16_Q(0.02313497),
  DSP16_Q(-0.03778753),
  DSP16_Q(0.08659894),
  DSP16_Q(0.38575587),
  DSP16_Q(-0.05915435),
  DSP16_Q(0.03089685),
  DSP16_Q(-0.01994873),
  DSP16_Q(0.01394143),
  DSP16_Q(-0.01005963),
  DSP16_Q(0.00731599),
  DSP16_Q(-0.00527728),
  DSP16_Q(0.00372427),
  DSP16_Q(-0.00253370),
  DSP16_Q(0.00162976),
  DSP16_Q(-0.00096164),
  DSP16_Q(0.00049226),
  DSP16_Q(-0.00019217),
  DSP16_Q(0.00003624),
  DSP16_Q(0.00000191),
  DSP16_Q(-0.00008166),
  DSP16_Q(0.00029508),
  DSP16_Q(-0.00066628),
  DSP16_Q(0.00122252),
  DSP16_Q(-0.00199658),
  DSP16_Q(0.00303099),
  DSP16_Q(-0.00438595),
  DSP16_Q(0.00615418),
  DSP16_Q(-0.00849151),
  DSP16_Q(0.01168541),
  DSP16_Q(-0.01633164),
  DSP16_Q(0.02388746),
  DSP16_Q(-0.03905878),
  DSP16_Q(0.08988045),
  DSP16_Q(0.38422619),
  DSP16_Q(-0.06058892),
  DSP16_Q(0.03171788),
  DSP16_Q(-0.02049415),
  DSP16_Q(0.01432702),
  DSP16_Q(-0.01033901),
  DSP16_Q(0.00751913),
  DSP16_Q(-0.00542330),
  DSP16_Q(0.00382663),
  DSP16_Q(-0.00260260),
  DSP16_Q(0.00167335),
  DSP16_Q(-0.00098670),
  DSP16_Q(0.00050450),
  DSP16_Q(-0.00019646),
  DSP16_Q(0.00003674),
  DSP16_Q(0.00000210),
  DSP16_Q(-0.00008492),
  DSP16_Q(0.00030536),
  DSP16_Q(-0.00068827),
  DSP16_Q(0.00126170),
  DSP16_Q(-0.00205940),
  DSP16_Q(0.00312521),
  DSP16_Q(-0.00452120),
  DSP16_Q(0.00634303),
  DSP16_Q(-0.00875154),
  DSP16_Q(0.01204365),
  DSP16_Q(-0.01683521),
  DSP16_Q(0.02463461),
  DSP16_Q(-0.04032428),
  DSP16_Q(0.09317862),
  DSP16_Q(0.38264934),
  DSP16_Q(-0.06198466),
  DSP16_Q(0.03252146),
  DSP16_Q(-0.02102900),
  DSP16_Q(0.01470543),
  DSP16_Q(-0.01061326),
  DSP16_Q(0.00771852),
  DSP16_Q(-0.00556658),
  DSP16_Q(0.00392702),
  DSP16_Q(-0.00267012),
  DSP16_Q(0.00171603),
  DSP16_Q(-0.00101118),
  DSP16_Q(0.00051641),
  DSP16_Q(-0.00020060),
  DSP16_Q(0.00003719),
  DSP16_Q(0.00000230),
  DSP16_Q(-0.00008820),
  DSP16_Q(0.00031564),
  DSP16_Q(-0.00071017),
  DSP16_Q(0.00130063),
  DSP16_Q(-0.00212175),
  DSP16_Q(0.00321866),
  DSP16_Q(-0.00465528),
  DSP16_Q(0.00653018),
  DSP16_Q(-0.00900919),
  DSP16_Q(0.01239865),
  DSP16_Q(-0.01733445),
  DSP16_Q(0.02537609),
  DSP16_Q(-0.04158350),
  DSP16_Q(0.09649281),
  DSP16_Q(0.38102566),
  DSP16_Q(-0.06334151),
  DSP16_Q(0.03330741),
  DSP16_Q(-0.02155313),
  DSP16_Q(0.01507654),
  DSP16_Q(-0.01088229),
  DSP16_Q(0.00791412),
  DSP16_Q(-0.00570710),
  DSP16_Q(0.00402542),
  DSP16_Q(-0.00273624),
  DSP16_Q(0.00175777),
  DSP16_Q(-0.00103507),
  DSP16_Q(0.00052799),
  DSP16_Q(-0.00020459),
  DSP16_Q(0.00003760),
  DSP16_Q(0.00000251),
  DSP16_Q(-0.00009149),
  DSP16_Q(0.00032591),
  DSP16_Q(-0.00073196),
  DSP16_Q(0.00133930),
  DSP16_Q(-0.00218361),
  DSP16_Q(0.00331130),
  DSP16_Q(-0.00478812),
  DSP16_Q(0.00671554),
  DSP16_Q(-0.00926435),
  DSP16_Q(0.01275025),
  DSP16_Q(-0.01782913),
  DSP16_Q(0.02611161),
  DSP16_Q(-0.04283594),
  DSP16_Q(0.09982238),
  DSP16_Q(0.37935556),
  DSP16_Q(-0.06465943),
  DSP16_Q(0.03407554),
  DSP16_Q(-0.02206639),
  DSP16_Q(0.01544025),
  DSP16_Q(-0.01114602),
  DSP16_Q(0.00810586),
  DSP16_Q(-0.00584481),
  DSP16_Q(0.00412179),
  DSP16_Q(-0.00280096),
  DSP16_Q(0.00179856),
  DSP16_Q(-0.00105837),
  DSP16_Q(0.00053924),
  DSP16_Q(-0.00020842),
  DSP16_Q(0.00003796),
  DSP16_Q(0.00000273),
  DSP16_Q(-0.00009481),
  DSP16_Q(0.00033615),
  DSP16_Q(-0.00075364),
  DSP16_Q(0.00137770),
  DSP16_Q(-0.00224495),
  DSP16_Q(0.00340308),
  DSP16_Q(-0.00491966),
  DSP16_Q(0.00689903),
  DSP16_Q(-0.00951691),
  DSP16_Q(0.01309831),
  DSP16_Q(-0.01831904),
  DSP16_Q(0.02684084),
  DSP16_Q(-0.04408109),
  DSP16_Q(0.10316670),
  DSP16_Q(0.37763941),
  DSP16_Q(-0.06593840),
  DSP16_Q(0.03482567),
  DSP16_Q(-0.02256863),
  DSP16_Q(0.01579644),
  DSP16_Q(-0.01140437),
  DSP16_Q(0.00829367),
  DSP16_Q(-0.00597965),
  DSP16_Q(0.00421612),
  DSP16_Q(-0.00286424),
  DSP16_Q(0.00183840),
  DSP16_Q(-0.00108108),
  DSP16_Q(0.00055015),
  DSP16_Q(-0.00021211),
  DSP16_Q(0.00003829),
  DSP16_Q(0.00000296),
  DSP16_Q(-0.00009815),
  DSP16_Q(0.00034637),
  DSP16_Q(-0.00077519),
  DSP16_Q(0.00141579),
  DSP16_Q(-0.00230574),
  DSP16_Q(0.00349397),
  DSP16_Q(-0.00504985),
  DSP16_Q(0.00708058),
  DSP16_Q(-0.00976676),
  DSP16_Q(0.01344267),
  DSP16_Q(-0.01880398),
  DSP16_Q(0.02756347),
  DSP16_Q(-0.04531844),
  DSP16_Q(0.10652511),
  DSP16_Q(0.37587761),
  DSP16_Q(-0.06717841),
  DSP16_Q(0.03555765),
  DSP16_Q(-0.02305972),
  DSP16_Q(0.01614501),
  DSP16_Q(-0.01165727),
  DSP16_Q(0.00847751),
  DSP16_Q(-0.00611160),
  DSP16_Q(0.00430836),
  DSP16_Q(-0.00292606),
  DSP16_Q(0.00187726),
  DSP16_Q(-0.00110317),
  DSP16_Q(0.00056073),
  DSP16_Q(-0.00021564),
  DSP16_Q(0.00003858),
  DSP16_Q(0.00000321),
  DSP16_Q(-0.00010151),
  DSP16_Q(0.00035657),
  DSP16_Q(-0.00079661),
  DSP16_Q(0.00145357),
  DSP16_Q(-0.00236596),
  DSP16_Q(0.00358393),
  DSP16_Q(-0.00517864),
  DSP16_Q(0.00726011),
  DSP16_Q(-0.01001379),
  DSP16_Q(0.01378319),
  DSP16_Q(-0.01928374),
  DSP16_Q(0.02827920),
  DSP16_Q(-0.04654748),
  DSP16_Q(0.10989695),
  DSP16_Q(0.37407058),
  DSP16_Q(-0.06837945),
  DSP16_Q(0.03627130),
  DSP16_Q(-0.02353952),
  DSP16_Q(0.01648585),
  DSP16_Q(-0.01190463),
  DSP16_Q(0.00865732),
  DSP16_Q(-0.00624062),
  DSP16_Q(0.00439850),
  DSP16_Q(-0.00298643),
  DSP16_Q(0.00191515),
  DSP16_Q(-0.00112467),
  DSP16_Q(0.00057097),
  DSP16_Q(-0.00021901),
  DSP16_Q(0.00003882),
  DSP16_Q(0.00000347),
  DSP16_Q(-0.00010488),
  DSP16_Q(0.00036673),
  DSP16_Q(-0.00081788),
  DSP16_Q(0.00149103),
  DSP16_Q(-0.00242557),
  DSP16_Q(0.00367291),
  DSP16_Q(-0.00530595),
  DSP16_Q(0.00743753),
  DSP16_Q(-0.01025790),
  DSP16_Q(0.01411972),
  DSP16_Q(-0.01975810),
  DSP16_Q(0.02898772),
  DSP16_Q(-0.04776768),
  DSP16_Q(0.11328157),
  DSP16_Q(0.37221873),
  DSP16_Q(-0.06954152),
  DSP16_Q(0.03696648),
  DSP16_Q(-0.02400791),
  DSP16_Q(0.01681887),
  DSP16_Q(-0.01214638),
  DSP16_Q(0.00883304),
  DSP16_Q(-0.00636666),
  DSP16_Q(0.00448651),
  DSP16_Q(-0.00304530),
  DSP16_Q(0.00195206),
  DSP16_Q(-0.00114555),
  DSP16_Q(0.00058087),
  DSP16_Q(-0.00022224),
  DSP16_Q(0.00003903),
  DSP16_Q(0.00000374),
  DSP16_Q(-0.00010827),
  DSP16_Q(0.00037685),
  DSP16_Q(-0.00083900),
  DSP16_Q(0.00152813),
  DSP16_Q(-0.00248456),
  DSP16_Q(0.00376087),
  DSP16_Q(-0.00543175),
  DSP16_Q(0.00761277),
  DSP16_Q(-0.01049898),
  DSP16_Q(0.01445211),
  DSP16_Q(-0.02022686),
  DSP16_Q(0.02968871),
  DSP16_Q(-0.04897854),
  DSP16_Q(0.11667829),
  DSP16_Q(0.37032249),
  DSP16_Q(-0.07066463),
  DSP16_Q(0.03764304),
  DSP16_Q(-0.02446476),
  DSP16_Q(0.01714397),
  DSP16_Q(-0.01238245),
  DSP16_Q(0.00900461),
  DSP16_Q(-0.00648968),
  DSP16_Q(0.00457236),
  DSP16_Q(-0.00310268),
  DSP16_Q(0.00198796),
  DSP16_Q(-0.00116581),
  DSP16_Q(0.00059043),
  DSP16_Q(-0.00022532),
  DSP16_Q(0.00003920),
  DSP16_Q(0.00000402),
  DSP16_Q(-0.00011166),
  DSP16_Q(0.00038692),
  DSP16_Q(-0.00085994),
  DSP16_Q(0.00156486),
  DSP16_Q(-0.00254289),
  DSP16_Q(0.00384778),
  DSP16_Q(-0.00555596),
  DSP16_Q(0.00778575),
  DSP16_Q(-0.01073691),
  DSP16_Q(0.01478021),
  DSP16_Q(-0.02068982),
  DSP16_Q(0.03038188),
  DSP16_Q(-0.05017955),
  DSP16_Q(0.12008644),
  DSP16_Q(0.36838231),
  DSP16_Q(-0.07174882),
  DSP16_Q(0.03830085),
  DSP16_Q(-0.02490994),
  DSP16_Q(0.01746105),
  DSP16_Q(-0.01261277),
  DSP16_Q(0.00917200),
  DSP16_Q(-0.00660966),
  DSP16_Q(0.00465603),
  DSP16_Q(-0.00315854),
  DSP16_Q(0.00202286),
  DSP16_Q(-0.00118546),
  DSP16_Q(0.00059965),
  DSP16_Q(-0.00022824),
  DSP16_Q(0.00003934),
  DSP16_Q(0.00000431),
  DSP16_Q(-0.00011507),
  DSP16_Q(0.00039695),
  DSP16_Q(-0.00088072),
  DSP16_Q(0.00160121),
  DSP16_Q(-0.00260053),
  DSP16_Q(0.00393360),
  DSP16_Q(-0.00567854),
  DSP16_Q(0.00795639),
  DSP16_Q(-0.01097161),
  DSP16_Q(0.01510389),
  DSP16_Q(-0.02114677),
  DSP16_Q(0.03106690),
  DSP16_Q(-0.05137018),
  DSP16_Q(0.12350536),
  DSP16_Q(0.36639864),
  DSP16_Q(-0.07279413),
  DSP16_Q(0.03893977),
  DSP16_Q(-0.02534335),
  DSP16_Q(0.01777004),
  DSP16_Q(-0.01283727),
  DSP16_Q(0.00933515),
  DSP16_Q(-0.00672656),
  DSP16_Q(0.00473749),
  DSP16_Q(-0.00321287),
  DSP16_Q(0.00205675),
  DSP16_Q(-0.00120448),
  DSP16_Q(0.00060853),
  DSP16_Q(-0.00023102),
  DSP16_Q(0.00003944),
  DSP16_Q(0.00000462),
  DSP16_Q(-0.00011849),
  DSP16_Q(0.00040693),
  DSP16_Q(-0.00090130),
  DSP16_Q(0.00163716),
  DSP16_Q(-0.00265746),
  DSP16_Q(0.00401828),
  DSP16_Q(-0.00579943),
  DSP16_Q(0.00812462),
  DSP16_Q(-0.01120296),
  DSP16_Q(0.01542300),
  DSP16_Q(-0.02159750),
  DSP16_Q(0.03174349),
  DSP16_Q(-0.05254993),
  DSP16_Q(0.12693434),
  DSP16_Q(0.36437193),
  DSP16_Q(-0.07380059),
  DSP16_Q(0.03955968),
  DSP16_Q(-0.02576487),
  DSP16_Q(0.01807084),
  DSP16_Q(-0.01305590),
  DSP16_Q(0.00949401),
  DSP16_Q(-0.00684034),
  DSP16_Q(0.00481673),
  DSP16_Q(-0.00326565),
  DSP16_Q(0.00208962),
  DSP16_Q(-0.00122287),
  DSP16_Q(0.00061707),
  DSP16_Q(-0.00023365),
  DSP16_Q(0.00003950),
  DSP16_Q(0.00000494),
  DSP16_Q(-0.00012191),
  DSP16_Q(0.00041684),
  DSP16_Q(-0.00092169),
  DSP16_Q(0.00167270),
  DSP16_Q(-0.00271365),
  DSP16_Q(0.00410179),
  DSP16_Q(-0.00591857),
  DSP16_Q(0.00829036),
  DSP16_Q(-0.01143085),
  DSP16_Q(0.01573739),
  DSP16_Q(-0.02204183),
  DSP16_Q(0.03241134),
  DSP16_Q(-0.05371828),
  DSP16_Q(0.13037271),
  DSP16_Q(0.36230265),
  DSP16_Q(-0.07476826),
  DSP16_Q(0.04016048),
  DSP16_Q(-0.02617441),
  DSP16_Q(0.01836337),
  DSP16_Q(-0.01326858),
  DSP16_Q(0.00964854),
  DSP16_Q(-0.00695098),
  DSP16_Q(0.00489372),
  DSP16_Q(-0.00331688),
  DSP16_Q(0.00212146),
  DSP16_Q(-0.00124063),
  DSP16_Q(0.00062527),
  DSP16_Q(-0.00023612),
  DSP16_Q(0.00003953),
  DSP16_Q(0.00000527),
  DSP16_Q(-0.00012534),
  DSP16_Q(0.00042669),
  DSP16_Q(-0.00094187),
  DSP16_Q(0.00170779),
  DSP16_Q(-0.00276908),
  DSP16_Q(0.00418408),
  DSP16_Q(-0.00603592),
  DSP16_Q(0.00845354),
  DSP16_Q(-0.01165519),
  DSP16_Q(0.01604692),
  DSP16_Q(-0.02247954),
  DSP16_Q(0.03307014),
  DSP16_Q(-0.05487471),
  DSP16_Q(0.13381978),
  DSP16_Q(0.36019129),
  DSP16_Q(-0.07569722),
  DSP16_Q(0.04074204),
  DSP16_Q(-0.02657185),
  DSP16_Q(0.01864756),
  DSP16_Q(-0.01347526),
  DSP16_Q(0.00979870),
  DSP16_Q(-0.00705844),
  DSP16_Q(0.00496844),
  DSP16_Q(-0.00336654),
  DSP16_Q(0.00215226),
  DSP16_Q(-0.00125776),
  DSP16_Q(0.00063313),
  DSP16_Q(-0.00023846),
  DSP16_Q(0.00003952),
  DSP16_Q(0.00000562),
  DSP16_Q(-0.00012877),
  DSP16_Q(0.00043647),
  DSP16_Q(-0.00096183),
  DSP16_Q(0.00174243),
  DSP16_Q(-0.00282371),
  DSP16_Q(0.00426513),
  DSP16_Q(-0.00615140),
  DSP16_Q(0.00861408),
  DSP16_Q(-0.01187588),
  DSP16_Q(0.01635146),
  DSP16_Q(-0.02291043),
  DSP16_Q(0.03371960),
  DSP16_Q(-0.05601871),
  DSP16_Q(0.13727484),
  DSP16_Q(0.35803833),
  DSP16_Q(-0.07658753),
  DSP16_Q(0.04130427),
  DSP16_Q(-0.02695711),
  DSP16_Q(0.01892332),
  DSP16_Q(-0.01367589),
  DSP16_Q(0.00994445),
  DSP16_Q(-0.00716270),
  DSP16_Q(0.00504088),
  DSP16_Q(-0.00341462),
  DSP16_Q(0.00218203),
  DSP16_Q(-0.00127426),
  DSP16_Q(0.00064064),
  DSP16_Q(-0.00024064),
  DSP16_Q(0.00003949),
  DSP16_Q(0.00000597),
  DSP16_Q(-0.00013220),
  DSP16_Q(0.00044617),
  DSP16_Q(-0.00098157),
  DSP16_Q(0.00177661),
  DSP16_Q(-0.00287753),
  DSP16_Q(0.00434489),
  DSP16_Q(-0.00626498),
  DSP16_Q(0.00877191),
  DSP16_Q(-0.01209281),
  DSP16_Q(0.01665086),
  DSP16_Q(-0.02333432),
  DSP16_Q(0.03435942),
  DSP16_Q(-0.05714976),
  DSP16_Q(0.14073721),
  DSP16_Q(0.35584427),
  DSP16_Q(-0.07743929),
  DSP16_Q(0.04184709),
  DSP16_Q(-0.02733010),
  DSP16_Q(0.01919059),
  DSP16_Q(-0.01387040),
  DSP16_Q(0.01008574),
  DSP16_Q(-0.00726372),
  DSP16_Q(0.00511101),
  DSP16_Q(-0.00346111),
  DSP16_Q(0.00221075),
  DSP16_Q(-0.00129012),
  DSP16_Q(0.00064781),
  DSP16_Q(-0.00024268),
  DSP16_Q(0.00003942),
  DSP16_Q(0.00000634),
  DSP16_Q(-0.00013563),
  DSP16_Q(0.00045579),
  DSP16_Q(-0.00100107),
  DSP16_Q(0.00181029),
  DSP16_Q(-0.00293050),
  DSP16_Q(0.00442332),
  DSP16_Q(-0.00637660),
  DSP16_Q(0.00892695),
  DSP16_Q(-0.01230588),
  DSP16_Q(0.01694499),
  DSP16_Q(-0.02375101),
  DSP16_Q(0.03498931),
  DSP16_Q(-0.05826735),
  DSP16_Q(0.14420617),
  DSP16_Q(0.35360961),
  DSP16_Q(-0.07825260),
  DSP16_Q(0.04237039),
  DSP16_Q(-0.02769073),
  DSP16_Q(0.01944930),
  DSP16_Q(-0.01405875),
  DSP16_Q(0.01022254),
  DSP16_Q(-0.00736148),
  DSP16_Q(0.00517881),
  DSP16_Q(-0.00350599),
  DSP16_Q(0.00223841),
  DSP16_Q(-0.00130534),
  DSP16_Q(0.00065463),
  DSP16_Q(-0.00024457),
  DSP16_Q(0.00003932),
  DSP16_Q(0.00000672),
  DSP16_Q(-0.00013905),
  DSP16_Q(0.00046533),
  DSP16_Q(-0.00102031),
  DSP16_Q(0.00184347),
  DSP16_Q(-0.00298261),
  DSP16_Q(0.00450038),
  DSP16_Q(-0.00648621),
  DSP16_Q(0.00907914),
  DSP16_Q(-0.01251500),
  DSP16_Q(0.01723372),
  DSP16_Q(-0.02416030),
  DSP16_Q(0.03560897),
  DSP16_Q(-0.05937098),
  DSP16_Q(0.14768102),
  DSP16_Q(0.35133488),
  DSP16_Q(-0.07902756),
  DSP16_Q(0.04287412),
  DSP16_Q(-0.02803893),
  DSP16_Q(0.01969939),
  DSP16_Q(-0.01424090),
  DSP16_Q(0.01035481),
  DSP16_Q(-0.00745596),
  DSP16_Q(0.00524428),
  DSP16_Q(-0.00354926),
  DSP16_Q(0.00226502),
  DSP16_Q(-0.00131992),
  DSP16_Q(0.00066111),
  DSP16_Q(-0.00024632),
  DSP16_Q(0.00003919),
  DSP16_Q(0.00000711),
  DSP16_Q(-0.00014247),
  DSP16_Q(0.00047478),
  DSP16_Q(-0.00103930),
  DSP16_Q(0.00187613),
  DSP16_Q(-0.00303382),
  DSP16_Q(0.00457605),
  DSP16_Q(-0.00659375),
  DSP16_Q(0.00922840),
  DSP16_Q(-0.01272007),
  DSP16_Q(0.01751690),
  DSP16_Q(-0.02456201),
  DSP16_Q(0.03621810),
  DSP16_Q(-0.06046012),
  DSP16_Q(0.15116105),
  DSP16_Q(0.34902059),
  DSP16_Q(-0.07976429),
  DSP16_Q(0.04335819),
  DSP16_Q(-0.02837461),
  DSP16_Q(0.01994079),
  DSP16_Q(-0.01441678),
  DSP16_Q(0.01048253),
  DSP16_Q(-0.00754714),
  DSP16_Q(0.00530740),
  DSP16_Q(-0.00359092),
  DSP16_Q(0.00229057),
  DSP16_Q(-0.00133385),
  DSP16_Q(0.00066726),
  DSP16_Q(-0.00024793),
  DSP16_Q(0.00003903),
  DSP16_Q(0.00000752),
  DSP16_Q(-0.00014588),
  DSP16_Q(0.00048413),
  DSP16_Q(-0.00105802),
  DSP16_Q(0.00190825),
  DSP16_Q(-0.00308410),
  DSP16_Q(0.00465028),
  DSP16_Q(-0.00669917),
  DSP16_Q(0.00937465),
  DSP16_Q(-0.01292098),
  DSP16_Q(0.01779441),
  DSP16_Q(-0.02495594),
  DSP16_Q(0.03681643),
  DSP16_Q(-0.06153426),
  DSP16_Q(0.15464554),
  DSP16_Q(0.34666729),
  DSP16_Q(-0.08046291),
  DSP16_Q(0.04382255),
  DSP16_Q(-0.02869771),
  DSP16_Q(0.02017345),
  DSP16_Q(-0.01458637),
  DSP16_Q(0.01060565),
  DSP16_Q(-0.00763498),
  DSP16_Q(0.00536815),
  DSP16_Q(-0.00363094),
  DSP16_Q(0.00231505),
  DSP16_Q(-0.00134714),
  DSP16_Q(0.00067306),
  DSP16_Q(-0.00024940),
  DSP16_Q(0.00003884),
  DSP16_Q(0.00000793),
  DSP16_Q(-0.00014929),
  DSP16_Q(0.00049337),
  DSP16_Q(-0.00107646),
  DSP16_Q(0.00193981),
  DSP16_Q(-0.00313344),
  DSP16_Q(0.00472303),
  DSP16_Q(-0.00680243),
  DSP16_Q(0.00951784),
  DSP16_Q(-0.01311766),
  DSP16_Q(0.01806611),
  DSP16_Q(-0.02534191),
  DSP16_Q(0.03740367),
  DSP16_Q(-0.06259291),
  DSP16_Q(0.15813377),
  DSP16_Q(0.34427551),
  DSP16_Q(-0.08112357),
  DSP16_Q(0.04426713),
  DSP16_Q(-0.02900817),
  DSP16_Q(0.02039731),
  DSP16_Q(-0.01474961),
  DSP16_Q(0.01072415),
  DSP16_Q(-0.00771948),
  DSP16_Q(0.00542652),
  DSP16_Q(-0.00366932),
  DSP16_Q(0.00233847),
  DSP16_Q(-0.00135979),
  DSP16_Q(0.00067852),
  DSP16_Q(-0.00025073),
  DSP16_Q(0.00003862),
  DSP16_Q(0.00000836),
  DSP16_Q(-0.00015268),
  DSP16_Q(0.00050251),
  DSP16_Q(-0.00109462),
  DSP16_Q(0.00197080),
  DSP16_Q(-0.00318181),
  DSP16_Q(0.00479427),
  DSP16_Q(-0.00690346),
  DSP16_Q(0.00965790),
  DSP16_Q(-0.01331000),
  DSP16_Q(0.01833188),
  DSP16_Q(-0.02571973),
  DSP16_Q(0.03797952),
  DSP16_Q(-0.06363554),
  DSP16_Q(0.16162503),
  DSP16_Q(0.34184580),
  DSP16_Q(-0.08174642),
  DSP16_Q(0.04469191),
  DSP16_Q(-0.02930592),
  DSP16_Q(0.02061233),
  DSP16_Q(-0.01490648),
  DSP16_Q(0.01083801),
  DSP16_Q(-0.00780061),
  DSP16_Q(0.00548249),
  DSP16_Q(-0.00370607),
  DSP16_Q(0.00236081),
  DSP16_Q(-0.00137180),
  DSP16_Q(0.00068364),
  DSP16_Q(-0.00025191),
  DSP16_Q(0.00003838),
  DSP16_Q(0.00000880),
  DSP16_Q(-0.00015606),
  DSP16_Q(0.00051154),
  DSP16_Q(-0.00111247),
  DSP16_Q(0.00200121),
  DSP16_Q(-0.00322919),
  DSP16_Q(0.00486397),
  DSP16_Q(-0.00700223),
  DSP16_Q(0.00979474),
  DSP16_Q(-0.01349791),
  DSP16_Q(0.01859159),
  DSP16_Q(-0.02608922),
  DSP16_Q(0.03854372),
  DSP16_Q(-0.06466166),
  DSP16_Q(0.16511858),
  DSP16_Q(0.33937872),
  DSP16_Q(-0.08233160),
  DSP16_Q(0.04509682),
  DSP16_Q(-0.02959091),
  DSP16_Q(0.02081846),
  DSP16_Q(-0.01505693),
  DSP16_Q(0.01094719),
  DSP16_Q(-0.00787836),
  DSP16_Q(0.00553606),
  DSP16_Q(-0.00374116),
  DSP16_Q(0.00238208),
  DSP16_Q(-0.00138315),
  DSP16_Q(0.00068842),
  DSP16_Q(-0.00025297),
  DSP16_Q(0.00003812),
  DSP16_Q(0.00000925),
  DSP16_Q(-0.00015942),
  DSP16_Q(0.00052045),
  DSP16_Q(-0.00113001),
  DSP16_Q(0.00203101),
  DSP16_Q(-0.00327554),
  DSP16_Q(0.00493208),
  DSP16_Q(-0.00709868),
  DSP16_Q(0.00992832),
  DSP16_Q(-0.01368130),
  DSP16_Q(0.01884511),
  DSP16_Q(-0.02645021),
  DSP16_Q(0.03909598),
  DSP16_Q(-0.06567076),
  DSP16_Q(0.16861371),
  DSP16_Q(0.33687484),
  DSP16_Q(-0.08287928),
  DSP16_Q(0.04548185),
  DSP16_Q(-0.02986310),
  DSP16_Q(0.02101565),
  DSP16_Q(-0.01520093),
  DSP16_Q(0.01105167),
  DSP16_Q(-0.00795270),
  DSP16_Q(0.00558722),
  DSP16_Q(-0.00377459),
  DSP16_Q(0.00240228),
  DSP16_Q(-0.00139387),
  DSP16_Q(0.00069286),
  DSP16_Q(-0.00025388),
  DSP16_Q(0.00003782),
  DSP16_Q(0.00000972),
  DSP16_Q(-0.00016277),
  DSP16_Q(0.00052923),
  DSP16_Q(-0.00114724),
  DSP16_Q(0.00206019),
  DSP16_Q(-0.00332085),
  DSP16_Q(0.00499858),
  DSP16_Q(-0.00719277),
  DSP16_Q(0.01005856),
  DSP16_Q(-0.01386008),
  DSP16_Q(0.01909231),
  DSP16_Q(-0.02680251),
  DSP16_Q(0.03963603),
  DSP16_Q(-0.06666233),
  DSP16_Q(0.17210968),
  DSP16_Q(0.33433473),
  DSP16_Q(-0.08338964),
  DSP16_Q(0.04584697),
  DSP16_Q(-0.03012243),
  DSP16_Q(0.02120387),
  DSP16_Q(-0.01533846),
  DSP16_Q(0.01115143),
  DSP16_Q(-0.00802362),
  DSP16_Q(0.00563596),
  DSP16_Q(-0.00380637),
  DSP16_Q(0.00242139),
  DSP16_Q(-0.00140394),
  DSP16_Q(0.00069697),
  DSP16_Q(-0.00025466),
  DSP16_Q(0.00003751),
  DSP16_Q(0.00001019),
  DSP16_Q(-0.00016609),
  DSP16_Q(0.00053789),
  DSP16_Q(-0.00116413),
  DSP16_Q(0.00208874),
  DSP16_Q(-0.00336509),
  DSP16_Q(0.00506343),
  DSP16_Q(-0.00728445),
  DSP16_Q(0.01018540),
  DSP16_Q(-0.01403416),
  DSP16_Q(0.01933309),
  DSP16_Q(-0.02714595),
  DSP16_Q(0.04016359),
  DSP16_Q(-0.06763588),
  DSP16_Q(0.17560577),
  DSP16_Q(0.33175898),
  DSP16_Q(-0.08386287),
  DSP16_Q(0.04619215),
  DSP16_Q(-0.03036888),
  DSP16_Q(0.02138307),
  DSP16_Q(-0.01546948),
  DSP16_Q(0.01124645),
  DSP16_Q(-0.00809112),
  DSP16_Q(0.00568226),
  DSP16_Q(-0.00383649),
  DSP16_Q(0.00243943),
  DSP16_Q(-0.00141336),
  DSP16_Q(0.00070075),
  DSP16_Q(-0.00025531),
  DSP16_Q(0.00003717),
  DSP16_Q(0.00001067),
  DSP16_Q(-0.00016939),
  DSP16_Q(0.00054641),
  DSP16_Q(-0.00118069),
  DSP16_Q(0.00211663),
  DSP16_Q(-0.00340824),
  DSP16_Q(0.00512660),
  DSP16_Q(-0.00737367),
  DSP16_Q(0.01030877),
  DSP16_Q(-0.01420346),
  DSP16_Q(0.01956731),
  DSP16_Q(-0.02748036),
  DSP16_Q(0.04067841),
  DSP16_Q(-0.06859090),
  DSP16_Q(0.17910123),
  DSP16_Q(0.32914817),
  DSP16_Q(-0.08429916),
  DSP16_Q(0.04651739),
  DSP16_Q(-0.03060240),
  DSP16_Q(0.02155324),
  DSP16_Q(-0.01559397),
  DSP16_Q(0.01133671),
  DSP16_Q(-0.00815517),
  DSP16_Q(0.00572612),
  DSP16_Q(-0.00386493),
  DSP16_Q(0.00245638),
  DSP16_Q(-0.00142215),
  DSP16_Q(0.00070419),
  DSP16_Q(-0.00025583),
  DSP16_Q(0.00003681),
  DSP16_Q(0.00001117),
  DSP16_Q(-0.00017267),
  DSP16_Q(0.00055479),
  DSP16_Q(-0.00119690),
  DSP16_Q(0.00214386),
  DSP16_Q(-0.00345027),
  DSP16_Q(0.00518805),
  DSP16_Q(-0.00746038),
  DSP16_Q(0.01042861),
  DSP16_Q(-0.01436789),
  DSP16_Q(0.01979487),
  DSP16_Q(-0.02780557),
  DSP16_Q(0.04118020),
  DSP16_Q(-0.06952691),
  DSP16_Q(0.18259533),
  DSP16_Q(0.32650290),
  DSP16_Q(-0.08469871),
  DSP16_Q(0.04682269),
  DSP16_Q(-0.03082296),
  DSP16_Q(0.02171434),
  DSP16_Q(-0.01571190),
  DSP16_Q(0.01142220),
  DSP16_Q(-0.00821577),
  DSP16_Q(0.00576754),
  DSP16_Q(-0.00389171),
  DSP16_Q(0.00247226),
  DSP16_Q(-0.00143029),
  DSP16_Q(0.00070730),
  DSP16_Q(-0.00025621),
  DSP16_Q(0.00003643),
  DSP16_Q(0.00001167),
  DSP16_Q(-0.00017592),
  DSP16_Q(0.00056302),
  DSP16_Q(-0.00121275),
  DSP16_Q(0.00217040),
  DSP16_Q(-0.00349116),
  DSP16_Q(0.00524775),
  DSP16_Q(-0.00754455),
  DSP16_Q(0.01054486),
  DSP16_Q(-0.01452736),
  DSP16_Q(0.02001564),
  DSP16_Q(-0.02812141),
  DSP16_Q(0.04166872),
  DSP16_Q(-0.07044341),
  DSP16_Q(0.18608734),
  DSP16_Q(0.32382378),
  DSP16_Q(-0.08506173),
  DSP16_Q(0.04710805),
  DSP16_Q(-0.03103055),
  DSP16_Q(0.02186635),
  DSP16_Q(-0.01582326),
  DSP16_Q(0.01150290),
  DSP16_Q(-0.00827291),
  DSP16_Q(0.00580651),
  DSP16_Q(-0.00391681),
  DSP16_Q(0.00248706),
  DSP16_Q(-0.00143779),
  DSP16_Q(0.00071008),
  DSP16_Q(-0.00025647),
  DSP16_Q(0.00003603),
  DSP16_Q(0.00001219),
  DSP16_Q(-0.00017914),
  DSP16_Q(0.00057111),
  DSP16_Q(-0.00122823),
  DSP16_Q(0.00219625),
  DSP16_Q(-0.00353090),
  DSP16_Q(0.00530567),
  DSP16_Q(-0.00762612),
  DSP16_Q(0.01065747),
  DSP16_Q(-0.01468181),
  DSP16_Q(0.02022951),
  DSP16_Q(-0.02842772),
  DSP16_Q(0.04214369),
  DSP16_Q(-0.07133990),
  DSP16_Q(0.18957652),
  DSP16_Q(0.32111142),
  DSP16_Q(-0.08538845),
  DSP16_Q(0.04737348),
  DSP16_Q(-0.03122514),
  DSP16_Q(0.02200924),
  DSP16_Q(-0.01592804),
  DSP16_Q(0.01157879),
  DSP16_Q(-0.00832658),
  DSP16_Q(0.00584303),
  DSP16_Q(-0.00394024),
  DSP16_Q(0.00250077),
  DSP16_Q(-0.00144465),
  DSP16_Q(0.00071253),
  DSP16_Q(-0.00025661),
  DSP16_Q(0.00003561),
  DSP16_Q(0.00001272),
  DSP16_Q(-0.00018232),
  DSP16_Q(0.00057904),
  DSP16_Q(-0.00124333),
  DSP16_Q(0.00222138),
  DSP16_Q(-0.00356945),
  DSP16_Q(0.00536178),
  DSP16_Q(-0.00770506),
  DSP16_Q(0.01076637),
  DSP16_Q(-0.01483113),
  DSP16_Q(0.02043637),
  DSP16_Q(-0.02872433),
  DSP16_Q(0.04260487),
  DSP16_Q(-0.07221591),
  DSP16_Q(0.19306213),
  DSP16_Q(0.31836644),
  DSP16_Q(-0.08567910),
  DSP16_Q(0.04761899),
  DSP16_Q(-0.03140672),
  DSP16_Q(0.02214300),
  DSP16_Q(-0.01602620),
  DSP16_Q(0.01164988),
  DSP16_Q(-0.00837678),
  DSP16_Q(0.00587709),
  DSP16_Q(-0.00396200),
  DSP16_Q(0.00251341),
  DSP16_Q(-0.00145088),
  DSP16_Q(0.00071466),
  DSP16_Q(-0.00025661),
  DSP16_Q(0.00003517),
  DSP16_Q(0.00001325),
  DSP16_Q(-0.00018548),
  DSP16_Q(0.00058681),
  DSP16_Q(-0.00125805),
  DSP16_Q(0.00224578),
  DSP16_Q(-0.00360679),
  DSP16_Q(0.00541604),
  DSP16_Q(-0.00778131),
  DSP16_Q(0.01087150),
  DSP16_Q(-0.01497527),
  DSP16_Q(0.02063611),
  DSP16_Q(-0.02901110),
  DSP16_Q(0.04305201),
  DSP16_Q(-0.07307094),
  DSP16_Q(0.19654342),
  DSP16_Q(0.31558945),
  DSP16_Q(-0.08593391),
  DSP16_Q(0.04784462),
  DSP16_Q(-0.03157529),
  DSP16_Q(0.02226761),
  DSP16_Q(-0.01611775),
  DSP16_Q(0.01171615),
  DSP16_Q(-0.00842349),
  DSP16_Q(0.00590869),
  DSP16_Q(-0.00398208),
  DSP16_Q(0.00252497),
  DSP16_Q(-0.00145647),
  DSP16_Q(0.00071646),
  DSP16_Q(-0.00025650),
  DSP16_Q(0.00003472),
  DSP16_Q(0.00001379),
  DSP16_Q(-0.00018860),
  DSP16_Q(0.00059441),
  DSP16_Q(-0.00127237),
  DSP16_Q(0.00226944),
  DSP16_Q(-0.00364291),
  DSP16_Q(0.00546843),
  DSP16_Q(-0.00785485),
  DSP16_Q(0.01097280),
  DSP16_Q(-0.01511413),
  DSP16_Q(0.02082862),
  DSP16_Q(-0.02928786),
  DSP16_Q(0.04348486),
  DSP16_Q(-0.07390452),
  DSP16_Q(0.20001965),
  DSP16_Q(0.31278111),
  DSP16_Q(-0.08615313),
  DSP16_Q(0.04805040),
  DSP16_Q(-0.03173083),
  DSP16_Q(0.02238306),
  DSP16_Q(-0.01620268),
  DSP16_Q(0.01177758),
  DSP16_Q(-0.00846672),
  DSP16_Q(0.00593783),
  DSP16_Q(-0.00400049),
  DSP16_Q(0.00253546),
  DSP16_Q(-0.00146143),
  DSP16_Q(0.00071794),
  DSP16_Q(-0.00025627),
  DSP16_Q(0.00003425),
  DSP16_Q(0.00001434),
  DSP16_Q(-0.00019168),
  DSP16_Q(0.00060184),
  DSP16_Q(-0.00128629),
  DSP16_Q(0.00229235),
  DSP16_Q(-0.00367778),
  DSP16_Q(0.00551892),
  DSP16_Q(-0.00792562),
  DSP16_Q(0.01107023),
  DSP16_Q(-0.01524765),
  DSP16_Q(0.02101381),
  DSP16_Q(-0.02955446),
  DSP16_Q(0.04390317),
  DSP16_Q(-0.07471617),
  DSP16_Q(0.20349009),
  DSP16_Q(0.30994203),
  DSP16_Q(-0.08633703),
  DSP16_Q(0.04823637),
  DSP16_Q(-0.03187334),
  DSP16_Q(0.02248936),
  DSP16_Q(-0.01628097),
  DSP16_Q(0.01183419),
  DSP16_Q(-0.00850646),
  DSP16_Q(0.00596452),
  DSP16_Q(-0.00401723),
  DSP16_Q(0.00254487),
  DSP16_Q(-0.00146575),
  DSP16_Q(0.00071911),
  DSP16_Q(-0.00025591),
  DSP16_Q(0.00003376),
  DSP16_Q(0.00001490),
  DSP16_Q(-0.00019471),
  DSP16_Q(0.00060910),
  DSP16_Q(-0.00129979),
  DSP16_Q(0.00231448),
  DSP16_Q(-0.00371138),
  DSP16_Q(0.00556747),
  DSP16_Q(-0.00799360),
  DSP16_Q(0.01116373),
  DSP16_Q(-0.01537575),
  DSP16_Q(0.02119156),
  DSP16_Q(-0.02981076),
  DSP16_Q(0.04430670),
  DSP16_Q(-0.07550540),
  DSP16_Q(0.20695398),
  DSP16_Q(0.30707287),
  DSP16_Q(-0.08648586),
  DSP16_Q(0.04840257),
  DSP16_Q(-0.03200284),
  DSP16_Q(0.02258648),
  DSP16_Q(-0.01635263),
  DSP16_Q(0.01188597),
  DSP16_Q(-0.00854271),
  DSP16_Q(0.00598874),
  DSP16_Q(-0.00403229),
  DSP16_Q(0.00255322),
  DSP16_Q(-0.00146946),
  DSP16_Q(0.00071996),
  DSP16_Q(-0.00025544),
  DSP16_Q(0.00003326),
  DSP16_Q(0.00001547),
  DSP16_Q(-0.00019771),
  DSP16_Q(0.00061617),
  DSP16_Q(-0.00131287),
  DSP16_Q(0.00233583),
  DSP16_Q(-0.00374370),
  DSP16_Q(0.00561406),
  DSP16_Q(-0.00805873),
  DSP16_Q(0.01125324),
  DSP16_Q(-0.01549836),
  DSP16_Q(0.02136179),
  DSP16_Q(-0.03005660),
  DSP16_Q(0.04469523),
  DSP16_Q(-0.07627177),
  DSP16_Q(0.21041059),
  DSP16_Q(0.30417428),
  DSP16_Q(-0.08659990),
  DSP16_Q(0.04854906),
  DSP16_Q(-0.03211934),
  DSP16_Q(0.02267444),
  DSP16_Q(-0.01641764),
  DSP16_Q(0.01193291),
  DSP16_Q(-0.00857548),
  DSP16_Q(0.00601050),
  DSP16_Q(-0.00404569),
  DSP16_Q(0.00256049),
  DSP16_Q(-0.00147253),
  DSP16_Q(0.00072050),
  DSP16_Q(-0.00025486),
  DSP16_Q(0.00003274),
  DSP16_Q(0.00001605),
  DSP16_Q(-0.00020066),
  DSP16_Q(0.00062305),
  DSP16_Q(-0.00132551),
  DSP16_Q(0.00235638),
  DSP16_Q(-0.00377470),
  DSP16_Q(0.00565867),
  DSP16_Q(-0.00812098),
  DSP16_Q(0.01133872),
  DSP16_Q(-0.01561541),
  DSP16_Q(0.02152438),
  DSP16_Q(-0.03029185),
  DSP16_Q(0.04506851),
  DSP16_Q(-0.07701478),
  DSP16_Q(0.21385917),
  DSP16_Q(0.30124692),
  DSP16_Q(-0.08667942),
  DSP16_Q(0.04867589),
  DSP16_Q(-0.03222284),
  DSP16_Q(0.02275324),
  DSP16_Q(-0.01647602),
  DSP16_Q(0.01197501),
  DSP16_Q(-0.00860476),
  DSP16_Q(0.00602981),
  DSP16_Q(-0.00405743),
  DSP16_Q(0.00256671),
  DSP16_Q(-0.00147499),
  DSP16_Q(0.00072073),
  DSP16_Q(-0.00025416),
  DSP16_Q(0.00003221),
  DSP16_Q(0.00001663),
  DSP16_Q(-0.00020356),
  DSP16_Q(0.00062975),
  DSP16_Q(-0.00133772),
  DSP16_Q(0.00237611),
  DSP16_Q(-0.00380438),
  DSP16_Q(0.00570126),
  DSP16_Q(-0.00818032),
  DSP16_Q(0.01142011),
  DSP16_Q(-0.01572683),
  DSP16_Q(0.02167926),
  DSP16_Q(-0.03051637),
  DSP16_Q(0.04542633),
  DSP16_Q(-0.07773399),
  DSP16_Q(0.21729897),
  DSP16_Q(0.29829144),
  DSP16_Q(-0.08672473),
  DSP16_Q(0.04878314),
  DSP16_Q(-0.03231338),
  DSP16_Q(0.02282288),
  DSP16_Q(-0.01652777),
  DSP16_Q(0.01201229),
  DSP16_Q(-0.00863056),
  DSP16_Q(0.00604667),
  DSP16_Q(-0.00406751),
  DSP16_Q(0.00257186),
  DSP16_Q(-0.00147684),
  DSP16_Q(0.00072065),
  DSP16_Q(-0.00025335),
  DSP16_Q(0.00003167),
  DSP16_Q(0.00001722),
  DSP16_Q(-0.00020641),
  DSP16_Q(0.00063624),
  DSP16_Q(-0.00134947),
  DSP16_Q(0.00239502),
  DSP16_Q(-0.00383271),
  DSP16_Q(0.00574180),
  DSP16_Q(-0.00823671),
  DSP16_Q(0.01149737),
  DSP16_Q(-0.01583256),
  DSP16_Q(0.02182632),
  DSP16_Q(-0.03073003),
  DSP16_Q(0.04576845),
  DSP16_Q(-0.07842894),
  DSP16_Q(0.22072925),
  DSP16_Q(0.29530851),
  DSP16_Q(-0.08673611),
  DSP16_Q(0.04887088),
  DSP16_Q(-0.03239097),
  DSP16_Q(0.02288338),
  DSP16_Q(-0.01657288),
  DSP16_Q(0.01204474),
  DSP16_Q(-0.00865288),
  DSP16_Q(0.00606108),
  DSP16_Q(-0.00407593),
  DSP16_Q(0.00257596),
  DSP16_Q(-0.00147806),
  DSP16_Q(0.00072026),
  DSP16_Q(-0.00025243),
  DSP16_Q(0.00003112),
  DSP16_Q(0.00001781),
  DSP16_Q(-0.00020920),
  DSP16_Q(0.00064253),
  DSP16_Q(-0.00136077),
  DSP16_Q(0.00241309),
  DSP16_Q(-0.00385967),
  DSP16_Q(0.00578028),
  DSP16_Q(-0.00829012),
  DSP16_Q(0.01157045),
  DSP16_Q(-0.01593253),
  DSP16_Q(0.02196547),
  DSP16_Q(-0.03093268),
  DSP16_Q(0.04609467),
  DSP16_Q(-0.07909917),
  DSP16_Q(0.22414928),
  DSP16_Q(0.29229881),
  DSP16_Q(-0.08671388),
  DSP16_Q(0.04893918),
  DSP16_Q(-0.03245565),
  DSP16_Q(0.02293475),
  DSP16_Q(-0.01661138),
  DSP16_Q(0.01207237),
  DSP16_Q(-0.00867174),
  DSP16_Q(0.00607305),
  DSP16_Q(-0.00408270),
  DSP16_Q(0.00257901),
  DSP16_Q(-0.00147869),
  DSP16_Q(0.00071958),
  DSP16_Q(-0.00025140),
  DSP16_Q(0.00003056),
  DSP16_Q(0.00001841),
  DSP16_Q(-0.00021194),
  DSP16_Q(0.00064862),
  DSP16_Q(-0.00137160),
  DSP16_Q(0.00243031),
  DSP16_Q(-0.00388525),
  DSP16_Q(0.00581667),
  DSP16_Q(-0.00834050),
  DSP16_Q(0.01163930),
  DSP16_Q(-0.01602669),
  DSP16_Q(0.02209664),
  DSP16_Q(-0.03112421),
  DSP16_Q(0.04640477),
  DSP16_Q(-0.07974422),
  DSP16_Q(0.22755830),
  DSP16_Q(0.28926302),
  DSP16_Q(-0.08665834),
  DSP16_Q(0.04898814),
  DSP16_Q(-0.03250745),
  DSP16_Q(0.02297701),
  DSP16_Q(-0.01664327),
  DSP16_Q(0.01209519),
  DSP16_Q(-0.00868712),
  DSP16_Q(0.00608259),
  DSP16_Q(-0.00408783),
  DSP16_Q(0.00258101),
  DSP16_Q(-0.00147870),
  DSP16_Q(0.00071860),
  DSP16_Q(-0.00025027),
  DSP16_Q(0.00002999),
  DSP16_Q(0.00001901),
  DSP16_Q(-0.00021462),
  DSP16_Q(0.00065449),
  DSP16_Q(-0.00138196),
  DSP16_Q(0.00244667),
  DSP16_Q(-0.00390943),
  DSP16_Q(0.00585093),
  DSP16_Q(-0.00838783),
  DSP16_Q(0.01170388),
  DSP16_Q(-0.01611496),
  DSP16_Q(0.02221973),
  DSP16_Q(-0.03130449),
  DSP16_Q(0.04669854),
  DSP16_Q(-0.08036367),
  DSP16_Q(0.23095558),
  DSP16_Q(0.28620182),
  DSP16_Q(-0.08656981),
  DSP16_Q(0.04901785),
  DSP16_Q(-0.03254641),
  DSP16_Q(0.02301018),
  DSP16_Q(-0.01666857),
  DSP16_Q(0.01211321),
  DSP16_Q(-0.00869905),
  DSP16_Q(0.00608970),
  DSP16_Q(-0.00409132),
  DSP16_Q(0.00258198),
  DSP16_Q(-0.00147812),
  DSP16_Q(0.00071733),
  DSP16_Q(-0.00024904),
  DSP16_Q(0.00002941),
  DSP16_Q(0.00001962),
  DSP16_Q(-0.00021725),
  DSP16_Q(0.00066015),
  DSP16_Q(-0.00139183),
  DSP16_Q(0.00246215),
  DSP16_Q(-0.00393219),
  DSP16_Q(0.00588306),
  DSP16_Q(-0.00843208),
  DSP16_Q(0.01176415),
  DSP16_Q(-0.01619730),
  DSP16_Q(0.02233467),
  DSP16_Q(-0.03147340),
  DSP16_Q(0.04697578),
  DSP16_Q(-0.08095706),
  DSP16_Q(0.23434037),
  DSP16_Q(0.28311589),
  DSP16_Q(-0.08644864),
  DSP16_Q(0.04902841),
  DSP16_Q(-0.03257257),
  DSP16_Q(0.02303428),
  DSP16_Q(-0.01668729),
  DSP16_Q(0.01212644),
  DSP16_Q(-0.00870754),
  DSP16_Q(0.00609439),
  DSP16_Q(-0.00409318),
  DSP16_Q(0.00258191),
  DSP16_Q(-0.00147694),
  DSP16_Q(0.00071576),
  DSP16_Q(-0.00024771),
  DSP16_Q(0.00002882),
  DSP16_Q(0.00002023),
  DSP16_Q(-0.00021981),
  DSP16_Q(0.00066558),
  DSP16_Q(-0.00140121),
  DSP16_Q(0.00247674),
  DSP16_Q(-0.00395351),
  DSP16_Q(0.00591302),
  DSP16_Q(-0.00847321),
  DSP16_Q(0.01182006),
  DSP16_Q(-0.01627364),
  DSP16_Q(0.02244138),
  DSP16_Q(-0.03163082),
  DSP16_Q(0.04723628),
  DSP16_Q(-0.08152396),
  DSP16_Q(0.23771194),
  DSP16_Q(0.28000593),
  DSP16_Q(-0.08629514),
  DSP16_Q(0.04901993),
  DSP16_Q(-0.03258598),
  DSP16_Q(0.02304934),
  DSP16_Q(-0.01669945),
  DSP16_Q(0.01213490),
  DSP16_Q(-0.00871259),
  DSP16_Q(0.00609667),
  DSP16_Q(-0.00409341),
  DSP16_Q(0.00258082),
  DSP16_Q(-0.00147518),
  DSP16_Q(0.00071391),
  DSP16_Q(-0.00024628),
  DSP16_Q(0.00002823),
  DSP16_Q(0.00002085),
  DSP16_Q(-0.00022230),
  DSP16_Q(0.00067079),
  DSP16_Q(-0.00141010),
  DSP16_Q(0.00249043),
  DSP16_Q(-0.00397339),
  DSP16_Q(0.00594080),
  DSP16_Q(-0.00851120),
  DSP16_Q(0.01187158),
  DSP16_Q(-0.01634394),
  DSP16_Q(0.02253978),
  DSP16_Q(-0.03177663),
  DSP16_Q(0.04747987),
  DSP16_Q(-0.08206394),
  DSP16_Q(0.24106954),
  DSP16_Q(0.27687264),
  DSP16_Q(-0.08610966),
  DSP16_Q(0.04899251),
  DSP16_Q(-0.03258671),
  DSP16_Q(0.02305539),
  DSP16_Q(-0.01670508),
  DSP16_Q(0.01213860),
  DSP16_Q(-0.00871422),
  DSP16_Q(0.00609656),
  DSP16_Q(-0.00409204),
  DSP16_Q(0.00257870),
  DSP16_Q(-0.00147283),
  DSP16_Q(0.00071178),
  DSP16_Q(-0.00024475),
  DSP16_Q(0.00002763),
  DSP16_Q(0.00002147),
  DSP16_Q(-0.00022473),
  DSP16_Q(0.00067576),
  DSP16_Q(-0.00141847),
  DSP16_Q(0.00250322),
  DSP16_Q(-0.00399179),
  DSP16_Q(0.00596637),
  DSP16_Q(-0.00854601),
  DSP16_Q(0.01191867),
  DSP16_Q(-0.01640814),
  DSP16_Q(0.02262980),
  DSP16_Q(-0.03191074),
  DSP16_Q(0.04770634),
  DSP16_Q(-0.08257658),
  DSP16_Q(0.24441244),
  DSP16_Q(0.27371672),
  DSP16_Q(-0.08589256),
  DSP16_Q(0.04894628),
  DSP16_Q(-0.03257479),
  DSP16_Q(0.02305248),
  DSP16_Q(-0.01670419),
  DSP16_Q(0.01213756),
  DSP16_Q(-0.00871244),
  DSP16_Q(0.00609405),
  DSP16_Q(-0.00408906),
  DSP16_Q(0.00257558),
  DSP16_Q(-0.00146990),
  DSP16_Q(0.00070936),
  DSP16_Q(-0.00024313),
  DSP16_Q(0.00002703),
  DSP16_Q(0.00002209),
  DSP16_Q(-0.00022708),
  DSP16_Q(0.00068050),
  DSP16_Q(-0.00142634),
  DSP16_Q(0.00251508),
  DSP16_Q(-0.00400871),
  DSP16_Q(0.00598971),
  DSP16_Q(-0.00857763),
  DSP16_Q(0.01196129),
  DSP16_Q(-0.01646620),
  DSP16_Q(0.02271137),
  DSP16_Q(-0.03203304),
  DSP16_Q(0.04791553),
  DSP16_Q(-0.08306145),
  DSP16_Q(0.24773992),
  DSP16_Q(0.27053887),
  DSP16_Q(-0.08564419),
  DSP16_Q(0.04888137),
  DSP16_Q(-0.03255031),
  DSP16_Q(0.02304063),
  DSP16_Q(-0.01669681),
  DSP16_Q(0.01213180),
  DSP16_Q(-0.00870727),
  DSP16_Q(0.00608917),
  DSP16_Q(-0.00408448),
  DSP16_Q(0.00257144),
  DSP16_Q(-0.00146639),
  DSP16_Q(0.00070668),
  DSP16_Q(-0.00024142),
  DSP16_Q(0.00002642),
  DSP16_Q(0.00002271),
  DSP16_Q(-0.00022937),
  DSP16_Q(0.00068500),
  DSP16_Q(-0.00143368),
  DSP16_Q(0.00252601),
  DSP16_Q(-0.00402414),
  DSP16_Q(0.00601081),
  DSP16_Q(-0.00860601),
  DSP16_Q(0.01199940),
  DSP16_Q(-0.01651806),
  DSP16_Q(0.02278443),
  DSP16_Q(-0.03214341),
  DSP16_Q(0.04810724),
  DSP16_Q(-0.08351815),
  DSP16_Q(0.25105122),
  DSP16_Q(0.26733980),
  DSP16_Q(-0.08536491),
  DSP16_Q(0.04879790),
  DSP16_Q(-0.03251331),
  DSP16_Q(0.02301988),
  DSP16_Q(-0.01668297),
  DSP16_Q(0.01212134),
  DSP16_Q(-0.00869873),
  DSP16_Q(0.00608193),
  DSP16_Q(-0.00407832),
  DSP16_Q(0.00256631),
  DSP16_Q(-0.00146232),
  DSP16_Q(0.00070372),
  DSP16_Q(-0.00023962),
  DSP16_Q(0.00002580),
  DSP16_Q(0.00002333),
  DSP16_Q(-0.00023158),
  DSP16_Q(0.00068925),
  DSP16_Q(-0.00144049),
  DSP16_Q(0.00253599),
  DSP16_Q(-0.00403805),
  DSP16_Q(0.00602963),
  DSP16_Q(-0.00863115),
  DSP16_Q(0.01203298),
  DSP16_Q(-0.01656368),
  DSP16_Q(0.02284891),
  DSP16_Q(-0.03224178),
  DSP16_Q(0.04828130),
  DSP16_Q(-0.08394626),
  DSP16_Q(0.25434563),
  DSP16_Q(0.26412022),
  DSP16_Q(-0.08505510),
  DSP16_Q(0.04869601),
  DSP16_Q(-0.03246389),
  DSP16_Q(0.02299029),
  DSP16_Q(-0.01666270),
  DSP16_Q(0.01210620),
  DSP16_Q(-0.00868682),
  DSP16_Q(0.00607234),
  DSP16_Q(-0.00407058),
  DSP16_Q(0.00256020),
  DSP16_Q(-0.00145769),
  DSP16_Q(0.00070049),
  DSP16_Q(-0.00023773),
  DSP16_Q(0.00002519),
  DSP16_Q(0.00002395),
  DSP16_Q(-0.00023371),
  DSP16_Q(0.00069325),
  DSP16_Q(-0.00144677),
  DSP16_Q(0.00254502),
  DSP16_Q(-0.00405044),
  DSP16_Q(0.00604618),
  DSP16_Q(-0.00865301),
  DSP16_Q(0.01206199),
  DSP16_Q(-0.01660302),
  DSP16_Q(0.02290475),
  DSP16_Q(-0.03232804),
  DSP16_Q(0.04843756),
  DSP16_Q(-0.08434539),
  DSP16_Q(0.25762242),
  DSP16_Q(0.26088085),
  DSP16_Q(-0.08471513),
  DSP16_Q(0.04857585),
  DSP16_Q(-0.03240210),
  DSP16_Q(0.02295189),
  DSP16_Q(-0.01663604),
  DSP16_Q(0.01208641),
  DSP16_Q(-0.00867158),
  DSP16_Q(0.00606042),
  DSP16_Q(-0.00406129),
  DSP16_Q(0.00255310),
  DSP16_Q(-0.00145250),
  DSP16_Q(0.00069700),
  DSP16_Q(-0.00023576),
  DSP16_Q(0.00002457),
  DSP16_Q(0.00002457),
  DSP16_Q(-0.00023576),
  DSP16_Q(0.00069700),
  DSP16_Q(-0.00145250),
  DSP16_Q(0.00255310),
  DSP16_Q(-0.00406129),
  DSP16_Q(0.00606042),
  DSP16_Q(-0.00867158),
  DSP16_Q(0.01208641),
  DSP16_Q(-0.01663604),
  DSP16_Q(0.02295189),
  DSP16_Q(-0.03240210),
  DSP16_Q(0.04857585),
  DSP16_Q(-0.08471513),
  DSP16_Q(0.26088085),
  DSP16_Q(0.25762242),
  DSP16_Q(-0.08434539),
  DSP16_Q(0.04843756),
  DSP16_Q(-0.03232804),
  DSP16_Q(0.02290475),
  DSP16_Q(-0.01660302),
  DSP16_Q(0.01206199),
  DSP16_Q(-0.00865301),
  DSP16_Q(0.00604618),
  DSP16_Q(-0.00405044),
  DSP16_Q(0.00254502),
  DSP16_Q(-0.00144677),
  DSP16_Q(0.00069325),
  DSP16_Q(-0.00023371),
  DSP16_Q(0.00002395),
  DSP16_Q(0.00002519),
  DSP16_Q(-0.00023773),
  DSP16_Q(0.00070049),
  DSP16_Q(-0.00145769),
  DSP16_Q(0.00256020),
  DSP16_Q(-0.00407058),
  DSP16_Q(0.00607234),
  DSP16_Q(-0.00868682),
  DSP16_Q(0.01210620),
  DSP16_Q(-0.01666270),
  DSP16_Q(0.02299029),
  DSP16_Q(-0.03246389),
  DSP16_Q(0.04869601),
  DSP16_Q(-0.08505510),
  DSP16_Q(0.26412022),
  DSP16_Q(0.25434563),
  DSP16_Q(-0.08394626),
  DSP16_Q(0.04828130),
  DSP16_Q(-0.03224178),
  DSP16_Q(0.02284891),
  DSP16_Q(-0.01656368),
  DSP16_Q(0.01203298),
  DSP16_Q(-0.00863115),
  DSP16_Q(0.00602963),
  DSP16_Q(-0.00403805),
  DSP16_Q(0.00253599),
  DSP16_Q(-0.00144049),
  DSP16_Q(0.00068925),
  DSP16_Q(-0.00023158),
  DSP16_Q(0.00002333),
  DSP16_Q(0.00002580),
  DSP16_Q(-0.00023962),
  DSP16_Q(0.00070372),
  DSP16_Q(-0.00146232),
  DSP16_Q(0.00256631),
  DSP16_Q(-0.00407832),
  DSP16_Q(0.00608193),
  DSP16_Q(-0.00869873),
  DSP16_Q(0.01212134),
  DSP16_Q(-0.01668297),
  DSP16_Q(0.02301988),
  DSP16_Q(-0.03251331),
  DSP16_Q(0.04879790),
  DSP16_Q(-0.08536491),
  DSP16_Q(0.26733980),
  DSP16_Q(0.25105122),
  DSP16_Q(-0.08351815),
  DSP16_Q(0.04810724),
  DSP16_Q(-0.03214341),
  DSP16_Q(0.02278443),
  DSP16_Q(-0.01651806),
  DSP16_Q(0.01199940),
  DSP16_Q(-0.00860601),
  DSP16_Q(0.00601081),
  DSP16_Q(-0.00402414),
  DSP16_Q(0.00252601),
  DSP16_Q(-0.00143368),
  DSP16_Q(0.00068500),
  DSP16_Q(-0.00022937),
  DSP16_Q(0.00002271),
  DSP16_Q(0.00002642),
  DSP16_Q(-0.00024142),
  DSP16_Q(0.00070668),
  DSP16_Q(-0.00146639),
  DSP16_Q(0.00257144),
  DSP16_Q(-0.00408448),
  DSP16_Q(0.00608917),
  DSP16_Q(-0.00870727),
  DSP16_Q(0.01213180),
  DSP16_Q(-0.01669681),
  DSP16_Q(0.02304063),
  DSP16_Q(-0.03255031),
  DSP16_Q(0.04888137),
  DSP16_Q(-0.08564419),
  DSP16_Q(0.27053887),
  DSP16_Q(0.24773992),
  DSP16_Q(-0.08306145),
  DSP16_Q(0.04791553),
  DSP16_Q(-0.03203304),
  DSP16_Q(0.02271137),
  DSP16_Q(-0.01646620),
  DSP16_Q(0.01196129),
  DSP16_Q(-0.00857763),
  DSP16_Q(0.00598971),
  DSP16_Q(-0.00400871),
  DSP16_Q(0.00251508),
  DSP16_Q(-0.00142634),
  DSP16_Q(0.00068050),
  DSP16_Q(-0.00022708),
  DSP16_Q(0.00002209),
  DSP16_Q(0.00002703),
  DSP16_Q(-0.00024313),
  DSP16_Q(0.00070936),
  DSP16_Q(-0.00146990),
  DSP16_Q(0.00257558),
  DSP16_Q(-0.00408906),
  DSP16_Q(0.00609405),
  DSP16_Q(-0.00871244),
  DSP16_Q(0.01213756),
  DSP16_Q(-0.01670419),
  DSP16_Q(0.02305248),
  DSP16_Q(-0.03257479),
  DSP16_Q(0.04894628),
  DSP16_Q(-0.08589256),
  DSP16_Q(0.27371672),
  DSP16_Q(0.24441244),
  DSP16_Q(-0.08257658),
  DSP16_Q(0.04770634),
  DSP16_Q(-0.03191074),
  DSP16_Q(0.02262980),
  DSP16_Q(-0.01640814),
  DSP16_Q(0.01191867),
  DSP16_Q(-0.00854601),
  DSP16_Q(0.00596637),
  DSP16_Q(-0.00399179),
  DSP16_Q(0.00250322),
  DSP16_Q(-0.00141847),
  DSP16_Q(0.00067576),
  DSP16_Q(-0.00022473),
  DSP16_Q(0.00002147),
  DSP16_Q(0.00002763),
  DSP16_Q(-0.00024475),
  DSP16_Q(0.00071178),
  DSP16_Q(-0.00147283),
  DSP16_Q(0.00257870),
  DSP16_Q(-0.00409204),
  DSP16_Q(0.00609656),
  DSP16_Q(-0.00871422),
  DSP16_Q(0.01213860),
  DSP16_Q(-0.01670508),
  DSP16_Q(0.02305539),
  DSP16_Q(-0.03258671),
  DSP16_Q(0.04899251),
  DSP16_Q(-0.08610966),
  DSP16_Q(0.27687264),
  DSP16_Q(0.24106954),
  DSP16_Q(-0.08206394),
  DSP16_Q(0.04747987),
  DSP16_Q(-0.03177663),
  DSP16_Q(0.02253978),
  DSP16_Q(-0.01634394),
  DSP16_Q(0.01187158),
  DSP16_Q(-0.00851120),
  DSP16_Q(0.00594080),
  DSP16_Q(-0.00397339),
  DSP16_Q(0.00249043),
  DSP16_Q(-0.00141010),
  DSP16_Q(0.00067079),
  DSP16_Q(-0.00022230),
  DSP16_Q(0.00002085),
  DSP16_Q(0.00002823),
  DSP16_Q(-0.00024628),
  DSP16_Q(0.00071391),
  DSP16_Q(-0.00147518),
  DSP16_Q(0.00258082),
  DSP16_Q(-0.00409341),
  DSP16_Q(0.00609667),
  DSP16_Q(-0.00871259),
  DSP16_Q(0.01213490),
  DSP16_Q(-0.01669945),
  DSP16_Q(0.02304934),
  DSP16_Q(-0.03258598),
  DSP16_Q(0.04901993),
  DSP16_Q(-0.08629514),
  DSP16_Q(0.28000593),
  DSP16_Q(0.23771194),
  DSP16_Q(-0.08152396),
  DSP16_Q(0.04723628),
  DSP16_Q(-0.03163082),
  DSP16_Q(0.02244138),
  DSP16_Q(-0.01627364),
  DSP16_Q(0.01182006),
  DSP16_Q(-0.00847321),
  DSP16_Q(0.00591302),
  DSP16_Q(-0.00395351),
  DSP16_Q(0.00247674),
  DSP16_Q(-0.00140121),
  DSP16_Q(0.00066558),
  DSP16_Q(-0.00021981),
  DSP16_Q(0.00002023),
  DSP16_Q(0.00002882),
  DSP16_Q(-0.00024771),
  DSP16_Q(0.00071576),
  DSP16_Q(-0.00147694),
  DSP16_Q(0.00258191),
  DSP16_Q(-0.00409318),
  DSP16_Q(0.00609439),
  DSP16_Q(-0.00870754),
  DSP16_Q(0.01212644),
  DSP16_Q(-0.01668729),
  DSP16_Q(0.02303428),
  DSP16_Q(-0.03257257),
  DSP16_Q(0.04902841),
  DSP16_Q(-0.08644864),
  DSP16_Q(0.28311589),
  DSP16_Q(0.23434037),
  DSP16_Q(-0.08095706),
  DSP16_Q(0.04697578),
  DSP16_Q(-0.03147340),
  DSP16_Q(0.02233467),
  DSP16_Q(-0.01619730),
  DSP16_Q(0.01176415),
  DSP16_Q(-0.00843208),
  DSP16_Q(0.00588306),
  DSP16_Q(-0.00393219),
  DSP16_Q(0.00246215),
  DSP16_Q(-0.00139183),
  DSP16_Q(0.00066015),
  DSP16_Q(-0.00021725),
  DSP16_Q(0.00001962),
  DSP16_Q(0.00002941),
  DSP16_Q(-0.00024904),
  DSP16_Q(0.00071733),
  DSP16_Q(-0.00147812),
  DSP16_Q(0.00258198),
  DSP16_Q(-0.00409132),
  DSP16_Q(0.00608970),
  DSP16_Q(-0.00869905),
  DSP16_Q(0.01211321),
  DSP16_Q(-0.01666857),
  DSP16_Q(0.02301018),
  DSP16_Q(-0.03254641),
  DSP16_Q(0.04901785),
  DSP16_Q(-0.08656981),
  DSP16_Q(0.28620182),
  DSP16_Q(0.23095558),
  DSP16_Q(-0.08036367),
  DSP16_Q(0.04669854),
  DSP16_Q(-0.03130449),
  DSP16_Q(0.02221973),
  DSP16_Q(-0.01611496),
  DSP16_Q(0.01170388),
  DSP16_Q(-0.00838783),
  DSP16_Q(0.00585093),
  DSP16_Q(-0.00390943),
  DSP16_Q(0.00244667),
  DSP16_Q(-0.00138196),
  DSP16_Q(0.00065449),
  DSP16_Q(-0.00021462),
  DSP16_Q(0.00001901),
  DSP16_Q(0.00002999),
  DSP16_Q(-0.00025027),
  DSP16_Q(0.00071860),
  DSP16_Q(-0.00147870),
  DSP16_Q(0.00258101),
  DSP16_Q(-0.00408783),
  DSP16_Q(0.00608259),
  DSP16_Q(-0.00868712),
  DSP16_Q(0.01209519),
  DSP16_Q(-0.01664327),
  DSP16_Q(0.02297701),
  DSP16_Q(-0.03250745),
  DSP16_Q(0.04898814),
  DSP16_Q(-0.08665834),
  DSP16_Q(0.28926302),
  DSP16_Q(0.22755830),
  DSP16_Q(-0.07974422),
  DSP16_Q(0.04640477),
  DSP16_Q(-0.03112421),
  DSP16_Q(0.02209664),
  DSP16_Q(-0.01602669),
  DSP16_Q(0.01163930),
  DSP16_Q(-0.00834050),
  DSP16_Q(0.00581667),
  DSP16_Q(-0.00388525),
  DSP16_Q(0.00243031),
  DSP16_Q(-0.00137160),
  DSP16_Q(0.00064862),
  DSP16_Q(-0.00021194),
  DSP16_Q(0.00001841),
  DSP16_Q(0.00003056),
  DSP16_Q(-0.00025140),
  DSP16_Q(0.00071958),
  DSP16_Q(-0.00147869),
  DSP16_Q(0.00257901),
  DSP16_Q(-0.00408270),
  DSP16_Q(0.00607305),
  DSP16_Q(-0.00867174),
  DSP16_Q(0.01207237),
  DSP16_Q(-0.01661138),
  DSP16_Q(0.02293475),
  DSP16_Q(-0.03245565),
  DSP16_Q(0.04893918),
  DSP16_Q(-0.08671388),
  DSP16_Q(0.29229881),
  DSP16_Q(0.22414928),
  DSP16_Q(-0.07909917),
  DSP16_Q(0.04609467),
  DSP16_Q(-0.03093268),
  DSP16_Q(0.02196547),
  DSP16_Q(-0.01593253),
  DSP16_Q(0.01157045),
  DSP16_Q(-0.00829012),
  DSP16_Q(0.00578028),
  DSP16_Q(-0.00385967),
  DSP16_Q(0.00241309),
  DSP16_Q(-0.00136077),
  DSP16_Q(0.00064253),
  DSP16_Q(-0.00020920),
  DSP16_Q(0.00001781),
  DSP16_Q(0.00003112),
  DSP16_Q(-0.00025243),
  DSP16_Q(0.00072026),
  DSP16_Q(-0.00147806),
  DSP16_Q(0.00257596),
  DSP16_Q(-0.00407593),
  DSP16_Q(0.00606108),
  DSP16_Q(-0.00865288),
  DSP16_Q(0.01204474),
  DSP16_Q(-0.01657288),
  DSP16_Q(0.02288338),
  DSP16_Q(-0.03239097),
  DSP16_Q(0.04887088),
  DSP16_Q(-0.08673611),
  DSP16_Q(0.29530851),
  DSP16_Q(0.22072925),
  DSP16_Q(-0.07842894),
  DSP16_Q(0.04576845),
  DSP16_Q(-0.03073003),
  DSP16_Q(0.02182632),
  DSP16_Q(-0.01583256),
  DSP16_Q(0.01149737),
  DSP16_Q(-0.00823671),
  DSP16_Q(0.00574180),
  DSP16_Q(-0.00383271),
  DSP16_Q(0.00239502),
  DSP16_Q(-0.00134947),
  DSP16_Q(0.00063624),
  DSP16_Q(-0.00020641),
  DSP16_Q(0.00001722),
  DSP16_Q(0.00003167),
  DSP16_Q(-0.00025335),
  DSP16_Q(0.00072065),
  DSP16_Q(-0.00147684),
  DSP16_Q(0.00257186),
  DSP16_Q(-0.00406751),
  DSP16_Q(0.00604667),
  DSP16_Q(-0.00863056),
  DSP16_Q(0.01201229),
  DSP16_Q(-0.01652777),
  DSP16_Q(0.02282288),
  DSP16_Q(-0.03231338),
  DSP16_Q(0.04878314),
  DSP16_Q(-0.08672473),
  DSP16_Q(0.29829144),
  DSP16_Q(0.21729897),
  DSP16_Q(-0.07773399),
  DSP16_Q(0.04542633),
  DSP16_Q(-0.03051637),
  DSP16_Q(0.02167926),
  DSP16_Q(-0.01572683),
  DSP16_Q(0.01142011),
  DSP16_Q(-0.00818032),
  DSP16_Q(0.00570126),
  DSP16_Q(-0.00380438),
  DSP16_Q(0.00237611),
  DSP16_Q(-0.00133772),
  DSP16_Q(0.00062975),
  DSP16_Q(-0.00020356),
  DSP16_Q(0.00001663),
  DSP16_Q(0.00003221),
  DSP16_Q(-0.00025416),
  DSP16_Q(0.00072073),
  DSP16_Q(-0.00147499),
  DSP16_Q(0.00256671),
  DSP16_Q(-0.00405743),
  DSP16_Q(0.00602981),
  DSP16_Q(-0.00860476),
  DSP16_Q(0.01197501),
  DSP16_Q(-0.01647602),
  DSP16_Q(0.02275324),
  DSP16_Q(-0.03222284),
  DSP16_Q(0.04867589),
  DSP16_Q(-0.08667942),
  DSP16_Q(0.30124692),
  DSP16_Q(0.21385917),
  DSP16_Q(-0.07701478),
  DSP16_Q(0.04506851),
  DSP16_Q(-0.03029185),
  DSP16_Q(0.02152438),
  DSP16_Q(-0.01561541),
  DSP16_Q(0.01133872),
  DSP16_Q(-0.00812098),
  DSP16_Q(0.00565867),
  DSP16_Q(-0.00377470),
  DSP16_Q(0.00235638),
  DSP16_Q(-0.00132551),
  DSP16_Q(0.00062305),
  DSP16_Q(-0.00020066),
  DSP16_Q(0.00001605),
  DSP16_Q(0.00003274),
  DSP16_Q(-0.00025486),
  DSP16_Q(0.00072050),
  DSP16_Q(-0.00147253),
  DSP16_Q(0.00256049),
  DSP16_Q(-0.00404569),
  DSP16_Q(0.00601050),
  DSP16_Q(-0.00857548),
  DSP16_Q(0.01193291),
  DSP16_Q(-0.01641764),
  DSP16_Q(0.02267444),
  DSP16_Q(-0.03211934),
  DSP16_Q(0.04854906),
  DSP16_Q(-0.08659990),
  DSP16_Q(0.30417428),
  DSP16_Q(0.21041059),
  DSP16_Q(-0.07627177),
  DSP16_Q(0.04469523),
  DSP16_Q(-0.03005660),
  DSP16_Q(0.02136179),
  DSP16_Q(-0.01549836),
  DSP16_Q(0.01125324),
  DSP16_Q(-0.00805873),
  DSP16_Q(0.00561406),
  DSP16_Q(-0.00374370),
  DSP16_Q(0.00233583),
  DSP16_Q(-0.00131287),
  DSP16_Q(0.00061617),
  DSP16_Q(-0.00019771),
  DSP16_Q(0.00001547),
  DSP16_Q(0.00003326),
  DSP16_Q(-0.00025544),
  DSP16_Q(0.00071996),
  DSP16_Q(-0.00146946),
  DSP16_Q(0.00255322),
  DSP16_Q(-0.00403229),
  DSP16_Q(0.00598874),
  DSP16_Q(-0.00854271),
  DSP16_Q(0.01188597),
  DSP16_Q(-0.01635263),
  DSP16_Q(0.02258648),
  DSP16_Q(-0.03200284),
  DSP16_Q(0.04840257),
  DSP16_Q(-0.08648586),
  DSP16_Q(0.30707287),
  DSP16_Q(0.20695398),
  DSP16_Q(-0.07550540),
  DSP16_Q(0.04430670),
  DSP16_Q(-0.02981076),
  DSP16_Q(0.02119156),
  DSP16_Q(-0.01537575),
  DSP16_Q(0.01116373),
  DSP16_Q(-0.00799360),
  DSP16_Q(0.00556747),
  DSP16_Q(-0.00371138),
  DSP16_Q(0.00231448),
  DSP16_Q(-0.00129979),
  DSP16_Q(0.00060910),
  DSP16_Q(-0.00019471),
  DSP16_Q(0.00001490),
  DSP16_Q(0.00003376),
  DSP16_Q(-0.00025591),
  DSP16_Q(0.00071911),
  DSP16_Q(-0.00146575),
  DSP16_Q(0.00254487),
  DSP16_Q(-0.00401723),
  DSP16_Q(0.00596452),
  DSP16_Q(-0.00850646),
  DSP16_Q(0.01183419),
  DSP16_Q(-0.01628097),
  DSP16_Q(0.02248936),
  DSP16_Q(-0.03187334),
  DSP16_Q(0.04823637),
  DSP16_Q(-0.08633703),
  DSP16_Q(0.30994203),
  DSP16_Q(0.20349009),
  DSP16_Q(-0.07471617),
  DSP16_Q(0.04390317),
  DSP16_Q(-0.02955446),
  DSP16_Q(0.02101381),
  DSP16_Q(-0.01524765),
  DSP16_Q(0.01107023),
  DSP16_Q(-0.00792562),
  DSP16_Q(0.00551892),
  DSP16_Q(-0.00367778),
  DSP16_Q(0.00229235),
  DSP16_Q(-0.00128629),
  DSP16_Q(0.00060184),
  DSP16_Q(-0.00019168),
  DSP16_Q(0.00001434),
  DSP16_Q(0.00003425),
  DSP16_Q(-0.00025627),
  DSP16_Q(0.00071794),
  DSP16_Q(-0.00146143),
  DSP16_Q(0.00253546),
  DSP16_Q(-0.00400049),
  DSP16_Q(0.00593783),
  DSP16_Q(-0.00846672),
  DSP16_Q(0.01177758),
  DSP16_Q(-0.01620268),
  DSP16_Q(0.02238306),
  DSP16_Q(-0.03173083),
  DSP16_Q(0.04805040),
  DSP16_Q(-0.08615313),
  DSP16_Q(0.31278111),
  DSP16_Q(0.20001965),
  DSP16_Q(-0.07390452),
  DSP16_Q(0.04348486),
  DSP16_Q(-0.02928786),
  DSP16_Q(0.02082862),
  DSP16_Q(-0.01511413),
  DSP16_Q(0.01097280),
  DSP16_Q(-0.00785485),
  DSP16_Q(0.00546843),
  DSP16_Q(-0.00364291),
  DSP16_Q(0.00226944),
  DSP16_Q(-0.00127237),
  DSP16_Q(0.00059441),
  DSP16_Q(-0.00018860),
  DSP16_Q(0.00001379),
  DSP16_Q(0.00003472),
  DSP16_Q(-0.00025650),
  DSP16_Q(0.00071646),
  DSP16_Q(-0.00145647),
  DSP16_Q(0.00252497),
  DSP16_Q(-0.00398208),
  DSP16_Q(0.00590869),
  DSP16_Q(-0.00842349),
  DSP16_Q(0.01171615),
  DSP16_Q(-0.01611775),
  DSP16_Q(0.02226761),
  DSP16_Q(-0.03157529),
  DSP16_Q(0.04784462),
  DSP16_Q(-0.08593391),
  DSP16_Q(0.31558945),
  DSP16_Q(0.19654342),
  DSP16_Q(-0.07307094),
  DSP16_Q(0.04305201),
  DSP16_Q(-0.02901110),
  DSP16_Q(0.02063611),
  DSP16_Q(-0.01497527),
  DSP16_Q(0.01087150),
  DSP16_Q(-0.00778131),
  DSP16_Q(0.00541604),
  DSP16_Q(-0.00360679),
  DSP16_Q(0.00224578),
  DSP16_Q(-0.00125805),
  DSP16_Q(0.00058681),
  DSP16_Q(-0.00018548),
  DSP16_Q(0.00001325),
  DSP16_Q(0.00003517),
  DSP16_Q(-0.00025661),
  DSP16_Q(0.00071466),
  DSP16_Q(-0.00145088),
  DSP16_Q(0.00251341),
  DSP16_Q(-0.00396200),
  DSP16_Q(0.00587709),
  DSP16_Q(-0.00837678),
  DSP16_Q(0.01164988),
  DSP16_Q(-0.01602620),
  DSP16_Q(0.02214300),
  DSP16_Q(-0.03140672),
  DSP16_Q(0.04761899),
  DSP16_Q(-0.08567910),
  DSP16_Q(0.31836644),
  DSP16_Q(0.19306213),
  DSP16_Q(-0.07221591),
  DSP16_Q(0.04260487),
  DSP16_Q(-0.02872433),
  DSP16_Q(0.02043637),
  DSP16_Q(-0.01483113),
  DSP16_Q(0.01076637),
  DSP16_Q(-0.00770506),
  DSP16_Q(0.00536178),
  DSP16_Q(-0.00356945),
  DSP16_Q(0.00222138),
  DSP16_Q(-0.00124333),
  DSP16_Q(0.00057904),
  DSP16_Q(-0.00018232),
  DSP16_Q(0.00001272),
  DSP16_Q(0.00003561),
  DSP16_Q(-0.00025661),
  DSP16_Q(0.00071253),
  DSP16_Q(-0.00144465),
  DSP16_Q(0.00250077),
  DSP16_Q(-0.00394024),
  DSP16_Q(0.00584303),
  DSP16_Q(-0.00832658),
  DSP16_Q(0.01157879),
  DSP16_Q(-0.01592804),
  DSP16_Q(0.02200924),
  DSP16_Q(-0.03122514),
  DSP16_Q(0.04737348),
  DSP16_Q(-0.08538845),
  DSP16_Q(0.32111142),
  DSP16_Q(0.18957652),
  DSP16_Q(-0.07133990),
  DSP16_Q(0.04214369),
  DSP16_Q(-0.02842772),
  DSP16_Q(0.02022951),
  DSP16_Q(-0.01468181),
  DSP16_Q(0.01065747),
  DSP16_Q(-0.00762612),
  DSP16_Q(0.00530567),
  DSP16_Q(-0.00353090),
  DSP16_Q(0.00219625),
  DSP16_Q(-0.00122823),
  DSP16_Q(0.00057111),
  DSP16_Q(-0.00017914),
  DSP16_Q(0.00001219),
  DSP16_Q(0.00003603),
  DSP16_Q(-0.00025647),
  DSP16_Q(0.00071008),
  DSP16_Q(-0.00143779),
  DSP16_Q(0.00248706),
  DSP16_Q(-0.00391681),
  DSP16_Q(0.00580651),
  DSP16_Q(-0.00827291),
  DSP16_Q(0.01150290),
  DSP16_Q(-0.01582326),
  DSP16_Q(0.02186635),
  DSP16_Q(-0.03103055),
  DSP16_Q(0.04710805),
  DSP16_Q(-0.08506173),
  DSP16_Q(0.32382378),
  DSP16_Q(0.18608734),
  DSP16_Q(-0.07044341),
  DSP16_Q(0.04166872),
  DSP16_Q(-0.02812141),
  DSP16_Q(0.02001564),
  DSP16_Q(-0.01452736),
  DSP16_Q(0.01054486),
  DSP16_Q(-0.00754455),
  DSP16_Q(0.00524775),
  DSP16_Q(-0.00349116),
  DSP16_Q(0.00217040),
  DSP16_Q(-0.00121275),
  DSP16_Q(0.00056302),
  DSP16_Q(-0.00017592),
  DSP16_Q(0.00001167),
  DSP16_Q(0.00003643),
  DSP16_Q(-0.00025621),
  DSP16_Q(0.00070730),
  DSP16_Q(-0.00143029),
  DSP16_Q(0.00247226),
  DSP16_Q(-0.00389171),
  DSP16_Q(0.00576754),
  DSP16_Q(-0.00821577),
  DSP16_Q(0.01142220),
  DSP16_Q(-0.01571190),
  DSP16_Q(0.02171434),
  DSP16_Q(-0.03082296),
  DSP16_Q(0.04682269),
  DSP16_Q(-0.08469871),
  DSP16_Q(0.32650290),
  DSP16_Q(0.18259533),
  DSP16_Q(-0.06952691),
  DSP16_Q(0.04118020),
  DSP16_Q(-0.02780557),
  DSP16_Q(0.01979487),
  DSP16_Q(-0.01436789),
  DSP16_Q(0.01042861),
  DSP16_Q(-0.00746038),
  DSP16_Q(0.00518805),
  DSP16_Q(-0.00345027),
  DSP16_Q(0.00214386),
  DSP16_Q(-0.00119690),
  DSP16_Q(0.00055479),
  DSP16_Q(-0.00017267),
  DSP16_Q(0.00001117),
  DSP16_Q(0.00003681),
  DSP16_Q(-0.00025583),
  DSP16_Q(0.00070419),
  DSP16_Q(-0.00142215),
  DSP16_Q(0.00245638),
  DSP16_Q(-0.00386493),
  DSP16_Q(0.00572612),
  DSP16_Q(-0.00815517),
  DSP16_Q(0.01133671),
  DSP16_Q(-0.01559397),
  DSP16_Q(0.02155324),
  DSP16_Q(-0.03060240),
  DSP16_Q(0.04651739),
  DSP16_Q(-0.08429916),
  DSP16_Q(0.32914817),
  DSP16_Q(0.17910123),
  DSP16_Q(-0.06859090),
  DSP16_Q(0.04067841),
  DSP16_Q(-0.02748036),
  DSP16_Q(0.01956731),
  DSP16_Q(-0.01420346),
  DSP16_Q(0.01030877),
  DSP16_Q(-0.00737367),
  DSP16_Q(0.00512660),
  DSP16_Q(-0.00340824),
  DSP16_Q(0.00211663),
  DSP16_Q(-0.00118069),
  DSP16_Q(0.00054641),
  DSP16_Q(-0.00016939),
  DSP16_Q(0.00001067),
  DSP16_Q(0.00003717),
  DSP16_Q(-0.00025531),
  DSP16_Q(0.00070075),
  DSP16_Q(-0.00141336),
  DSP16_Q(0.00243943),
  DSP16_Q(-0.00383649),
  DSP16_Q(0.00568226),
  DSP16_Q(-0.00809112),
  DSP16_Q(0.01124645),
  DSP16_Q(-0.01546948),
  DSP16_Q(0.02138307),
  DSP16_Q(-0.03036888),
  DSP16_Q(0.04619215),
  DSP16_Q(-0.08386287),
  DSP16_Q(0.33175898),
  DSP16_Q(0.17560577),
  DSP16_Q(-0.06763588),
  DSP16_Q(0.04016359),
  DSP16_Q(-0.02714595),
  DSP16_Q(0.01933309),
  DSP16_Q(-0.01403416),
  DSP16_Q(0.01018540),
  DSP16_Q(-0.00728445),
  DSP16_Q(0.00506343),
  DSP16_Q(-0.00336509),
  DSP16_Q(0.00208874),
  DSP16_Q(-0.00116413),
  DSP16_Q(0.00053789),
  DSP16_Q(-0.00016609),
  DSP16_Q(0.00001019),
  DSP16_Q(0.00003751),
  DSP16_Q(-0.00025466),
  DSP16_Q(0.00069697),
  DSP16_Q(-0.00140394),
  DSP16_Q(0.00242139),
  DSP16_Q(-0.00380637),
  DSP16_Q(0.00563596),
  DSP16_Q(-0.00802362),
  DSP16_Q(0.01115143),
  DSP16_Q(-0.01533846),
  DSP16_Q(0.02120387),
  DSP16_Q(-0.03012243),
  DSP16_Q(0.04584697),
  DSP16_Q(-0.08338964),
  DSP16_Q(0.33433473),
  DSP16_Q(0.17210968),
  DSP16_Q(-0.06666233),
  DSP16_Q(0.03963603),
  DSP16_Q(-0.02680251),
  DSP16_Q(0.01909231),
  DSP16_Q(-0.01386008),
  DSP16_Q(0.01005856),
  DSP16_Q(-0.00719277),
  DSP16_Q(0.00499858),
  DSP16_Q(-0.00332085),
  DSP16_Q(0.00206019),
  DSP16_Q(-0.00114724),
  DSP16_Q(0.00052923),
  DSP16_Q(-0.00016277),
  DSP16_Q(0.00000972),
  DSP16_Q(0.00003782),
  DSP16_Q(-0.00025388),
  DSP16_Q(0.00069286),
  DSP16_Q(-0.00139387),
  DSP16_Q(0.00240228),
  DSP16_Q(-0.00377459),
  DSP16_Q(0.00558722),
  DSP16_Q(-0.00795270),
  DSP16_Q(0.01105167),
  DSP16_Q(-0.01520093),
  DSP16_Q(0.02101565),
  DSP16_Q(-0.02986310),
  DSP16_Q(0.04548185),
  DSP16_Q(-0.08287928),
  DSP16_Q(0.33687484),
  DSP16_Q(0.16861371),
  DSP16_Q(-0.06567076),
  DSP16_Q(0.03909598),
  DSP16_Q(-0.02645021),
  DSP16_Q(0.01884511),
  DSP16_Q(-0.01368130),
  DSP16_Q(0.00992832),
  DSP16_Q(-0.00709868),
  DSP16_Q(0.00493208),
  DSP16_Q(-0.00327554),
  DSP16_Q(0.00203101),
  DSP16_Q(-0.00113001),
  DSP16_Q(0.00052045),
  DSP16_Q(-0.00015942),
  DSP16_Q(0.00000925),
  DSP16_Q(0.00003812),
  DSP16_Q(-0.00025297),
  DSP16_Q(0.00068842),
  DSP16_Q(-0.00138315),
  DSP16_Q(0.00238208),
  DSP16_Q(-0.00374116),
  DSP16_Q(0.00553606),
  DSP16_Q(-0.00787836),
  DSP16_Q(0.01094719),
  DSP16_Q(-0.01505693),
  DSP16_Q(0.02081846),
  DSP16_Q(-0.02959091),
  DSP16_Q(0.04509682),
  DSP16_Q(-0.08233160),
  DSP16_Q(0.33937872),
  DSP16_Q(0.16511858),
  DSP16_Q(-0.06466166),
  DSP16_Q(0.03854372),
  DSP16_Q(-0.02608922),
  DSP16_Q(0.01859159),
  DSP16_Q(-0.01349791),
  DSP16_Q(0.00979474),
  DSP16_Q(-0.00700223),
  DSP16_Q(0.00486397),
  DSP16_Q(-0.00322919),
  DSP16_Q(0.00200121),
  DSP16_Q(-0.00111247),
  DSP16_Q(0.00051154),
  DSP16_Q(-0.00015606),
  DSP16_Q(0.00000880),
  DSP16_Q(0.00003838),
  DSP16_Q(-0.00025191),
  DSP16_Q(0.00068364),
  DSP16_Q(-0.00137180),
  DSP16_Q(0.00236081),
  DSP16_Q(-0.00370607),
  DSP16_Q(0.00548249),
  DSP16_Q(-0.00780061),
  DSP16_Q(0.01083801),
  DSP16_Q(-0.01490648),
  DSP16_Q(0.02061233),
  DSP16_Q(-0.02930592),
  DSP16_Q(0.04469191),
  DSP16_Q(-0.08174642),
  DSP16_Q(0.34184580),
  DSP16_Q(0.16162503),
  DSP16_Q(-0.06363554),
  DSP16_Q(0.03797952),
  DSP16_Q(-0.02571973),
  DSP16_Q(0.01833188),
  DSP16_Q(-0.01331000),
  DSP16_Q(0.00965790),
  DSP16_Q(-0.00690346),
  DSP16_Q(0.00479427),
  DSP16_Q(-0.00318181),
  DSP16_Q(0.00197080),
  DSP16_Q(-0.00109462),
  DSP16_Q(0.00050251),
  DSP16_Q(-0.00015268),
  DSP16_Q(0.00000836),
  DSP16_Q(0.00003862),
  DSP16_Q(-0.00025073),
  DSP16_Q(0.00067852),
  DSP16_Q(-0.00135979),
  DSP16_Q(0.00233847),
  DSP16_Q(-0.00366932),
  DSP16_Q(0.00542652),
  DSP16_Q(-0.00771948),
  DSP16_Q(0.01072415),
  DSP16_Q(-0.01474961),
  DSP16_Q(0.02039731),
  DSP16_Q(-0.02900817),
  DSP16_Q(0.04426713),
  DSP16_Q(-0.08112357),
  DSP16_Q(0.34427551),
  DSP16_Q(0.15813377),
  DSP16_Q(-0.06259291),
  DSP16_Q(0.03740367),
  DSP16_Q(-0.02534191),
  DSP16_Q(0.01806611),
  DSP16_Q(-0.01311766),
  DSP16_Q(0.00951784),
  DSP16_Q(-0.00680243),
  DSP16_Q(0.00472303),
  DSP16_Q(-0.00313344),
  DSP16_Q(0.00193981),
  DSP16_Q(-0.00107646),
  DSP16_Q(0.00049337),
  DSP16_Q(-0.00014929),
  DSP16_Q(0.00000793),
  DSP16_Q(0.00003884),
  DSP16_Q(-0.00024940),
  DSP16_Q(0.00067306),
  DSP16_Q(-0.00134714),
  DSP16_Q(0.00231505),
  DSP16_Q(-0.00363094),
  DSP16_Q(0.00536815),
  DSP16_Q(-0.00763498),
  DSP16_Q(0.01060565),
  DSP16_Q(-0.01458637),
  DSP16_Q(0.02017345),
  DSP16_Q(-0.02869771),
  DSP16_Q(0.04382255),
  DSP16_Q(-0.08046291),
  DSP16_Q(0.34666729),
  DSP16_Q(0.15464554),
  DSP16_Q(-0.06153426),
  DSP16_Q(0.03681643),
  DSP16_Q(-0.02495594),
  DSP16_Q(0.01779441),
  DSP16_Q(-0.01292098),
  DSP16_Q(0.00937465),
  DSP16_Q(-0.00669917),
  DSP16_Q(0.00465028),
  DSP16_Q(-0.00308410),
  DSP16_Q(0.00190825),
  DSP16_Q(-0.00105802),
  DSP16_Q(0.00048413),
  DSP16_Q(-0.00014588),
  DSP16_Q(0.00000752),
  DSP16_Q(0.00003903),
  DSP16_Q(-0.00024793),
  DSP16_Q(0.00066726),
  DSP16_Q(-0.00133385),
  DSP16_Q(0.00229057),
  DSP16_Q(-0.00359092),
  DSP16_Q(0.00530740),
  DSP16_Q(-0.00754714),
  DSP16_Q(0.01048253),
  DSP16_Q(-0.01441678),
  DSP16_Q(0.01994079),
  DSP16_Q(-0.02837461),
  DSP16_Q(0.04335819),
  DSP16_Q(-0.07976429),
  DSP16_Q(0.34902059),
  DSP16_Q(0.15116105),
  DSP16_Q(-0.06046012),
  DSP16_Q(0.03621810),
  DSP16_Q(-0.02456201),
  DSP16_Q(0.01751690),
  DSP16_Q(-0.01272007),
  DSP16_Q(0.00922840),
  DSP16_Q(-0.00659375),
  DSP16_Q(0.00457605),
  DSP16_Q(-0.00303382),
  DSP16_Q(0.00187613),
  DSP16_Q(-0.00103930),
  DSP16_Q(0.00047478),
  DSP16_Q(-0.00014247),
  DSP16_Q(0.00000711),
  DSP16_Q(0.00003919),
  DSP16_Q(-0.00024632),
  DSP16_Q(0.00066111),
  DSP16_Q(-0.00131992),
  DSP16_Q(0.00226502),
  DSP16_Q(-0.00354926),
  DSP16_Q(0.00524428),
  DSP16_Q(-0.00745596),
  DSP16_Q(0.01035481),
  DSP16_Q(-0.01424090),
  DSP16_Q(0.01969939),
  DSP16_Q(-0.02803893),
  DSP16_Q(0.04287412),
  DSP16_Q(-0.07902756),
  DSP16_Q(0.35133488),
  DSP16_Q(0.14768102),
  DSP16_Q(-0.05937098),
  DSP16_Q(0.03560897),
  DSP16_Q(-0.02416030),
  DSP16_Q(0.01723372),
  DSP16_Q(-0.01251500),
  DSP16_Q(0.00907914),
  DSP16_Q(-0.00648621),
  DSP16_Q(0.00450038),
  DSP16_Q(-0.00298261),
  DSP16_Q(0.00184347),
  DSP16_Q(-0.00102031),
  DSP16_Q(0.00046533),
  DSP16_Q(-0.00013905),
  DSP16_Q(0.00000672),
  DSP16_Q(0.00003932),
  DSP16_Q(-0.00024457),
  DSP16_Q(0.00065463),
  DSP16_Q(-0.00130534),
  DSP16_Q(0.00223841),
  DSP16_Q(-0.00350599),
  DSP16_Q(0.00517881),
  DSP16_Q(-0.00736148),
  DSP16_Q(0.01022254),
  DSP16_Q(-0.01405875),
  DSP16_Q(0.01944930),
  DSP16_Q(-0.02769073),
  DSP16_Q(0.04237039),
  DSP16_Q(-0.07825260),
  DSP16_Q(0.35360961),
  DSP16_Q(0.14420617),
  DSP16_Q(-0.05826735),
  DSP16_Q(0.03498931),
  DSP16_Q(-0.02375101),
  DSP16_Q(0.01694499),
  DSP16_Q(-0.01230588),
  DSP16_Q(0.00892695),
  DSP16_Q(-0.00637660),
  DSP16_Q(0.00442332),
  DSP16_Q(-0.00293050),
  DSP16_Q(0.00181029),
  DSP16_Q(-0.00100107),
  DSP16_Q(0.00045579),
  DSP16_Q(-0.00013563),
  DSP16_Q(0.00000634),
  DSP16_Q(0.00003942),
  DSP16_Q(-0.00024268),
  DSP16_Q(0.00064781),
  DSP16_Q(-0.00129012),
  DSP16_Q(0.00221075),
  DSP16_Q(-0.00346111),
  DSP16_Q(0.00511101),
  DSP16_Q(-0.00726372),
  DSP16_Q(0.01008574),
  DSP16_Q(-0.01387040),
  DSP16_Q(0.01919059),
  DSP16_Q(-0.02733010),
  DSP16_Q(0.04184709),
  DSP16_Q(-0.07743929),
  DSP16_Q(0.35584427),
  DSP16_Q(0.14073721),
  DSP16_Q(-0.05714976),
  DSP16_Q(0.03435942),
  DSP16_Q(-0.02333432),
  DSP16_Q(0.01665086),
  DSP16_Q(-0.01209281),
  DSP16_Q(0.00877191),
  DSP16_Q(-0.00626498),
  DSP16_Q(0.00434489),
  DSP16_Q(-0.00287753),
  DSP16_Q(0.00177661),
  DSP16_Q(-0.00098157),
  DSP16_Q(0.00044617),
  DSP16_Q(-0.00013220),
  DSP16_Q(0.00000597),
  DSP16_Q(0.00003949),
  DSP16_Q(-0.00024064),
  DSP16_Q(0.00064064),
  DSP16_Q(-0.00127426),
  DSP16_Q(0.00218203),
  DSP16_Q(-0.00341462),
  DSP16_Q(0.00504088),
  DSP16_Q(-0.00716270),
  DSP16_Q(0.00994445),
  DSP16_Q(-0.01367589),
  DSP16_Q(0.01892332),
  DSP16_Q(-0.02695711),
  DSP16_Q(0.04130427),
  DSP16_Q(-0.07658753),
  DSP16_Q(0.35803833),
  DSP16_Q(0.13727484),
  DSP16_Q(-0.05601871),
  DSP16_Q(0.03371960),
  DSP16_Q(-0.02291043),
  DSP16_Q(0.01635146),
  DSP16_Q(-0.01187588),
  DSP16_Q(0.00861408),
  DSP16_Q(-0.00615140),
  DSP16_Q(0.00426513),
  DSP16_Q(-0.00282371),
  DSP16_Q(0.00174243),
  DSP16_Q(-0.00096183),
  DSP16_Q(0.00043647),
  DSP16_Q(-0.00012877),
  DSP16_Q(0.00000562),
  DSP16_Q(0.00003952),
  DSP16_Q(-0.00023846),
  DSP16_Q(0.00063313),
  DSP16_Q(-0.00125776),
  DSP16_Q(0.00215226),
  DSP16_Q(-0.00336654),
  DSP16_Q(0.00496844),
  DSP16_Q(-0.00705844),
  DSP16_Q(0.00979870),
  DSP16_Q(-0.01347526),
  DSP16_Q(0.01864756),
  DSP16_Q(-0.02657185),
  DSP16_Q(0.04074204),
  DSP16_Q(-0.07569722),
  DSP16_Q(0.36019129),
  DSP16_Q(0.13381978),
  DSP16_Q(-0.05487471),
  DSP16_Q(0.03307014),
  DSP16_Q(-0.02247954),
  DSP16_Q(0.01604692),
  DSP16_Q(-0.01165519),
  DSP16_Q(0.00845354),
  DSP16_Q(-0.00603592),
  DSP16_Q(0.00418408),
  DSP16_Q(-0.00276908),
  DSP16_Q(0.00170779),
  DSP16_Q(-0.00094187),
  DSP16_Q(0.00042669),
  DSP16_Q(-0.00012534),
  DSP16_Q(0.00000527),
  DSP16_Q(0.00003953),
  DSP16_Q(-0.00023612),
  DSP16_Q(0.00062527),
  DSP16_Q(-0.00124063),
  DSP16_Q(0.00212146),
  DSP16_Q(-0.00331688),
  DSP16_Q(0.00489372),
  DSP16_Q(-0.00695098),
  DSP16_Q(0.00964854),
  DSP16_Q(-0.01326858),
  DSP16_Q(0.01836337),
  DSP16_Q(-0.02617441),
  DSP16_Q(0.04016048),
  DSP16_Q(-0.07476826),
  DSP16_Q(0.36230265),
  DSP16_Q(0.13037271),
  DSP16_Q(-0.05371828),
  DSP16_Q(0.03241134),
  DSP16_Q(-0.02204183),
  DSP16_Q(0.01573739),
  DSP16_Q(-0.01143085),
  DSP16_Q(0.00829036),
  DSP16_Q(-0.00591857),
  DSP16_Q(0.00410179),
  DSP16_Q(-0.00271365),
  DSP16_Q(0.00167270),
  DSP16_Q(-0.00092169),
  DSP16_Q(0.00041684),
  DSP16_Q(-0.00012191),
  DSP16_Q(0.00000494),
  DSP16_Q(0.00003950),
  DSP16_Q(-0.00023365),
  DSP16_Q(0.00061707),
  DSP16_Q(-0.00122287),
  DSP16_Q(0.00208962),
  DSP16_Q(-0.00326565),
  DSP16_Q(0.00481673),
  DSP16_Q(-0.00684034),
  DSP16_Q(0.00949401),
  DSP16_Q(-0.01305590),
  DSP16_Q(0.01807084),
  DSP16_Q(-0.02576487),
  DSP16_Q(0.03955968),
  DSP16_Q(-0.07380059),
  DSP16_Q(0.36437193),
  DSP16_Q(0.12693434),
  DSP16_Q(-0.05254993),
  DSP16_Q(0.03174349),
  DSP16_Q(-0.02159750),
  DSP16_Q(0.01542300),
  DSP16_Q(-0.01120296),
  DSP16_Q(0.00812462),
  DSP16_Q(-0.00579943),
  DSP16_Q(0.00401828),
  DSP16_Q(-0.00265746),
  DSP16_Q(0.00163716),
  DSP16_Q(-0.00090130),
  DSP16_Q(0.00040693),
  DSP16_Q(-0.00011849),
  DSP16_Q(0.00000462),
  DSP16_Q(0.00003944),
  DSP16_Q(-0.00023102),
  DSP16_Q(0.00060853),
  DSP16_Q(-0.00120448),
  DSP16_Q(0.00205675),
  DSP16_Q(-0.00321287),
  DSP16_Q(0.00473749),
  DSP16_Q(-0.00672656),
  DSP16_Q(0.00933515),
  DSP16_Q(-0.01283727),
  DSP16_Q(0.01777004),
  DSP16_Q(-0.02534335),
  DSP16_Q(0.03893977),
  DSP16_Q(-0.07279413),
  DSP16_Q(0.36639864),
  DSP16_Q(0.12350536),
  DSP16_Q(-0.05137018),
  DSP16_Q(0.03106690),
  DSP16_Q(-0.02114677),
  DSP16_Q(0.01510389),
  DSP16_Q(-0.01097161),
  DSP16_Q(0.00795639),
  DSP16_Q(-0.00567854),
  DSP16_Q(0.00393360),
  DSP16_Q(-0.00260053),
  DSP16_Q(0.00160121),
  DSP16_Q(-0.00088072),
  DSP16_Q(0.00039695),
  DSP16_Q(-0.00011507),
  DSP16_Q(0.00000431),
  DSP16_Q(0.00003934),
  DSP16_Q(-0.00022824),
  DSP16_Q(0.00059965),
  DSP16_Q(-0.00118546),
  DSP16_Q(0.00202286),
  DSP16_Q(-0.00315854),
  DSP16_Q(0.00465603),
  DSP16_Q(-0.00660966),
  DSP16_Q(0.00917200),
  DSP16_Q(-0.01261277),
  DSP16_Q(0.01746105),
  DSP16_Q(-0.02490994),
  DSP16_Q(0.03830085),
  DSP16_Q(-0.07174882),
  DSP16_Q(0.36838231),
  DSP16_Q(0.12008644),
  DSP16_Q(-0.05017955),
  DSP16_Q(0.03038188),
  DSP16_Q(-0.02068982),
  DSP16_Q(0.01478021),
  DSP16_Q(-0.01073691),
  DSP16_Q(0.00778575),
  DSP16_Q(-0.00555596),
  DSP16_Q(0.00384778),
  DSP16_Q(-0.00254289),
  DSP16_Q(0.00156486),
  DSP16_Q(-0.00085994),
  DSP16_Q(0.00038692),
  DSP16_Q(-0.00011166),
  DSP16_Q(0.00000402),
  DSP16_Q(0.00003920),
  DSP16_Q(-0.00022532),
  DSP16_Q(0.00059043),
  DSP16_Q(-0.00116581),
  DSP16_Q(0.00198796),
  DSP16_Q(-0.00310268),
  DSP16_Q(0.00457236),
  DSP16_Q(-0.00648968),
  DSP16_Q(0.00900461),
  DSP16_Q(-0.01238245),
  DSP16_Q(0.01714397),
  DSP16_Q(-0.02446476),
  DSP16_Q(0.03764304),
  DSP16_Q(-0.07066463),
  DSP16_Q(0.37032249),
  DSP16_Q(0.11667829),
  DSP16_Q(-0.04897854),
  DSP16_Q(0.02968871),
  DSP16_Q(-0.02022686),
  DSP16_Q(0.01445211),
  DSP16_Q(-0.01049898),
  DSP16_Q(0.00761277),
  DSP16_Q(-0.00543175),
  DSP16_Q(0.00376087),
  DSP16_Q(-0.00248456),
  DSP16_Q(0.00152813),
  DSP16_Q(-0.00083900),
  DSP16_Q(0.00037685),
  DSP16_Q(-0.00010827),
  DSP16_Q(0.00000374),
  DSP16_Q(0.00003903),
  DSP16_Q(-0.00022224),
  DSP16_Q(0.00058087),
  DSP16_Q(-0.00114555),
  DSP16_Q(0.00195206),
  DSP16_Q(-0.00304530),
  DSP16_Q(0.00448651),
  DSP16_Q(-0.00636666),
  DSP16_Q(0.00883304),
  DSP16_Q(-0.01214638),
  DSP16_Q(0.01681887),
  DSP16_Q(-0.02400791),
  DSP16_Q(0.03696648),
  DSP16_Q(-0.06954152),
  DSP16_Q(0.37221873),
  DSP16_Q(0.11328157),
  DSP16_Q(-0.04776768),
  DSP16_Q(0.02898772),
  DSP16_Q(-0.01975810),
  DSP16_Q(0.01411972),
  DSP16_Q(-0.01025790),
  DSP16_Q(0.00743753),
  DSP16_Q(-0.00530595),
  DSP16_Q(0.00367291),
  DSP16_Q(-0.00242557),
  DSP16_Q(0.00149103),
  DSP16_Q(-0.00081788),
  DSP16_Q(0.00036673),
  DSP16_Q(-0.00010488),
  DSP16_Q(0.00000347),
  DSP16_Q(0.00003882),
  DSP16_Q(-0.00021901),
  DSP16_Q(0.00057097),
  DSP16_Q(-0.00112467),
  DSP16_Q(0.00191515),
  DSP16_Q(-0.00298643),
  DSP16_Q(0.00439850),
  DSP16_Q(-0.00624062),
  DSP16_Q(0.00865732),
  DSP16_Q(-0.01190463),
  DSP16_Q(0.01648585),
  DSP16_Q(-0.02353952),
  DSP16_Q(0.03627130),
  DSP16_Q(-0.06837945),
  DSP16_Q(0.37407058),
  DSP16_Q(0.10989695),
  DSP16_Q(-0.04654748),
  DSP16_Q(0.02827920),
  DSP16_Q(-0.01928374),
  DSP16_Q(0.01378319),
  DSP16_Q(-0.01001379),
  DSP16_Q(0.00726011),
  DSP16_Q(-0.00517864),
  DSP16_Q(0.00358393),
  DSP16_Q(-0.00236596),
  DSP16_Q(0.00145357),
  DSP16_Q(-0.00079661),
  DSP16_Q(0.00035657),
  DSP16_Q(-0.00010151),
  DSP16_Q(0.00000321),
  DSP16_Q(0.00003858),
  DSP16_Q(-0.00021564),
  DSP16_Q(0.00056073),
  DSP16_Q(-0.00110317),
  DSP16_Q(0.00187726),
  DSP16_Q(-0.00292606),
  DSP16_Q(0.00430836),
  DSP16_Q(-0.00611160),
  DSP16_Q(0.00847751),
  DSP16_Q(-0.01165727),
  DSP16_Q(0.01614501),
  DSP16_Q(-0.02305972),
  DSP16_Q(0.03555765),
  DSP16_Q(-0.06717841),
  DSP16_Q(0.37587761),
  DSP16_Q(0.10652511),
  DSP16_Q(-0.04531844),
  DSP16_Q(0.02756347),
  DSP16_Q(-0.01880398),
  DSP16_Q(0.01344267),
  DSP16_Q(-0.00976676),
  DSP16_Q(0.00708058),
  DSP16_Q(-0.00504985),
  DSP16_Q(0.00349397),
  DSP16_Q(-0.00230574),
  DSP16_Q(0.00141579),
  DSP16_Q(-0.00077519),
  DSP16_Q(0.00034637),
  DSP16_Q(-0.00009815),
  DSP16_Q(0.00000296),
  DSP16_Q(0.00003829),
  DSP16_Q(-0.00021211),
  DSP16_Q(0.00055015),
  DSP16_Q(-0.00108108),
  DSP16_Q(0.00183840),
  DSP16_Q(-0.00286424),
  DSP16_Q(0.00421612),
  DSP16_Q(-0.00597965),
  DSP16_Q(0.00829367),
  DSP16_Q(-0.01140437),
  DSP16_Q(0.01579644),
  DSP16_Q(-0.02256863),
  DSP16_Q(0.03482567),
  DSP16_Q(-0.06593840),
  DSP16_Q(0.37763941),
  DSP16_Q(0.10316670),
  DSP16_Q(-0.04408109),
  DSP16_Q(0.02684084),
  DSP16_Q(-0.01831904),
  DSP16_Q(0.01309831),
  DSP16_Q(-0.00951691),
  DSP16_Q(0.00689903),
  DSP16_Q(-0.00491966),
  DSP16_Q(0.00340308),
  DSP16_Q(-0.00224495),
  DSP16_Q(0.00137770),
  DSP16_Q(-0.00075364),
  DSP16_Q(0.00033615),
  DSP16_Q(-0.00009481),
  DSP16_Q(0.00000273),
  DSP16_Q(0.00003796),
  DSP16_Q(-0.00020842),
  DSP16_Q(0.00053924),
  DSP16_Q(-0.00105837),
  DSP16_Q(0.00179856),
  DSP16_Q(-0.00280096),
  DSP16_Q(0.00412179),
  DSP16_Q(-0.00584481),
  DSP16_Q(0.00810586),
  DSP16_Q(-0.01114602),
  DSP16_Q(0.01544025),
  DSP16_Q(-0.02206639),
  DSP16_Q(0.03407554),
  DSP16_Q(-0.06465943),
  DSP16_Q(0.37935556),
  DSP16_Q(0.09982238),
  DSP16_Q(-0.04283594),
  DSP16_Q(0.02611161),
  DSP16_Q(-0.01782913),
  DSP16_Q(0.01275025),
  DSP16_Q(-0.00926435),
  DSP16_Q(0.00671554),
  DSP16_Q(-0.00478812),
  DSP16_Q(0.00331130),
  DSP16_Q(-0.00218361),
  DSP16_Q(0.00133930),
  DSP16_Q(-0.00073196),
  DSP16_Q(0.00032591),
  DSP16_Q(-0.00009149),
  DSP16_Q(0.00000251),
  DSP16_Q(0.00003760),
  DSP16_Q(-0.00020459),
  DSP16_Q(0.00052799),
  DSP16_Q(-0.00103507),
  DSP16_Q(0.00175777),
  DSP16_Q(-0.00273624),
  DSP16_Q(0.00402542),
  DSP16_Q(-0.00570710),
  DSP16_Q(0.00791412),
  DSP16_Q(-0.01088229),
  DSP16_Q(0.01507654),
  DSP16_Q(-0.02155313),
  DSP16_Q(0.03330741),
  DSP16_Q(-0.06334151),
  DSP16_Q(0.38102566),
  DSP16_Q(0.09649281),
  DSP16_Q(-0.04158350),
  DSP16_Q(0.02537609),
  DSP16_Q(-0.01733445),
  DSP16_Q(0.01239865),
  DSP16_Q(-0.00900919),
  DSP16_Q(0.00653018),
  DSP16_Q(-0.00465528),
  DSP16_Q(0.00321866),
  DSP16_Q(-0.00212175),
  DSP16_Q(0.00130063),
  DSP16_Q(-0.00071017),
  DSP16_Q(0.00031564),
  DSP16_Q(-0.00008820),
  DSP16_Q(0.00000230),
  DSP16_Q(0.00003719),
  DSP16_Q(-0.00020060),
  DSP16_Q(0.00051641),
  DSP16_Q(-0.00101118),
  DSP16_Q(0.00171603),
  DSP16_Q(-0.00267012),
  DSP16_Q(0.00392702),
  DSP16_Q(-0.00556658),
  DSP16_Q(0.00771852),
  DSP16_Q(-0.01061326),
  DSP16_Q(0.01470543),
  DSP16_Q(-0.02102900),
  DSP16_Q(0.03252146),
  DSP16_Q(-0.06198466),
  DSP16_Q(0.38264934),
  DSP16_Q(0.09317862),
  DSP16_Q(-0.04032428),
  DSP16_Q(0.02463461),
  DSP16_Q(-0.01683521),
  DSP16_Q(0.01204365),
  DSP16_Q(-0.00875154),
  DSP16_Q(0.00634303),
  DSP16_Q(-0.00452120),
  DSP16_Q(0.00312521),
  DSP16_Q(-0.00205940),
  DSP16_Q(0.00126170),
  DSP16_Q(-0.00068827),
  DSP16_Q(0.00030536),
  DSP16_Q(-0.00008492),
  DSP16_Q(0.00000210),
  DSP16_Q(0.00003674),
  DSP16_Q(-0.00019646),
  DSP16_Q(0.00050450),
  DSP16_Q(-0.00098670),
  DSP16_Q(0.00167335),
  DSP16_Q(-0.00260260),
  DSP16_Q(0.00382663),
  DSP16_Q(-0.00542330),
  DSP16_Q(0.00751913),
  DSP16_Q(-0.01033901),
  DSP16_Q(0.01432702),
  DSP16_Q(-0.02049415),
  DSP16_Q(0.03171788),
  DSP16_Q(-0.06058892),
  DSP16_Q(0.38422619),
  DSP16_Q(0.08988045),
  DSP16_Q(-0.03905878),
  DSP16_Q(0.02388746),
  DSP16_Q(-0.01633164),
  DSP16_Q(0.01168541),
  DSP16_Q(-0.00849151),
  DSP16_Q(0.00615418),
  DSP16_Q(-0.00438595),
  DSP16_Q(0.00303099),
  DSP16_Q(-0.00199658),
  DSP16_Q(0.00122252),
  DSP16_Q(-0.00066628),
  DSP16_Q(0.00029508),
  DSP16_Q(-0.00008166),
  DSP16_Q(0.00000191),
  DSP16_Q(0.00003624),
  DSP16_Q(-0.00019217),
  DSP16_Q(0.00049226),
  DSP16_Q(-0.00096164),
  DSP16_Q(0.00162976),
  DSP16_Q(-0.00253370),
  DSP16_Q(0.00372427),
  DSP16_Q(-0.00527728),
  DSP16_Q(0.00731599),
  DSP16_Q(-0.01005963),
  DSP16_Q(0.01394143),
  DSP16_Q(-0.01994873),
  DSP16_Q(0.03089685),
  DSP16_Q(-0.05915435),
  DSP16_Q(0.38575587),
  DSP16_Q(0.08659894),
  DSP16_Q(-0.03778753),
  DSP16_Q(0.02313497),
  DSP16_Q(-0.01582393),
  DSP16_Q(0.01132408),
  DSP16_Q(-0.00822921),
  DSP16_Q(0.00596371),
  DSP16_Q(-0.00424957),
  DSP16_Q(0.00293604),
  DSP16_Q(-0.00193332),
  DSP16_Q(0.00118312),
  DSP16_Q(-0.00064420),
  DSP16_Q(0.00028478),
  DSP16_Q(-0.00007844),
  DSP16_Q(0.00000173),
  DSP16_Q(0.00003570),
  DSP16_Q(-0.00018773),
  DSP16_Q(0.00047970),
  DSP16_Q(-0.00093601),
  DSP16_Q(0.00158525),
  DSP16_Q(-0.00246345),
  DSP16_Q(0.00361999),
  DSP16_Q(-0.00512859),
  DSP16_Q(0.00710918),
  DSP16_Q(-0.00977522),
  DSP16_Q(0.01354878),
  DSP16_Q(-0.01939290),
  DSP16_Q(0.03005857),
  DSP16_Q(-0.05768099),
  DSP16_Q(0.38723802),
  DSP16_Q(0.08333471),
  DSP16_Q(-0.03651101),
  DSP16_Q(0.02237745),
  DSP16_Q(-0.01531231),
  DSP16_Q(0.01095981),
  DSP16_Q(-0.00796475),
  DSP16_Q(0.00577169),
  DSP16_Q(-0.00411214),
  DSP16_Q(0.00284040),
  DSP16_Q(-0.00186965),
  DSP16_Q(0.00114351),
  DSP16_Q(-0.00062205),
  DSP16_Q(0.00027449),
  DSP16_Q(-0.00007523),
  DSP16_Q(0.00000156),
  DSP16_Q(0.00003512),
  DSP16_Q(-0.00018313),
  DSP16_Q(0.00046681),
  DSP16_Q(-0.00090981),
  DSP16_Q(0.00153984),
  DSP16_Q(-0.00239186),
  DSP16_Q(0.00351380),
  DSP16_Q(-0.00497726),
  DSP16_Q(0.00689877),
  DSP16_Q(-0.00948585),
  DSP16_Q(0.01314920),
  DSP16_Q(-0.01882683),
  DSP16_Q(0.02920324),
  DSP16_Q(-0.05616893),
  DSP16_Q(0.38867228),
  DSP16_Q(0.08008839),
  DSP16_Q(-0.03522975),
  DSP16_Q(0.02161521),
  DSP16_Q(-0.01479699),
  DSP16_Q(0.01059275),
  DSP16_Q(-0.00769824),
  DSP16_Q(0.00557821),
  DSP16_Q(-0.00397370),
  DSP16_Q(0.00274411),
  DSP16_Q(-0.00180561),
  DSP16_Q(0.00110371),
  DSP16_Q(-0.00059983),
  DSP16_Q(0.00026421),
  DSP16_Q(-0.00007206),
  DSP16_Q(0.00000141),
  DSP16_Q(0.00003449),
  DSP16_Q(-0.00017838),
  DSP16_Q(0.00045361),
  DSP16_Q(-0.00088305),
  DSP16_Q(0.00149354),
  DSP16_Q(-0.00231896),
  DSP16_Q(0.00340576),
  DSP16_Q(-0.00482335),
  DSP16_Q(0.00668482),
  DSP16_Q(-0.00919163),
  DSP16_Q(0.01274280),
  DSP16_Q(-0.01825067),
  DSP16_Q(0.02833108),
  DSP16_Q(-0.05461823),
  DSP16_Q(0.39005832),
  DSP16_Q(0.07686058),
  DSP16_Q(-0.03394423),
  DSP16_Q(0.02084856),
  DSP16_Q(-0.01427817),
  DSP16_Q(0.01022306),
  DSP16_Q(-0.00742980),
  DSP16_Q(0.00538334),
  DSP16_Q(-0.00383431),
  DSP16_Q(0.00264721),
  DSP16_Q(-0.00174121),
  DSP16_Q(0.00106374),
  DSP16_Q(-0.00057756),
  DSP16_Q(0.00025393),
  DSP16_Q(-0.00006891),
  DSP16_Q(0.00000126),
  DSP16_Q(0.00003382),
  DSP16_Q(-0.00017348),
  DSP16_Q(0.00044008),
  DSP16_Q(-0.00085573),
  DSP16_Q(0.00144638),
  DSP16_Q(-0.00224478),
  DSP16_Q(0.00329588),
  DSP16_Q(-0.00466690),
  DSP16_Q(0.00646740),
  DSP16_Q(-0.00889265),
  DSP16_Q(0.01232971),
  DSP16_Q(-0.01766460),
  DSP16_Q(0.02744231),
  DSP16_Q(-0.05302900),
  DSP16_Q(0.39139582),
  DSP16_Q(0.07365189),
  DSP16_Q(-0.03265497),
  DSP16_Q(0.02007782),
  DSP16_Q(-0.01375609),
  DSP16_Q(0.00985089),
  DSP16_Q(-0.00715953),
  DSP16_Q(0.00518718),
  DSP16_Q(-0.00369404),
  DSP16_Q(0.00254975),
  DSP16_Q(-0.00167648),
  DSP16_Q(0.00102361),
  DSP16_Q(-0.00055524),
  DSP16_Q(0.00024367),
  DSP16_Q(-0.00006580),
  DSP16_Q(0.00000113),
  DSP16_Q(0.00003310),
  DSP16_Q(-0.00016843),
  DSP16_Q(0.00042624),
  DSP16_Q(-0.00082787),
  DSP16_Q(0.00139835),
  DSP16_Q(-0.00216932),
  DSP16_Q(0.00318420),
  DSP16_Q(-0.00450798),
  DSP16_Q(0.00624658),
  DSP16_Q(-0.00858900),
  DSP16_Q(0.01191008),
  DSP16_Q(-0.01706881),
  DSP16_Q(0.02653715),
  DSP16_Q(-0.05140132),
  DSP16_Q(0.39268447),
  DSP16_Q(0.07046292),
  DSP16_Q(-0.03136245),
  DSP16_Q(0.01930330),
  DSP16_Q(-0.01323094),
  DSP16_Q(0.00947640),
  DSP16_Q(-0.00688756),
  DSP16_Q(0.00498980),
  DSP16_Q(-0.00355295),
  DSP16_Q(0.00245176),
  DSP16_Q(-0.00161145),
  DSP16_Q(0.00098334),
  DSP16_Q(-0.00053289),
  DSP16_Q(0.00023343),
  DSP16_Q(-0.00006272),
  DSP16_Q(0.00000100),
  DSP16_Q(0.00003234),
  DSP16_Q(-0.00016322),
  DSP16_Q(0.00041209),
  DSP16_Q(-0.00079947),
  DSP16_Q(0.00134948),
  DSP16_Q(-0.00209263),
  DSP16_Q(0.00307077),
  DSP16_Q(-0.00434662),
  DSP16_Q(0.00602244),
  DSP16_Q(-0.00828078),
  DSP16_Q(0.01148403),
  DSP16_Q(-0.01646346),
  DSP16_Q(0.02561584),
  DSP16_Q(-0.04973532),
  DSP16_Q(0.39392397),
  DSP16_Q(0.06729426),
  DSP16_Q(-0.03006718),
  DSP16_Q(0.01852532),
  DSP16_Q(-0.01270295),
  DSP16_Q(0.00909973),
  DSP16_Q(-0.00661398),
  DSP16_Q(0.00479129),
  DSP16_Q(-0.00341108),
  DSP16_Q(0.00235329),
  DSP16_Q(-0.00154615),
  DSP16_Q(0.00094295),
  DSP16_Q(-0.00051052),
  DSP16_Q(0.00022322),
  DSP16_Q(-0.00005967),
  DSP16_Q(0.00000088),
  DSP16_Q(0.00003153),
  DSP16_Q(-0.00015787),
  DSP16_Q(0.00039762),
  DSP16_Q(-0.00077053),
  DSP16_Q(0.00129979),
  DSP16_Q(-0.00201471),
  DSP16_Q(0.00295562),
  DSP16_Q(-0.00418288),
  DSP16_Q(0.00579504),
  DSP16_Q(-0.00796811),
  DSP16_Q(0.01105170),
  DSP16_Q(-0.01584875),
  DSP16_Q(0.02467861),
  DSP16_Q(-0.04803112),
  DSP16_Q(0.39511402),
  DSP16_Q(0.06414650),
  DSP16_Q(-0.02876965),
  DSP16_Q(0.01774419),
  DSP16_Q(-0.01217233),
  DSP16_Q(0.00872105),
  DSP16_Q(-0.00633892),
  DSP16_Q(0.00459173),
  DSP16_Q(-0.00326851),
  DSP16_Q(0.00225437),
  DSP16_Q(-0.00148061),
  DSP16_Q(0.00090246),
  DSP16_Q(-0.00048813),
  DSP16_Q(0.00021303),
  DSP16_Q(-0.00005665),
  DSP16_Q(0.00000078),
  DSP16_Q(0.00003067),
  DSP16_Q(-0.00015236),
  DSP16_Q(0.00038286),
  DSP16_Q(-0.00074108),
  DSP16_Q(0.00124927),
  DSP16_Q(-0.00193560),
  DSP16_Q(0.00283878),
  DSP16_Q(-0.00401682),
  DSP16_Q(0.00556447),
  DSP16_Q(-0.00765107),
  DSP16_Q(0.01061323),
  DSP16_Q(-0.01522486),
  DSP16_Q(0.02372572),
  DSP16_Q(-0.04628885),
  DSP16_Q(0.39625434),
  DSP16_Q(0.06102022),
  DSP16_Q(-0.02747035),
  DSP16_Q(0.01696022),
  DSP16_Q(-0.01163930),
  DSP16_Q(0.00834050),
  DSP16_Q(-0.00606249),
  DSP16_Q(0.00439119),
  DSP16_Q(-0.00312529),
  DSP16_Q(0.00215506),
  DSP16_Q(-0.00141485),
  DSP16_Q(0.00086188),
  DSP16_Q(-0.00046573),
  DSP16_Q(0.00020288),
  DSP16_Q(-0.00005367),
  DSP16_Q(0.00000068),
  DSP16_Q(0.00002976),
  DSP16_Q(-0.00014671),
  DSP16_Q(0.00036779),
  DSP16_Q(-0.00071111),
  DSP16_Q(0.00119797),
  DSP16_Q(-0.00185533),
  DSP16_Q(0.00272029),
  DSP16_Q(-0.00384849),
  DSP16_Q(0.00533081),
  DSP16_Q(-0.00732978),
  DSP16_Q(0.01016876),
  DSP16_Q(-0.01459199),
  DSP16_Q(0.02275742),
  DSP16_Q(-0.04450865),
  DSP16_Q(0.39734468),
  DSP16_Q(0.05791598),
  DSP16_Q(-0.02616977),
  DSP16_Q(0.01617373),
  DSP16_Q(-0.01110408),
  DSP16_Q(0.00795825),
  DSP16_Q(-0.00578479),
  DSP16_Q(0.00418977),
  DSP16_Q(-0.00298148),
  DSP16_Q(0.00205539),
  DSP16_Q(-0.00134891),
  DSP16_Q(0.00082123),
  DSP16_Q(-0.00044334),
  DSP16_Q(0.00019276),
  DSP16_Q(-0.00005073),
  DSP16_Q(0.00000059),
  DSP16_Q(0.00002880),
  DSP16_Q(-0.00014091),
  DSP16_Q(0.00035242),
  DSP16_Q(-0.00068063),
  DSP16_Q(0.00114587),
  DSP16_Q(-0.00177391),
  DSP16_Q(0.00260020),
  DSP16_Q(-0.00367795),
  DSP16_Q(0.00509412),
  DSP16_Q(-0.00700435),
  DSP16_Q(0.00971845),
  DSP16_Q(-0.01395034),
  DSP16_Q(0.02177397),
  DSP16_Q(-0.04269068),
  DSP16_Q(0.39838477),
  DSP16_Q(0.05483434),
  DSP16_Q(-0.02486840),
  DSP16_Q(0.01538502),
  DSP16_Q(-0.01056687),
  DSP16_Q(0.00757445),
  DSP16_Q(-0.00550595),
  DSP16_Q(0.00398754),
  DSP16_Q(-0.00283714),
  DSP16_Q(0.00195539),
  DSP16_Q(-0.00128280),
  DSP16_Q(0.00078053),
  DSP16_Q(-0.00042096),
  DSP16_Q(0.00018268),
  DSP16_Q(-0.00004783),
  DSP16_Q(0.00000050),
  DSP16_Q(0.00002780),
  DSP16_Q(-0.00013496),
  DSP16_Q(0.00033676),
  DSP16_Q(-0.00064966),
  DSP16_Q(0.00109302),
  DSP16_Q(-0.00169138),
  DSP16_Q(0.00247854),
  DSP16_Q(-0.00350525),
  DSP16_Q(0.00485450),
  DSP16_Q(-0.00667488),
  DSP16_Q(0.00926244),
  DSP16_Q(-0.01330011),
  DSP16_Q(0.02077565),
  DSP16_Q(-0.04083512),
  DSP16_Q(0.39937438),
  DSP16_Q(0.05177587),
  DSP16_Q(-0.02356671),
  DSP16_Q(0.01459441),
  DSP16_Q(-0.01002789),
  DSP16_Q(0.00718925),
  DSP16_Q(-0.00522608),
  DSP16_Q(0.00378459),
  DSP16_Q(-0.00269233),
  DSP16_Q(0.00185513),
  DSP16_Q(-0.00121657),
  DSP16_Q(0.00073980),
  DSP16_Q(-0.00039860),
  DSP16_Q(0.00017265),
  DSP16_Q(-0.00004496),
  DSP16_Q(0.00000043),
  DSP16_Q(0.00002674),
  DSP16_Q(-0.00012887),
  DSP16_Q(0.00032081),
  DSP16_Q(-0.00061820),
  DSP16_Q(0.00103941),
  DSP16_Q(-0.00160776),
  DSP16_Q(0.00235536),
  DSP16_Q(-0.00333046),
  DSP16_Q(0.00461203),
  DSP16_Q(-0.00634149),
  DSP16_Q(0.00880088),
  DSP16_Q(-0.01264151),
  DSP16_Q(0.01976272),
  DSP16_Q(-0.03894212),
  DSP16_Q(0.40031326),
  DSP16_Q(0.04874110),
  DSP16_Q(-0.02226519),
  DSP16_Q(0.01380221),
  DSP16_Q(-0.00948736),
  DSP16_Q(0.00680280),
  DSP16_Q(-0.00494528),
  DSP16_Q(0.00358099),
  DSP16_Q(-0.00254710),
  DSP16_Q(0.00175462),
  DSP16_Q(-0.00115022),
  DSP16_Q(0.00069905),
  DSP16_Q(-0.00037627),
  DSP16_Q(0.00016267),
  DSP16_Q(-0.00004214),
  DSP16_Q(0.00000036),
  DSP16_Q(0.00002564),
  DSP16_Q(-0.00012263),
  DSP16_Q(0.00030458),
  DSP16_Q(-0.00058626),
  DSP16_Q(0.00098507),
  DSP16_Q(-0.00152308),
  DSP16_Q(0.00223069),
  DSP16_Q(-0.00315364),
  DSP16_Q(0.00436678),
  DSP16_Q(-0.00600428),
  DSP16_Q(0.00833393),
  DSP16_Q(-0.01197475),
  DSP16_Q(0.01873548),
  DSP16_Q(-0.03701189),
  DSP16_Q(0.40120121),
  DSP16_Q(0.04573058),
  DSP16_Q(-0.02096431),
  DSP16_Q(0.01300872),
  DSP16_Q(-0.00894550),
  DSP16_Q(0.00641527),
  DSP16_Q(-0.00466368),
  DSP16_Q(0.00337684),
  DSP16_Q(-0.00240152),
  DSP16_Q(0.00165392),
  DSP16_Q(-0.00108380),
  DSP16_Q(0.00065829),
  DSP16_Q(-0.00035399),
  DSP16_Q(0.00015274),
  DSP16_Q(-0.00003935),
  DSP16_Q(0.00000030),
  DSP16_Q(0.00002448),
  DSP16_Q(-0.00011624),
  DSP16_Q(0.00028806),
  DSP16_Q(-0.00055386),
  DSP16_Q(0.00093002),
  DSP16_Q(-0.00143737),
  DSP16_Q(0.00210459),
  DSP16_Q(-0.00297484),
  DSP16_Q(0.00411884),
  DSP16_Q(-0.00566339),
  DSP16_Q(0.00786174),
  DSP16_Q(-0.01130005),
  DSP16_Q(0.01769421),
  DSP16_Q(-0.03504462),
  DSP16_Q(0.40203800),
  DSP16_Q(0.04274484),
  DSP16_Q(-0.01966455),
  DSP16_Q(0.01221425),
  DSP16_Q(-0.00840251),
  DSP16_Q(0.00602681),
  DSP16_Q(-0.00438138),
  DSP16_Q(0.00317222),
  DSP16_Q(-0.00225564),
  DSP16_Q(0.00155307),
  DSP16_Q(-0.00101732),
  DSP16_Q(0.00061755),
  DSP16_Q(-0.00033175),
  DSP16_Q(0.00014287),
  DSP16_Q(-0.00003661),
  DSP16_Q(0.00000025),
  DSP16_Q(0.00002328),
  DSP16_Q(-0.00010971),
  DSP16_Q(0.00027127),
  DSP16_Q(-0.00052100),
  DSP16_Q(0.00087428),
  DSP16_Q(-0.00135065),
  DSP16_Q(0.00197708),
  DSP16_Q(-0.00279414),
  DSP16_Q(0.00386831),
  DSP16_Q(-0.00531892),
  DSP16_Q(0.00738448),
  DSP16_Q(-0.01061761),
  DSP16_Q(0.01663921),
  DSP16_Q(-0.03304052),
  DSP16_Q(0.40282345),
  DSP16_Q(0.03978440),
  DSP16_Q(-0.01836637),
  DSP16_Q(0.01141912),
  DSP16_Q(-0.00785862),
  DSP16_Q(0.00563757),
  DSP16_Q(-0.00409850),
  DSP16_Q(0.00296719),
  DSP16_Q(-0.00210953),
  DSP16_Q(0.00145210),
  DSP16_Q(-0.00095082),
  DSP16_Q(0.00057684),
  DSP16_Q(-0.00030958),
  DSP16_Q(0.00013306),
  DSP16_Q(-0.00003391),
  DSP16_Q(0.00000021),
  DSP16_Q(0.00002202),
  DSP16_Q(-0.00010304),
  DSP16_Q(0.00025421),
  DSP16_Q(-0.00048769),
  DSP16_Q(0.00081785),
  DSP16_Q(-0.00126297),
  DSP16_Q(0.00184823),
  DSP16_Q(-0.00261158),
  DSP16_Q(0.00361526),
  DSP16_Q(-0.00497100),
  DSP16_Q(0.00690231),
  DSP16_Q(-0.00992768),
  DSP16_Q(0.01557078),
  DSP16_Q(-0.03099980),
  DSP16_Q(0.40355737),
  DSP16_Q(0.03684977),
  DSP16_Q(-0.01707025),
  DSP16_Q(0.01062363),
  DSP16_Q(-0.00731402),
  DSP16_Q(0.00524770),
  DSP16_Q(-0.00381515),
  DSP16_Q(0.00276186),
  DSP16_Q(-0.00196324),
  DSP16_Q(0.00135106),
  DSP16_Q(-0.00088433),
  DSP16_Q(0.00053618),
  DSP16_Q(-0.00028747),
  DSP16_Q(0.00012332),
  DSP16_Q(-0.00003125),
  DSP16_Q(0.00000017),
  DSP16_Q(0.00002071),
  DSP16_Q(-0.00009623),
  DSP16_Q(0.00023687),
  DSP16_Q(-0.00045394),
  DSP16_Q(0.00076077),
  DSP16_Q(-0.00117434),
  DSP16_Q(0.00171806),
  DSP16_Q(-0.00242724),
  DSP16_Q(0.00335978),
  DSP16_Q(-0.00461974),
  DSP16_Q(0.00641540),
  DSP16_Q(-0.00923047),
  DSP16_Q(0.01448924),
  DSP16_Q(-0.02892271),
  DSP16_Q(0.40423960),
  DSP16_Q(0.03394145),
  DSP16_Q(-0.01577663),
  DSP16_Q(0.00982807),
  DSP16_Q(-0.00676895),
  DSP16_Q(0.00485736),
  DSP16_Q(-0.00353145),
  DSP16_Q(0.00255629),
  DSP16_Q(-0.00181683),
  DSP16_Q(0.00124999),
  DSP16_Q(-0.00081786),
  DSP16_Q(0.00049559),
  DSP16_Q(-0.00026544),
  DSP16_Q(0.00011365),
  DSP16_Q(-0.00002864),
  DSP16_Q(0.00000013),
  DSP16_Q(0.00001935),
  DSP16_Q(-0.00008929),
  DSP16_Q(0.00021928),
  DSP16_Q(-0.00041977),
  DSP16_Q(0.00070305),
  DSP16_Q(-0.00108480),
  DSP16_Q(0.00158663),
  DSP16_Q(-0.00224118),
  DSP16_Q(0.00310197),
  DSP16_Q(-0.00426527),
  DSP16_Q(0.00592391),
  DSP16_Q(-0.00852621),
  DSP16_Q(0.01339489),
  DSP16_Q(-0.02680947),
  DSP16_Q(0.40486996),
  DSP16_Q(0.03105995),
  DSP16_Q(-0.01448599),
  DSP16_Q(0.00903276),
  DSP16_Q(-0.00622360),
  DSP16_Q(0.00446670),
  DSP16_Q(-0.00324749),
  DSP16_Q(0.00235058),
  DSP16_Q(-0.00167036),
  DSP16_Q(0.00114893),
  DSP16_Q(-0.00075144),
  DSP16_Q(0.00045507),
  DSP16_Q(-0.00024350),
  DSP16_Q(0.00010405),
  DSP16_Q(-0.00002607),
  DSP16_Q(0.00000010),
  DSP16_Q(0.00001794),
  DSP16_Q(-0.00008220),
  DSP16_Q(0.00020143),
  DSP16_Q(-0.00038518),
  DSP16_Q(0.00064471),
  DSP16_Q(-0.00099437),
  DSP16_Q(0.00145399),
  DSP16_Q(-0.00205347),
  DSP16_Q(0.00284192),
  DSP16_Q(-0.00390772),
  DSP16_Q(0.00542802),
  DSP16_Q(-0.00781515),
  DSP16_Q(0.01228807),
  DSP16_Q(-0.02466035),
  DSP16_Q(0.40544831),
  DSP16_Q(0.02820576),
  DSP16_Q(-0.01319876),
  DSP16_Q(0.00823800),
  DSP16_Q(-0.00567820),
  DSP16_Q(0.00407587),
  DSP16_Q(-0.00296340),
  DSP16_Q(0.00214480),
  DSP16_Q(-0.00152389),
  DSP16_Q(0.00104791),
  DSP16_Q(-0.00068511),
  DSP16_Q(0.00041465),
  DSP16_Q(-0.00022165),
  DSP16_Q(0.00009452),
  DSP16_Q(-0.00002355),
  DSP16_Q(0.00000008),
  DSP16_Q(0.00001648),
  DSP16_Q(-0.00007498),
  DSP16_Q(0.00018333),
  DSP16_Q(-0.00035019),
  DSP16_Q(0.00058578),
  DSP16_Q(-0.00090310),
  DSP16_Q(0.00132018),
  DSP16_Q(-0.00186417),
  DSP16_Q(0.00257972),
  DSP16_Q(-0.00354721),
  DSP16_Q(0.00492789),
  DSP16_Q(-0.00709752),
  DSP16_Q(0.01116911),
  DSP16_Q(-0.02247560),
  DSP16_Q(0.40597452),
  DSP16_Q(0.02537934),
  DSP16_Q(-0.01191542),
  DSP16_Q(0.00744407),
  DSP16_Q(-0.00513294),
  DSP16_Q(0.00368503),
  DSP16_Q(-0.00267929),
  DSP16_Q(0.00193902),
  DSP16_Q(-0.00137747),
  DSP16_Q(0.00094699),
  DSP16_Q(-0.00061889),
  DSP16_Q(0.00037435),
  DSP16_Q(-0.00019990),
  DSP16_Q(0.00008508),
  DSP16_Q(-0.00002108),
  DSP16_Q(0.00000006),
  DSP16_Q(0.00001497),
  DSP16_Q(-0.00006763),
  DSP16_Q(0.00016499),
  DSP16_Q(-0.00031481),
  DSP16_Q(0.00052626),
  DSP16_Q(-0.00081101),
  DSP16_Q(0.00118524),
  DSP16_Q(-0.00167335),
  DSP16_Q(0.00231546),
  DSP16_Q(-0.00318387),
  DSP16_Q(0.00442370),
  DSP16_Q(-0.00637356),
  DSP16_Q(0.01003833),
  DSP16_Q(-0.02025550),
  DSP16_Q(0.40644845),
  DSP16_Q(0.02258117),
  DSP16_Q(-0.01063638),
  DSP16_Q(0.00665130),
  DSP16_Q(-0.00458804),
  DSP16_Q(0.00329433),
  DSP16_Q(-0.00239527),
  DSP16_Q(0.00173334),
  DSP16_Q(-0.00123116),
  DSP16_Q(0.00084619),
  DSP16_Q(-0.00055280),
  DSP16_Q(0.00033417),
  DSP16_Q(-0.00017827),
  DSP16_Q(0.00007572),
  DSP16_Q(-0.00001865),
  DSP16_Q(0.00000004),
  DSP16_Q(0.00001340),
  DSP16_Q(-0.00006014),
  DSP16_Q(0.00014640),
  DSP16_Q(-0.00027905),
  DSP16_Q(0.00046618),
  DSP16_Q(-0.00071814),
  DSP16_Q(0.00104923),
  DSP16_Q(-0.00148108),
  DSP16_Q(0.00204924),
  DSP16_Q(-0.00281783),
  DSP16_Q(0.00391564),
  DSP16_Q(-0.00564351),
  DSP16_Q(0.00889609),
  DSP16_Q(-0.01800033),
  DSP16_Q(0.40687001),
  DSP16_Q(0.01981171),
  DSP16_Q(-0.00936211),
  DSP16_Q(0.00585995),
  DSP16_Q(-0.00404371),
  DSP16_Q(0.00290391),
  DSP16_Q(-0.00211144),
  DSP16_Q(0.00152784),
  DSP16_Q(-0.00108502),
  DSP16_Q(0.00074555),
  DSP16_Q(-0.00048686),
  DSP16_Q(0.00029414),
  DSP16_Q(-0.00015675),
  DSP16_Q(0.00006645),
  DSP16_Q(-0.00001627),
  DSP16_Q(0.00000003),
  DSP16_Q(0.00001178),
  DSP16_Q(-0.00005252),
  DSP16_Q(0.00012758),
  DSP16_Q(-0.00024292),
  DSP16_Q(0.00040557),
  DSP16_Q(-0.00062451),
  DSP16_Q(0.00091220),
  DSP16_Q(-0.00128743),
  DSP16_Q(0.00178116),
  DSP16_Q(-0.00244922),
  DSP16_Q(0.00340387),
  DSP16_Q(-0.00490763),
  DSP16_Q(0.00774273),
  DSP16_Q(-0.01571038),
  DSP16_Q(0.40723910),
  DSP16_Q(0.01707142),
  DSP16_Q(-0.00809304),
  DSP16_Q(0.00507034),
  DSP16_Q(-0.00350015),
  DSP16_Q(0.00251394),
  DSP16_Q(-0.00182792),
  DSP16_Q(0.00132258),
  DSP16_Q(-0.00093910),
  DSP16_Q(0.00064512),
  DSP16_Q(-0.00042112),
  DSP16_Q(0.00025426),
  DSP16_Q(-0.00013537),
  DSP16_Q(0.00005727),
  DSP16_Q(-0.00001394),
  DSP16_Q(0.00000002),
  DSP16_Q(0.00001011),
  DSP16_Q(-0.00004478),
  DSP16_Q(0.00010854),
  DSP16_Q(-0.00020643),
  DSP16_Q(0.00034444),
  DSP16_Q(-0.00053017),
  DSP16_Q(0.00077419),
  DSP16_Q(-0.00109247),
  DSP16_Q(0.00151131),
  DSP16_Q(-0.00207818),
  DSP16_Q(0.00288859),
  DSP16_Q(-0.00416618),
  DSP16_Q(0.00657861),
  DSP16_Q(-0.01338596),
  DSP16_Q(0.40755561),
  DSP16_Q(0.01436073),
  DSP16_Q(-0.00682958),
  DSP16_Q(0.00428276),
  DSP16_Q(-0.00295758),
  DSP16_Q(0.00212455),
  DSP16_Q(-0.00154481),
  DSP16_Q(0.00111766),
  DSP16_Q(-0.00079347),
  DSP16_Q(0.00054494),
  DSP16_Q(-0.00035558),
  DSP16_Q(0.00021456),
  DSP16_Q(-0.00011411),
  DSP16_Q(0.00004818),
  DSP16_Q(-0.00001166),
  DSP16_Q(0.00000001),
  DSP16_Q(0.00000839),
  DSP16_Q(-0.00003691),
  DSP16_Q(0.00008927),
  DSP16_Q(-0.00016961),
  DSP16_Q(0.00028282),
  DSP16_Q(-0.00043515),
  DSP16_Q(0.00063526),
  DSP16_Q(-0.00089627),
  DSP16_Q(0.00123979),
  DSP16_Q(-0.00170483),
  DSP16_Q(0.00236998),
  DSP16_Q(-0.00341939),
  DSP16_Q(0.00540409),
  DSP16_Q(-0.01102738),
  DSP16_Q(0.40781949),
  DSP16_Q(0.01168008),
  DSP16_Q(-0.00557219),
  DSP16_Q(0.00349748),
  DSP16_Q(-0.00241619),
  DSP16_Q(0.00173589),
  DSP16_Q(-0.00126223),
  DSP16_Q(0.00091315),
  DSP16_Q(-0.00064817),
  DSP16_Q(0.00044504),
  DSP16_Q(-0.00029028),
  DSP16_Q(0.00017505),
  DSP16_Q(-0.00009301),
  DSP16_Q(0.00003919),
  DSP16_Q(-0.00000943),
  DSP16_Q(0.00000001),
  DSP16_Q(0.00000662),
  DSP16_Q(-0.00002892),
  DSP16_Q(0.00006979),
  DSP16_Q(-0.00013245),
  DSP16_Q(0.00022072),
  DSP16_Q(-0.00033947),
  DSP16_Q(0.00049546),
  DSP16_Q(-0.00069891),
  DSP16_Q(0.00096671),
  DSP16_Q(-0.00132933),
  DSP16_Q(0.00184821),
  DSP16_Q(-0.00266754),
  DSP16_Q(0.00421953),
  DSP16_Q(-0.00863496),
  DSP16_Q(0.40803067),
  DSP16_Q(0.00902989),
  DSP16_Q(-0.00432126),
  DSP16_Q(0.00271481),
  DSP16_Q(-0.00187618),
  DSP16_Q(0.00134812),
  DSP16_Q(-0.00098029),
  DSP16_Q(0.00070912),
  DSP16_Q(-0.00050327),
  DSP16_Q(0.00034546),
  DSP16_Q(-0.00022524),
  DSP16_Q(0.00013575),
  DSP16_Q(-0.00007205),
  DSP16_Q(0.00003029),
  DSP16_Q(-0.00000724),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000479),
  DSP16_Q(-0.00002080),
  DSP16_Q(0.00005010),
  DSP16_Q(-0.00009498),
  DSP16_Q(0.00015818),
  DSP16_Q(-0.00024318),
  DSP16_Q(0.00035483),
  DSP16_Q(-0.00050045),
  DSP16_Q(0.00069215),
  DSP16_Q(-0.00095179),
  DSP16_Q(0.00132349),
  DSP16_Q(-0.00191089),
  DSP16_Q(0.00302531),
  DSP16_Q(-0.00620905),
  DSP16_Q(0.40818909),
  DSP16_Q(0.00641057),
  DSP16_Q(-0.00307723),
  DSP16_Q(0.00193501),
  DSP16_Q(-0.00133777),
  DSP16_Q(0.00096139),
  DSP16_Q(-0.00069908),
  DSP16_Q(0.00050566),
  DSP16_Q(-0.00035882),
  DSP16_Q(0.00024624),
  DSP16_Q(-0.00016048),
  DSP16_Q(0.00009666),
  DSP16_Q(-0.00005125),
  DSP16_Q(0.00002150),
  DSP16_Q(-0.00000511),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000291),
  DSP16_Q(-0.00001257),
  DSP16_Q(0.00003020),
  DSP16_Q(-0.00005720),
  DSP16_Q(0.00009521),
  DSP16_Q(-0.00014631),
  DSP16_Q(0.00021343),
  DSP16_Q(-0.00030097),
  DSP16_Q(0.00041623),
  DSP16_Q(-0.00057237),
  DSP16_Q(0.00079600),
  DSP16_Q(-0.00114970),
  DSP16_Q(0.00182181),
  DSP16_Q(-0.00374999),
  DSP16_Q(0.40829473),
  DSP16_Q(0.00382254),
  DSP16_Q(-0.00184051),
  DSP16_Q(0.00115839),
  DSP16_Q(-0.00080114),
  DSP16_Q(0.00057582),
  DSP16_Q(-0.00041872),
  DSP16_Q(0.00030285),
  DSP16_Q(-0.00021486),
  DSP16_Q(0.00014741),
  DSP16_Q(-0.00009604),
  DSP16_Q(0.00005781),
  DSP16_Q(-0.00003062),
  DSP16_Q(0.00001282),
  DSP16_Q(-0.00000303),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000098),
  DSP16_Q(-0.00000422),
  DSP16_Q(0.00001012),
  DSP16_Q(-0.00001914),
  DSP16_Q(0.00003183),
  DSP16_Q(-0.00004890),
  DSP16_Q(0.00007131),
  DSP16_Q(-0.00010054),
  DSP16_Q(0.00013904),
  DSP16_Q(-0.00019120),
  DSP16_Q(0.00026594),
  DSP16_Q(-0.00038425),
  DSP16_Q(0.00060941),
  DSP16_Q(-0.00125812),
  DSP16_Q(0.40834756),
  DSP16_Q(0.00126618),
  DSP16_Q(-0.00061149),
  DSP16_Q(0.00038521),
  DSP16_Q(-0.00026651),
  DSP16_Q(0.00019158),
  DSP16_Q(-0.00013931),
  DSP16_Q(0.00010075),
  DSP16_Q(-0.00007147),
  DSP16_Q(0.00004902),
  DSP16_Q(-0.00003192),
  DSP16_Q(0.00001920),
  DSP16_Q(-0.00001016),
  DSP16_Q(0.00000425),
  DSP16_Q(-0.00000100),
  DSP16_Q(0.00000000)
};
