/*****************************************************************************
 *
 * \file
 *
 * \brief FIR coefficients for the dsp16_resampling function from the DPSLib.
 *        These coefficients have the following caracterizations:
 *          - Input sampling frequency: 48000 Hz
 *          - Output sampling frequency: 44200 Hz
 *          - Re-sampling order: 30
 *          - Coefficients are normalized
 *          - Memory foot print: 13260 bytes
 *         It matches the following parameters:
 *         (dsp16_resampling_options_t::dsp16_custom_filter)
 *          - Cut-off frequency (fc_hz): 22100
 *          - Sampling frequency (fs_hz): ******
 *          - Actual FIR filter order (order): 6630
 *
 * Copyright (c) 2010 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/

A_ALIGNED static const dsp16_t dsp16_resampling_fircoef_ord30_48000_44200_norm[] = {
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00004076),
  DSP16_Q(-0.00005007),
  DSP16_Q(-0.00018334),
  DSP16_Q(0.00089816),
  DSP16_Q(-0.00231816),
  DSP16_Q(0.00460760),
  DSP16_Q(-0.00783219),
  DSP16_Q(0.01193273),
  DSP16_Q(-0.01671705),
  DSP16_Q(0.02187299),
  DSP16_Q(-0.02700262),
  DSP16_Q(0.03167658),
  DSP16_Q(-0.03551684),
  DSP16_Q(0.03843687),
  DSP16_Q(0.44421821),
  DSP16_Q(0.03633708),
  DSP16_Q(-0.03458544),
  DSP16_Q(0.03117449),
  DSP16_Q(-0.02673249),
  DSP16_Q(0.02174441),
  DSP16_Q(-0.01667576),
  DSP16_Q(0.01194168),
  DSP16_Q(-0.00786523),
  DSP16_Q(0.00464699),
  DSP16_Q(-0.00235311),
  DSP16_Q(0.00092360),
  DSP16_Q(-0.00019849),
  DSP16_Q(-0.00004320),
  DSP16_Q(0.00003892),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00004263),
  DSP16_Q(-0.00005699),
  DSP16_Q(-0.00016805),
  DSP16_Q(0.00087243),
  DSP16_Q(-0.00228265),
  DSP16_Q(0.00456726),
  DSP16_Q(-0.00779768),
  DSP16_Q(0.01192168),
  DSP16_Q(-0.01675556),
  DSP16_Q(0.02199814),
  DSP16_Q(-0.02726891),
  DSP16_Q(0.03217501),
  DSP16_Q(-0.03644670),
  DSP16_Q(0.04054955),
  DSP16_Q(0.44419264),
  DSP16_Q(0.03425033),
  DSP16_Q(-0.03365265),
  DSP16_Q(0.03066884),
  DSP16_Q(-0.02645858),
  DSP16_Q(0.02161244),
  DSP16_Q(-0.01663169),
  DSP16_Q(0.01194852),
  DSP16_Q(-0.00789679),
  DSP16_Q(0.00468542),
  DSP16_Q(-0.00238750),
  DSP16_Q(0.00094874),
  DSP16_Q(-0.00021350),
  DSP16_Q(-0.00003639),
  DSP16_Q(0.00003709),
  DSP16_Q(-0.00000001),
  DSP16_Q(0.00004452),
  DSP16_Q(-0.00006397),
  DSP16_Q(-0.00015264),
  DSP16_Q(0.00084641),
  DSP16_Q(-0.00224658),
  DSP16_Q(0.00452597),
  DSP16_Q(-0.00776168),
  DSP16_Q(0.01190852),
  DSP16_Q(-0.01679126),
  DSP16_Q(0.02211985),
  DSP16_Q(-0.02753131),
  DSP16_Q(0.03266968),
  DSP16_Q(-0.03737485),
  DSP16_Q(0.04267495),
  DSP16_Q(0.44414150),
  DSP16_Q(0.03217677),
  DSP16_Q(-0.03271864),
  DSP16_Q(0.03015973),
  DSP16_Q(-0.02618095),
  DSP16_Q(0.02147711),
  DSP16_Q(-0.01658487),
  DSP16_Q(0.01195327),
  DSP16_Q(-0.00792688),
  DSP16_Q(0.00472289),
  DSP16_Q(-0.00242132),
  DSP16_Q(0.00097359),
  DSP16_Q(-0.00022838),
  DSP16_Q(-0.00002964),
  DSP16_Q(0.00003529),
  DSP16_Q(-0.00000001),
  DSP16_Q(0.00004643),
  DSP16_Q(-0.00007101),
  DSP16_Q(-0.00013709),
  DSP16_Q(0.00082011),
  DSP16_Q(-0.00220997),
  DSP16_Q(0.00448374),
  DSP16_Q(-0.00772422),
  DSP16_Q(0.01189325),
  DSP16_Q(-0.01682415),
  DSP16_Q(0.02223808),
  DSP16_Q(-0.02778975),
  DSP16_Q(0.03316050),
  DSP16_Q(-0.03830113),
  DSP16_Q(0.04481292),
  DSP16_Q(0.44406480),
  DSP16_Q(0.03011658),
  DSP16_Q(-0.03178356),
  DSP16_Q(0.02964726),
  DSP16_Q(-0.02589966),
  DSP16_Q(0.02133847),
  DSP16_Q(-0.01653532),
  DSP16_Q(0.01195592),
  DSP16_Q(-0.00795548),
  DSP16_Q(0.00475939),
  DSP16_Q(-0.00245458),
  DSP16_Q(0.00099813),
  DSP16_Q(-0.00024311),
  DSP16_Q(-0.00002295),
  DSP16_Q(0.00003352),
  DSP16_Q(-0.00000002),
  DSP16_Q(0.00004837),
  DSP16_Q(-0.00007809),
  DSP16_Q(-0.00012141),
  DSP16_Q(0.00079352),
  DSP16_Q(-0.00217281),
  DSP16_Q(0.00444056),
  DSP16_Q(-0.00768528),
  DSP16_Q(0.01187585),
  DSP16_Q(-0.01685421),
  DSP16_Q(0.02235279),
  DSP16_Q(-0.02804418),
  DSP16_Q(0.03364738),
  DSP16_Q(-0.03922538),
  DSP16_Q(0.04696328),
  DSP16_Q(0.44396254),
  DSP16_Q(0.02806989),
  DSP16_Q(-0.03084756),
  DSP16_Q(0.02913153),
  DSP16_Q(-0.02561476),
  DSP16_Q(0.02119653),
  DSP16_Q(-0.01648304),
  DSP16_Q(0.01195649),
  DSP16_Q(-0.00798260),
  DSP16_Q(0.00479493),
  DSP16_Q(-0.00248726),
  DSP16_Q(0.00102237),
  DSP16_Q(-0.00025771),
  DSP16_Q(-0.00001632),
  DSP16_Q(0.00003176),
  DSP16_Q(-0.00000004),
  DSP16_Q(0.00005032),
  DSP16_Q(-0.00008523),
  DSP16_Q(-0.00010561),
  DSP16_Q(0.00076666),
  DSP16_Q(-0.00213510),
  DSP16_Q(0.00439645),
  DSP16_Q(-0.00764487),
  DSP16_Q(0.01185634),
  DSP16_Q(-0.01688143),
  DSP16_Q(0.02246395),
  DSP16_Q(-0.02829455),
  DSP16_Q(0.03413020),
  DSP16_Q(-0.04014745),
  DSP16_Q(0.04912587),
  DSP16_Q(0.44383474),
  DSP16_Q(0.02603686),
  DSP16_Q(-0.02991081),
  DSP16_Q(0.02861263),
  DSP16_Q(-0.02532632),
  DSP16_Q(0.02105134),
  DSP16_Q(-0.01642805),
  DSP16_Q(0.01195499),
  DSP16_Q(-0.00800824),
  DSP16_Q(0.00482950),
  DSP16_Q(-0.00251936),
  DSP16_Q(0.00104630),
  DSP16_Q(-0.00027215),
  DSP16_Q(-0.00000974),
  DSP16_Q(0.00003003),
  DSP16_Q(-0.00000005),
  DSP16_Q(0.00005230),
  DSP16_Q(-0.00009242),
  DSP16_Q(-0.00008969),
  DSP16_Q(0.00073952),
  DSP16_Q(-0.00209686),
  DSP16_Q(0.00435140),
  DSP16_Q(-0.00760299),
  DSP16_Q(0.01183470),
  DSP16_Q(-0.01690580),
  DSP16_Q(0.02257154),
  DSP16_Q(-0.02854079),
  DSP16_Q(0.03460888),
  DSP16_Q(-0.04106717),
  DSP16_Q(0.05130052),
  DSP16_Q(0.44368140),
  DSP16_Q(0.02401764),
  DSP16_Q(-0.02897347),
  DSP16_Q(0.02809066),
  DSP16_Q(-0.02503440),
  DSP16_Q(0.02090292),
  DSP16_Q(-0.01637037),
  DSP16_Q(0.01195140),
  DSP16_Q(-0.00803241),
  DSP16_Q(0.00486310),
  DSP16_Q(-0.00255088),
  DSP16_Q(0.00106992),
  DSP16_Q(-0.00028645),
  DSP16_Q(-0.00000323),
  DSP16_Q(0.00002833),
  DSP16_Q(-0.00000007),
  DSP16_Q(0.00005429),
  DSP16_Q(-0.00009965),
  DSP16_Q(-0.00007364),
  DSP16_Q(0.00071211),
  DSP16_Q(-0.00205809),
  DSP16_Q(0.00430542),
  DSP16_Q(-0.00755965),
  DSP16_Q(0.01181093),
  DSP16_Q(-0.01692730),
  DSP16_Q(0.02267553),
  DSP16_Q(-0.02878286),
  DSP16_Q(0.03508332),
  DSP16_Q(-0.04198437),
  DSP16_Q(0.05348707),
  DSP16_Q(0.44350256),
  DSP16_Q(0.02201237),
  DSP16_Q(-0.02803568),
  DSP16_Q(0.02756573),
  DSP16_Q(-0.02473905),
  DSP16_Q(0.02075133),
  DSP16_Q(-0.01631003),
  DSP16_Q(0.01194576),
  DSP16_Q(-0.00805509),
  DSP16_Q(0.00489572),
  DSP16_Q(-0.00258182),
  DSP16_Q(0.00109323),
  DSP16_Q(-0.00030061),
  DSP16_Q(0.00000322),
  DSP16_Q(0.00002665),
  DSP16_Q(-0.00000010),
  DSP16_Q(0.00005631),
  DSP16_Q(-0.00010694),
  DSP16_Q(-0.00005748),
  DSP16_Q(0.00068443),
  DSP16_Q(-0.00201879),
  DSP16_Q(0.00425853),
  DSP16_Q(-0.00751484),
  DSP16_Q(0.01178504),
  DSP16_Q(-0.01694591),
  DSP16_Q(0.02277589),
  DSP16_Q(-0.02902069),
  DSP16_Q(0.03555342),
  DSP16_Q(-0.04289890),
  DSP16_Q(0.05568535),
  DSP16_Q(0.44329821),
  DSP16_Q(0.02002120),
  DSP16_Q(-0.02709761),
  DSP16_Q(0.02703793),
  DSP16_Q(-0.02444035),
  DSP16_Q(0.02059658),
  DSP16_Q(-0.01624703),
  DSP16_Q(0.01193805),
  DSP16_Q(-0.00807630),
  DSP16_Q(0.00492737),
  DSP16_Q(-0.00261217),
  DSP16_Q(0.00111622),
  DSP16_Q(-0.00031461),
  DSP16_Q(0.00000960),
  DSP16_Q(0.00002499),
  DSP16_Q(-0.00000012),
  DSP16_Q(0.00005835),
  DSP16_Q(-0.00011427),
  DSP16_Q(-0.00004120),
  DSP16_Q(0.00065649),
  DSP16_Q(-0.00197897),
  DSP16_Q(0.00421071),
  DSP16_Q(-0.00746858),
  DSP16_Q(0.01175701),
  DSP16_Q(-0.01696164),
  DSP16_Q(0.02287260),
  DSP16_Q(-0.02925424),
  DSP16_Q(0.03601910),
  DSP16_Q(-0.04381059),
  DSP16_Q(0.05789517),
  DSP16_Q(0.44306840),
  DSP16_Q(0.01804428),
  DSP16_Q(-0.02615941),
  DSP16_Q(0.02650737),
  DSP16_Q(-0.02413834),
  DSP16_Q(0.02043871),
  DSP16_Q(-0.01618140),
  DSP16_Q(0.01192829),
  DSP16_Q(-0.00809603),
  DSP16_Q(0.00495803),
  DSP16_Q(-0.00264193),
  DSP16_Q(0.00113890),
  DSP16_Q(-0.00032846),
  DSP16_Q(0.00001592),
  DSP16_Q(0.00002335),
  DSP16_Q(-0.00000015),
  DSP16_Q(0.00006041),
  DSP16_Q(-0.00012165),
  DSP16_Q(-0.00002480),
  DSP16_Q(0.00062829),
  DSP16_Q(-0.00193863),
  DSP16_Q(0.00416198),
  DSP16_Q(-0.00742086),
  DSP16_Q(0.01172685),
  DSP16_Q(-0.01697446),
  DSP16_Q(0.02296561),
  DSP16_Q(-0.02948345),
  DSP16_Q(0.03648024),
  DSP16_Q(-0.04471928),
  DSP16_Q(0.06011636),
  DSP16_Q(0.44281313),
  DSP16_Q(0.01608174),
  DSP16_Q(-0.02522123),
  DSP16_Q(0.02597413),
  DSP16_Q(-0.02383310),
  DSP16_Q(0.02027777),
  DSP16_Q(-0.01611315),
  DSP16_Q(0.01191649),
  DSP16_Q(-0.00811428),
  DSP16_Q(0.00498772),
  DSP16_Q(-0.00267109),
  DSP16_Q(0.00116125),
  DSP16_Q(-0.00034216),
  DSP16_Q(0.00002218),
  DSP16_Q(0.00002175),
  DSP16_Q(-0.00000019),
  DSP16_Q(0.00006248),
  DSP16_Q(-0.00012907),
  DSP16_Q(-0.00000829),
  DSP16_Q(0.00059983),
  DSP16_Q(-0.00189778),
  DSP16_Q(0.00411234),
  DSP16_Q(-0.00737169),
  DSP16_Q(0.01169456),
  DSP16_Q(-0.01698438),
  DSP16_Q(0.02305491),
  DSP16_Q(-0.02970827),
  DSP16_Q(0.03693676),
  DSP16_Q(-0.04562481),
  DSP16_Q(0.06234875),
  DSP16_Q(0.44253243),
  DSP16_Q(0.01413372),
  DSP16_Q(-0.02428322),
  DSP16_Q(0.02543833),
  DSP16_Q(-0.02352468),
  DSP16_Q(0.02011378),
  DSP16_Q(-0.01604231),
  DSP16_Q(0.01190266),
  DSP16_Q(-0.00813106),
  DSP16_Q(0.00501642),
  DSP16_Q(-0.00269966),
  DSP16_Q(0.00118328),
  DSP16_Q(-0.00035570),
  DSP16_Q(0.00002837),
  DSP16_Q(0.00002016),
  DSP16_Q(-0.00000023),
  DSP16_Q(0.00006458),
  DSP16_Q(-0.00013654),
  DSP16_Q(0.00000832),
  DSP16_Q(0.00057112),
  DSP16_Q(-0.00185642),
  DSP16_Q(0.00406180),
  DSP16_Q(-0.00732107),
  DSP16_Q(0.01166014),
  DSP16_Q(-0.01699136),
  DSP16_Q(0.02314047),
  DSP16_Q(-0.02992864),
  DSP16_Q(0.03738857),
  DSP16_Q(-0.04652701),
  DSP16_Q(0.06459216),
  DSP16_Q(0.44222635),
  DSP16_Q(0.01220036),
  DSP16_Q(-0.02334554),
  DSP16_Q(0.02490006),
  DSP16_Q(-0.02321315),
  DSP16_Q(0.01994680),
  DSP16_Q(-0.01596889),
  DSP16_Q(0.01188680),
  DSP16_Q(-0.00814637),
  DSP16_Q(0.00504414),
  DSP16_Q(-0.00272764),
  DSP16_Q(0.00120498),
  DSP16_Q(-0.00036909),
  DSP16_Q(0.00003449),
  DSP16_Q(0.00001860),
  DSP16_Q(-0.00000027),
  DSP16_Q(0.00006670),
  DSP16_Q(-0.00014405),
  DSP16_Q(0.00002504),
  DSP16_Q(0.00054217),
  DSP16_Q(-0.00181456),
  DSP16_Q(0.00401037),
  DSP16_Q(-0.00726900),
  DSP16_Q(0.01162357),
  DSP16_Q(-0.01699542),
  DSP16_Q(0.02322227),
  DSP16_Q(-0.03014452),
  DSP16_Q(0.03783557),
  DSP16_Q(-0.04742571),
  DSP16_Q(0.06684641),
  DSP16_Q(0.44189490),
  DSP16_Q(0.01028180),
  DSP16_Q(-0.02240835),
  DSP16_Q(0.02435942),
  DSP16_Q(-0.02289857),
  DSP16_Q(0.01977684),
  DSP16_Q(-0.01589291),
  DSP16_Q(0.01186892),
  DSP16_Q(-0.00816020),
  DSP16_Q(0.00507087),
  DSP16_Q(-0.00275501),
  DSP16_Q(0.00122636),
  DSP16_Q(-0.00038231),
  DSP16_Q(0.00004055),
  DSP16_Q(0.00001707),
  DSP16_Q(-0.00000032),
  DSP16_Q(0.00006883),
  DSP16_Q(-0.00015160),
  DSP16_Q(0.00004187),
  DSP16_Q(0.00051297),
  DSP16_Q(-0.00177220),
  DSP16_Q(0.00395804),
  DSP16_Q(-0.00721550),
  DSP16_Q(0.01158488),
  DSP16_Q(-0.01699654),
  DSP16_Q(0.02330028),
  DSP16_Q(-0.03035585),
  DSP16_Q(0.03827766),
  DSP16_Q(-0.04832076),
  DSP16_Q(0.06911131),
  DSP16_Q(0.44153812),
  DSP16_Q(0.00837817),
  DSP16_Q(-0.02147178),
  DSP16_Q(0.02381651),
  DSP16_Q(-0.02258100),
  DSP16_Q(0.01960395),
  DSP16_Q(-0.01581440),
  DSP16_Q(0.01184903),
  DSP16_Q(-0.00817257),
  DSP16_Q(0.00509662),
  DSP16_Q(-0.00278178),
  DSP16_Q(0.00124740),
  DSP16_Q(-0.00039538),
  DSP16_Q(0.00004653),
  DSP16_Q(0.00001555),
  DSP16_Q(-0.00000037),
  DSP16_Q(0.00007098),
  DSP16_Q(-0.00015920),
  DSP16_Q(0.00005880),
  DSP16_Q(0.00048353),
  DSP16_Q(-0.00172935),
  DSP16_Q(0.00390483),
  DSP16_Q(-0.00716056),
  DSP16_Q(0.01154405),
  DSP16_Q(-0.01699470),
  DSP16_Q(0.02337447),
  DSP16_Q(-0.03056258),
  DSP16_Q(0.03871476),
  DSP16_Q(-0.04921198),
  DSP16_Q(0.07138669),
  DSP16_Q(0.44115605),
  DSP16_Q(0.00648959),
  DSP16_Q(-0.02053600),
  DSP16_Q(0.02327144),
  DSP16_Q(-0.02226051),
  DSP16_Q(0.01942818),
  DSP16_Q(-0.01573338),
  DSP16_Q(0.01182714),
  DSP16_Q(-0.00818347),
  DSP16_Q(0.00512138),
  DSP16_Q(-0.00280794),
  DSP16_Q(0.00126811),
  DSP16_Q(-0.00040829),
  DSP16_Q(0.00005245),
  DSP16_Q(0.00001407),
  DSP16_Q(-0.00000043),
  DSP16_Q(0.00007315),
  DSP16_Q(-0.00016683),
  DSP16_Q(0.00007582),
  DSP16_Q(0.00045386),
  DSP16_Q(-0.00168602),
  DSP16_Q(0.00385074),
  DSP16_Q(-0.00710420),
  DSP16_Q(0.01150109),
  DSP16_Q(-0.01698991),
  DSP16_Q(0.02344483),
  DSP16_Q(-0.03076467),
  DSP16_Q(0.03914677),
  DSP16_Q(-0.05009922),
  DSP16_Q(0.07367236),
  DSP16_Q(0.44074873),
  DSP16_Q(0.00461620),
  DSP16_Q(-0.01960115),
  DSP16_Q(0.02272429),
  DSP16_Q(-0.02193716),
  DSP16_Q(0.01924955),
  DSP16_Q(-0.01564986),
  DSP16_Q(0.01180327),
  DSP16_Q(-0.00819291),
  DSP16_Q(0.00514515),
  DSP16_Q(-0.00283349),
  DSP16_Q(0.00128849),
  DSP16_Q(-0.00042103),
  DSP16_Q(0.00005830),
  DSP16_Q(0.00001261),
  DSP16_Q(-0.00000049),
  DSP16_Q(0.00007534),
  DSP16_Q(-0.00017449),
  DSP16_Q(0.00009294),
  DSP16_Q(0.00042395),
  DSP16_Q(-0.00164221),
  DSP16_Q(0.00379579),
  DSP16_Q(-0.00704641),
  DSP16_Q(0.01145599),
  DSP16_Q(-0.01698215),
  DSP16_Q(0.02351132),
  DSP16_Q(-0.03096206),
  DSP16_Q(0.03957360),
  DSP16_Q(-0.05098231),
  DSP16_Q(0.07596812),
  DSP16_Q(0.44031620),
  DSP16_Q(0.00275813),
  DSP16_Q(-0.01866738),
  DSP16_Q(0.02217518),
  DSP16_Q(-0.02161102),
  DSP16_Q(0.01906810),
  DSP16_Q(-0.01556387),
  DSP16_Q(0.01177741),
  DSP16_Q(-0.00820089),
  DSP16_Q(0.00516793),
  DSP16_Q(-0.00285844),
  DSP16_Q(0.00130853),
  DSP16_Q(-0.00043361),
  DSP16_Q(0.00006408),
  DSP16_Q(0.00001117),
  DSP16_Q(-0.00000055),
  DSP16_Q(0.00007754),
  DSP16_Q(-0.00018220),
  DSP16_Q(0.00011016),
  DSP16_Q(0.00039382),
  DSP16_Q(-0.00159793),
  DSP16_Q(0.00373996),
  DSP16_Q(-0.00698720),
  DSP16_Q(0.01140877),
  DSP16_Q(-0.01697141),
  DSP16_Q(0.02357393),
  DSP16_Q(-0.03115470),
  DSP16_Q(0.03999515),
  DSP16_Q(-0.05186108),
  DSP16_Q(0.07827380),
  DSP16_Q(0.43985851),
  DSP16_Q(0.00091549),
  DSP16_Q(-0.01773484),
  DSP16_Q(0.02162420),
  DSP16_Q(-0.02128215),
  DSP16_Q(0.01888389),
  DSP16_Q(-0.01547543),
  DSP16_Q(0.01174959),
  DSP16_Q(-0.00820741),
  DSP16_Q(0.00518972),
  DSP16_Q(-0.00288277),
  DSP16_Q(0.00132822),
  DSP16_Q(-0.00044602),
  DSP16_Q(0.00006979),
  DSP16_Q(0.00000976),
  DSP16_Q(-0.00000062),
  DSP16_Q(0.00007976),
  DSP16_Q(-0.00018994),
  DSP16_Q(0.00012747),
  DSP16_Q(0.00036347),
  DSP16_Q(-0.00155317),
  DSP16_Q(0.00368328),
  DSP16_Q(-0.00692658),
  DSP16_Q(0.01135941),
  DSP16_Q(-0.01695770),
  DSP16_Q(0.02363263),
  DSP16_Q(-0.03134255),
  DSP16_Q(0.04041135),
  DSP16_Q(-0.05273537),
  DSP16_Q(0.08058921),
  DSP16_Q(0.43937571),
  DSP16_Q(-0.00091159),
  DSP16_Q(-0.01680367),
  DSP16_Q(0.02107145),
  DSP16_Q(-0.02095061),
  DSP16_Q(0.01869694),
  DSP16_Q(-0.01538457),
  DSP16_Q(0.01171980),
  DSP16_Q(-0.00821248),
  DSP16_Q(0.00521052),
  DSP16_Q(-0.00290649),
  DSP16_Q(0.00134758),
  DSP16_Q(-0.00045827),
  DSP16_Q(0.00007543),
  DSP16_Q(0.00000838),
  DSP16_Q(-0.00000070),
  DSP16_Q(0.00008200),
  DSP16_Q(-0.00019771),
  DSP16_Q(0.00014486),
  DSP16_Q(0.00033290),
  DSP16_Q(-0.00150796),
  DSP16_Q(0.00362575),
  DSP16_Q(-0.00686455),
  DSP16_Q(0.01130793),
  DSP16_Q(-0.01694100),
  DSP16_Q(0.02368741),
  DSP16_Q(-0.03152556),
  DSP16_Q(0.04082208),
  DSP16_Q(-0.05360501),
  DSP16_Q(0.08291414),
  DSP16_Q(0.43886784),
  DSP16_Q(-0.00272298),
  DSP16_Q(-0.01587402),
  DSP16_Q(0.02051703),
  DSP16_Q(-0.02061647),
  DSP16_Q(0.01850729),
  DSP16_Q(-0.01529130),
  DSP16_Q(0.01168807),
  DSP16_Q(-0.00821610),
  DSP16_Q(0.00523033),
  DSP16_Q(-0.00292959),
  DSP16_Q(0.00136660),
  DSP16_Q(-0.00047034),
  DSP16_Q(0.00008099),
  DSP16_Q(0.00000702),
  DSP16_Q(-0.00000078),
  DSP16_Q(0.00008425),
  DSP16_Q(-0.00020551),
  DSP16_Q(0.00016234),
  DSP16_Q(0.00030212),
  DSP16_Q(-0.00146230),
  DSP16_Q(0.00356737),
  DSP16_Q(-0.00680113),
  DSP16_Q(0.01125433),
  DSP16_Q(-0.01692131),
  DSP16_Q(0.02373823),
  DSP16_Q(-0.03170368),
  DSP16_Q(0.04122728),
  DSP16_Q(-0.05446984),
  DSP16_Q(0.08524842),
  DSP16_Q(0.43833496),
  DSP16_Q(-0.00451858),
  DSP16_Q(-0.01494604),
  DSP16_Q(0.01996104),
  DSP16_Q(-0.02027980),
  DSP16_Q(0.01831499),
  DSP16_Q(-0.01519565),
  DSP16_Q(0.01165441),
  DSP16_Q(-0.00821828),
  DSP16_Q(0.00524915),
  DSP16_Q(-0.00295207),
  DSP16_Q(0.00138527),
  DSP16_Q(-0.00048225),
  DSP16_Q(0.00008649),
  DSP16_Q(0.00000569),
  DSP16_Q(-0.00000087),
  DSP16_Q(0.00008652),
  DSP16_Q(-0.00021334),
  DSP16_Q(0.00017990),
  DSP16_Q(0.00027113),
  DSP16_Q(-0.00141618),
  DSP16_Q(0.00350816),
  DSP16_Q(-0.00673631),
  DSP16_Q(0.01119860),
  DSP16_Q(-0.01689862),
  DSP16_Q(0.02378509),
  DSP16_Q(-0.03187687),
  DSP16_Q(0.04162684),
  DSP16_Q(-0.05532969),
  DSP16_Q(0.08759184),
  DSP16_Q(0.43777712),
  DSP16_Q(-0.00629826),
  DSP16_Q(-0.01401987),
  DSP16_Q(0.01940359),
  DSP16_Q(-0.01994065),
  DSP16_Q(0.01812008),
  DSP16_Q(-0.01509764),
  DSP16_Q(0.01161882),
  DSP16_Q(-0.00821901),
  DSP16_Q(0.00526698),
  DSP16_Q(-0.00297394),
  DSP16_Q(0.00140359),
  DSP16_Q(-0.00049399),
  DSP16_Q(0.00009191),
  DSP16_Q(0.00000438),
  DSP16_Q(-0.00000096),
  DSP16_Q(0.00008880),
  DSP16_Q(-0.00022121),
  DSP16_Q(0.00019754),
  DSP16_Q(0.00023994),
  DSP16_Q(-0.00136962),
  DSP16_Q(0.00344812),
  DSP16_Q(-0.00667010),
  DSP16_Q(0.01114076),
  DSP16_Q(-0.01687293),
  DSP16_Q(0.02382795),
  DSP16_Q(-0.03204508),
  DSP16_Q(0.04202069),
  DSP16_Q(-0.05618439),
  DSP16_Q(0.08994421),
  DSP16_Q(0.43719439),
  DSP16_Q(-0.00806191),
  DSP16_Q(-0.01309565),
  DSP16_Q(0.01884476),
  DSP16_Q(-0.01959911),
  DSP16_Q(0.01792260),
  DSP16_Q(-0.01499729),
  DSP16_Q(0.01158132),
  DSP16_Q(-0.00821831),
  DSP16_Q(0.00528383),
  DSP16_Q(-0.00299519),
  DSP16_Q(0.00142157),
  DSP16_Q(-0.00050555),
  DSP16_Q(0.00009725),
  DSP16_Q(0.00000310),
  DSP16_Q(-0.00000105),
  DSP16_Q(0.00009110),
  DSP16_Q(-0.00022910),
  DSP16_Q(0.00021525),
  DSP16_Q(0.00020855),
  DSP16_Q(-0.00132263),
  DSP16_Q(0.00338726),
  DSP16_Q(-0.00660252),
  DSP16_Q(0.01108080),
  DSP16_Q(-0.01684423),
  DSP16_Q(0.02386681),
  DSP16_Q(-0.03220827),
  DSP16_Q(0.04240872),
  DSP16_Q(-0.05703379),
  DSP16_Q(0.09230533),
  DSP16_Q(0.43658682),
  DSP16_Q(-0.00980942),
  DSP16_Q(-0.01217353),
  DSP16_Q(0.01828466),
  DSP16_Q(-0.01925522),
  DSP16_Q(0.01772259),
  DSP16_Q(-0.01489464),
  DSP16_Q(0.01154192),
  DSP16_Q(-0.00821618),
  DSP16_Q(0.00529968),
  DSP16_Q(-0.00301581),
  DSP16_Q(0.00143919),
  DSP16_Q(-0.00051694),
  DSP16_Q(0.00010252),
  DSP16_Q(0.00000184),
  DSP16_Q(-0.00000115),
  DSP16_Q(0.00009341),
  DSP16_Q(-0.00023701),
  DSP16_Q(0.00023304),
  DSP16_Q(0.00017696),
  DSP16_Q(-0.00127521),
  DSP16_Q(0.00332558),
  DSP16_Q(-0.00653357),
  DSP16_Q(0.01101874),
  DSP16_Q(-0.01681252),
  DSP16_Q(0.02390165),
  DSP16_Q(-0.03236639),
  DSP16_Q(0.04279086),
  DSP16_Q(-0.05787771),
  DSP16_Q(0.09467500),
  DSP16_Q(0.43595448),
  DSP16_Q(-0.01154068),
  DSP16_Q(-0.01125365),
  DSP16_Q(0.01772340),
  DSP16_Q(-0.01890906),
  DSP16_Q(0.01752009),
  DSP16_Q(-0.01478970),
  DSP16_Q(0.01150063),
  DSP16_Q(-0.00821262),
  DSP16_Q(0.00531454),
  DSP16_Q(-0.00303582),
  DSP16_Q(0.00145647),
  DSP16_Q(-0.00052816),
  DSP16_Q(0.00010772),
  DSP16_Q(0.00000061),
  DSP16_Q(-0.00000126),
  DSP16_Q(0.00009573),
  DSP16_Q(-0.00024496),
  DSP16_Q(0.00025090),
  DSP16_Q(0.00014519),
  DSP16_Q(-0.00122737),
  DSP16_Q(0.00326310),
  DSP16_Q(-0.00646325),
  DSP16_Q(0.01095457),
  DSP16_Q(-0.01677781),
  DSP16_Q(0.02393243),
  DSP16_Q(-0.03251940),
  DSP16_Q(0.04316701),
  DSP16_Q(-0.05871599),
  DSP16_Q(0.09705302),
  DSP16_Q(0.43529743),
  DSP16_Q(-0.01325559),
  DSP16_Q(-0.01033614),
  DSP16_Q(0.01716106),
  DSP16_Q(-0.01856070),
  DSP16_Q(0.01731514),
  DSP16_Q(-0.01468251),
  DSP16_Q(0.01145747),
  DSP16_Q(-0.00820764),
  DSP16_Q(0.00532842),
  DSP16_Q(-0.00305520),
  DSP16_Q(0.00147339),
  DSP16_Q(-0.00053920),
  DSP16_Q(0.00011284),
  DSP16_Q(-0.00000060),
  DSP16_Q(-0.00000137),
  DSP16_Q(0.00009807),
  DSP16_Q(-0.00025292),
  DSP16_Q(0.00026882),
  DSP16_Q(0.00011323),
  DSP16_Q(-0.00117912),
  DSP16_Q(0.00319983),
  DSP16_Q(-0.00639157),
  DSP16_Q(0.01088830),
  DSP16_Q(-0.01674007),
  DSP16_Q(0.02395916),
  DSP16_Q(-0.03266726),
  DSP16_Q(0.04353709),
  DSP16_Q(-0.05954846),
  DSP16_Q(0.09943919),
  DSP16_Q(0.43461574),
  DSP16_Q(-0.01495403),
  DSP16_Q(-0.00942115),
  DSP16_Q(0.01659775),
  DSP16_Q(-0.01821020),
  DSP16_Q(0.01710779),
  DSP16_Q(-0.01457307),
  DSP16_Q(0.01141245),
  DSP16_Q(-0.00820124),
  DSP16_Q(0.00534131),
  DSP16_Q(-0.00307395),
  DSP16_Q(0.00148996),
  DSP16_Q(-0.00055007),
  DSP16_Q(0.00011789),
  DSP16_Q(-0.00000178),
  DSP16_Q(-0.00000149),
  DSP16_Q(0.00010041),
  DSP16_Q(-0.00026091),
  DSP16_Q(0.00028681),
  DSP16_Q(0.00008109),
  DSP16_Q(-0.00113045),
  DSP16_Q(0.00313576),
  DSP16_Q(-0.00631855),
  DSP16_Q(0.01081993),
  DSP16_Q(-0.01669932),
  DSP16_Q(0.02398181),
  DSP16_Q(-0.03280992),
  DSP16_Q(0.04390102),
  DSP16_Q(-0.06037496),
  DSP16_Q(0.10183332),
  DSP16_Q(0.43390948),
  DSP16_Q(-0.01663591),
  DSP16_Q(-0.00850882),
  DSP16_Q(0.01603356),
  DSP16_Q(-0.01785762),
  DSP16_Q(0.01689808),
  DSP16_Q(-0.01446143),
  DSP16_Q(0.01136558),
  DSP16_Q(-0.00819344),
  DSP16_Q(0.00535322),
  DSP16_Q(-0.00309209),
  DSP16_Q(0.00150617),
  DSP16_Q(-0.00056076),
  DSP16_Q(0.00012286),
  DSP16_Q(-0.00000294),
  DSP16_Q(-0.00000161),
  DSP16_Q(0.00010277),
  DSP16_Q(-0.00026891),
  DSP16_Q(0.00030486),
  DSP16_Q(0.00004878),
  DSP16_Q(-0.00108139),
  DSP16_Q(0.00307092),
  DSP16_Q(-0.00624419),
  DSP16_Q(0.01074948),
  DSP16_Q(-0.01665555),
  DSP16_Q(0.02400037),
  DSP16_Q(-0.03294735),
  DSP16_Q(0.04425872),
  DSP16_Q(-0.06119532),
  DSP16_Q(0.10423518),
  DSP16_Q(0.43317874),
  DSP16_Q(-0.01830112),
  DSP16_Q(-0.00759929),
  DSP16_Q(0.01546860),
  DSP16_Q(-0.01750304),
  DSP16_Q(0.01668605),
  DSP16_Q(-0.01434760),
  DSP16_Q(0.01131687),
  DSP16_Q(-0.00818423),
  DSP16_Q(0.00536414),
  DSP16_Q(-0.00310959),
  DSP16_Q(0.00152203),
  DSP16_Q(-0.00057127),
  DSP16_Q(0.00012776),
  DSP16_Q(-0.00000407),
  DSP16_Q(-0.00000174),
  DSP16_Q(0.00010515),
  DSP16_Q(-0.00027694),
  DSP16_Q(0.00032297),
  DSP16_Q(0.00001630),
  DSP16_Q(-0.00103193),
  DSP16_Q(0.00300530),
  DSP16_Q(-0.00616850),
  DSP16_Q(0.01067695),
  DSP16_Q(-0.01660876),
  DSP16_Q(0.02401481),
  DSP16_Q(-0.03307951),
  DSP16_Q(0.04461009),
  DSP16_Q(-0.06200938),
  DSP16_Q(0.10664458),
  DSP16_Q(0.43242357),
  DSP16_Q(-0.01994957),
  DSP16_Q(-0.00669268),
  DSP16_Q(0.01490296),
  DSP16_Q(-0.01714652),
  DSP16_Q(0.01647175),
  DSP16_Q(-0.01423161),
  DSP16_Q(0.01126635),
  DSP16_Q(-0.00817362),
  DSP16_Q(0.00537409),
  DSP16_Q(-0.00312647),
  DSP16_Q(0.00153753),
  DSP16_Q(-0.00058160),
  DSP16_Q(0.00013258),
  DSP16_Q(-0.00000517),
  DSP16_Q(-0.00000188),
  DSP16_Q(0.00010753),
  DSP16_Q(-0.00028498),
  DSP16_Q(0.00034114),
  DSP16_Q(-0.00001634),
  DSP16_Q(-0.00098209),
  DSP16_Q(0.00293893),
  DSP16_Q(-0.00609149),
  DSP16_Q(0.01060234),
  DSP16_Q(-0.01655895),
  DSP16_Q(0.02402514),
  DSP16_Q(-0.03320635),
  DSP16_Q(0.04495505),
  DSP16_Q(-0.06281697),
  DSP16_Q(0.10906131),
  DSP16_Q(0.43164407),
  DSP16_Q(-0.02158116),
  DSP16_Q(-0.00578914),
  DSP16_Q(0.01433675),
  DSP16_Q(-0.01678813),
  DSP16_Q(0.01625522),
  DSP16_Q(-0.01411350),
  DSP16_Q(0.01121402),
  DSP16_Q(-0.00816162),
  DSP16_Q(0.00538305),
  DSP16_Q(-0.00314272),
  DSP16_Q(0.00155267),
  DSP16_Q(-0.00059175),
  DSP16_Q(0.00013732),
  DSP16_Q(-0.00000625),
  DSP16_Q(-0.00000202),
  DSP16_Q(0.00010992),
  DSP16_Q(-0.00029303),
  DSP16_Q(0.00035935),
  DSP16_Q(-0.00004914),
  DSP16_Q(-0.00093186),
  DSP16_Q(0.00287180),
  DSP16_Q(-0.00601317),
  DSP16_Q(0.01052566),
  DSP16_Q(-0.01650612),
  DSP16_Q(0.02403132),
  DSP16_Q(-0.03332784),
  DSP16_Q(0.04529352),
  DSP16_Q(-0.06361793),
  DSP16_Q(0.11148516),
  DSP16_Q(0.43084030),
  DSP16_Q(-0.02319579),
  DSP16_Q(-0.00488879),
  DSP16_Q(0.01377005),
  DSP16_Q(-0.01642794),
  DSP16_Q(0.01603650),
  DSP16_Q(-0.01399327),
  DSP16_Q(0.01115990),
  DSP16_Q(-0.00814824),
  DSP16_Q(0.00539103),
  DSP16_Q(-0.00315835),
  DSP16_Q(0.00156745),
  DSP16_Q(-0.00060172),
  DSP16_Q(0.00014198),
  DSP16_Q(-0.00000730),
  DSP16_Q(-0.00000217),
  DSP16_Q(0.00011232),
  DSP16_Q(-0.00030110),
  DSP16_Q(0.00037762),
  DSP16_Q(-0.00008210),
  DSP16_Q(-0.00088127),
  DSP16_Q(0.00280393),
  DSP16_Q(-0.00593355),
  DSP16_Q(0.01044692),
  DSP16_Q(-0.01645027),
  DSP16_Q(0.02403336),
  DSP16_Q(-0.03344394),
  DSP16_Q(0.04562543),
  DSP16_Q(-0.06441209),
  DSP16_Q(0.11391593),
  DSP16_Q(0.43001237),
  DSP16_Q(-0.02479338),
  DSP16_Q(-0.00399178),
  DSP16_Q(0.01320297),
  DSP16_Q(-0.01606600),
  DSP16_Q(0.01581563),
  DSP16_Q(-0.01387097),
  DSP16_Q(0.01110400),
  DSP16_Q(-0.00813347),
  DSP16_Q(0.00539804),
  DSP16_Q(-0.00317335),
  DSP16_Q(0.00158187),
  DSP16_Q(-0.00061151),
  DSP16_Q(0.00014657),
  DSP16_Q(-0.00000833),
  DSP16_Q(-0.00000232),
  DSP16_Q(0.00011473),
  DSP16_Q(-0.00030919),
  DSP16_Q(0.00039593),
  DSP16_Q(-0.00011520),
  DSP16_Q(-0.00083031),
  DSP16_Q(0.00273532),
  DSP16_Q(-0.00585263),
  DSP16_Q(0.01036612),
  DSP16_Q(-0.01639139),
  DSP16_Q(0.02403123),
  DSP16_Q(-0.03355461),
  DSP16_Q(0.04595068),
  DSP16_Q(-0.06519929),
  DSP16_Q(0.11635339),
  DSP16_Q(0.42916035),
  DSP16_Q(-0.02637384),
  DSP16_Q(-0.00309824),
  DSP16_Q(0.01263561),
  DSP16_Q(-0.01570240),
  DSP16_Q(0.01559267),
  DSP16_Q(-0.01374662),
  DSP16_Q(0.01104634),
  DSP16_Q(-0.00811734),
  DSP16_Q(0.00540408),
  DSP16_Q(-0.00318772),
  DSP16_Q(0.00159593),
  DSP16_Q(-0.00062111),
  DSP16_Q(0.00015107),
  DSP16_Q(-0.00000933),
  DSP16_Q(-0.00000247),
  DSP16_Q(0.00011715),
  DSP16_Q(-0.00031728),
  DSP16_Q(0.00041428),
  DSP16_Q(-0.00014844),
  DSP16_Q(-0.00077900),
  DSP16_Q(0.00266599),
  DSP16_Q(-0.00577043),
  DSP16_Q(0.01028328),
  DSP16_Q(-0.01632951),
  DSP16_Q(0.02402493),
  DSP16_Q(-0.03365982),
  DSP16_Q(0.04626921),
  DSP16_Q(-0.06597936),
  DSP16_Q(0.11879735),
  DSP16_Q(0.42828433),
  DSP16_Q(-0.02793707),
  DSP16_Q(-0.00220829),
  DSP16_Q(0.01206805),
  DSP16_Q(-0.01533720),
  DSP16_Q(0.01536766),
  DSP16_Q(-0.01362025),
  DSP16_Q(0.01098694),
  DSP16_Q(-0.00809985),
  DSP16_Q(0.00540914),
  DSP16_Q(-0.00320147),
  DSP16_Q(0.00160962),
  DSP16_Q(-0.00063054),
  DSP16_Q(0.00015550),
  DSP16_Q(-0.00001031),
  DSP16_Q(-0.00000264),
  DSP16_Q(0.00011958),
  DSP16_Q(-0.00032538),
  DSP16_Q(0.00043267),
  DSP16_Q(-0.00018183),
  DSP16_Q(-0.00072734),
  DSP16_Q(0.00259594),
  DSP16_Q(-0.00568697),
  DSP16_Q(0.01019840),
  DSP16_Q(-0.01626460),
  DSP16_Q(0.02401445),
  DSP16_Q(-0.03375953),
  DSP16_Q(0.04658092),
  DSP16_Q(-0.06675214),
  DSP16_Q(0.12124758),
  DSP16_Q(0.42738440),
  DSP16_Q(-0.02948300),
  DSP16_Q(-0.00132207),
  DSP16_Q(0.01150041),
  DSP16_Q(-0.01497046),
  DSP16_Q(0.01514063),
  DSP16_Q(-0.01349187),
  DSP16_Q(0.01092581),
  DSP16_Q(-0.00808100),
  DSP16_Q(0.00541324),
  DSP16_Q(-0.00321459),
  DSP16_Q(0.00162296),
  DSP16_Q(-0.00063978),
  DSP16_Q(0.00015986),
  DSP16_Q(-0.00001127),
  DSP16_Q(-0.00000281),
  DSP16_Q(0.00012201),
  DSP16_Q(-0.00033349),
  DSP16_Q(0.00045109),
  DSP16_Q(-0.00021534),
  DSP16_Q(-0.00067534),
  DSP16_Q(0.00252519),
  DSP16_Q(-0.00560224),
  DSP16_Q(0.01011149),
  DSP16_Q(-0.01619668),
  DSP16_Q(0.02399977),
  DSP16_Q(-0.03385371),
  DSP16_Q(0.04688574),
  DSP16_Q(-0.06751746),
  DSP16_Q(0.12370387),
  DSP16_Q(0.42646067),
  DSP16_Q(-0.03101154),
  DSP16_Q(-0.00043970),
  DSP16_Q(0.01093277),
  DSP16_Q(-0.01460225),
  DSP16_Q(0.01491164),
  DSP16_Q(-0.01336154),
  DSP16_Q(0.01086296),
  DSP16_Q(-0.00806080),
  DSP16_Q(0.00541637),
  DSP16_Q(-0.00322708),
  DSP16_Q(0.00163593),
  DSP16_Q(-0.00064883),
  DSP16_Q(0.00016413),
  DSP16_Q(-0.00001219),
  DSP16_Q(-0.00000298),
  DSP16_Q(0.00012446),
  DSP16_Q(-0.00034161),
  DSP16_Q(0.00046955),
  DSP16_Q(-0.00024898),
  DSP16_Q(-0.00062300),
  DSP16_Q(0.00245374),
  DSP16_Q(-0.00551626),
  DSP16_Q(0.01002256),
  DSP16_Q(-0.01612576),
  DSP16_Q(0.02398088),
  DSP16_Q(-0.03394232),
  DSP16_Q(0.04718360),
  DSP16_Q(-0.06827517),
  DSP16_Q(0.12616601),
  DSP16_Q(0.42551321),
  DSP16_Q(-0.03252260),
  DSP16_Q(0.00043869),
  DSP16_Q(0.01036523),
  DSP16_Q(-0.01423264),
  DSP16_Q(0.01468073),
  DSP16_Q(-0.01322926),
  DSP16_Q(0.01079842),
  DSP16_Q(-0.00803926),
  DSP16_Q(0.00541854),
  DSP16_Q(-0.00323895),
  DSP16_Q(0.00164854),
  DSP16_Q(-0.00065770),
  DSP16_Q(0.00016832),
  DSP16_Q(-0.00001310),
  DSP16_Q(-0.00000316),
  DSP16_Q(0.00012690),
  DSP16_Q(-0.00034973),
  DSP16_Q(0.00048804),
  DSP16_Q(-0.00028274),
  DSP16_Q(-0.00057035),
  DSP16_Q(0.00238161),
  DSP16_Q(-0.00542904),
  DSP16_Q(0.00993163),
  DSP16_Q(-0.01605183),
  DSP16_Q(0.02395778),
  DSP16_Q(-0.03402533),
  DSP16_Q(0.04747442),
  DSP16_Q(-0.06902510),
  DSP16_Q(0.12863377),
  DSP16_Q(0.42454214),
  DSP16_Q(-0.03401612),
  DSP16_Q(0.00131297),
  DSP16_Q(0.00979789),
  DSP16_Q(-0.01386170),
  DSP16_Q(0.01444795),
  DSP16_Q(-0.01309507),
  DSP16_Q(0.01073219),
  DSP16_Q(-0.00801638),
  DSP16_Q(0.00541975),
  DSP16_Q(-0.00325019),
  DSP16_Q(0.00166078),
  DSP16_Q(-0.00066639),
  DSP16_Q(0.00017244),
  DSP16_Q(-0.00001397),
  DSP16_Q(-0.00000335),
  DSP16_Q(0.00012936),
  DSP16_Q(-0.00035785),
  DSP16_Q(0.00050655),
  DSP16_Q(-0.00031661),
  DSP16_Q(-0.00051738),
  DSP16_Q(0.00230881),
  DSP16_Q(-0.00534059),
  DSP16_Q(0.00983869),
  DSP16_Q(-0.01597489),
  DSP16_Q(0.02393045),
  DSP16_Q(-0.03410271),
  DSP16_Q(0.04775812),
  DSP16_Q(-0.06976708),
  DSP16_Q(0.13110695),
  DSP16_Q(0.42354755),
  DSP16_Q(-0.03549202),
  DSP16_Q(0.00218301),
  DSP16_Q(0.00923084),
  DSP16_Q(-0.01348950),
  DSP16_Q(0.01421334),
  DSP16_Q(-0.01295900),
  DSP16_Q(0.01066430),
  DSP16_Q(-0.00799219),
  DSP16_Q(0.00542000),
  DSP16_Q(-0.00326081),
  DSP16_Q(0.00167266),
  DSP16_Q(-0.00067489),
  DSP16_Q(0.00017647),
  DSP16_Q(-0.00001483),
  DSP16_Q(-0.00000354),
  DSP16_Q(0.00013181),
  DSP16_Q(-0.00036597),
  DSP16_Q(0.00052508),
  DSP16_Q(-0.00035059),
  DSP16_Q(-0.00046409),
  DSP16_Q(0.00223534),
  DSP16_Q(-0.00525093),
  DSP16_Q(0.00974376),
  DSP16_Q(-0.01589496),
  DSP16_Q(0.02389890),
  DSP16_Q(-0.03417443),
  DSP16_Q(0.04803462),
  DSP16_Q(-0.07050095),
  DSP16_Q(0.13358532),
  DSP16_Q(0.42252954),
  DSP16_Q(-0.03695022),
  DSP16_Q(0.00304870),
  DSP16_Q(0.00866418),
  DSP16_Q(-0.01311610),
  DSP16_Q(0.01397694),
  DSP16_Q(-0.01282107),
  DSP16_Q(0.01059476),
  DSP16_Q(-0.00796668),
  DSP16_Q(0.00541930),
  DSP16_Q(-0.00327080),
  DSP16_Q(0.00168417),
  DSP16_Q(-0.00068320),
  DSP16_Q(0.00018043),
  DSP16_Q(-0.00001566),
  DSP16_Q(-0.00000374),
  DSP16_Q(0.00013428),
  DSP16_Q(-0.00037409),
  DSP16_Q(0.00054363),
  DSP16_Q(-0.00038468),
  DSP16_Q(-0.00041052),
  DSP16_Q(0.00216122),
  DSP16_Q(-0.00516007),
  DSP16_Q(0.00964685),
  DSP16_Q(-0.01581204),
  DSP16_Q(0.02386310),
  DSP16_Q(-0.03424045),
  DSP16_Q(0.04830386),
  DSP16_Q(-0.07122655),
  DSP16_Q(0.13606866),
  DSP16_Q(0.42148823),
  DSP16_Q(-0.03839065),
  DSP16_Q(0.00390990),
  DSP16_Q(0.00809801),
  DSP16_Q(-0.01274157),
  DSP16_Q(0.01373881),
  DSP16_Q(-0.01268133),
  DSP16_Q(0.01052359),
  DSP16_Q(-0.00793986),
  DSP16_Q(0.00541765),
  DSP16_Q(-0.00328017),
  DSP16_Q(0.00169532),
  DSP16_Q(-0.00069133),
  DSP16_Q(0.00018431),
  DSP16_Q(-0.00001646),
  DSP16_Q(-0.00000395),
  DSP16_Q(0.00013674),
  DSP16_Q(-0.00038221),
  DSP16_Q(0.00056220),
  DSP16_Q(-0.00041886),
  DSP16_Q(-0.00035665),
  DSP16_Q(0.00208646),
  DSP16_Q(-0.00506802),
  DSP16_Q(0.00954798),
  DSP16_Q(-0.01572613),
  DSP16_Q(0.02382307),
  DSP16_Q(-0.03430075),
  DSP16_Q(0.04856575),
  DSP16_Q(-0.07194372),
  DSP16_Q(0.13855675),
  DSP16_Q(0.42042372),
  DSP16_Q(-0.03981325),
  DSP16_Q(0.00476651),
  DSP16_Q(0.00753240),
  DSP16_Q(-0.01236598),
  DSP16_Q(0.01349899),
  DSP16_Q(-0.01253979),
  DSP16_Q(0.01045080),
  DSP16_Q(-0.00791174),
  DSP16_Q(0.00541506),
  DSP16_Q(-0.00328891),
  DSP16_Q(0.00170610),
  DSP16_Q(-0.00069927),
  DSP16_Q(0.00018810),
  DSP16_Q(-0.00001724),
  DSP16_Q(-0.00000416),
  DSP16_Q(0.00013921),
  DSP16_Q(-0.00039032),
  DSP16_Q(0.00058077),
  DSP16_Q(-0.00045313),
  DSP16_Q(-0.00030249),
  DSP16_Q(0.00201106),
  DSP16_Q(-0.00497478),
  DSP16_Q(0.00944714),
  DSP16_Q(-0.01563724),
  DSP16_Q(0.02377878),
  DSP16_Q(-0.03435530),
  DSP16_Q(0.04882024),
  DSP16_Q(-0.07265230),
  DSP16_Q(0.14104937),
  DSP16_Q(0.41933612),
  DSP16_Q(-0.04121794),
  DSP16_Q(0.00561839),
  DSP16_Q(0.00696747),
  DSP16_Q(-0.01198939),
  DSP16_Q(0.01325753),
  DSP16_Q(-0.01239648),
  DSP16_Q(0.01037642),
  DSP16_Q(-0.00788234),
  DSP16_Q(0.00541153),
  DSP16_Q(-0.00329704),
  DSP16_Q(0.00171652),
  DSP16_Q(-0.00070702),
  DSP16_Q(0.00019182),
  DSP16_Q(-0.00001800),
  DSP16_Q(-0.00000437),
  DSP16_Q(0.00014168),
  DSP16_Q(-0.00039843),
  DSP16_Q(0.00059936),
  DSP16_Q(-0.00048749),
  DSP16_Q(-0.00024807),
  DSP16_Q(0.00193505),
  DSP16_Q(-0.00488038),
  DSP16_Q(0.00934437),
  DSP16_Q(-0.01554538),
  DSP16_Q(0.02373024),
  DSP16_Q(-0.03440407),
  DSP16_Q(0.04906724),
  DSP16_Q(-0.07335213),
  DSP16_Q(0.14354630),
  DSP16_Q(0.41822555),
  DSP16_Q(-0.04260467),
  DSP16_Q(0.00646544),
  DSP16_Q(0.00640331),
  DSP16_Q(-0.01161188),
  DSP16_Q(0.01301447),
  DSP16_Q(-0.01225144),
  DSP16_Q(0.01030046),
  DSP16_Q(-0.00785166),
  DSP16_Q(0.00540705),
  DSP16_Q(-0.00330454),
  DSP16_Q(0.00172657),
  DSP16_Q(-0.00071459),
  DSP16_Q(0.00019546),
  DSP16_Q(-0.00001873),
  DSP16_Q(-0.00000459),
  DSP16_Q(0.00014416),
  DSP16_Q(-0.00040653),
  DSP16_Q(0.00061795),
  DSP16_Q(-0.00052193),
  DSP16_Q(-0.00019338),
  DSP16_Q(0.00185843),
  DSP16_Q(-0.00478483),
  DSP16_Q(0.00923966),
  DSP16_Q(-0.01545055),
  DSP16_Q(0.02367744),
  DSP16_Q(-0.03444704),
  DSP16_Q(0.04930668),
  DSP16_Q(-0.07404304),
  DSP16_Q(0.14604731),
  DSP16_Q(0.41709211),
  DSP16_Q(-0.04397336),
  DSP16_Q(0.00730752),
  DSP16_Q(0.00584000),
  DSP16_Q(-0.01123351),
  DSP16_Q(0.01276985),
  DSP16_Q(-0.01210470),
  DSP16_Q(0.01022295),
  DSP16_Q(-0.00781971),
  DSP16_Q(0.00540165),
  DSP16_Q(-0.00331143),
  DSP16_Q(0.00173626),
  DSP16_Q(-0.00072197),
  DSP16_Q(0.00019901),
  DSP16_Q(-0.00001944),
  DSP16_Q(-0.00000482),
  DSP16_Q(0.00014663),
  DSP16_Q(-0.00041462),
  DSP16_Q(0.00063654),
  DSP16_Q(-0.00055645),
  DSP16_Q(-0.00013843),
  DSP16_Q(0.00178121),
  DSP16_Q(-0.00468813),
  DSP16_Q(0.00913303),
  DSP16_Q(-0.01535276),
  DSP16_Q(0.02362038),
  DSP16_Q(-0.03448417),
  DSP16_Q(0.04953851),
  DSP16_Q(-0.07472488),
  DSP16_Q(0.14855218),
  DSP16_Q(0.41593594),
  DSP16_Q(-0.04532397),
  DSP16_Q(0.00814453),
  DSP16_Q(0.00527764),
  DSP16_Q(-0.01085435),
  DSP16_Q(0.01252374),
  DSP16_Q(-0.01195628),
  DSP16_Q(0.01014389),
  DSP16_Q(-0.00778650),
  DSP16_Q(0.00539532),
  DSP16_Q(-0.00331770),
  DSP16_Q(0.00174558),
  DSP16_Q(-0.00072916),
  DSP16_Q(0.00020249),
  DSP16_Q(-0.00002012),
  DSP16_Q(-0.00000505),
  DSP16_Q(0.00014910),
  DSP16_Q(-0.00042270),
  DSP16_Q(0.00065513),
  DSP16_Q(-0.00059103),
  DSP16_Q(-0.00008324),
  DSP16_Q(0.00170341),
  DSP16_Q(-0.00459031),
  DSP16_Q(0.00902449),
  DSP16_Q(-0.01525203),
  DSP16_Q(0.02355906),
  DSP16_Q(-0.03451545),
  DSP16_Q(0.04976264),
  DSP16_Q(-0.07539749),
  DSP16_Q(0.15106067),
  DSP16_Q(0.41475714),
  DSP16_Q(-0.04665643),
  DSP16_Q(0.00897635),
  DSP16_Q(0.00471632),
  DSP16_Q(-0.01047446),
  DSP16_Q(0.01227616),
  DSP16_Q(-0.01180622),
  DSP16_Q(0.01006330),
  DSP16_Q(-0.00775204),
  DSP16_Q(0.00538806),
  DSP16_Q(-0.00332335),
  DSP16_Q(0.00175453),
  DSP16_Q(-0.00073616),
  DSP16_Q(0.00020589),
  DSP16_Q(-0.00002078),
  DSP16_Q(-0.00000529),
  DSP16_Q(0.00015158),
  DSP16_Q(-0.00043076),
  DSP16_Q(0.00067371),
  DSP16_Q(-0.00062567),
  DSP16_Q(-0.00002780),
  DSP16_Q(0.00162503),
  DSP16_Q(-0.00449138),
  DSP16_Q(0.00891406),
  DSP16_Q(-0.01514836),
  DSP16_Q(0.02349347),
  DSP16_Q(-0.03454085),
  DSP16_Q(0.04997901),
  DSP16_Q(-0.07606071),
  DSP16_Q(0.15357258),
  DSP16_Q(0.41355584),
  DSP16_Q(-0.04797069),
  DSP16_Q(0.00980286),
  DSP16_Q(0.00415614),
  DSP16_Q(-0.01009392),
  DSP16_Q(0.01202718),
  DSP16_Q(-0.01165454),
  DSP16_Q(0.00998121),
  DSP16_Q(-0.00771634),
  DSP16_Q(0.00537988),
  DSP16_Q(-0.00332839),
  DSP16_Q(0.00176312),
  DSP16_Q(-0.00074298),
  DSP16_Q(0.00020920),
  DSP16_Q(-0.00002142),
  DSP16_Q(-0.00000554),
  DSP16_Q(0.00015405),
  DSP16_Q(-0.00043881),
  DSP16_Q(0.00069229),
  DSP16_Q(-0.00066037),
  DSP16_Q(0.00002786),
  DSP16_Q(0.00154609),
  DSP16_Q(-0.00439134),
  DSP16_Q(0.00880175),
  DSP16_Q(-0.01504175),
  DSP16_Q(0.02342361),
  DSP16_Q(-0.03456035),
  DSP16_Q(0.05018755),
  DSP16_Q(-0.07671437),
  DSP16_Q(0.15608766),
  DSP16_Q(0.41233217),
  DSP16_Q(-0.04926669),
  DSP16_Q(0.01062396),
  DSP16_Q(0.00359718),
  DSP16_Q(-0.00971279),
  DSP16_Q(0.01177683),
  DSP16_Q(-0.01150129),
  DSP16_Q(0.00989764),
  DSP16_Q(-0.00767941),
  DSP16_Q(0.00537079),
  DSP16_Q(-0.00333282),
  DSP16_Q(0.00177135),
  DSP16_Q(-0.00074960),
  DSP16_Q(0.00021244),
  DSP16_Q(-0.00002203),
  DSP16_Q(-0.00000579),
  DSP16_Q(0.00015652),
  DSP16_Q(-0.00044684),
  DSP16_Q(0.00071084),
  DSP16_Q(-0.00069512),
  DSP16_Q(0.00008374),
  DSP16_Q(0.00146660),
  DSP16_Q(-0.00429022),
  DSP16_Q(0.00868757),
  DSP16_Q(-0.01493223),
  DSP16_Q(0.02334949),
  DSP16_Q(-0.03457392),
  DSP16_Q(0.05038821),
  DSP16_Q(-0.07735833),
  DSP16_Q(0.15860569),
  DSP16_Q(0.41108625),
  DSP16_Q(-0.05054439),
  DSP16_Q(0.01143953),
  DSP16_Q(0.00303954),
  DSP16_Q(-0.00933114),
  DSP16_Q(0.01152516),
  DSP16_Q(-0.01134648),
  DSP16_Q(0.00981260),
  DSP16_Q(-0.00764126),
  DSP16_Q(0.00536079),
  DSP16_Q(-0.00333663),
  DSP16_Q(0.00177921),
  DSP16_Q(-0.00075604),
  DSP16_Q(0.00021560),
  DSP16_Q(-0.00002263),
  DSP16_Q(-0.00000604),
  DSP16_Q(0.00015899),
  DSP16_Q(-0.00045485),
  DSP16_Q(0.00072939),
  DSP16_Q(-0.00072991),
  DSP16_Q(0.00013983),
  DSP16_Q(0.00138658),
  DSP16_Q(-0.00418804),
  DSP16_Q(0.00857154),
  DSP16_Q(-0.01481980),
  DSP16_Q(0.02327110),
  DSP16_Q(-0.03458154),
  DSP16_Q(0.05058091),
  DSP16_Q(-0.07799243),
  DSP16_Q(0.16112644),
  DSP16_Q(0.40981821),
  DSP16_Q(-0.05180374),
  DSP16_Q(0.01224946),
  DSP16_Q(0.00248330),
  DSP16_Q(-0.00894904),
  DSP16_Q(0.01127223),
  DSP16_Q(-0.01119016),
  DSP16_Q(0.00972611),
  DSP16_Q(-0.00760191),
  DSP16_Q(0.00534988),
  DSP16_Q(-0.00333984),
  DSP16_Q(0.00178671),
  DSP16_Q(-0.00076229),
  DSP16_Q(0.00021868),
  DSP16_Q(-0.00002319),
  DSP16_Q(-0.00000630),
  DSP16_Q(0.00016146),
  DSP16_Q(-0.00046284),
  DSP16_Q(0.00074791),
  DSP16_Q(-0.00076474),
  DSP16_Q(0.00019613),
  DSP16_Q(0.00130603),
  DSP16_Q(-0.00408479),
  DSP16_Q(0.00845368),
  DSP16_Q(-0.01470447),
  DSP16_Q(0.02318844),
  DSP16_Q(-0.03458320),
  DSP16_Q(0.05076559),
  DSP16_Q(-0.07861650),
  DSP16_Q(0.16364968),
  DSP16_Q(0.40852818),
  DSP16_Q(-0.05304468),
  DSP16_Q(0.01305365),
  DSP16_Q(0.00192855),
  DSP16_Q(-0.00856654),
  DSP16_Q(0.01101807),
  DSP16_Q(-0.01103235),
  DSP16_Q(0.00963819),
  DSP16_Q(-0.00756136),
  DSP16_Q(0.00533808),
  DSP16_Q(-0.00334244),
  DSP16_Q(0.00179384),
  DSP16_Q(-0.00076835),
  DSP16_Q(0.00022167),
  DSP16_Q(-0.00002374),
  DSP16_Q(-0.00000657),
  DSP16_Q(0.00016392),
  DSP16_Q(-0.00047081),
  DSP16_Q(0.00076640),
  DSP16_Q(-0.00079959),
  DSP16_Q(0.00025262),
  DSP16_Q(0.00122496),
  DSP16_Q(-0.00398050),
  DSP16_Q(0.00833399),
  DSP16_Q(-0.01458625),
  DSP16_Q(0.02310152),
  DSP16_Q(-0.03457887),
  DSP16_Q(0.05094220),
  DSP16_Q(-0.07923040),
  DSP16_Q(0.16617518),
  DSP16_Q(0.40721630),
  DSP16_Q(-0.05426719),
  DSP16_Q(0.01385198),
  DSP16_Q(0.00137539),
  DSP16_Q(-0.00818373),
  DSP16_Q(0.01076274),
  DSP16_Q(-0.01087308),
  DSP16_Q(0.00954886),
  DSP16_Q(-0.00751962),
  DSP16_Q(0.00532538),
  DSP16_Q(-0.00334443),
  DSP16_Q(0.00180061),
  DSP16_Q(-0.00077423),
  DSP16_Q(0.00022459),
  DSP16_Q(-0.00002426),
  DSP16_Q(-0.00000684),
  DSP16_Q(0.00016638),
  DSP16_Q(-0.00047875),
  DSP16_Q(0.00078487),
  DSP16_Q(-0.00083448),
  DSP16_Q(0.00030929),
  DSP16_Q(0.00114340),
  DSP16_Q(-0.00387519),
  DSP16_Q(0.00821250),
  DSP16_Q(-0.01446516),
  DSP16_Q(0.02301034),
  DSP16_Q(-0.03456853),
  DSP16_Q(0.05111066),
  DSP16_Q(-0.07983397),
  DSP16_Q(0.16870271),
  DSP16_Q(0.40588270),
  DSP16_Q(-0.05547121),
  DSP16_Q(0.01464436),
  DSP16_Q(0.00082390),
  DSP16_Q(-0.00780066),
  DSP16_Q(0.01050629),
  DSP16_Q(-0.01071239),
  DSP16_Q(0.00945815),
  DSP16_Q(-0.00747671),
  DSP16_Q(0.00531180),
  DSP16_Q(-0.00334583),
  DSP16_Q(0.00180702),
  DSP16_Q(-0.00077991),
  DSP16_Q(0.00022743),
  DSP16_Q(-0.00002476),
  DSP16_Q(-0.00000712),
  DSP16_Q(0.00016883),
  DSP16_Q(-0.00048667),
  DSP16_Q(0.00080331),
  DSP16_Q(-0.00086938),
  DSP16_Q(0.00036613),
  DSP16_Q(0.00106135),
  DSP16_Q(-0.00376886),
  DSP16_Q(0.00808922),
  DSP16_Q(-0.01434120),
  DSP16_Q(0.02291489),
  DSP16_Q(-0.03455218),
  DSP16_Q(0.05127092),
  DSP16_Q(-0.08042705),
  DSP16_Q(0.17123203),
  DSP16_Q(0.40452752),
  DSP16_Q(-0.05665672),
  DSP16_Q(0.01543067),
  DSP16_Q(0.00027418),
  DSP16_Q(-0.00741740),
  DSP16_Q(0.01024875),
  DSP16_Q(-0.01055031),
  DSP16_Q(0.00936607),
  DSP16_Q(-0.00743263),
  DSP16_Q(0.00529733),
  DSP16_Q(-0.00334662),
  DSP16_Q(0.00181307),
  DSP16_Q(-0.00078541),
  DSP16_Q(0.00023019),
  DSP16_Q(-0.00002524),
  DSP16_Q(-0.00000740),
  DSP16_Q(0.00017127),
  DSP16_Q(-0.00049456),
  DSP16_Q(0.00082171),
  DSP16_Q(-0.00090430),
  DSP16_Q(0.00042314),
  DSP16_Q(0.00097882),
  DSP16_Q(-0.00366155),
  DSP16_Q(0.00796416),
  DSP16_Q(-0.01421440),
  DSP16_Q(0.02281520),
  DSP16_Q(-0.03452978),
  DSP16_Q(0.05142293),
  DSP16_Q(-0.08100950),
  DSP16_Q(0.17376292),
  DSP16_Q(0.40315090),
  DSP16_Q(-0.05782366),
  DSP16_Q(0.01621082),
  DSP16_Q(-0.00027370),
  DSP16_Q(-0.00703403),
  DSP16_Q(0.00999019),
  DSP16_Q(-0.01038687),
  DSP16_Q(0.00927264),
  DSP16_Q(-0.00738741),
  DSP16_Q(0.00528198),
  DSP16_Q(-0.00334682),
  DSP16_Q(0.00181875),
  DSP16_Q(-0.00079072),
  DSP16_Q(0.00023287),
  DSP16_Q(-0.00002570),
  DSP16_Q(-0.00000769),
  DSP16_Q(0.00017371),
  DSP16_Q(-0.00050241),
  DSP16_Q(0.00084007),
  DSP16_Q(-0.00093922),
  DSP16_Q(0.00048030),
  DSP16_Q(0.00089584),
  DSP16_Q(-0.00355325),
  DSP16_Q(0.00783735),
  DSP16_Q(-0.01408476),
  DSP16_Q(0.02271125),
  DSP16_Q(-0.03450133),
  DSP16_Q(0.05156662),
  DSP16_Q(-0.08158115),
  DSP16_Q(0.17629514),
  DSP16_Q(0.40175298),
  DSP16_Q(-0.05897201),
  DSP16_Q(0.01698470),
  DSP16_Q(-0.00081965),
  DSP16_Q(-0.00665059),
  DSP16_Q(0.00973063),
  DSP16_Q(-0.01022210),
  DSP16_Q(0.00917788),
  DSP16_Q(-0.00734104),
  DSP16_Q(0.00526577),
  DSP16_Q(-0.00334642),
  DSP16_Q(0.00182408),
  DSP16_Q(-0.00079584),
  DSP16_Q(0.00023547),
  DSP16_Q(-0.00002614),
  DSP16_Q(-0.00000798),
  DSP16_Q(0.00017614),
  DSP16_Q(-0.00051024),
  DSP16_Q(0.00085839),
  DSP16_Q(-0.00097414),
  DSP16_Q(0.00053761),
  DSP16_Q(0.00081240),
  DSP16_Q(-0.00344398),
  DSP16_Q(0.00770880),
  DSP16_Q(-0.01395231),
  DSP16_Q(0.02260306),
  DSP16_Q(-0.03446681),
  DSP16_Q(0.05170193),
  DSP16_Q(-0.08214186),
  DSP16_Q(0.17882845),
  DSP16_Q(0.40033392),
  DSP16_Q(-0.06010174),
  DSP16_Q(0.01775221),
  DSP16_Q(-0.00136358),
  DSP16_Q(-0.00626717),
  DSP16_Q(0.00947015),
  DSP16_Q(-0.01005604),
  DSP16_Q(0.00908181),
  DSP16_Q(-0.00729355),
  DSP16_Q(0.00524869),
  DSP16_Q(-0.00334542),
  DSP16_Q(0.00182905),
  DSP16_Q(-0.00080078),
  DSP16_Q(0.00023799),
  DSP16_Q(-0.00002655),
  DSP16_Q(-0.00000828),
  DSP16_Q(0.00017857),
  DSP16_Q(-0.00051803),
  DSP16_Q(0.00087666),
  DSP16_Q(-0.00100905),
  DSP16_Q(0.00059505),
  DSP16_Q(0.00072853),
  DSP16_Q(-0.00333377),
  DSP16_Q(0.00757852),
  DSP16_Q(-0.01381705),
  DSP16_Q(0.02249063),
  DSP16_Q(-0.03442621),
  DSP16_Q(0.05182882),
  DSP16_Q(-0.08269148),
  DSP16_Q(0.18136263),
  DSP16_Q(0.39889384),
  DSP16_Q(-0.06121282),
  DSP16_Q(0.01851325),
  DSP16_Q(-0.00190540),
  DSP16_Q(-0.00588383),
  DSP16_Q(0.00920877),
  DSP16_Q(-0.00988871),
  DSP16_Q(0.00898446),
  DSP16_Q(-0.00724494),
  DSP16_Q(0.00523075),
  DSP16_Q(-0.00334384),
  DSP16_Q(0.00183366),
  DSP16_Q(-0.00080553),
  DSP16_Q(0.00024044),
  DSP16_Q(-0.00002694),
  DSP16_Q(-0.00000858),
  DSP16_Q(0.00018098),
  DSP16_Q(-0.00052579),
  DSP16_Q(0.00089488),
  DSP16_Q(-0.00104395),
  DSP16_Q(0.00065262),
  DSP16_Q(0.00064424),
  DSP16_Q(-0.00322263),
  DSP16_Q(0.00744654),
  DSP16_Q(-0.01367899),
  DSP16_Q(0.02237397),
  DSP16_Q(-0.03437952),
  DSP16_Q(0.05194722),
  DSP16_Q(-0.08322985),
  DSP16_Q(0.18389744),
  DSP16_Q(0.39743291),
  DSP16_Q(-0.06230521),
  DSP16_Q(0.01926774),
  DSP16_Q(-0.00244503),
  DSP16_Q(-0.00550062),
  DSP16_Q(0.00894655),
  DSP16_Q(-0.00972016),
  DSP16_Q(0.00888585),
  DSP16_Q(-0.00719523),
  DSP16_Q(0.00521196),
  DSP16_Q(-0.00334167),
  DSP16_Q(0.00183791),
  DSP16_Q(-0.00081009),
  DSP16_Q(0.00024280),
  DSP16_Q(-0.00002731),
  DSP16_Q(-0.00000889),
  DSP16_Q(0.00018338),
  DSP16_Q(-0.00053350),
  DSP16_Q(0.00091305),
  DSP16_Q(-0.00107883),
  DSP16_Q(0.00071030),
  DSP16_Q(0.00055954),
  DSP16_Q(-0.00311057),
  DSP16_Q(0.00731287),
  DSP16_Q(-0.01353817),
  DSP16_Q(0.02225309),
  DSP16_Q(-0.03432672),
  DSP16_Q(0.05205709),
  DSP16_Q(-0.08375683),
  DSP16_Q(0.18643263),
  DSP16_Q(0.39595127),
  DSP16_Q(-0.06337890),
  DSP16_Q(0.02001556),
  DSP16_Q(-0.00298239),
  DSP16_Q(-0.00511763),
  DSP16_Q(0.00868354),
  DSP16_Q(-0.00955041),
  DSP16_Q(0.00878598),
  DSP16_Q(-0.00714442),
  DSP16_Q(0.00519232),
  DSP16_Q(-0.00333892),
  DSP16_Q(0.00184181),
  DSP16_Q(-0.00081447),
  DSP16_Q(0.00024509),
  DSP16_Q(-0.00002767),
  DSP16_Q(-0.00000920),
  DSP16_Q(0.00018578),
  DSP16_Q(-0.00054118),
  DSP16_Q(0.00093116),
  DSP16_Q(-0.00111368),
  DSP16_Q(0.00076809),
  DSP16_Q(0.00047445),
  DSP16_Q(-0.00299762),
  DSP16_Q(0.00717753),
  DSP16_Q(-0.01339459),
  DSP16_Q(0.02212799),
  DSP16_Q(-0.03426780),
  DSP16_Q(0.05215837),
  DSP16_Q(-0.08427226),
  DSP16_Q(0.18896798),
  DSP16_Q(0.39444908),
  DSP16_Q(-0.06443386),
  DSP16_Q(0.02075663),
  DSP16_Q(-0.00351739),
  DSP16_Q(-0.00473490),
  DSP16_Q(0.00841979),
  DSP16_Q(-0.00937949),
  DSP16_Q(0.00868490),
  DSP16_Q(-0.00709254),
  DSP16_Q(0.00517185),
  DSP16_Q(-0.00333559),
  DSP16_Q(0.00184535),
  DSP16_Q(-0.00081866),
  DSP16_Q(0.00024729),
  DSP16_Q(-0.00002800),
  DSP16_Q(-0.00000951),
  DSP16_Q(0.00018816),
  DSP16_Q(-0.00054882),
  DSP16_Q(0.00094920),
  DSP16_Q(-0.00114850),
  DSP16_Q(0.00082597),
  DSP16_Q(0.00038898),
  DSP16_Q(-0.00288378),
  DSP16_Q(0.00704054),
  DSP16_Q(-0.01324827),
  DSP16_Q(0.02199868),
  DSP16_Q(-0.03420276),
  DSP16_Q(0.05225101),
  DSP16_Q(-0.08477601),
  DSP16_Q(0.19150325),
  DSP16_Q(0.39292649),
  DSP16_Q(-0.06547007),
  DSP16_Q(0.02149085),
  DSP16_Q(-0.00404995),
  DSP16_Q(-0.00435252),
  DSP16_Q(0.00815534),
  DSP16_Q(-0.00920745),
  DSP16_Q(0.00858261),
  DSP16_Q(-0.00703959),
  DSP16_Q(0.00515054),
  DSP16_Q(-0.00333168),
  DSP16_Q(0.00184854),
  DSP16_Q(-0.00082266),
  DSP16_Q(0.00024943),
  DSP16_Q(-0.00002831),
  DSP16_Q(-0.00000983),
  DSP16_Q(0.00019053),
  DSP16_Q(-0.00055641),
  DSP16_Q(0.00096718),
  DSP16_Q(-0.00118328),
  DSP16_Q(0.00088394),
  DSP16_Q(0.00030313),
  DSP16_Q(-0.00276908),
  DSP16_Q(0.00690192),
  DSP16_Q(-0.01309922),
  DSP16_Q(0.02186518),
  DSP16_Q(-0.03413158),
  DSP16_Q(0.05233497),
  DSP16_Q(-0.08526792),
  DSP16_Q(0.19403820),
  DSP16_Q(0.39138366),
  DSP16_Q(-0.06648752),
  DSP16_Q(0.02221813),
  DSP16_Q(-0.00457998),
  DSP16_Q(-0.00397053),
  DSP16_Q(0.00789023),
  DSP16_Q(-0.00903431),
  DSP16_Q(0.00847915),
  DSP16_Q(-0.00698559),
  DSP16_Q(0.00512841),
  DSP16_Q(-0.00332719),
  DSP16_Q(0.00185137),
  DSP16_Q(-0.00082649),
  DSP16_Q(0.00025148),
  DSP16_Q(-0.00002860),
  DSP16_Q(-0.00001015),
  DSP16_Q(0.00019288),
  DSP16_Q(-0.00056396),
  DSP16_Q(0.00098509),
  DSP16_Q(-0.00121801),
  DSP16_Q(0.00094199),
  DSP16_Q(0.00021694),
  DSP16_Q(-0.00265354),
  DSP16_Q(0.00676169),
  DSP16_Q(-0.01294747),
  DSP16_Q(0.02172750),
  DSP16_Q(-0.03405426),
  DSP16_Q(0.05241019),
  DSP16_Q(-0.08574785),
  DSP16_Q(0.19657260),
  DSP16_Q(0.38982075),
  DSP16_Q(-0.06748618),
  DSP16_Q(0.02293839),
  DSP16_Q(-0.00510741),
  DSP16_Q(-0.00358902),
  DSP16_Q(0.00762453),
  DSP16_Q(-0.00886010),
  DSP16_Q(0.00837452),
  DSP16_Q(-0.00693055),
  DSP16_Q(0.00510546),
  DSP16_Q(-0.00332213),
  DSP16_Q(0.00185386),
  DSP16_Q(-0.00083012),
  DSP16_Q(0.00025345),
  DSP16_Q(-0.00002887),
  DSP16_Q(-0.00001048),
  DSP16_Q(0.00019523),
  DSP16_Q(-0.00057146),
  DSP16_Q(0.00100293),
  DSP16_Q(-0.00125269),
  DSP16_Q(0.00100010),
  DSP16_Q(0.00013041),
  DSP16_Q(-0.00253716),
  DSP16_Q(0.00661987),
  DSP16_Q(-0.01279304),
  DSP16_Q(0.02158564),
  DSP16_Q(-0.03397079),
  DSP16_Q(0.05247663),
  DSP16_Q(-0.08621565),
  DSP16_Q(0.19910620),
  DSP16_Q(0.38823792),
  DSP16_Q(-0.06846605),
  DSP16_Q(0.02365153),
  DSP16_Q(-0.00563216),
  DSP16_Q(-0.00320803),
  DSP16_Q(0.00735827),
  DSP16_Q(-0.00868486),
  DSP16_Q(0.00826876),
  DSP16_Q(-0.00687448),
  DSP16_Q(0.00508170),
  DSP16_Q(-0.00331651),
  DSP16_Q(0.00185599),
  DSP16_Q(-0.00083358),
  DSP16_Q(0.00025535),
  DSP16_Q(-0.00002912),
  DSP16_Q(-0.00001081),
  DSP16_Q(0.00019756),
  DSP16_Q(-0.00057891),
  DSP16_Q(0.00102069),
  DSP16_Q(-0.00128731),
  DSP16_Q(0.00105826),
  DSP16_Q(0.00004355),
  DSP16_Q(-0.00241998),
  DSP16_Q(0.00647648),
  DSP16_Q(-0.01263593),
  DSP16_Q(0.02143962),
  DSP16_Q(-0.03388116),
  DSP16_Q(0.05253425),
  DSP16_Q(-0.08667118),
  DSP16_Q(0.20163877),
  DSP16_Q(0.38663532),
  DSP16_Q(-0.06942711),
  DSP16_Q(0.02435746),
  DSP16_Q(-0.00615415),
  DSP16_Q(-0.00282764),
  DSP16_Q(0.00709150),
  DSP16_Q(-0.00850863),
  DSP16_Q(0.00816188),
  DSP16_Q(-0.00681740),
  DSP16_Q(0.00505713),
  DSP16_Q(-0.00331032),
  DSP16_Q(0.00185778),
  DSP16_Q(-0.00083685),
  DSP16_Q(0.00025718),
  DSP16_Q(-0.00002935),
  DSP16_Q(-0.00001115),
  DSP16_Q(0.00019987),
  DSP16_Q(-0.00058630),
  DSP16_Q(0.00103837),
  DSP16_Q(-0.00132187),
  DSP16_Q(0.00111647),
  DSP16_Q(-0.00004362),
  DSP16_Q(-0.00230200),
  DSP16_Q(0.00633153),
  DSP16_Q(-0.01247619),
  DSP16_Q(0.02128945),
  DSP16_Q(-0.03378538),
  DSP16_Q(0.05258299),
  DSP16_Q(-0.08711429),
  DSP16_Q(0.20417007),
  DSP16_Q(0.38501314),
  DSP16_Q(-0.07036936),
  DSP16_Q(0.02505611),
  DSP16_Q(-0.00667329),
  DSP16_Q(-0.00244790),
  DSP16_Q(0.00682428),
  DSP16_Q(-0.00833143),
  DSP16_Q(0.00805391),
  DSP16_Q(-0.00675931),
  DSP16_Q(0.00503177),
  DSP16_Q(-0.00330357),
  DSP16_Q(0.00185922),
  DSP16_Q(-0.00083993),
  DSP16_Q(0.00025892),
  DSP16_Q(-0.00002957),
  DSP16_Q(-0.00001149),
  DSP16_Q(0.00020216),
  DSP16_Q(-0.00059365),
  DSP16_Q(0.00105596),
  DSP16_Q(-0.00135635),
  DSP16_Q(0.00117472),
  DSP16_Q(-0.00013109),
  DSP16_Q(-0.00218325),
  DSP16_Q(0.00618505),
  DSP16_Q(-0.01231381),
  DSP16_Q(0.02113515),
  DSP16_Q(-0.03368343),
  DSP16_Q(0.05262282),
  DSP16_Q(-0.08754485),
  DSP16_Q(0.20669986),
  DSP16_Q(0.38337153),
  DSP16_Q(-0.07129278),
  DSP16_Q(0.02574738),
  DSP16_Q(-0.00718950),
  DSP16_Q(-0.00206889),
  DSP16_Q(0.00655664),
  DSP16_Q(-0.00815330),
  DSP16_Q(0.00794487),
  DSP16_Q(-0.00670024),
  DSP16_Q(0.00500562),
  DSP16_Q(-0.00329626),
  DSP16_Q(0.00186031),
  DSP16_Q(-0.00084284),
  DSP16_Q(0.00026059),
  DSP16_Q(-0.00002976),
  DSP16_Q(-0.00001183),
  DSP16_Q(0.00020444),
  DSP16_Q(-0.00060094),
  DSP16_Q(0.00107347),
  DSP16_Q(-0.00139075),
  DSP16_Q(0.00123299),
  DSP16_Q(-0.00021883),
  DSP16_Q(-0.00206375),
  DSP16_Q(0.00603707),
  DSP16_Q(-0.01214883),
  DSP16_Q(0.02097673),
  DSP16_Q(-0.03357532),
  DSP16_Q(0.05265369),
  DSP16_Q(-0.08796272),
  DSP16_Q(0.20922791),
  DSP16_Q(0.38171066),
  DSP16_Q(-0.07219738),
  DSP16_Q(0.02643120),
  DSP16_Q(-0.00770272),
  DSP16_Q(-0.00169066),
  DSP16_Q(0.00628864),
  DSP16_Q(-0.00797428),
  DSP16_Q(0.00783478),
  DSP16_Q(-0.00664020),
  DSP16_Q(0.00497869),
  DSP16_Q(-0.00328840),
  DSP16_Q(0.00186107),
  DSP16_Q(-0.00084556),
  DSP16_Q(0.00026219),
  DSP16_Q(-0.00002994),
  DSP16_Q(-0.00001217),
  DSP16_Q(0.00020671),
  DSP16_Q(-0.00060817),
  DSP16_Q(0.00109088),
  DSP16_Q(-0.00142507),
  DSP16_Q(0.00129127),
  DSP16_Q(-0.00030685),
  DSP16_Q(-0.00194350),
  DSP16_Q(0.00588759),
  DSP16_Q(-0.01198126),
  DSP16_Q(0.02081420),
  DSP16_Q(-0.03346104),
  DSP16_Q(0.05267556),
  DSP16_Q(-0.08836775),
  DSP16_Q(0.21175396),
  DSP16_Q(0.38003070),
  DSP16_Q(-0.07308315),
  DSP16_Q(0.02710749),
  DSP16_Q(-0.00821286),
  DSP16_Q(-0.00131328),
  DSP16_Q(0.00602032),
  DSP16_Q(-0.00779439),
  DSP16_Q(0.00772367),
  DSP16_Q(-0.00657920),
  DSP16_Q(0.00495098),
  DSP16_Q(-0.00327999),
  DSP16_Q(0.00186148),
  DSP16_Q(-0.00084811),
  DSP16_Q(0.00026371),
  DSP16_Q(-0.00003010),
  DSP16_Q(-0.00001252),
  DSP16_Q(0.00020895),
  DSP16_Q(-0.00061534),
  DSP16_Q(0.00110819),
  DSP16_Q(-0.00145929),
  DSP16_Q(0.00134956),
  DSP16_Q(-0.00039511),
  DSP16_Q(-0.00182254),
  DSP16_Q(0.00573665),
  DSP16_Q(-0.01181113),
  DSP16_Q(0.02064758),
  DSP16_Q(-0.03334059),
  DSP16_Q(0.05268840),
  DSP16_Q(-0.08875980),
  DSP16_Q(0.21427779),
  DSP16_Q(0.37833183),
  DSP16_Q(-0.07395009),
  DSP16_Q(0.02777616),
  DSP16_Q(-0.00871985),
  DSP16_Q(-0.00093680),
  DSP16_Q(0.00575173),
  DSP16_Q(-0.00761367),
  DSP16_Q(0.00761155),
  DSP16_Q(-0.00651725),
  DSP16_Q(0.00492251),
  DSP16_Q(-0.00327103),
  DSP16_Q(0.00186155),
  DSP16_Q(-0.00085047),
  DSP16_Q(0.00026516),
  DSP16_Q(-0.00003024),
  DSP16_Q(-0.00001287),
  DSP16_Q(0.00021117),
  DSP16_Q(-0.00062245),
  DSP16_Q(0.00112541),
  DSP16_Q(-0.00149342),
  DSP16_Q(0.00140783),
  DSP16_Q(-0.00048362),
  DSP16_Q(-0.00170088),
  DSP16_Q(0.00558427),
  DSP16_Q(-0.01163846),
  DSP16_Q(0.02047689),
  DSP16_Q(-0.03321398),
  DSP16_Q(0.05269217),
  DSP16_Q(-0.08913875),
  DSP16_Q(0.21679916),
  DSP16_Q(0.37661422),
  DSP16_Q(-0.07479821),
  DSP16_Q(0.02843713),
  DSP16_Q(-0.00922360),
  DSP16_Q(-0.00056130),
  DSP16_Q(0.00548291),
  DSP16_Q(-0.00743216),
  DSP16_Q(0.00749845),
  DSP16_Q(-0.00645437),
  DSP16_Q(0.00489328),
  DSP16_Q(-0.00326153),
  DSP16_Q(0.00186128),
  DSP16_Q(-0.00085266),
  DSP16_Q(0.00026653),
  DSP16_Q(-0.00003036),
  DSP16_Q(-0.00001323),
  DSP16_Q(0.00021338),
  DSP16_Q(-0.00062950),
  DSP16_Q(0.00114252),
  DSP16_Q(-0.00152743),
  DSP16_Q(0.00146610),
  DSP16_Q(-0.00057234),
  DSP16_Q(-0.00157854),
  DSP16_Q(0.00543046),
  DSP16_Q(-0.01146326),
  DSP16_Q(0.02030215),
  DSP16_Q(-0.03308121),
  DSP16_Q(0.05268682),
  DSP16_Q(-0.08950444),
  DSP16_Q(0.21931782),
  DSP16_Q(0.37487804),
  DSP16_Q(-0.07562751),
  DSP16_Q(0.02909034),
  DSP16_Q(-0.00972406),
  DSP16_Q(-0.00018683),
  DSP16_Q(0.00521393),
  DSP16_Q(-0.00724989),
  DSP16_Q(0.00738439),
  DSP16_Q(-0.00639058),
  DSP16_Q(0.00486331),
  DSP16_Q(-0.00325150),
  DSP16_Q(0.00186068),
  DSP16_Q(-0.00085467),
  DSP16_Q(0.00026783),
  DSP16_Q(-0.00003047),
  DSP16_Q(-0.00001359),
  DSP16_Q(0.00021556),
  DSP16_Q(-0.00063649),
  DSP16_Q(0.00115952),
  DSP16_Q(-0.00156134),
  DSP16_Q(0.00152433),
  DSP16_Q(-0.00066128),
  DSP16_Q(-0.00145554),
  DSP16_Q(0.00527526),
  DSP16_Q(-0.01128558),
  DSP16_Q(0.02012337),
  DSP16_Q(-0.03294227),
  DSP16_Q(0.05267234),
  DSP16_Q(-0.08985675),
  DSP16_Q(0.22183353),
  DSP16_Q(0.37312348),
  DSP16_Q(-0.07643799),
  DSP16_Q(0.02973570),
  DSP16_Q(-0.01022113),
  DSP16_Q(0.00018655),
  DSP16_Q(0.00494481),
  DSP16_Q(-0.00706689),
  DSP16_Q(0.00726940),
  DSP16_Q(-0.00632588),
  DSP16_Q(0.00483259),
  DSP16_Q(-0.00324093),
  DSP16_Q(0.00185974),
  DSP16_Q(-0.00085650),
  DSP16_Q(0.00026905),
  DSP16_Q(-0.00003056),
  DSP16_Q(-0.00001394),
  DSP16_Q(0.00021772),
  DSP16_Q(-0.00064340),
  DSP16_Q(0.00117641),
  DSP16_Q(-0.00159512),
  DSP16_Q(0.00158253),
  DSP16_Q(-0.00075041),
  DSP16_Q(-0.00133190),
  DSP16_Q(0.00511867),
  DSP16_Q(-0.01110542),
  DSP16_Q(0.01994057),
  DSP16_Q(-0.03279718),
  DSP16_Q(0.05264867),
  DSP16_Q(-0.09019555),
  DSP16_Q(0.22434605),
  DSP16_Q(0.37135071),
  DSP16_Q(-0.07722968),
  DSP16_Q(0.03037315),
  DSP16_Q(-0.01071476),
  DSP16_Q(0.00055877),
  DSP16_Q(0.00467561),
  DSP16_Q(-0.00688319),
  DSP16_Q(0.00715350),
  DSP16_Q(-0.00626029),
  DSP16_Q(0.00480113),
  DSP16_Q(-0.00322983),
  DSP16_Q(0.00185847),
  DSP16_Q(-0.00085815),
  DSP16_Q(0.00027020),
  DSP16_Q(-0.00003063),
  DSP16_Q(-0.00001431),
  DSP16_Q(0.00021986),
  DSP16_Q(-0.00065025),
  DSP16_Q(0.00119318),
  DSP16_Q(-0.00162878),
  DSP16_Q(0.00164067),
  DSP16_Q(-0.00083971),
  DSP16_Q(-0.00120763),
  DSP16_Q(0.00496074),
  DSP16_Q(-0.01092281),
  DSP16_Q(0.01975377),
  DSP16_Q(-0.03264593),
  DSP16_Q(0.05261579),
  DSP16_Q(-0.09052070),
  DSP16_Q(0.22685515),
  DSP16_Q(0.36955992),
  DSP16_Q(-0.07800256),
  DSP16_Q(0.03100260),
  DSP16_Q(-0.01120487),
  DSP16_Q(0.00092978),
  DSP16_Q(0.00440638),
  DSP16_Q(-0.00669884),
  DSP16_Q(0.00703670),
  DSP16_Q(-0.00619383),
  DSP16_Q(0.00476895),
  DSP16_Q(-0.00321821),
  DSP16_Q(0.00185687),
  DSP16_Q(-0.00085963),
  DSP16_Q(0.00027128),
  DSP16_Q(-0.00003069),
  DSP16_Q(-0.00001467),
  DSP16_Q(0.00022197),
  DSP16_Q(-0.00065702),
  DSP16_Q(0.00120984),
  DSP16_Q(-0.00166231),
  DSP16_Q(0.00169876),
  DSP16_Q(-0.00092918),
  DSP16_Q(-0.00108277),
  DSP16_Q(0.00480147),
  DSP16_Q(-0.01073778),
  DSP16_Q(0.01956300),
  DSP16_Q(-0.03248854),
  DSP16_Q(0.05257367),
  DSP16_Q(-0.09083206),
  DSP16_Q(0.22936058),
  DSP16_Q(0.36775129),
  DSP16_Q(-0.07875668),
  DSP16_Q(0.03162400),
  DSP16_Q(-0.01169138),
  DSP16_Q(0.00129951),
  DSP16_Q(0.00413716),
  DSP16_Q(-0.00651386),
  DSP16_Q(0.00691904),
  DSP16_Q(-0.00612651),
  DSP16_Q(0.00473606),
  DSP16_Q(-0.00320607),
  DSP16_Q(0.00185494),
  DSP16_Q(-0.00086094),
  DSP16_Q(0.00027229),
  DSP16_Q(-0.00003073),
  DSP16_Q(-0.00001503),
  DSP16_Q(0.00022406),
  DSP16_Q(-0.00066373),
  DSP16_Q(0.00122637),
  DSP16_Q(-0.00169570),
  DSP16_Q(0.00175678),
  DSP16_Q(-0.00101879),
  DSP16_Q(-0.00095732),
  DSP16_Q(0.00464090),
  DSP16_Q(-0.01055036),
  DSP16_Q(0.01936827),
  DSP16_Q(-0.03232500),
  DSP16_Q(0.05252228),
  DSP16_Q(-0.09112952),
  DSP16_Q(0.23186211),
  DSP16_Q(0.36592499),
  DSP16_Q(-0.07949202),
  DSP16_Q(0.03223727),
  DSP16_Q(-0.01217422),
  DSP16_Q(0.00166791),
  DSP16_Q(0.00386800),
  DSP16_Q(-0.00632829),
  DSP16_Q(0.00680054),
  DSP16_Q(-0.00605835),
  DSP16_Q(0.00470245),
  DSP16_Q(-0.00319341),
  DSP16_Q(0.00185268),
  DSP16_Q(-0.00086207),
  DSP16_Q(0.00027323),
  DSP16_Q(-0.00003075),
  DSP16_Q(-0.00001540),
  DSP16_Q(0.00022612),
  DSP16_Q(-0.00067035),
  DSP16_Q(0.00124277),
  DSP16_Q(-0.00172894),
  DSP16_Q(0.00181471),
  DSP16_Q(-0.00110854),
  DSP16_Q(-0.00083131),
  DSP16_Q(0.00447905),
  DSP16_Q(-0.01036056),
  DSP16_Q(0.01916960),
  DSP16_Q(-0.03215534),
  DSP16_Q(0.05246159),
  DSP16_Q(-0.09141293),
  DSP16_Q(0.23435948),
  DSP16_Q(0.36408123),
  DSP16_Q(-0.08020863),
  DSP16_Q(0.03284235),
  DSP16_Q(-0.01265333),
  DSP16_Q(0.00203491),
  DSP16_Q(0.00359894),
  DSP16_Q(-0.00614216),
  DSP16_Q(0.00668122),
  DSP16_Q(-0.00598935),
  DSP16_Q(0.00466815),
  DSP16_Q(-0.00318024),
  DSP16_Q(0.00185010),
  DSP16_Q(-0.00086303),
  DSP16_Q(0.00027410),
  DSP16_Q(-0.00003076),
  DSP16_Q(-0.00001577),
  DSP16_Q(0.00022816),
  DSP16_Q(-0.00067690),
  DSP16_Q(0.00125904),
  DSP16_Q(-0.00176202),
  DSP16_Q(0.00187255),
  DSP16_Q(-0.00119840),
  DSP16_Q(-0.00070476),
  DSP16_Q(0.00431594),
  DSP16_Q(-0.01016842),
  DSP16_Q(0.01896703),
  DSP16_Q(-0.03197955),
  DSP16_Q(0.05239157),
  DSP16_Q(-0.09168218),
  DSP16_Q(0.23685248),
  DSP16_Q(0.36222019),
  DSP16_Q(-0.08090651),
  DSP16_Q(0.03343916),
  DSP16_Q(-0.01312864),
  DSP16_Q(0.00240046),
  DSP16_Q(0.00333003),
  DSP16_Q(-0.00595551),
  DSP16_Q(0.00656111),
  DSP16_Q(-0.00591954),
  DSP16_Q(0.00463316),
  DSP16_Q(-0.00316656),
  DSP16_Q(0.00184720),
  DSP16_Q(-0.00086381),
  DSP16_Q(0.00027489),
  DSP16_Q(-0.00003075),
  DSP16_Q(-0.00001614),
  DSP16_Q(0.00023017),
  DSP16_Q(-0.00068337),
  DSP16_Q(0.00127518),
  DSP16_Q(-0.00179495),
  DSP16_Q(0.00193029),
  DSP16_Q(-0.00128836),
  DSP16_Q(-0.00057769),
  DSP16_Q(0.00415160),
  DSP16_Q(-0.00997395),
  DSP16_Q(0.01876056),
  DSP16_Q(-0.03179765),
  DSP16_Q(0.05231220),
  DSP16_Q(-0.09193714),
  DSP16_Q(0.23934084),
  DSP16_Q(0.36034206),
  DSP16_Q(-0.08158569),
  DSP16_Q(0.03402766),
  DSP16_Q(-0.01360008),
  DSP16_Q(0.00276450),
  DSP16_Q(0.00306132),
  DSP16_Q(-0.00576837),
  DSP16_Q(0.00644022),
  DSP16_Q(-0.00584893),
  DSP16_Q(0.00459748),
  DSP16_Q(-0.00315238),
  DSP16_Q(0.00184398),
  DSP16_Q(-0.00086443),
  DSP16_Q(0.00027562),
  DSP16_Q(-0.00003073),
  DSP16_Q(-0.00001651),
  DSP16_Q(0.00023215),
  DSP16_Q(-0.00068976),
  DSP16_Q(0.00129117),
  DSP16_Q(-0.00182771),
  DSP16_Q(0.00198792),
  DSP16_Q(-0.00137841),
  DSP16_Q(-0.00045012),
  DSP16_Q(0.00398606),
  DSP16_Q(-0.00977720),
  DSP16_Q(0.01855024),
  DSP16_Q(-0.03160964),
  DSP16_Q(0.05222346),
  DSP16_Q(-0.09217767),
  DSP16_Q(0.24182433),
  DSP16_Q(0.35844703),
  DSP16_Q(-0.08224619),
  DSP16_Q(0.03460776),
  DSP16_Q(-0.01406758),
  DSP16_Q(0.00312697),
  DSP16_Q(0.00279285),
  DSP16_Q(-0.00558077),
  DSP16_Q(0.00631858),
  DSP16_Q(-0.00577754),
  DSP16_Q(0.00456113),
  DSP16_Q(-0.00313770),
  DSP16_Q(0.00184045),
  DSP16_Q(-0.00086488),
  DSP16_Q(0.00027627),
  DSP16_Q(-0.00003070),
  DSP16_Q(-0.00001688),
  DSP16_Q(0.00023411),
  DSP16_Q(-0.00069607),
  DSP16_Q(0.00130703),
  DSP16_Q(-0.00186029),
  DSP16_Q(0.00204542),
  DSP16_Q(-0.00146852),
  DSP16_Q(-0.00032208),
  DSP16_Q(0.00381933),
  DSP16_Q(-0.00957818),
  DSP16_Q(0.01833607),
  DSP16_Q(-0.03141555),
  DSP16_Q(0.05212532),
  DSP16_Q(-0.09240367),
  DSP16_Q(0.24430272),
  DSP16_Q(0.35653529),
  DSP16_Q(-0.08288805),
  DSP16_Q(0.03517943),
  DSP16_Q(-0.01453107),
  DSP16_Q(0.00348782),
  DSP16_Q(0.00252468),
  DSP16_Q(-0.00539275),
  DSP16_Q(0.00619621),
  DSP16_Q(-0.00570538),
  DSP16_Q(0.00452412),
  DSP16_Q(-0.00312253),
  DSP16_Q(0.00183659),
  DSP16_Q(-0.00086516),
  DSP16_Q(0.00027686),
  DSP16_Q(-0.00003065),
  DSP16_Q(-0.00001725),
  DSP16_Q(0.00023603),
  DSP16_Q(-0.00070229),
  DSP16_Q(0.00132273),
  DSP16_Q(-0.00189269),
  DSP16_Q(0.00210279),
  DSP16_Q(-0.00155869),
  DSP16_Q(-0.00019357),
  DSP16_Q(0.00365144),
  DSP16_Q(-0.00937692),
  DSP16_Q(0.01811809),
  DSP16_Q(-0.03121539),
  DSP16_Q(0.05201776),
  DSP16_Q(-0.09261500),
  DSP16_Q(0.24677576),
  DSP16_Q(0.35460703),
  DSP16_Q(-0.08351128),
  DSP16_Q(0.03574258),
  DSP16_Q(-0.01499050),
  DSP16_Q(0.00384698),
  DSP16_Q(0.00225683),
  DSP16_Q(-0.00520434),
  DSP16_Q(0.00607315),
  DSP16_Q(-0.00563246),
  DSP16_Q(0.00448645),
  DSP16_Q(-0.00310688),
  DSP16_Q(0.00183243),
  DSP16_Q(-0.00086527),
  DSP16_Q(0.00027738),
  DSP16_Q(-0.00003058),
  DSP16_Q(-0.00001763),
  DSP16_Q(0.00023793),
  DSP16_Q(-0.00070843),
  DSP16_Q(0.00133829),
  DSP16_Q(-0.00192491),
  DSP16_Q(0.00216001),
  DSP16_Q(-0.00164890),
  DSP16_Q(-0.00006463),
  DSP16_Q(0.00348243),
  DSP16_Q(-0.00917345),
  DSP16_Q(0.01789632),
  DSP16_Q(-0.03100916),
  DSP16_Q(0.05190075),
  DSP16_Q(-0.09281154),
  DSP16_Q(0.24924322),
  DSP16_Q(0.35266246),
  DSP16_Q(-0.08411592),
  DSP16_Q(0.03629718),
  DSP16_Q(-0.01544579),
  DSP16_Q(0.00420439),
  DSP16_Q(0.00198937),
  DSP16_Q(-0.00501558),
  DSP16_Q(0.00594940),
  DSP16_Q(-0.00555880),
  DSP16_Q(0.00444814),
  DSP16_Q(-0.00309074),
  DSP16_Q(0.00182795),
  DSP16_Q(-0.00086522),
  DSP16_Q(0.00027784),
  DSP16_Q(-0.00003051),
  DSP16_Q(-0.00001800),
  DSP16_Q(0.00023979),
  DSP16_Q(-0.00071448),
  DSP16_Q(0.00135369),
  DSP16_Q(-0.00195693),
  DSP16_Q(0.00221708),
  DSP16_Q(-0.00173913),
  DSP16_Q(0.00006473),
  DSP16_Q(0.00331231),
  DSP16_Q(-0.00896781),
  DSP16_Q(0.01767079),
  DSP16_Q(-0.03079688),
  DSP16_Q(0.05177430),
  DSP16_Q(-0.09299318),
  DSP16_Q(0.25170484),
  DSP16_Q(0.35070178),
  DSP16_Q(-0.08470202),
  DSP16_Q(0.03684315),
  DSP16_Q(-0.01589688),
  DSP16_Q(0.00456002),
  DSP16_Q(0.00172233),
  DSP16_Q(-0.00482650),
  DSP16_Q(0.00582501),
  DSP16_Q(-0.00548442),
  DSP16_Q(0.00440919),
  DSP16_Q(-0.00307412),
  DSP16_Q(0.00182317),
  DSP16_Q(-0.00086500),
  DSP16_Q(0.00027822),
  DSP16_Q(-0.00003042),
  DSP16_Q(-0.00001837),
  DSP16_Q(0.00024162),
  DSP16_Q(-0.00072044),
  DSP16_Q(0.00136893),
  DSP16_Q(-0.00198875),
  DSP16_Q(0.00227398),
  DSP16_Q(-0.00182937),
  DSP16_Q(0.00019448),
  DSP16_Q(0.00314111),
  DSP16_Q(-0.00876002),
  DSP16_Q(0.01744153),
  DSP16_Q(-0.03057858),
  DSP16_Q(0.05163836),
  DSP16_Q(-0.09315980),
  DSP16_Q(0.25416041),
  DSP16_Q(0.34872517),
  DSP16_Q(-0.08526959),
  DSP16_Q(0.03738046),
  DSP16_Q(-0.01634372),
  DSP16_Q(0.00491379),
  DSP16_Q(0.00145576),
  DSP16_Q(-0.00463713),
  DSP16_Q(0.00569998),
  DSP16_Q(-0.00540933),
  DSP16_Q(0.00436961),
  DSP16_Q(-0.00305703),
  DSP16_Q(0.00181808),
  DSP16_Q(-0.00086462),
  DSP16_Q(0.00027854),
  DSP16_Q(-0.00003031),
  DSP16_Q(-0.00001874),
  DSP16_Q(0.00024342),
  DSP16_Q(-0.00072630),
  DSP16_Q(0.00138401),
  DSP16_Q(-0.00202037),
  DSP16_Q(0.00233070),
  DSP16_Q(-0.00191960),
  DSP16_Q(0.00032460),
  DSP16_Q(0.00296887),
  DSP16_Q(-0.00855010),
  DSP16_Q(0.01720857),
  DSP16_Q(-0.03035426),
  DSP16_Q(0.05149294),
  DSP16_Q(-0.09331127),
  DSP16_Q(0.25660966),
  DSP16_Q(0.34673285),
  DSP16_Q(-0.08581868),
  DSP16_Q(0.03790904),
  DSP16_Q(-0.01678623),
  DSP16_Q(0.00526565),
  DSP16_Q(0.00118970),
  DSP16_Q(-0.00444751),
  DSP16_Q(0.00557434),
  DSP16_Q(-0.00533355),
  DSP16_Q(0.00432942),
  DSP16_Q(-0.00303948),
  DSP16_Q(0.00181270),
  DSP16_Q(-0.00086407),
  DSP16_Q(0.00027880),
  DSP16_Q(-0.00003020),
  DSP16_Q(-0.00001911),
  DSP16_Q(0.00024518),
  DSP16_Q(-0.00073207),
  DSP16_Q(0.00139893),
  DSP16_Q(-0.00205177),
  DSP16_Q(0.00238723),
  DSP16_Q(-0.00200980),
  DSP16_Q(0.00045508),
  DSP16_Q(0.00279560),
  DSP16_Q(-0.00833810),
  DSP16_Q(0.01697193),
  DSP16_Q(-0.03012396),
  DSP16_Q(0.05133802),
  DSP16_Q(-0.09344750),
  DSP16_Q(0.25905238),
  DSP16_Q(0.34472501),
  DSP16_Q(-0.08634932),
  DSP16_Q(0.03842884),
  DSP16_Q(-0.01722436),
  DSP16_Q(0.00561555),
  DSP16_Q(0.00092420),
  DSP16_Q(-0.00425767),
  DSP16_Q(0.00544812),
  DSP16_Q(-0.00525709),
  DSP16_Q(0.00428861),
  DSP16_Q(-0.00302146),
  DSP16_Q(0.00180701),
  DSP16_Q(-0.00086337),
  DSP16_Q(0.00027898),
  DSP16_Q(-0.00003007),
  DSP16_Q(-0.00001948),
  DSP16_Q(0.00024691),
  DSP16_Q(-0.00073774),
  DSP16_Q(0.00141367),
  DSP16_Q(-0.00208295),
  DSP16_Q(0.00244356),
  DSP16_Q(-0.00209996),
  DSP16_Q(0.00058588),
  DSP16_Q(0.00262133),
  DSP16_Q(-0.00812404),
  DSP16_Q(0.01673165),
  DSP16_Q(-0.02988768),
  DSP16_Q(0.05117358),
  DSP16_Q(-0.09356835),
  DSP16_Q(0.26148832),
  DSP16_Q(0.34270186),
  DSP16_Q(-0.08686157),
  DSP16_Q(0.03893982),
  DSP16_Q(-0.01765804),
  DSP16_Q(0.00596343),
  DSP16_Q(0.00065931),
  DSP16_Q(-0.00406764),
  DSP16_Q(0.00532134),
  DSP16_Q(-0.00517998),
  DSP16_Q(0.00424721),
  DSP16_Q(-0.00300298),
  DSP16_Q(0.00180102),
  DSP16_Q(-0.00086250),
  DSP16_Q(0.00027911),
  DSP16_Q(-0.00002993),
  DSP16_Q(-0.00001985),
  DSP16_Q(0.00024861),
  DSP16_Q(-0.00074332),
  DSP16_Q(0.00142825),
  DSP16_Q(-0.00211390),
  DSP16_Q(0.00249968),
  DSP16_Q(-0.00219006),
  DSP16_Q(0.00071699),
  DSP16_Q(0.00244610),
  DSP16_Q(-0.00790795),
  DSP16_Q(0.01648775),
  DSP16_Q(-0.02964544),
  DSP16_Q(0.05099962),
  DSP16_Q(-0.09367373),
  DSP16_Q(0.26391723),
  DSP16_Q(0.34066360),
  DSP16_Q(-0.08735546),
  DSP16_Q(0.03944192),
  DSP16_Q(-0.01808723),
  DSP16_Q(0.00630924),
  DSP16_Q(0.00039506),
  DSP16_Q(-0.00387746),
  DSP16_Q(0.00519403),
  DSP16_Q(-0.00510221),
  DSP16_Q(0.00420522),
  DSP16_Q(-0.00298406),
  DSP16_Q(0.00179474),
  DSP16_Q(-0.00086148),
  DSP16_Q(0.00027917),
  DSP16_Q(-0.00002978),
  DSP16_Q(-0.00002022),
  DSP16_Q(0.00025026),
  DSP16_Q(-0.00074879),
  DSP16_Q(0.00144264),
  DSP16_Q(-0.00214461),
  DSP16_Q(0.00255558),
  DSP16_Q(-0.00228008),
  DSP16_Q(0.00084838),
  DSP16_Q(0.00226992),
  DSP16_Q(-0.00768987),
  DSP16_Q(0.01624028),
  DSP16_Q(-0.02939728),
  DSP16_Q(0.05081612),
  DSP16_Q(-0.09376352),
  DSP16_Q(0.26633889),
  DSP16_Q(0.33861044),
  DSP16_Q(-0.08783104),
  DSP16_Q(0.03993511),
  DSP16_Q(-0.01851185),
  DSP16_Q(0.00665293),
  DSP16_Q(0.00013151),
  DSP16_Q(-0.00368717),
  DSP16_Q(0.00506620),
  DSP16_Q(-0.00502382),
  DSP16_Q(0.00416265),
  DSP16_Q(-0.00296469),
  DSP16_Q(0.00178817),
  DSP16_Q(-0.00086030),
  DSP16_Q(0.00027917),
  DSP16_Q(-0.00002961),
  DSP16_Q(-0.00002059),
  DSP16_Q(0.00025188),
  DSP16_Q(-0.00075417),
  DSP16_Q(0.00145685),
  DSP16_Q(-0.00217509),
  DSP16_Q(0.00261124),
  DSP16_Q(-0.00237002),
  DSP16_Q(0.00098004),
  DSP16_Q(0.00209283),
  DSP16_Q(-0.00746982),
  DSP16_Q(0.01598925),
  DSP16_Q(-0.02914321),
  DSP16_Q(0.05062307),
  DSP16_Q(-0.09383760),
  DSP16_Q(0.26875306),
  DSP16_Q(0.33654259),
  DSP16_Q(-0.08828837),
  DSP16_Q(0.04041933),
  DSP16_Q(-0.01893186),
  DSP16_Q(0.00699444),
  DSP16_Q(-0.00013132),
  DSP16_Q(-0.00349679),
  DSP16_Q(0.00493789),
  DSP16_Q(-0.00494482),
  DSP16_Q(0.00411951),
  DSP16_Q(-0.00294487),
  DSP16_Q(0.00178131),
  DSP16_Q(-0.00085896),
  DSP16_Q(0.00027911),
  DSP16_Q(-0.00002944),
  DSP16_Q(-0.00002095),
  DSP16_Q(0.00025347),
  DSP16_Q(-0.00075943),
  DSP16_Q(0.00147088),
  DSP16_Q(-0.00220532),
  DSP16_Q(0.00266666),
  DSP16_Q(-0.00245985),
  DSP16_Q(0.00111194),
  DSP16_Q(0.00191486),
  DSP16_Q(-0.00724784),
  DSP16_Q(0.01573470),
  DSP16_Q(-0.02888326),
  DSP16_Q(0.05042048),
  DSP16_Q(-0.09389588),
  DSP16_Q(0.27115950),
  DSP16_Q(0.33446025),
  DSP16_Q(-0.08872748),
  DSP16_Q(0.04089455),
  DSP16_Q(-0.01934719),
  DSP16_Q(0.00733372),
  DSP16_Q(-0.00039336),
  DSP16_Q(-0.00330635),
  DSP16_Q(0.00480911),
  DSP16_Q(-0.00486521),
  DSP16_Q(0.00407581),
  DSP16_Q(-0.00292463),
  DSP16_Q(0.00177417),
  DSP16_Q(-0.00085747),
  DSP16_Q(0.00027898),
  DSP16_Q(-0.00002925),
  DSP16_Q(-0.00002131),
  DSP16_Q(0.00025501),
  DSP16_Q(-0.00076460),
  DSP16_Q(0.00148472),
  DSP16_Q(-0.00223529),
  DSP16_Q(0.00272183),
  DSP16_Q(-0.00254956),
  DSP16_Q(0.00124405),
  DSP16_Q(0.00173603),
  DSP16_Q(-0.00702397),
  DSP16_Q(0.01547667),
  DSP16_Q(-0.02861745),
  DSP16_Q(0.05020834),
  DSP16_Q(-0.09393825),
  DSP16_Q(0.27355797),
  DSP16_Q(0.33236365),
  DSP16_Q(-0.08914843),
  DSP16_Q(0.04136072),
  DSP16_Q(-0.01975780),
  DSP16_Q(0.00767072),
  DSP16_Q(-0.00065458),
  DSP16_Q(-0.00311590),
  DSP16_Q(0.00467990),
  DSP16_Q(-0.00478503),
  DSP16_Q(0.00403156),
  DSP16_Q(-0.00290395),
  DSP16_Q(0.00176674),
  DSP16_Q(-0.00085583),
  DSP16_Q(0.00027879),
  DSP16_Q(-0.00002906),
  DSP16_Q(-0.00002167),
  DSP16_Q(0.00025651),
  DSP16_Q(-0.00076965),
  DSP16_Q(0.00149837),
  DSP16_Q(-0.00226500),
  DSP16_Q(0.00277673),
  DSP16_Q(-0.00263912),
  DSP16_Q(0.00137636),
  DSP16_Q(0.00155637),
  DSP16_Q(-0.00679823),
  DSP16_Q(0.01521519),
  DSP16_Q(-0.02834580),
  DSP16_Q(0.04998664),
  DSP16_Q(-0.09396460),
  DSP16_Q(0.27594824),
  DSP16_Q(0.33025297),
  DSP16_Q(-0.08955128),
  DSP16_Q(0.04181780),
  DSP16_Q(-0.02016363),
  DSP16_Q(0.00800539),
  DSP16_Q(-0.00091494),
  DSP16_Q(-0.00292547),
  DSP16_Q(0.00455027),
  DSP16_Q(-0.00470428),
  DSP16_Q(0.00398677),
  DSP16_Q(-0.00288285),
  DSP16_Q(0.00175903),
  DSP16_Q(-0.00085404),
  DSP16_Q(0.00027855),
  DSP16_Q(-0.00002885),
  DSP16_Q(-0.00002203),
  DSP16_Q(0.00025798),
  DSP16_Q(-0.00077460),
  DSP16_Q(0.00151182),
  DSP16_Q(-0.00229444),
  DSP16_Q(0.00283136),
  DSP16_Q(-0.00272853),
  DSP16_Q(0.00150884),
  DSP16_Q(0.00137591),
  DSP16_Q(-0.00657066),
  DSP16_Q(0.01495029),
  DSP16_Q(-0.02806836),
  DSP16_Q(0.04975537),
  DSP16_Q(-0.09397484),
  DSP16_Q(0.27833007),
  DSP16_Q(0.32812845),
  DSP16_Q(-0.08993608),
  DSP16_Q(0.04226576),
  DSP16_Q(-0.02056462),
  DSP16_Q(0.00833767),
  DSP16_Q(-0.00117439),
  DSP16_Q(-0.00273508),
  DSP16_Q(0.00442024),
  DSP16_Q(-0.00462298),
  DSP16_Q(0.00394146),
  DSP16_Q(-0.00286134),
  DSP16_Q(0.00175105),
  DSP16_Q(-0.00085209),
  DSP16_Q(0.00027824),
  DSP16_Q(-0.00002864),
  DSP16_Q(-0.00002239),
  DSP16_Q(0.00025940),
  DSP16_Q(-0.00077943),
  DSP16_Q(0.00152507),
  DSP16_Q(-0.00232361),
  DSP16_Q(0.00288570),
  DSP16_Q(-0.00281777),
  DSP16_Q(0.00164147),
  DSP16_Q(0.00119468),
  DSP16_Q(-0.00634129),
  DSP16_Q(0.01468202),
  DSP16_Q(-0.02778513),
  DSP16_Q(0.04951456),
  DSP16_Q(-0.09396885),
  DSP16_Q(0.28070323),
  DSP16_Q(0.32599030),
  DSP16_Q(-0.09030289),
  DSP16_Q(0.04270455),
  DSP16_Q(-0.02096072),
  DSP16_Q(0.00866753),
  DSP16_Q(-0.00143289),
  DSP16_Q(-0.00254478),
  DSP16_Q(0.00428985),
  DSP16_Q(-0.00454115),
  DSP16_Q(0.00389562),
  DSP16_Q(-0.00283941),
  DSP16_Q(0.00174279),
  DSP16_Q(-0.00085000),
  DSP16_Q(0.00027788),
  DSP16_Q(-0.00002841),
  DSP16_Q(-0.00002274),
  DSP16_Q(0.00026078),
  DSP16_Q(-0.00078416),
  DSP16_Q(0.00153812),
  DSP16_Q(-0.00235250),
  DSP16_Q(0.00293974),
  DSP16_Q(-0.00290683),
  DSP16_Q(0.00177423),
  DSP16_Q(0.00101272),
  DSP16_Q(-0.00611016),
  DSP16_Q(0.01441040),
  DSP16_Q(-0.02749616),
  DSP16_Q(0.04926418),
  DSP16_Q(-0.09394655),
  DSP16_Q(0.28306748),
  DSP16_Q(0.32383873),
  DSP16_Q(-0.09065177),
  DSP16_Q(0.04313415),
  DSP16_Q(-0.02135189),
  DSP16_Q(0.00899490),
  DSP16_Q(-0.00169040),
  DSP16_Q(-0.00235458),
  DSP16_Q(0.00415912),
  DSP16_Q(-0.00445880),
  DSP16_Q(0.00384927),
  DSP16_Q(-0.00281707),
  DSP16_Q(0.00173426),
  DSP16_Q(-0.00084776),
  DSP16_Q(0.00027745),
  DSP16_Q(-0.00002818),
  DSP16_Q(-0.00002308),
  DSP16_Q(0.00026212),
  DSP16_Q(-0.00078876),
  DSP16_Q(0.00155097),
  DSP16_Q(-0.00238110),
  DSP16_Q(0.00299347),
  DSP16_Q(-0.00299567),
  DSP16_Q(0.00190710),
  DSP16_Q(0.00083004),
  DSP16_Q(-0.00587731),
  DSP16_Q(0.01413548),
  DSP16_Q(-0.02720148),
  DSP16_Q(0.04900425),
  DSP16_Q(-0.09390782),
  DSP16_Q(0.28542260),
  DSP16_Q(0.32167395),
  DSP16_Q(-0.09098279),
  DSP16_Q(0.04355452),
  DSP16_Q(-0.02173807),
  DSP16_Q(0.00931975),
  DSP16_Q(-0.00194688),
  DSP16_Q(-0.00216454),
  DSP16_Q(0.00402806),
  DSP16_Q(-0.00437595),
  DSP16_Q(0.00380242),
  DSP16_Q(-0.00279434),
  DSP16_Q(0.00172546),
  DSP16_Q(-0.00084538),
  DSP16_Q(0.00027697),
  DSP16_Q(-0.00002793),
  DSP16_Q(-0.00002343),
  DSP16_Q(0.00026341),
  DSP16_Q(-0.00079325),
  DSP16_Q(0.00156360),
  DSP16_Q(-0.00240940),
  DSP16_Q(0.00304688),
  DSP16_Q(-0.00308430),
  DSP16_Q(0.00204004),
  DSP16_Q(0.00064668),
  DSP16_Q(-0.00564276),
  DSP16_Q(0.01385728),
  DSP16_Q(-0.02690111),
  DSP16_Q(0.04873477),
  DSP16_Q(-0.09385259),
  DSP16_Q(0.28776835),
  DSP16_Q(0.31949619),
  DSP16_Q(-0.09129601),
  DSP16_Q(0.04396562),
  DSP16_Q(-0.02211921),
  DSP16_Q(0.00964201),
  DSP16_Q(-0.00220229),
  DSP16_Q(-0.00197467),
  DSP16_Q(0.00389671),
  DSP16_Q(-0.00429262),
  DSP16_Q(0.00375509),
  DSP16_Q(-0.00277121),
  DSP16_Q(0.00171640),
  DSP16_Q(-0.00084285),
  DSP16_Q(0.00027644),
  DSP16_Q(-0.00002768),
  DSP16_Q(-0.00002377),
  DSP16_Q(0.00026466),
  DSP16_Q(-0.00079762),
  DSP16_Q(0.00157602),
  DSP16_Q(-0.00243741),
  DSP16_Q(0.00309996),
  DSP16_Q(-0.00317269),
  DSP16_Q(0.00217304),
  DSP16_Q(0.00046267),
  DSP16_Q(-0.00540656),
  DSP16_Q(0.01357586),
  DSP16_Q(-0.02659508),
  DSP16_Q(0.04845574),
  DSP16_Q(-0.09378075),
  DSP16_Q(0.29010449),
  DSP16_Q(0.31730566),
  DSP16_Q(-0.09159149),
  DSP16_Q(0.04436744),
  DSP16_Q(-0.02249526),
  DSP16_Q(0.00996165),
  DSP16_Q(-0.00245658),
  DSP16_Q(-0.00178502),
  DSP16_Q(0.00376509),
  DSP16_Q(-0.00420882),
  DSP16_Q(0.00370727),
  DSP16_Q(-0.00274769),
  DSP16_Q(0.00170708),
  DSP16_Q(-0.00084018),
  DSP16_Q(0.00027584),
  DSP16_Q(-0.00002742),
  DSP16_Q(-0.00002410),
  DSP16_Q(0.00026586),
  DSP16_Q(-0.00080187),
  DSP16_Q(0.00158822),
  DSP16_Q(-0.00246511),
  DSP16_Q(0.00315270),
  DSP16_Q(-0.00326082),
  DSP16_Q(0.00230608),
  DSP16_Q(0.00027804),
  DSP16_Q(-0.00516874),
  DSP16_Q(0.01329124),
  DSP16_Q(-0.02628344),
  DSP16_Q(0.04816718),
  DSP16_Q(-0.09369221),
  DSP16_Q(0.29243079),
  DSP16_Q(0.31510258),
  DSP16_Q(-0.09186930),
  DSP16_Q(0.04475993),
  DSP16_Q(-0.02286618),
  DSP16_Q(0.01027861),
  DSP16_Q(-0.00270971),
  DSP16_Q(-0.00159561),
  DSP16_Q(0.00363322),
  DSP16_Q(-0.00412456),
  DSP16_Q(0.00365899),
  DSP16_Q(-0.00272379),
  DSP16_Q(0.00169750),
  DSP16_Q(-0.00083737),
  DSP16_Q(0.00027520),
  DSP16_Q(-0.00002715),
  DSP16_Q(-0.00002443),
  DSP16_Q(0.00026701),
  DSP16_Q(-0.00080600),
  DSP16_Q(0.00160020),
  DSP16_Q(-0.00249249),
  DSP16_Q(0.00320509),
  DSP16_Q(-0.00334868),
  DSP16_Q(0.00243913),
  DSP16_Q(0.00009282),
  DSP16_Q(-0.00492933),
  DSP16_Q(0.01300348),
  DSP16_Q(-0.02596622),
  DSP16_Q(0.04786910),
  DSP16_Q(-0.09358688),
  DSP16_Q(0.29474703),
  DSP16_Q(0.31288717),
  DSP16_Q(-0.09212952),
  DSP16_Q(0.04514308),
  DSP16_Q(-0.02323192),
  DSP16_Q(0.01059285),
  DSP16_Q(-0.00296165),
  DSP16_Q(-0.00140648),
  DSP16_Q(0.00350112),
  DSP16_Q(-0.00403988),
  DSP16_Q(0.00361025),
  DSP16_Q(-0.00269951),
  DSP16_Q(0.00168766),
  DSP16_Q(-0.00083442),
  DSP16_Q(0.00027449),
  DSP16_Q(-0.00002688),
  DSP16_Q(-0.00002476),
  DSP16_Q(0.00026812),
  DSP16_Q(-0.00081000),
  DSP16_Q(0.00161195),
  DSP16_Q(-0.00251956),
  DSP16_Q(0.00325712),
  DSP16_Q(-0.00343626),
  DSP16_Q(0.00257217),
  DSP16_Q(-0.00009296),
  DSP16_Q(-0.00468838),
  DSP16_Q(0.01271260),
  DSP16_Q(-0.02564345),
  DSP16_Q(0.04756149),
  DSP16_Q(-0.09346467),
  DSP16_Q(0.29705298),
  DSP16_Q(0.31065967),
  DSP16_Q(-0.09237222),
  DSP16_Q(0.04551686),
  DSP16_Q(-0.02359244),
  DSP16_Q(0.01090433),
  DSP16_Q(-0.00321235),
  DSP16_Q(-0.00121765),
  DSP16_Q(0.00336883),
  DSP16_Q(-0.00395477),
  DSP16_Q(0.00356106),
  DSP16_Q(-0.00267487),
  DSP16_Q(0.00167758),
  DSP16_Q(-0.00083133),
  DSP16_Q(0.00027374),
  DSP16_Q(-0.00002659),
  DSP16_Q(-0.00002508),
  DSP16_Q(0.00026918),
  DSP16_Q(-0.00081388),
  DSP16_Q(0.00162348),
  DSP16_Q(-0.00254629),
  DSP16_Q(0.00330877),
  DSP16_Q(-0.00352353),
  DSP16_Q(0.00270517),
  DSP16_Q(-0.00027927),
  DSP16_Q(-0.00444592),
  DSP16_Q(0.01241865),
  DSP16_Q(-0.02531516),
  DSP16_Q(0.04724439),
  DSP16_Q(-0.09332549),
  DSP16_Q(0.29934840),
  DSP16_Q(0.30842028),
  DSP16_Q(-0.09259746),
  DSP16_Q(0.04588124),
  DSP16_Q(-0.02394769),
  DSP16_Q(0.01121299),
  DSP16_Q(-0.00346177),
  DSP16_Q(-0.00102917),
  DSP16_Q(0.00323635),
  DSP16_Q(-0.00386926),
  DSP16_Q(0.00351143),
  DSP16_Q(-0.00264986),
  DSP16_Q(0.00166724),
  DSP16_Q(-0.00082810),
  DSP16_Q(0.00027293),
  DSP16_Q(-0.00002630),
  DSP16_Q(-0.00002540),
  DSP16_Q(0.00027019),
  DSP16_Q(-0.00081763),
  DSP16_Q(0.00163478),
  DSP16_Q(-0.00257270),
  DSP16_Q(0.00336004),
  DSP16_Q(-0.00361049),
  DSP16_Q(0.00283811),
  DSP16_Q(-0.00046607),
  DSP16_Q(-0.00420200),
  DSP16_Q(0.01212167),
  DSP16_Q(-0.02498141),
  DSP16_Q(0.04691779),
  DSP16_Q(-0.09316927),
  DSP16_Q(0.30163307),
  DSP16_Q(0.30616923),
  DSP16_Q(-0.09280533),
  DSP16_Q(0.04623620),
  DSP16_Q(-0.02429763),
  DSP16_Q(0.01151880),
  DSP16_Q(-0.00370988),
  DSP16_Q(-0.00084105),
  DSP16_Q(0.00310373),
  DSP16_Q(-0.00378337),
  DSP16_Q(0.00346138),
  DSP16_Q(-0.00262449),
  DSP16_Q(0.00165666),
  DSP16_Q(-0.00082475),
  DSP16_Q(0.00027207),
  DSP16_Q(-0.00002601),
  DSP16_Q(-0.00002570),
  DSP16_Q(0.00027116),
  DSP16_Q(-0.00082126),
  DSP16_Q(0.00164584),
  DSP16_Q(-0.00259877),
  DSP16_Q(0.00341091),
  DSP16_Q(-0.00369710),
  DSP16_Q(0.00297097),
  DSP16_Q(-0.00065335),
  DSP16_Q(-0.00395664),
  DSP16_Q(0.01182171),
  DSP16_Q(-0.02464221),
  DSP16_Q(0.04658173),
  DSP16_Q(-0.09299591),
  DSP16_Q(0.30390675),
  DSP16_Q(0.30390675),
  DSP16_Q(-0.09299591),
  DSP16_Q(0.04658173),
  DSP16_Q(-0.02464221),
  DSP16_Q(0.01182171),
  DSP16_Q(-0.00395664),
  DSP16_Q(-0.00065335),
  DSP16_Q(0.00297097),
  DSP16_Q(-0.00369710),
  DSP16_Q(0.00341091),
  DSP16_Q(-0.00259877),
  DSP16_Q(0.00164584),
  DSP16_Q(-0.00082126),
  DSP16_Q(0.00027116),
  DSP16_Q(-0.00002570),
  DSP16_Q(-0.00002601),
  DSP16_Q(0.00027207),
  DSP16_Q(-0.00082475),
  DSP16_Q(0.00165666),
  DSP16_Q(-0.00262449),
  DSP16_Q(0.00346138),
  DSP16_Q(-0.00378337),
  DSP16_Q(0.00310373),
  DSP16_Q(-0.00084105),
  DSP16_Q(-0.00370988),
  DSP16_Q(0.01151880),
  DSP16_Q(-0.02429763),
  DSP16_Q(0.04623620),
  DSP16_Q(-0.09280533),
  DSP16_Q(0.30616923),
  DSP16_Q(0.30163307),
  DSP16_Q(-0.09316927),
  DSP16_Q(0.04691779),
  DSP16_Q(-0.02498141),
  DSP16_Q(0.01212167),
  DSP16_Q(-0.00420200),
  DSP16_Q(-0.00046607),
  DSP16_Q(0.00283811),
  DSP16_Q(-0.00361049),
  DSP16_Q(0.00336004),
  DSP16_Q(-0.00257270),
  DSP16_Q(0.00163478),
  DSP16_Q(-0.00081763),
  DSP16_Q(0.00027019),
  DSP16_Q(-0.00002540),
  DSP16_Q(-0.00002630),
  DSP16_Q(0.00027293),
  DSP16_Q(-0.00082810),
  DSP16_Q(0.00166724),
  DSP16_Q(-0.00264986),
  DSP16_Q(0.00351143),
  DSP16_Q(-0.00386926),
  DSP16_Q(0.00323635),
  DSP16_Q(-0.00102917),
  DSP16_Q(-0.00346177),
  DSP16_Q(0.01121299),
  DSP16_Q(-0.02394769),
  DSP16_Q(0.04588124),
  DSP16_Q(-0.09259746),
  DSP16_Q(0.30842028),
  DSP16_Q(0.29934840),
  DSP16_Q(-0.09332549),
  DSP16_Q(0.04724439),
  DSP16_Q(-0.02531516),
  DSP16_Q(0.01241865),
  DSP16_Q(-0.00444592),
  DSP16_Q(-0.00027927),
  DSP16_Q(0.00270517),
  DSP16_Q(-0.00352353),
  DSP16_Q(0.00330877),
  DSP16_Q(-0.00254629),
  DSP16_Q(0.00162348),
  DSP16_Q(-0.00081388),
  DSP16_Q(0.00026918),
  DSP16_Q(-0.00002508),
  DSP16_Q(-0.00002659),
  DSP16_Q(0.00027374),
  DSP16_Q(-0.00083133),
  DSP16_Q(0.00167758),
  DSP16_Q(-0.00267487),
  DSP16_Q(0.00356106),
  DSP16_Q(-0.00395477),
  DSP16_Q(0.00336883),
  DSP16_Q(-0.00121765),
  DSP16_Q(-0.00321235),
  DSP16_Q(0.01090433),
  DSP16_Q(-0.02359244),
  DSP16_Q(0.04551686),
  DSP16_Q(-0.09237222),
  DSP16_Q(0.31065967),
  DSP16_Q(0.29705298),
  DSP16_Q(-0.09346467),
  DSP16_Q(0.04756149),
  DSP16_Q(-0.02564345),
  DSP16_Q(0.01271260),
  DSP16_Q(-0.00468838),
  DSP16_Q(-0.00009296),
  DSP16_Q(0.00257217),
  DSP16_Q(-0.00343626),
  DSP16_Q(0.00325712),
  DSP16_Q(-0.00251956),
  DSP16_Q(0.00161195),
  DSP16_Q(-0.00081000),
  DSP16_Q(0.00026812),
  DSP16_Q(-0.00002476),
  DSP16_Q(-0.00002688),
  DSP16_Q(0.00027449),
  DSP16_Q(-0.00083442),
  DSP16_Q(0.00168766),
  DSP16_Q(-0.00269951),
  DSP16_Q(0.00361025),
  DSP16_Q(-0.00403988),
  DSP16_Q(0.00350112),
  DSP16_Q(-0.00140648),
  DSP16_Q(-0.00296165),
  DSP16_Q(0.01059285),
  DSP16_Q(-0.02323192),
  DSP16_Q(0.04514308),
  DSP16_Q(-0.09212952),
  DSP16_Q(0.31288717),
  DSP16_Q(0.29474703),
  DSP16_Q(-0.09358688),
  DSP16_Q(0.04786910),
  DSP16_Q(-0.02596622),
  DSP16_Q(0.01300348),
  DSP16_Q(-0.00492933),
  DSP16_Q(0.00009282),
  DSP16_Q(0.00243913),
  DSP16_Q(-0.00334868),
  DSP16_Q(0.00320509),
  DSP16_Q(-0.00249249),
  DSP16_Q(0.00160020),
  DSP16_Q(-0.00080600),
  DSP16_Q(0.00026701),
  DSP16_Q(-0.00002443),
  DSP16_Q(-0.00002715),
  DSP16_Q(0.00027520),
  DSP16_Q(-0.00083737),
  DSP16_Q(0.00169750),
  DSP16_Q(-0.00272379),
  DSP16_Q(0.00365899),
  DSP16_Q(-0.00412456),
  DSP16_Q(0.00363322),
  DSP16_Q(-0.00159561),
  DSP16_Q(-0.00270971),
  DSP16_Q(0.01027861),
  DSP16_Q(-0.02286618),
  DSP16_Q(0.04475993),
  DSP16_Q(-0.09186930),
  DSP16_Q(0.31510258),
  DSP16_Q(0.29243079),
  DSP16_Q(-0.09369221),
  DSP16_Q(0.04816718),
  DSP16_Q(-0.02628344),
  DSP16_Q(0.01329124),
  DSP16_Q(-0.00516874),
  DSP16_Q(0.00027804),
  DSP16_Q(0.00230608),
  DSP16_Q(-0.00326082),
  DSP16_Q(0.00315270),
  DSP16_Q(-0.00246511),
  DSP16_Q(0.00158822),
  DSP16_Q(-0.00080187),
  DSP16_Q(0.00026586),
  DSP16_Q(-0.00002410),
  DSP16_Q(-0.00002742),
  DSP16_Q(0.00027584),
  DSP16_Q(-0.00084018),
  DSP16_Q(0.00170708),
  DSP16_Q(-0.00274769),
  DSP16_Q(0.00370727),
  DSP16_Q(-0.00420882),
  DSP16_Q(0.00376509),
  DSP16_Q(-0.00178502),
  DSP16_Q(-0.00245658),
  DSP16_Q(0.00996165),
  DSP16_Q(-0.02249526),
  DSP16_Q(0.04436744),
  DSP16_Q(-0.09159149),
  DSP16_Q(0.31730566),
  DSP16_Q(0.29010449),
  DSP16_Q(-0.09378075),
  DSP16_Q(0.04845574),
  DSP16_Q(-0.02659508),
  DSP16_Q(0.01357586),
  DSP16_Q(-0.00540656),
  DSP16_Q(0.00046267),
  DSP16_Q(0.00217304),
  DSP16_Q(-0.00317269),
  DSP16_Q(0.00309996),
  DSP16_Q(-0.00243741),
  DSP16_Q(0.00157602),
  DSP16_Q(-0.00079762),
  DSP16_Q(0.00026466),
  DSP16_Q(-0.00002377),
  DSP16_Q(-0.00002768),
  DSP16_Q(0.00027644),
  DSP16_Q(-0.00084285),
  DSP16_Q(0.00171640),
  DSP16_Q(-0.00277121),
  DSP16_Q(0.00375509),
  DSP16_Q(-0.00429262),
  DSP16_Q(0.00389671),
  DSP16_Q(-0.00197467),
  DSP16_Q(-0.00220229),
  DSP16_Q(0.00964201),
  DSP16_Q(-0.02211921),
  DSP16_Q(0.04396562),
  DSP16_Q(-0.09129601),
  DSP16_Q(0.31949619),
  DSP16_Q(0.28776835),
  DSP16_Q(-0.09385259),
  DSP16_Q(0.04873477),
  DSP16_Q(-0.02690111),
  DSP16_Q(0.01385728),
  DSP16_Q(-0.00564276),
  DSP16_Q(0.00064668),
  DSP16_Q(0.00204004),
  DSP16_Q(-0.00308430),
  DSP16_Q(0.00304688),
  DSP16_Q(-0.00240940),
  DSP16_Q(0.00156360),
  DSP16_Q(-0.00079325),
  DSP16_Q(0.00026341),
  DSP16_Q(-0.00002343),
  DSP16_Q(-0.00002793),
  DSP16_Q(0.00027697),
  DSP16_Q(-0.00084538),
  DSP16_Q(0.00172546),
  DSP16_Q(-0.00279434),
  DSP16_Q(0.00380242),
  DSP16_Q(-0.00437595),
  DSP16_Q(0.00402806),
  DSP16_Q(-0.00216454),
  DSP16_Q(-0.00194688),
  DSP16_Q(0.00931975),
  DSP16_Q(-0.02173807),
  DSP16_Q(0.04355452),
  DSP16_Q(-0.09098279),
  DSP16_Q(0.32167395),
  DSP16_Q(0.28542260),
  DSP16_Q(-0.09390782),
  DSP16_Q(0.04900425),
  DSP16_Q(-0.02720148),
  DSP16_Q(0.01413548),
  DSP16_Q(-0.00587731),
  DSP16_Q(0.00083004),
  DSP16_Q(0.00190710),
  DSP16_Q(-0.00299567),
  DSP16_Q(0.00299347),
  DSP16_Q(-0.00238110),
  DSP16_Q(0.00155097),
  DSP16_Q(-0.00078876),
  DSP16_Q(0.00026212),
  DSP16_Q(-0.00002308),
  DSP16_Q(-0.00002818),
  DSP16_Q(0.00027745),
  DSP16_Q(-0.00084776),
  DSP16_Q(0.00173426),
  DSP16_Q(-0.00281707),
  DSP16_Q(0.00384927),
  DSP16_Q(-0.00445880),
  DSP16_Q(0.00415912),
  DSP16_Q(-0.00235458),
  DSP16_Q(-0.00169040),
  DSP16_Q(0.00899490),
  DSP16_Q(-0.02135189),
  DSP16_Q(0.04313415),
  DSP16_Q(-0.09065177),
  DSP16_Q(0.32383873),
  DSP16_Q(0.28306748),
  DSP16_Q(-0.09394655),
  DSP16_Q(0.04926418),
  DSP16_Q(-0.02749616),
  DSP16_Q(0.01441040),
  DSP16_Q(-0.00611016),
  DSP16_Q(0.00101272),
  DSP16_Q(0.00177423),
  DSP16_Q(-0.00290683),
  DSP16_Q(0.00293974),
  DSP16_Q(-0.00235250),
  DSP16_Q(0.00153812),
  DSP16_Q(-0.00078416),
  DSP16_Q(0.00026078),
  DSP16_Q(-0.00002274),
  DSP16_Q(-0.00002841),
  DSP16_Q(0.00027788),
  DSP16_Q(-0.00085000),
  DSP16_Q(0.00174279),
  DSP16_Q(-0.00283941),
  DSP16_Q(0.00389562),
  DSP16_Q(-0.00454115),
  DSP16_Q(0.00428985),
  DSP16_Q(-0.00254478),
  DSP16_Q(-0.00143289),
  DSP16_Q(0.00866753),
  DSP16_Q(-0.02096072),
  DSP16_Q(0.04270455),
  DSP16_Q(-0.09030289),
  DSP16_Q(0.32599030),
  DSP16_Q(0.28070323),
  DSP16_Q(-0.09396885),
  DSP16_Q(0.04951456),
  DSP16_Q(-0.02778513),
  DSP16_Q(0.01468202),
  DSP16_Q(-0.00634129),
  DSP16_Q(0.00119468),
  DSP16_Q(0.00164147),
  DSP16_Q(-0.00281777),
  DSP16_Q(0.00288570),
  DSP16_Q(-0.00232361),
  DSP16_Q(0.00152507),
  DSP16_Q(-0.00077943),
  DSP16_Q(0.00025940),
  DSP16_Q(-0.00002239),
  DSP16_Q(-0.00002864),
  DSP16_Q(0.00027824),
  DSP16_Q(-0.00085209),
  DSP16_Q(0.00175105),
  DSP16_Q(-0.00286134),
  DSP16_Q(0.00394146),
  DSP16_Q(-0.00462298),
  DSP16_Q(0.00442024),
  DSP16_Q(-0.00273508),
  DSP16_Q(-0.00117439),
  DSP16_Q(0.00833767),
  DSP16_Q(-0.02056462),
  DSP16_Q(0.04226576),
  DSP16_Q(-0.08993608),
  DSP16_Q(0.32812845),
  DSP16_Q(0.27833007),
  DSP16_Q(-0.09397484),
  DSP16_Q(0.04975537),
  DSP16_Q(-0.02806836),
  DSP16_Q(0.01495029),
  DSP16_Q(-0.00657066),
  DSP16_Q(0.00137591),
  DSP16_Q(0.00150884),
  DSP16_Q(-0.00272853),
  DSP16_Q(0.00283136),
  DSP16_Q(-0.00229444),
  DSP16_Q(0.00151182),
  DSP16_Q(-0.00077460),
  DSP16_Q(0.00025798),
  DSP16_Q(-0.00002203),
  DSP16_Q(-0.00002885),
  DSP16_Q(0.00027855),
  DSP16_Q(-0.00085404),
  DSP16_Q(0.00175903),
  DSP16_Q(-0.00288285),
  DSP16_Q(0.00398677),
  DSP16_Q(-0.00470428),
  DSP16_Q(0.00455027),
  DSP16_Q(-0.00292547),
  DSP16_Q(-0.00091494),
  DSP16_Q(0.00800539),
  DSP16_Q(-0.02016363),
  DSP16_Q(0.04181780),
  DSP16_Q(-0.08955128),
  DSP16_Q(0.33025297),
  DSP16_Q(0.27594824),
  DSP16_Q(-0.09396460),
  DSP16_Q(0.04998664),
  DSP16_Q(-0.02834580),
  DSP16_Q(0.01521519),
  DSP16_Q(-0.00679823),
  DSP16_Q(0.00155637),
  DSP16_Q(0.00137636),
  DSP16_Q(-0.00263912),
  DSP16_Q(0.00277673),
  DSP16_Q(-0.00226500),
  DSP16_Q(0.00149837),
  DSP16_Q(-0.00076965),
  DSP16_Q(0.00025651),
  DSP16_Q(-0.00002167),
  DSP16_Q(-0.00002906),
  DSP16_Q(0.00027879),
  DSP16_Q(-0.00085583),
  DSP16_Q(0.00176674),
  DSP16_Q(-0.00290395),
  DSP16_Q(0.00403156),
  DSP16_Q(-0.00478503),
  DSP16_Q(0.00467990),
  DSP16_Q(-0.00311590),
  DSP16_Q(-0.00065458),
  DSP16_Q(0.00767072),
  DSP16_Q(-0.01975780),
  DSP16_Q(0.04136072),
  DSP16_Q(-0.08914843),
  DSP16_Q(0.33236365),
  DSP16_Q(0.27355797),
  DSP16_Q(-0.09393825),
  DSP16_Q(0.05020834),
  DSP16_Q(-0.02861745),
  DSP16_Q(0.01547667),
  DSP16_Q(-0.00702397),
  DSP16_Q(0.00173603),
  DSP16_Q(0.00124405),
  DSP16_Q(-0.00254956),
  DSP16_Q(0.00272183),
  DSP16_Q(-0.00223529),
  DSP16_Q(0.00148472),
  DSP16_Q(-0.00076460),
  DSP16_Q(0.00025501),
  DSP16_Q(-0.00002131),
  DSP16_Q(-0.00002925),
  DSP16_Q(0.00027898),
  DSP16_Q(-0.00085747),
  DSP16_Q(0.00177417),
  DSP16_Q(-0.00292463),
  DSP16_Q(0.00407581),
  DSP16_Q(-0.00486521),
  DSP16_Q(0.00480911),
  DSP16_Q(-0.00330635),
  DSP16_Q(-0.00039336),
  DSP16_Q(0.00733372),
  DSP16_Q(-0.01934719),
  DSP16_Q(0.04089455),
  DSP16_Q(-0.08872748),
  DSP16_Q(0.33446025),
  DSP16_Q(0.27115950),
  DSP16_Q(-0.09389588),
  DSP16_Q(0.05042048),
  DSP16_Q(-0.02888326),
  DSP16_Q(0.01573470),
  DSP16_Q(-0.00724784),
  DSP16_Q(0.00191486),
  DSP16_Q(0.00111194),
  DSP16_Q(-0.00245985),
  DSP16_Q(0.00266666),
  DSP16_Q(-0.00220532),
  DSP16_Q(0.00147088),
  DSP16_Q(-0.00075943),
  DSP16_Q(0.00025347),
  DSP16_Q(-0.00002095),
  DSP16_Q(-0.00002944),
  DSP16_Q(0.00027911),
  DSP16_Q(-0.00085896),
  DSP16_Q(0.00178131),
  DSP16_Q(-0.00294487),
  DSP16_Q(0.00411951),
  DSP16_Q(-0.00494482),
  DSP16_Q(0.00493789),
  DSP16_Q(-0.00349679),
  DSP16_Q(-0.00013132),
  DSP16_Q(0.00699444),
  DSP16_Q(-0.01893186),
  DSP16_Q(0.04041933),
  DSP16_Q(-0.08828837),
  DSP16_Q(0.33654259),
  DSP16_Q(0.26875306),
  DSP16_Q(-0.09383760),
  DSP16_Q(0.05062307),
  DSP16_Q(-0.02914321),
  DSP16_Q(0.01598925),
  DSP16_Q(-0.00746982),
  DSP16_Q(0.00209283),
  DSP16_Q(0.00098004),
  DSP16_Q(-0.00237002),
  DSP16_Q(0.00261124),
  DSP16_Q(-0.00217509),
  DSP16_Q(0.00145685),
  DSP16_Q(-0.00075417),
  DSP16_Q(0.00025188),
  DSP16_Q(-0.00002059),
  DSP16_Q(-0.00002961),
  DSP16_Q(0.00027917),
  DSP16_Q(-0.00086030),
  DSP16_Q(0.00178817),
  DSP16_Q(-0.00296469),
  DSP16_Q(0.00416265),
  DSP16_Q(-0.00502382),
  DSP16_Q(0.00506620),
  DSP16_Q(-0.00368717),
  DSP16_Q(0.00013151),
  DSP16_Q(0.00665293),
  DSP16_Q(-0.01851185),
  DSP16_Q(0.03993511),
  DSP16_Q(-0.08783104),
  DSP16_Q(0.33861044),
  DSP16_Q(0.26633889),
  DSP16_Q(-0.09376352),
  DSP16_Q(0.05081612),
  DSP16_Q(-0.02939728),
  DSP16_Q(0.01624028),
  DSP16_Q(-0.00768987),
  DSP16_Q(0.00226992),
  DSP16_Q(0.00084838),
  DSP16_Q(-0.00228008),
  DSP16_Q(0.00255558),
  DSP16_Q(-0.00214461),
  DSP16_Q(0.00144264),
  DSP16_Q(-0.00074879),
  DSP16_Q(0.00025026),
  DSP16_Q(-0.00002022),
  DSP16_Q(-0.00002978),
  DSP16_Q(0.00027917),
  DSP16_Q(-0.00086148),
  DSP16_Q(0.00179474),
  DSP16_Q(-0.00298406),
  DSP16_Q(0.00420522),
  DSP16_Q(-0.00510221),
  DSP16_Q(0.00519403),
  DSP16_Q(-0.00387746),
  DSP16_Q(0.00039506),
  DSP16_Q(0.00630924),
  DSP16_Q(-0.01808723),
  DSP16_Q(0.03944192),
  DSP16_Q(-0.08735546),
  DSP16_Q(0.34066360),
  DSP16_Q(0.26391723),
  DSP16_Q(-0.09367373),
  DSP16_Q(0.05099962),
  DSP16_Q(-0.02964544),
  DSP16_Q(0.01648775),
  DSP16_Q(-0.00790795),
  DSP16_Q(0.00244610),
  DSP16_Q(0.00071699),
  DSP16_Q(-0.00219006),
  DSP16_Q(0.00249968),
  DSP16_Q(-0.00211390),
  DSP16_Q(0.00142825),
  DSP16_Q(-0.00074332),
  DSP16_Q(0.00024861),
  DSP16_Q(-0.00001985),
  DSP16_Q(-0.00002993),
  DSP16_Q(0.00027911),
  DSP16_Q(-0.00086250),
  DSP16_Q(0.00180102),
  DSP16_Q(-0.00300298),
  DSP16_Q(0.00424721),
  DSP16_Q(-0.00517998),
  DSP16_Q(0.00532134),
  DSP16_Q(-0.00406764),
  DSP16_Q(0.00065931),
  DSP16_Q(0.00596343),
  DSP16_Q(-0.01765804),
  DSP16_Q(0.03893982),
  DSP16_Q(-0.08686157),
  DSP16_Q(0.34270186),
  DSP16_Q(0.26148832),
  DSP16_Q(-0.09356835),
  DSP16_Q(0.05117358),
  DSP16_Q(-0.02988768),
  DSP16_Q(0.01673165),
  DSP16_Q(-0.00812404),
  DSP16_Q(0.00262133),
  DSP16_Q(0.00058588),
  DSP16_Q(-0.00209996),
  DSP16_Q(0.00244356),
  DSP16_Q(-0.00208295),
  DSP16_Q(0.00141367),
  DSP16_Q(-0.00073774),
  DSP16_Q(0.00024691),
  DSP16_Q(-0.00001948),
  DSP16_Q(-0.00003007),
  DSP16_Q(0.00027898),
  DSP16_Q(-0.00086337),
  DSP16_Q(0.00180701),
  DSP16_Q(-0.00302146),
  DSP16_Q(0.00428861),
  DSP16_Q(-0.00525709),
  DSP16_Q(0.00544812),
  DSP16_Q(-0.00425767),
  DSP16_Q(0.00092420),
  DSP16_Q(0.00561555),
  DSP16_Q(-0.01722436),
  DSP16_Q(0.03842884),
  DSP16_Q(-0.08634932),
  DSP16_Q(0.34472501),
  DSP16_Q(0.25905238),
  DSP16_Q(-0.09344750),
  DSP16_Q(0.05133802),
  DSP16_Q(-0.03012396),
  DSP16_Q(0.01697193),
  DSP16_Q(-0.00833810),
  DSP16_Q(0.00279560),
  DSP16_Q(0.00045508),
  DSP16_Q(-0.00200980),
  DSP16_Q(0.00238723),
  DSP16_Q(-0.00205177),
  DSP16_Q(0.00139893),
  DSP16_Q(-0.00073207),
  DSP16_Q(0.00024518),
  DSP16_Q(-0.00001911),
  DSP16_Q(-0.00003020),
  DSP16_Q(0.00027880),
  DSP16_Q(-0.00086407),
  DSP16_Q(0.00181270),
  DSP16_Q(-0.00303948),
  DSP16_Q(0.00432942),
  DSP16_Q(-0.00533355),
  DSP16_Q(0.00557434),
  DSP16_Q(-0.00444751),
  DSP16_Q(0.00118970),
  DSP16_Q(0.00526565),
  DSP16_Q(-0.01678623),
  DSP16_Q(0.03790904),
  DSP16_Q(-0.08581868),
  DSP16_Q(0.34673285),
  DSP16_Q(0.25660966),
  DSP16_Q(-0.09331127),
  DSP16_Q(0.05149294),
  DSP16_Q(-0.03035426),
  DSP16_Q(0.01720857),
  DSP16_Q(-0.00855010),
  DSP16_Q(0.00296887),
  DSP16_Q(0.00032460),
  DSP16_Q(-0.00191960),
  DSP16_Q(0.00233070),
  DSP16_Q(-0.00202037),
  DSP16_Q(0.00138401),
  DSP16_Q(-0.00072630),
  DSP16_Q(0.00024342),
  DSP16_Q(-0.00001874),
  DSP16_Q(-0.00003031),
  DSP16_Q(0.00027854),
  DSP16_Q(-0.00086462),
  DSP16_Q(0.00181808),
  DSP16_Q(-0.00305703),
  DSP16_Q(0.00436961),
  DSP16_Q(-0.00540933),
  DSP16_Q(0.00569998),
  DSP16_Q(-0.00463713),
  DSP16_Q(0.00145576),
  DSP16_Q(0.00491379),
  DSP16_Q(-0.01634372),
  DSP16_Q(0.03738046),
  DSP16_Q(-0.08526959),
  DSP16_Q(0.34872517),
  DSP16_Q(0.25416041),
  DSP16_Q(-0.09315980),
  DSP16_Q(0.05163836),
  DSP16_Q(-0.03057858),
  DSP16_Q(0.01744153),
  DSP16_Q(-0.00876002),
  DSP16_Q(0.00314111),
  DSP16_Q(0.00019448),
  DSP16_Q(-0.00182937),
  DSP16_Q(0.00227398),
  DSP16_Q(-0.00198875),
  DSP16_Q(0.00136893),
  DSP16_Q(-0.00072044),
  DSP16_Q(0.00024162),
  DSP16_Q(-0.00001837),
  DSP16_Q(-0.00003042),
  DSP16_Q(0.00027822),
  DSP16_Q(-0.00086500),
  DSP16_Q(0.00182317),
  DSP16_Q(-0.00307412),
  DSP16_Q(0.00440919),
  DSP16_Q(-0.00548442),
  DSP16_Q(0.00582501),
  DSP16_Q(-0.00482650),
  DSP16_Q(0.00172233),
  DSP16_Q(0.00456002),
  DSP16_Q(-0.01589688),
  DSP16_Q(0.03684315),
  DSP16_Q(-0.08470202),
  DSP16_Q(0.35070178),
  DSP16_Q(0.25170484),
  DSP16_Q(-0.09299318),
  DSP16_Q(0.05177430),
  DSP16_Q(-0.03079688),
  DSP16_Q(0.01767079),
  DSP16_Q(-0.00896781),
  DSP16_Q(0.00331231),
  DSP16_Q(0.00006473),
  DSP16_Q(-0.00173913),
  DSP16_Q(0.00221708),
  DSP16_Q(-0.00195693),
  DSP16_Q(0.00135369),
  DSP16_Q(-0.00071448),
  DSP16_Q(0.00023979),
  DSP16_Q(-0.00001800),
  DSP16_Q(-0.00003051),
  DSP16_Q(0.00027784),
  DSP16_Q(-0.00086522),
  DSP16_Q(0.00182795),
  DSP16_Q(-0.00309074),
  DSP16_Q(0.00444814),
  DSP16_Q(-0.00555880),
  DSP16_Q(0.00594940),
  DSP16_Q(-0.00501558),
  DSP16_Q(0.00198937),
  DSP16_Q(0.00420439),
  DSP16_Q(-0.01544579),
  DSP16_Q(0.03629718),
  DSP16_Q(-0.08411592),
  DSP16_Q(0.35266246),
  DSP16_Q(0.24924322),
  DSP16_Q(-0.09281154),
  DSP16_Q(0.05190075),
  DSP16_Q(-0.03100916),
  DSP16_Q(0.01789632),
  DSP16_Q(-0.00917345),
  DSP16_Q(0.00348243),
  DSP16_Q(-0.00006463),
  DSP16_Q(-0.00164890),
  DSP16_Q(0.00216001),
  DSP16_Q(-0.00192491),
  DSP16_Q(0.00133829),
  DSP16_Q(-0.00070843),
  DSP16_Q(0.00023793),
  DSP16_Q(-0.00001763),
  DSP16_Q(-0.00003058),
  DSP16_Q(0.00027738),
  DSP16_Q(-0.00086527),
  DSP16_Q(0.00183243),
  DSP16_Q(-0.00310688),
  DSP16_Q(0.00448645),
  DSP16_Q(-0.00563246),
  DSP16_Q(0.00607315),
  DSP16_Q(-0.00520434),
  DSP16_Q(0.00225683),
  DSP16_Q(0.00384698),
  DSP16_Q(-0.01499050),
  DSP16_Q(0.03574258),
  DSP16_Q(-0.08351128),
  DSP16_Q(0.35460703),
  DSP16_Q(0.24677576),
  DSP16_Q(-0.09261500),
  DSP16_Q(0.05201776),
  DSP16_Q(-0.03121539),
  DSP16_Q(0.01811809),
  DSP16_Q(-0.00937692),
  DSP16_Q(0.00365144),
  DSP16_Q(-0.00019357),
  DSP16_Q(-0.00155869),
  DSP16_Q(0.00210279),
  DSP16_Q(-0.00189269),
  DSP16_Q(0.00132273),
  DSP16_Q(-0.00070229),
  DSP16_Q(0.00023603),
  DSP16_Q(-0.00001725),
  DSP16_Q(-0.00003065),
  DSP16_Q(0.00027686),
  DSP16_Q(-0.00086516),
  DSP16_Q(0.00183659),
  DSP16_Q(-0.00312253),
  DSP16_Q(0.00452412),
  DSP16_Q(-0.00570538),
  DSP16_Q(0.00619621),
  DSP16_Q(-0.00539275),
  DSP16_Q(0.00252468),
  DSP16_Q(0.00348782),
  DSP16_Q(-0.01453107),
  DSP16_Q(0.03517943),
  DSP16_Q(-0.08288805),
  DSP16_Q(0.35653529),
  DSP16_Q(0.24430272),
  DSP16_Q(-0.09240367),
  DSP16_Q(0.05212532),
  DSP16_Q(-0.03141555),
  DSP16_Q(0.01833607),
  DSP16_Q(-0.00957818),
  DSP16_Q(0.00381933),
  DSP16_Q(-0.00032208),
  DSP16_Q(-0.00146852),
  DSP16_Q(0.00204542),
  DSP16_Q(-0.00186029),
  DSP16_Q(0.00130703),
  DSP16_Q(-0.00069607),
  DSP16_Q(0.00023411),
  DSP16_Q(-0.00001688),
  DSP16_Q(-0.00003070),
  DSP16_Q(0.00027627),
  DSP16_Q(-0.00086488),
  DSP16_Q(0.00184045),
  DSP16_Q(-0.00313770),
  DSP16_Q(0.00456113),
  DSP16_Q(-0.00577754),
  DSP16_Q(0.00631858),
  DSP16_Q(-0.00558077),
  DSP16_Q(0.00279285),
  DSP16_Q(0.00312697),
  DSP16_Q(-0.01406758),
  DSP16_Q(0.03460776),
  DSP16_Q(-0.08224619),
  DSP16_Q(0.35844703),
  DSP16_Q(0.24182433),
  DSP16_Q(-0.09217767),
  DSP16_Q(0.05222346),
  DSP16_Q(-0.03160964),
  DSP16_Q(0.01855024),
  DSP16_Q(-0.00977720),
  DSP16_Q(0.00398606),
  DSP16_Q(-0.00045012),
  DSP16_Q(-0.00137841),
  DSP16_Q(0.00198792),
  DSP16_Q(-0.00182771),
  DSP16_Q(0.00129117),
  DSP16_Q(-0.00068976),
  DSP16_Q(0.00023215),
  DSP16_Q(-0.00001651),
  DSP16_Q(-0.00003073),
  DSP16_Q(0.00027562),
  DSP16_Q(-0.00086443),
  DSP16_Q(0.00184398),
  DSP16_Q(-0.00315238),
  DSP16_Q(0.00459748),
  DSP16_Q(-0.00584893),
  DSP16_Q(0.00644022),
  DSP16_Q(-0.00576837),
  DSP16_Q(0.00306132),
  DSP16_Q(0.00276450),
  DSP16_Q(-0.01360008),
  DSP16_Q(0.03402766),
  DSP16_Q(-0.08158569),
  DSP16_Q(0.36034206),
  DSP16_Q(0.23934084),
  DSP16_Q(-0.09193714),
  DSP16_Q(0.05231220),
  DSP16_Q(-0.03179765),
  DSP16_Q(0.01876056),
  DSP16_Q(-0.00997395),
  DSP16_Q(0.00415160),
  DSP16_Q(-0.00057769),
  DSP16_Q(-0.00128836),
  DSP16_Q(0.00193029),
  DSP16_Q(-0.00179495),
  DSP16_Q(0.00127518),
  DSP16_Q(-0.00068337),
  DSP16_Q(0.00023017),
  DSP16_Q(-0.00001614),
  DSP16_Q(-0.00003075),
  DSP16_Q(0.00027489),
  DSP16_Q(-0.00086381),
  DSP16_Q(0.00184720),
  DSP16_Q(-0.00316656),
  DSP16_Q(0.00463316),
  DSP16_Q(-0.00591954),
  DSP16_Q(0.00656111),
  DSP16_Q(-0.00595551),
  DSP16_Q(0.00333003),
  DSP16_Q(0.00240046),
  DSP16_Q(-0.01312864),
  DSP16_Q(0.03343916),
  DSP16_Q(-0.08090651),
  DSP16_Q(0.36222019),
  DSP16_Q(0.23685248),
  DSP16_Q(-0.09168218),
  DSP16_Q(0.05239157),
  DSP16_Q(-0.03197955),
  DSP16_Q(0.01896703),
  DSP16_Q(-0.01016842),
  DSP16_Q(0.00431594),
  DSP16_Q(-0.00070476),
  DSP16_Q(-0.00119840),
  DSP16_Q(0.00187255),
  DSP16_Q(-0.00176202),
  DSP16_Q(0.00125904),
  DSP16_Q(-0.00067690),
  DSP16_Q(0.00022816),
  DSP16_Q(-0.00001577),
  DSP16_Q(-0.00003076),
  DSP16_Q(0.00027410),
  DSP16_Q(-0.00086303),
  DSP16_Q(0.00185010),
  DSP16_Q(-0.00318024),
  DSP16_Q(0.00466815),
  DSP16_Q(-0.00598935),
  DSP16_Q(0.00668122),
  DSP16_Q(-0.00614216),
  DSP16_Q(0.00359894),
  DSP16_Q(0.00203491),
  DSP16_Q(-0.01265333),
  DSP16_Q(0.03284235),
  DSP16_Q(-0.08020863),
  DSP16_Q(0.36408123),
  DSP16_Q(0.23435948),
  DSP16_Q(-0.09141293),
  DSP16_Q(0.05246159),
  DSP16_Q(-0.03215534),
  DSP16_Q(0.01916960),
  DSP16_Q(-0.01036056),
  DSP16_Q(0.00447905),
  DSP16_Q(-0.00083131),
  DSP16_Q(-0.00110854),
  DSP16_Q(0.00181471),
  DSP16_Q(-0.00172894),
  DSP16_Q(0.00124277),
  DSP16_Q(-0.00067035),
  DSP16_Q(0.00022612),
  DSP16_Q(-0.00001540),
  DSP16_Q(-0.00003075),
  DSP16_Q(0.00027323),
  DSP16_Q(-0.00086207),
  DSP16_Q(0.00185268),
  DSP16_Q(-0.00319341),
  DSP16_Q(0.00470245),
  DSP16_Q(-0.00605835),
  DSP16_Q(0.00680054),
  DSP16_Q(-0.00632829),
  DSP16_Q(0.00386800),
  DSP16_Q(0.00166791),
  DSP16_Q(-0.01217422),
  DSP16_Q(0.03223727),
  DSP16_Q(-0.07949202),
  DSP16_Q(0.36592499),
  DSP16_Q(0.23186211),
  DSP16_Q(-0.09112952),
  DSP16_Q(0.05252228),
  DSP16_Q(-0.03232500),
  DSP16_Q(0.01936827),
  DSP16_Q(-0.01055036),
  DSP16_Q(0.00464090),
  DSP16_Q(-0.00095732),
  DSP16_Q(-0.00101879),
  DSP16_Q(0.00175678),
  DSP16_Q(-0.00169570),
  DSP16_Q(0.00122637),
  DSP16_Q(-0.00066373),
  DSP16_Q(0.00022406),
  DSP16_Q(-0.00001503),
  DSP16_Q(-0.00003073),
  DSP16_Q(0.00027229),
  DSP16_Q(-0.00086094),
  DSP16_Q(0.00185494),
  DSP16_Q(-0.00320607),
  DSP16_Q(0.00473606),
  DSP16_Q(-0.00612651),
  DSP16_Q(0.00691904),
  DSP16_Q(-0.00651386),
  DSP16_Q(0.00413716),
  DSP16_Q(0.00129951),
  DSP16_Q(-0.01169138),
  DSP16_Q(0.03162400),
  DSP16_Q(-0.07875668),
  DSP16_Q(0.36775129),
  DSP16_Q(0.22936058),
  DSP16_Q(-0.09083206),
  DSP16_Q(0.05257367),
  DSP16_Q(-0.03248854),
  DSP16_Q(0.01956300),
  DSP16_Q(-0.01073778),
  DSP16_Q(0.00480147),
  DSP16_Q(-0.00108277),
  DSP16_Q(-0.00092918),
  DSP16_Q(0.00169876),
  DSP16_Q(-0.00166231),
  DSP16_Q(0.00120984),
  DSP16_Q(-0.00065702),
  DSP16_Q(0.00022197),
  DSP16_Q(-0.00001467),
  DSP16_Q(-0.00003069),
  DSP16_Q(0.00027128),
  DSP16_Q(-0.00085963),
  DSP16_Q(0.00185687),
  DSP16_Q(-0.00321821),
  DSP16_Q(0.00476895),
  DSP16_Q(-0.00619383),
  DSP16_Q(0.00703670),
  DSP16_Q(-0.00669884),
  DSP16_Q(0.00440638),
  DSP16_Q(0.00092978),
  DSP16_Q(-0.01120487),
  DSP16_Q(0.03100260),
  DSP16_Q(-0.07800256),
  DSP16_Q(0.36955992),
  DSP16_Q(0.22685515),
  DSP16_Q(-0.09052070),
  DSP16_Q(0.05261579),
  DSP16_Q(-0.03264593),
  DSP16_Q(0.01975377),
  DSP16_Q(-0.01092281),
  DSP16_Q(0.00496074),
  DSP16_Q(-0.00120763),
  DSP16_Q(-0.00083971),
  DSP16_Q(0.00164067),
  DSP16_Q(-0.00162878),
  DSP16_Q(0.00119318),
  DSP16_Q(-0.00065025),
  DSP16_Q(0.00021986),
  DSP16_Q(-0.00001431),
  DSP16_Q(-0.00003063),
  DSP16_Q(0.00027020),
  DSP16_Q(-0.00085815),
  DSP16_Q(0.00185847),
  DSP16_Q(-0.00322983),
  DSP16_Q(0.00480113),
  DSP16_Q(-0.00626029),
  DSP16_Q(0.00715350),
  DSP16_Q(-0.00688319),
  DSP16_Q(0.00467561),
  DSP16_Q(0.00055877),
  DSP16_Q(-0.01071476),
  DSP16_Q(0.03037315),
  DSP16_Q(-0.07722968),
  DSP16_Q(0.37135071),
  DSP16_Q(0.22434605),
  DSP16_Q(-0.09019555),
  DSP16_Q(0.05264867),
  DSP16_Q(-0.03279718),
  DSP16_Q(0.01994057),
  DSP16_Q(-0.01110542),
  DSP16_Q(0.00511867),
  DSP16_Q(-0.00133190),
  DSP16_Q(-0.00075041),
  DSP16_Q(0.00158253),
  DSP16_Q(-0.00159512),
  DSP16_Q(0.00117641),
  DSP16_Q(-0.00064340),
  DSP16_Q(0.00021772),
  DSP16_Q(-0.00001394),
  DSP16_Q(-0.00003056),
  DSP16_Q(0.00026905),
  DSP16_Q(-0.00085650),
  DSP16_Q(0.00185974),
  DSP16_Q(-0.00324093),
  DSP16_Q(0.00483259),
  DSP16_Q(-0.00632588),
  DSP16_Q(0.00726940),
  DSP16_Q(-0.00706689),
  DSP16_Q(0.00494481),
  DSP16_Q(0.00018655),
  DSP16_Q(-0.01022113),
  DSP16_Q(0.02973570),
  DSP16_Q(-0.07643799),
  DSP16_Q(0.37312348),
  DSP16_Q(0.22183353),
  DSP16_Q(-0.08985675),
  DSP16_Q(0.05267234),
  DSP16_Q(-0.03294227),
  DSP16_Q(0.02012337),
  DSP16_Q(-0.01128558),
  DSP16_Q(0.00527526),
  DSP16_Q(-0.00145554),
  DSP16_Q(-0.00066128),
  DSP16_Q(0.00152433),
  DSP16_Q(-0.00156134),
  DSP16_Q(0.00115952),
  DSP16_Q(-0.00063649),
  DSP16_Q(0.00021556),
  DSP16_Q(-0.00001359),
  DSP16_Q(-0.00003047),
  DSP16_Q(0.00026783),
  DSP16_Q(-0.00085467),
  DSP16_Q(0.00186068),
  DSP16_Q(-0.00325150),
  DSP16_Q(0.00486331),
  DSP16_Q(-0.00639058),
  DSP16_Q(0.00738439),
  DSP16_Q(-0.00724989),
  DSP16_Q(0.00521393),
  DSP16_Q(-0.00018683),
  DSP16_Q(-0.00972406),
  DSP16_Q(0.02909034),
  DSP16_Q(-0.07562751),
  DSP16_Q(0.37487804),
  DSP16_Q(0.21931782),
  DSP16_Q(-0.08950444),
  DSP16_Q(0.05268682),
  DSP16_Q(-0.03308121),
  DSP16_Q(0.02030215),
  DSP16_Q(-0.01146326),
  DSP16_Q(0.00543046),
  DSP16_Q(-0.00157854),
  DSP16_Q(-0.00057234),
  DSP16_Q(0.00146610),
  DSP16_Q(-0.00152743),
  DSP16_Q(0.00114252),
  DSP16_Q(-0.00062950),
  DSP16_Q(0.00021338),
  DSP16_Q(-0.00001323),
  DSP16_Q(-0.00003036),
  DSP16_Q(0.00026653),
  DSP16_Q(-0.00085266),
  DSP16_Q(0.00186128),
  DSP16_Q(-0.00326153),
  DSP16_Q(0.00489328),
  DSP16_Q(-0.00645437),
  DSP16_Q(0.00749845),
  DSP16_Q(-0.00743216),
  DSP16_Q(0.00548291),
  DSP16_Q(-0.00056130),
  DSP16_Q(-0.00922360),
  DSP16_Q(0.02843713),
  DSP16_Q(-0.07479821),
  DSP16_Q(0.37661422),
  DSP16_Q(0.21679916),
  DSP16_Q(-0.08913875),
  DSP16_Q(0.05269217),
  DSP16_Q(-0.03321398),
  DSP16_Q(0.02047689),
  DSP16_Q(-0.01163846),
  DSP16_Q(0.00558427),
  DSP16_Q(-0.00170088),
  DSP16_Q(-0.00048362),
  DSP16_Q(0.00140783),
  DSP16_Q(-0.00149342),
  DSP16_Q(0.00112541),
  DSP16_Q(-0.00062245),
  DSP16_Q(0.00021117),
  DSP16_Q(-0.00001287),
  DSP16_Q(-0.00003024),
  DSP16_Q(0.00026516),
  DSP16_Q(-0.00085047),
  DSP16_Q(0.00186155),
  DSP16_Q(-0.00327103),
  DSP16_Q(0.00492251),
  DSP16_Q(-0.00651725),
  DSP16_Q(0.00761155),
  DSP16_Q(-0.00761367),
  DSP16_Q(0.00575173),
  DSP16_Q(-0.00093680),
  DSP16_Q(-0.00871985),
  DSP16_Q(0.02777616),
  DSP16_Q(-0.07395009),
  DSP16_Q(0.37833183),
  DSP16_Q(0.21427779),
  DSP16_Q(-0.08875980),
  DSP16_Q(0.05268840),
  DSP16_Q(-0.03334059),
  DSP16_Q(0.02064758),
  DSP16_Q(-0.01181113),
  DSP16_Q(0.00573665),
  DSP16_Q(-0.00182254),
  DSP16_Q(-0.00039511),
  DSP16_Q(0.00134956),
  DSP16_Q(-0.00145929),
  DSP16_Q(0.00110819),
  DSP16_Q(-0.00061534),
  DSP16_Q(0.00020895),
  DSP16_Q(-0.00001252),
  DSP16_Q(-0.00003010),
  DSP16_Q(0.00026371),
  DSP16_Q(-0.00084811),
  DSP16_Q(0.00186148),
  DSP16_Q(-0.00327999),
  DSP16_Q(0.00495098),
  DSP16_Q(-0.00657920),
  DSP16_Q(0.00772367),
  DSP16_Q(-0.00779439),
  DSP16_Q(0.00602032),
  DSP16_Q(-0.00131328),
  DSP16_Q(-0.00821286),
  DSP16_Q(0.02710749),
  DSP16_Q(-0.07308315),
  DSP16_Q(0.38003070),
  DSP16_Q(0.21175396),
  DSP16_Q(-0.08836775),
  DSP16_Q(0.05267556),
  DSP16_Q(-0.03346104),
  DSP16_Q(0.02081420),
  DSP16_Q(-0.01198126),
  DSP16_Q(0.00588759),
  DSP16_Q(-0.00194350),
  DSP16_Q(-0.00030685),
  DSP16_Q(0.00129127),
  DSP16_Q(-0.00142507),
  DSP16_Q(0.00109088),
  DSP16_Q(-0.00060817),
  DSP16_Q(0.00020671),
  DSP16_Q(-0.00001217),
  DSP16_Q(-0.00002994),
  DSP16_Q(0.00026219),
  DSP16_Q(-0.00084556),
  DSP16_Q(0.00186107),
  DSP16_Q(-0.00328840),
  DSP16_Q(0.00497869),
  DSP16_Q(-0.00664020),
  DSP16_Q(0.00783478),
  DSP16_Q(-0.00797428),
  DSP16_Q(0.00628864),
  DSP16_Q(-0.00169066),
  DSP16_Q(-0.00770272),
  DSP16_Q(0.02643120),
  DSP16_Q(-0.07219738),
  DSP16_Q(0.38171066),
  DSP16_Q(0.20922791),
  DSP16_Q(-0.08796272),
  DSP16_Q(0.05265369),
  DSP16_Q(-0.03357532),
  DSP16_Q(0.02097673),
  DSP16_Q(-0.01214883),
  DSP16_Q(0.00603707),
  DSP16_Q(-0.00206375),
  DSP16_Q(-0.00021883),
  DSP16_Q(0.00123299),
  DSP16_Q(-0.00139075),
  DSP16_Q(0.00107347),
  DSP16_Q(-0.00060094),
  DSP16_Q(0.00020444),
  DSP16_Q(-0.00001183),
  DSP16_Q(-0.00002976),
  DSP16_Q(0.00026059),
  DSP16_Q(-0.00084284),
  DSP16_Q(0.00186031),
  DSP16_Q(-0.00329626),
  DSP16_Q(0.00500562),
  DSP16_Q(-0.00670024),
  DSP16_Q(0.00794487),
  DSP16_Q(-0.00815330),
  DSP16_Q(0.00655664),
  DSP16_Q(-0.00206889),
  DSP16_Q(-0.00718950),
  DSP16_Q(0.02574738),
  DSP16_Q(-0.07129278),
  DSP16_Q(0.38337153),
  DSP16_Q(0.20669986),
  DSP16_Q(-0.08754485),
  DSP16_Q(0.05262282),
  DSP16_Q(-0.03368343),
  DSP16_Q(0.02113515),
  DSP16_Q(-0.01231381),
  DSP16_Q(0.00618505),
  DSP16_Q(-0.00218325),
  DSP16_Q(-0.00013109),
  DSP16_Q(0.00117472),
  DSP16_Q(-0.00135635),
  DSP16_Q(0.00105596),
  DSP16_Q(-0.00059365),
  DSP16_Q(0.00020216),
  DSP16_Q(-0.00001149),
  DSP16_Q(-0.00002957),
  DSP16_Q(0.00025892),
  DSP16_Q(-0.00083993),
  DSP16_Q(0.00185922),
  DSP16_Q(-0.00330357),
  DSP16_Q(0.00503177),
  DSP16_Q(-0.00675931),
  DSP16_Q(0.00805391),
  DSP16_Q(-0.00833143),
  DSP16_Q(0.00682428),
  DSP16_Q(-0.00244790),
  DSP16_Q(-0.00667329),
  DSP16_Q(0.02505611),
  DSP16_Q(-0.07036936),
  DSP16_Q(0.38501314),
  DSP16_Q(0.20417007),
  DSP16_Q(-0.08711429),
  DSP16_Q(0.05258299),
  DSP16_Q(-0.03378538),
  DSP16_Q(0.02128945),
  DSP16_Q(-0.01247619),
  DSP16_Q(0.00633153),
  DSP16_Q(-0.00230200),
  DSP16_Q(-0.00004362),
  DSP16_Q(0.00111647),
  DSP16_Q(-0.00132187),
  DSP16_Q(0.00103837),
  DSP16_Q(-0.00058630),
  DSP16_Q(0.00019987),
  DSP16_Q(-0.00001115),
  DSP16_Q(-0.00002935),
  DSP16_Q(0.00025718),
  DSP16_Q(-0.00083685),
  DSP16_Q(0.00185778),
  DSP16_Q(-0.00331032),
  DSP16_Q(0.00505713),
  DSP16_Q(-0.00681740),
  DSP16_Q(0.00816188),
  DSP16_Q(-0.00850863),
  DSP16_Q(0.00709150),
  DSP16_Q(-0.00282764),
  DSP16_Q(-0.00615415),
  DSP16_Q(0.02435746),
  DSP16_Q(-0.06942711),
  DSP16_Q(0.38663532),
  DSP16_Q(0.20163877),
  DSP16_Q(-0.08667118),
  DSP16_Q(0.05253425),
  DSP16_Q(-0.03388116),
  DSP16_Q(0.02143962),
  DSP16_Q(-0.01263593),
  DSP16_Q(0.00647648),
  DSP16_Q(-0.00241998),
  DSP16_Q(0.00004355),
  DSP16_Q(0.00105826),
  DSP16_Q(-0.00128731),
  DSP16_Q(0.00102069),
  DSP16_Q(-0.00057891),
  DSP16_Q(0.00019756),
  DSP16_Q(-0.00001081),
  DSP16_Q(-0.00002912),
  DSP16_Q(0.00025535),
  DSP16_Q(-0.00083358),
  DSP16_Q(0.00185599),
  DSP16_Q(-0.00331651),
  DSP16_Q(0.00508170),
  DSP16_Q(-0.00687448),
  DSP16_Q(0.00826876),
  DSP16_Q(-0.00868486),
  DSP16_Q(0.00735827),
  DSP16_Q(-0.00320803),
  DSP16_Q(-0.00563216),
  DSP16_Q(0.02365153),
  DSP16_Q(-0.06846605),
  DSP16_Q(0.38823792),
  DSP16_Q(0.19910620),
  DSP16_Q(-0.08621565),
  DSP16_Q(0.05247663),
  DSP16_Q(-0.03397079),
  DSP16_Q(0.02158564),
  DSP16_Q(-0.01279304),
  DSP16_Q(0.00661987),
  DSP16_Q(-0.00253716),
  DSP16_Q(0.00013041),
  DSP16_Q(0.00100010),
  DSP16_Q(-0.00125269),
  DSP16_Q(0.00100293),
  DSP16_Q(-0.00057146),
  DSP16_Q(0.00019523),
  DSP16_Q(-0.00001048),
  DSP16_Q(-0.00002887),
  DSP16_Q(0.00025345),
  DSP16_Q(-0.00083012),
  DSP16_Q(0.00185386),
  DSP16_Q(-0.00332213),
  DSP16_Q(0.00510546),
  DSP16_Q(-0.00693055),
  DSP16_Q(0.00837452),
  DSP16_Q(-0.00886010),
  DSP16_Q(0.00762453),
  DSP16_Q(-0.00358902),
  DSP16_Q(-0.00510741),
  DSP16_Q(0.02293839),
  DSP16_Q(-0.06748618),
  DSP16_Q(0.38982075),
  DSP16_Q(0.19657260),
  DSP16_Q(-0.08574785),
  DSP16_Q(0.05241019),
  DSP16_Q(-0.03405426),
  DSP16_Q(0.02172750),
  DSP16_Q(-0.01294747),
  DSP16_Q(0.00676169),
  DSP16_Q(-0.00265354),
  DSP16_Q(0.00021694),
  DSP16_Q(0.00094199),
  DSP16_Q(-0.00121801),
  DSP16_Q(0.00098509),
  DSP16_Q(-0.00056396),
  DSP16_Q(0.00019288),
  DSP16_Q(-0.00001015),
  DSP16_Q(-0.00002860),
  DSP16_Q(0.00025148),
  DSP16_Q(-0.00082649),
  DSP16_Q(0.00185137),
  DSP16_Q(-0.00332719),
  DSP16_Q(0.00512841),
  DSP16_Q(-0.00698559),
  DSP16_Q(0.00847915),
  DSP16_Q(-0.00903431),
  DSP16_Q(0.00789023),
  DSP16_Q(-0.00397053),
  DSP16_Q(-0.00457998),
  DSP16_Q(0.02221813),
  DSP16_Q(-0.06648752),
  DSP16_Q(0.39138366),
  DSP16_Q(0.19403820),
  DSP16_Q(-0.08526792),
  DSP16_Q(0.05233497),
  DSP16_Q(-0.03413158),
  DSP16_Q(0.02186518),
  DSP16_Q(-0.01309922),
  DSP16_Q(0.00690192),
  DSP16_Q(-0.00276908),
  DSP16_Q(0.00030313),
  DSP16_Q(0.00088394),
  DSP16_Q(-0.00118328),
  DSP16_Q(0.00096718),
  DSP16_Q(-0.00055641),
  DSP16_Q(0.00019053),
  DSP16_Q(-0.00000983),
  DSP16_Q(-0.00002831),
  DSP16_Q(0.00024943),
  DSP16_Q(-0.00082266),
  DSP16_Q(0.00184854),
  DSP16_Q(-0.00333168),
  DSP16_Q(0.00515054),
  DSP16_Q(-0.00703959),
  DSP16_Q(0.00858261),
  DSP16_Q(-0.00920745),
  DSP16_Q(0.00815534),
  DSP16_Q(-0.00435252),
  DSP16_Q(-0.00404995),
  DSP16_Q(0.02149085),
  DSP16_Q(-0.06547007),
  DSP16_Q(0.39292649),
  DSP16_Q(0.19150325),
  DSP16_Q(-0.08477601),
  DSP16_Q(0.05225101),
  DSP16_Q(-0.03420276),
  DSP16_Q(0.02199868),
  DSP16_Q(-0.01324827),
  DSP16_Q(0.00704054),
  DSP16_Q(-0.00288378),
  DSP16_Q(0.00038898),
  DSP16_Q(0.00082597),
  DSP16_Q(-0.00114850),
  DSP16_Q(0.00094920),
  DSP16_Q(-0.00054882),
  DSP16_Q(0.00018816),
  DSP16_Q(-0.00000951),
  DSP16_Q(-0.00002800),
  DSP16_Q(0.00024729),
  DSP16_Q(-0.00081866),
  DSP16_Q(0.00184535),
  DSP16_Q(-0.00333559),
  DSP16_Q(0.00517185),
  DSP16_Q(-0.00709254),
  DSP16_Q(0.00868490),
  DSP16_Q(-0.00937949),
  DSP16_Q(0.00841979),
  DSP16_Q(-0.00473490),
  DSP16_Q(-0.00351739),
  DSP16_Q(0.02075663),
  DSP16_Q(-0.06443386),
  DSP16_Q(0.39444908),
  DSP16_Q(0.18896798),
  DSP16_Q(-0.08427226),
  DSP16_Q(0.05215837),
  DSP16_Q(-0.03426780),
  DSP16_Q(0.02212799),
  DSP16_Q(-0.01339459),
  DSP16_Q(0.00717753),
  DSP16_Q(-0.00299762),
  DSP16_Q(0.00047445),
  DSP16_Q(0.00076809),
  DSP16_Q(-0.00111368),
  DSP16_Q(0.00093116),
  DSP16_Q(-0.00054118),
  DSP16_Q(0.00018578),
  DSP16_Q(-0.00000920),
  DSP16_Q(-0.00002767),
  DSP16_Q(0.00024509),
  DSP16_Q(-0.00081447),
  DSP16_Q(0.00184181),
  DSP16_Q(-0.00333892),
  DSP16_Q(0.00519232),
  DSP16_Q(-0.00714442),
  DSP16_Q(0.00878598),
  DSP16_Q(-0.00955041),
  DSP16_Q(0.00868354),
  DSP16_Q(-0.00511763),
  DSP16_Q(-0.00298239),
  DSP16_Q(0.02001556),
  DSP16_Q(-0.06337890),
  DSP16_Q(0.39595127),
  DSP16_Q(0.18643263),
  DSP16_Q(-0.08375683),
  DSP16_Q(0.05205709),
  DSP16_Q(-0.03432672),
  DSP16_Q(0.02225309),
  DSP16_Q(-0.01353817),
  DSP16_Q(0.00731287),
  DSP16_Q(-0.00311057),
  DSP16_Q(0.00055954),
  DSP16_Q(0.00071030),
  DSP16_Q(-0.00107883),
  DSP16_Q(0.00091305),
  DSP16_Q(-0.00053350),
  DSP16_Q(0.00018338),
  DSP16_Q(-0.00000889),
  DSP16_Q(-0.00002731),
  DSP16_Q(0.00024280),
  DSP16_Q(-0.00081009),
  DSP16_Q(0.00183791),
  DSP16_Q(-0.00334167),
  DSP16_Q(0.00521196),
  DSP16_Q(-0.00719523),
  DSP16_Q(0.00888585),
  DSP16_Q(-0.00972016),
  DSP16_Q(0.00894655),
  DSP16_Q(-0.00550062),
  DSP16_Q(-0.00244503),
  DSP16_Q(0.01926774),
  DSP16_Q(-0.06230521),
  DSP16_Q(0.39743291),
  DSP16_Q(0.18389744),
  DSP16_Q(-0.08322985),
  DSP16_Q(0.05194722),
  DSP16_Q(-0.03437952),
  DSP16_Q(0.02237397),
  DSP16_Q(-0.01367899),
  DSP16_Q(0.00744654),
  DSP16_Q(-0.00322263),
  DSP16_Q(0.00064424),
  DSP16_Q(0.00065262),
  DSP16_Q(-0.00104395),
  DSP16_Q(0.00089488),
  DSP16_Q(-0.00052579),
  DSP16_Q(0.00018098),
  DSP16_Q(-0.00000858),
  DSP16_Q(-0.00002694),
  DSP16_Q(0.00024044),
  DSP16_Q(-0.00080553),
  DSP16_Q(0.00183366),
  DSP16_Q(-0.00334384),
  DSP16_Q(0.00523075),
  DSP16_Q(-0.00724494),
  DSP16_Q(0.00898446),
  DSP16_Q(-0.00988871),
  DSP16_Q(0.00920877),
  DSP16_Q(-0.00588383),
  DSP16_Q(-0.00190540),
  DSP16_Q(0.01851325),
  DSP16_Q(-0.06121282),
  DSP16_Q(0.39889384),
  DSP16_Q(0.18136263),
  DSP16_Q(-0.08269148),
  DSP16_Q(0.05182882),
  DSP16_Q(-0.03442621),
  DSP16_Q(0.02249063),
  DSP16_Q(-0.01381705),
  DSP16_Q(0.00757852),
  DSP16_Q(-0.00333377),
  DSP16_Q(0.00072853),
  DSP16_Q(0.00059505),
  DSP16_Q(-0.00100905),
  DSP16_Q(0.00087666),
  DSP16_Q(-0.00051803),
  DSP16_Q(0.00017857),
  DSP16_Q(-0.00000828),
  DSP16_Q(-0.00002655),
  DSP16_Q(0.00023799),
  DSP16_Q(-0.00080078),
  DSP16_Q(0.00182905),
  DSP16_Q(-0.00334542),
  DSP16_Q(0.00524869),
  DSP16_Q(-0.00729355),
  DSP16_Q(0.00908181),
  DSP16_Q(-0.01005604),
  DSP16_Q(0.00947015),
  DSP16_Q(-0.00626717),
  DSP16_Q(-0.00136358),
  DSP16_Q(0.01775221),
  DSP16_Q(-0.06010174),
  DSP16_Q(0.40033392),
  DSP16_Q(0.17882845),
  DSP16_Q(-0.08214186),
  DSP16_Q(0.05170193),
  DSP16_Q(-0.03446681),
  DSP16_Q(0.02260306),
  DSP16_Q(-0.01395231),
  DSP16_Q(0.00770880),
  DSP16_Q(-0.00344398),
  DSP16_Q(0.00081240),
  DSP16_Q(0.00053761),
  DSP16_Q(-0.00097414),
  DSP16_Q(0.00085839),
  DSP16_Q(-0.00051024),
  DSP16_Q(0.00017614),
  DSP16_Q(-0.00000798),
  DSP16_Q(-0.00002614),
  DSP16_Q(0.00023547),
  DSP16_Q(-0.00079584),
  DSP16_Q(0.00182408),
  DSP16_Q(-0.00334642),
  DSP16_Q(0.00526577),
  DSP16_Q(-0.00734104),
  DSP16_Q(0.00917788),
  DSP16_Q(-0.01022210),
  DSP16_Q(0.00973063),
  DSP16_Q(-0.00665059),
  DSP16_Q(-0.00081965),
  DSP16_Q(0.01698470),
  DSP16_Q(-0.05897201),
  DSP16_Q(0.40175298),
  DSP16_Q(0.17629514),
  DSP16_Q(-0.08158115),
  DSP16_Q(0.05156662),
  DSP16_Q(-0.03450133),
  DSP16_Q(0.02271125),
  DSP16_Q(-0.01408476),
  DSP16_Q(0.00783735),
  DSP16_Q(-0.00355325),
  DSP16_Q(0.00089584),
  DSP16_Q(0.00048030),
  DSP16_Q(-0.00093922),
  DSP16_Q(0.00084007),
  DSP16_Q(-0.00050241),
  DSP16_Q(0.00017371),
  DSP16_Q(-0.00000769),
  DSP16_Q(-0.00002570),
  DSP16_Q(0.00023287),
  DSP16_Q(-0.00079072),
  DSP16_Q(0.00181875),
  DSP16_Q(-0.00334682),
  DSP16_Q(0.00528198),
  DSP16_Q(-0.00738741),
  DSP16_Q(0.00927264),
  DSP16_Q(-0.01038687),
  DSP16_Q(0.00999019),
  DSP16_Q(-0.00703403),
  DSP16_Q(-0.00027370),
  DSP16_Q(0.01621082),
  DSP16_Q(-0.05782366),
  DSP16_Q(0.40315090),
  DSP16_Q(0.17376292),
  DSP16_Q(-0.08100950),
  DSP16_Q(0.05142293),
  DSP16_Q(-0.03452978),
  DSP16_Q(0.02281520),
  DSP16_Q(-0.01421440),
  DSP16_Q(0.00796416),
  DSP16_Q(-0.00366155),
  DSP16_Q(0.00097882),
  DSP16_Q(0.00042314),
  DSP16_Q(-0.00090430),
  DSP16_Q(0.00082171),
  DSP16_Q(-0.00049456),
  DSP16_Q(0.00017127),
  DSP16_Q(-0.00000740),
  DSP16_Q(-0.00002524),
  DSP16_Q(0.00023019),
  DSP16_Q(-0.00078541),
  DSP16_Q(0.00181307),
  DSP16_Q(-0.00334662),
  DSP16_Q(0.00529733),
  DSP16_Q(-0.00743263),
  DSP16_Q(0.00936607),
  DSP16_Q(-0.01055031),
  DSP16_Q(0.01024875),
  DSP16_Q(-0.00741740),
  DSP16_Q(0.00027418),
  DSP16_Q(0.01543067),
  DSP16_Q(-0.05665672),
  DSP16_Q(0.40452752),
  DSP16_Q(0.17123203),
  DSP16_Q(-0.08042705),
  DSP16_Q(0.05127092),
  DSP16_Q(-0.03455218),
  DSP16_Q(0.02291489),
  DSP16_Q(-0.01434120),
  DSP16_Q(0.00808922),
  DSP16_Q(-0.00376886),
  DSP16_Q(0.00106135),
  DSP16_Q(0.00036613),
  DSP16_Q(-0.00086938),
  DSP16_Q(0.00080331),
  DSP16_Q(-0.00048667),
  DSP16_Q(0.00016883),
  DSP16_Q(-0.00000712),
  DSP16_Q(-0.00002476),
  DSP16_Q(0.00022743),
  DSP16_Q(-0.00077991),
  DSP16_Q(0.00180702),
  DSP16_Q(-0.00334583),
  DSP16_Q(0.00531180),
  DSP16_Q(-0.00747671),
  DSP16_Q(0.00945815),
  DSP16_Q(-0.01071239),
  DSP16_Q(0.01050629),
  DSP16_Q(-0.00780066),
  DSP16_Q(0.00082390),
  DSP16_Q(0.01464436),
  DSP16_Q(-0.05547121),
  DSP16_Q(0.40588270),
  DSP16_Q(0.16870271),
  DSP16_Q(-0.07983397),
  DSP16_Q(0.05111066),
  DSP16_Q(-0.03456853),
  DSP16_Q(0.02301034),
  DSP16_Q(-0.01446516),
  DSP16_Q(0.00821250),
  DSP16_Q(-0.00387519),
  DSP16_Q(0.00114340),
  DSP16_Q(0.00030929),
  DSP16_Q(-0.00083448),
  DSP16_Q(0.00078487),
  DSP16_Q(-0.00047875),
  DSP16_Q(0.00016638),
  DSP16_Q(-0.00000684),
  DSP16_Q(-0.00002426),
  DSP16_Q(0.00022459),
  DSP16_Q(-0.00077423),
  DSP16_Q(0.00180061),
  DSP16_Q(-0.00334443),
  DSP16_Q(0.00532538),
  DSP16_Q(-0.00751962),
  DSP16_Q(0.00954886),
  DSP16_Q(-0.01087308),
  DSP16_Q(0.01076274),
  DSP16_Q(-0.00818373),
  DSP16_Q(0.00137539),
  DSP16_Q(0.01385198),
  DSP16_Q(-0.05426719),
  DSP16_Q(0.40721630),
  DSP16_Q(0.16617518),
  DSP16_Q(-0.07923040),
  DSP16_Q(0.05094220),
  DSP16_Q(-0.03457887),
  DSP16_Q(0.02310152),
  DSP16_Q(-0.01458625),
  DSP16_Q(0.00833399),
  DSP16_Q(-0.00398050),
  DSP16_Q(0.00122496),
  DSP16_Q(0.00025262),
  DSP16_Q(-0.00079959),
  DSP16_Q(0.00076640),
  DSP16_Q(-0.00047081),
  DSP16_Q(0.00016392),
  DSP16_Q(-0.00000657),
  DSP16_Q(-0.00002374),
  DSP16_Q(0.00022167),
  DSP16_Q(-0.00076835),
  DSP16_Q(0.00179384),
  DSP16_Q(-0.00334244),
  DSP16_Q(0.00533808),
  DSP16_Q(-0.00756136),
  DSP16_Q(0.00963819),
  DSP16_Q(-0.01103235),
  DSP16_Q(0.01101807),
  DSP16_Q(-0.00856654),
  DSP16_Q(0.00192855),
  DSP16_Q(0.01305365),
  DSP16_Q(-0.05304468),
  DSP16_Q(0.40852818),
  DSP16_Q(0.16364968),
  DSP16_Q(-0.07861650),
  DSP16_Q(0.05076559),
  DSP16_Q(-0.03458320),
  DSP16_Q(0.02318844),
  DSP16_Q(-0.01470447),
  DSP16_Q(0.00845368),
  DSP16_Q(-0.00408479),
  DSP16_Q(0.00130603),
  DSP16_Q(0.00019613),
  DSP16_Q(-0.00076474),
  DSP16_Q(0.00074791),
  DSP16_Q(-0.00046284),
  DSP16_Q(0.00016146),
  DSP16_Q(-0.00000630),
  DSP16_Q(-0.00002319),
  DSP16_Q(0.00021868),
  DSP16_Q(-0.00076229),
  DSP16_Q(0.00178671),
  DSP16_Q(-0.00333984),
  DSP16_Q(0.00534988),
  DSP16_Q(-0.00760191),
  DSP16_Q(0.00972611),
  DSP16_Q(-0.01119016),
  DSP16_Q(0.01127223),
  DSP16_Q(-0.00894904),
  DSP16_Q(0.00248330),
  DSP16_Q(0.01224946),
  DSP16_Q(-0.05180374),
  DSP16_Q(0.40981821),
  DSP16_Q(0.16112644),
  DSP16_Q(-0.07799243),
  DSP16_Q(0.05058091),
  DSP16_Q(-0.03458154),
  DSP16_Q(0.02327110),
  DSP16_Q(-0.01481980),
  DSP16_Q(0.00857154),
  DSP16_Q(-0.00418804),
  DSP16_Q(0.00138658),
  DSP16_Q(0.00013983),
  DSP16_Q(-0.00072991),
  DSP16_Q(0.00072939),
  DSP16_Q(-0.00045485),
  DSP16_Q(0.00015899),
  DSP16_Q(-0.00000604),
  DSP16_Q(-0.00002263),
  DSP16_Q(0.00021560),
  DSP16_Q(-0.00075604),
  DSP16_Q(0.00177921),
  DSP16_Q(-0.00333663),
  DSP16_Q(0.00536079),
  DSP16_Q(-0.00764126),
  DSP16_Q(0.00981260),
  DSP16_Q(-0.01134648),
  DSP16_Q(0.01152516),
  DSP16_Q(-0.00933114),
  DSP16_Q(0.00303954),
  DSP16_Q(0.01143953),
  DSP16_Q(-0.05054439),
  DSP16_Q(0.41108625),
  DSP16_Q(0.15860569),
  DSP16_Q(-0.07735833),
  DSP16_Q(0.05038821),
  DSP16_Q(-0.03457392),
  DSP16_Q(0.02334949),
  DSP16_Q(-0.01493223),
  DSP16_Q(0.00868757),
  DSP16_Q(-0.00429022),
  DSP16_Q(0.00146660),
  DSP16_Q(0.00008374),
  DSP16_Q(-0.00069512),
  DSP16_Q(0.00071084),
  DSP16_Q(-0.00044684),
  DSP16_Q(0.00015652),
  DSP16_Q(-0.00000579),
  DSP16_Q(-0.00002203),
  DSP16_Q(0.00021244),
  DSP16_Q(-0.00074960),
  DSP16_Q(0.00177135),
  DSP16_Q(-0.00333282),
  DSP16_Q(0.00537079),
  DSP16_Q(-0.00767941),
  DSP16_Q(0.00989764),
  DSP16_Q(-0.01150129),
  DSP16_Q(0.01177683),
  DSP16_Q(-0.00971279),
  DSP16_Q(0.00359718),
  DSP16_Q(0.01062396),
  DSP16_Q(-0.04926669),
  DSP16_Q(0.41233217),
  DSP16_Q(0.15608766),
  DSP16_Q(-0.07671437),
  DSP16_Q(0.05018755),
  DSP16_Q(-0.03456035),
  DSP16_Q(0.02342361),
  DSP16_Q(-0.01504175),
  DSP16_Q(0.00880175),
  DSP16_Q(-0.00439134),
  DSP16_Q(0.00154609),
  DSP16_Q(0.00002786),
  DSP16_Q(-0.00066037),
  DSP16_Q(0.00069229),
  DSP16_Q(-0.00043881),
  DSP16_Q(0.00015405),
  DSP16_Q(-0.00000554),
  DSP16_Q(-0.00002142),
  DSP16_Q(0.00020920),
  DSP16_Q(-0.00074298),
  DSP16_Q(0.00176312),
  DSP16_Q(-0.00332839),
  DSP16_Q(0.00537988),
  DSP16_Q(-0.00771634),
  DSP16_Q(0.00998121),
  DSP16_Q(-0.01165454),
  DSP16_Q(0.01202718),
  DSP16_Q(-0.01009392),
  DSP16_Q(0.00415614),
  DSP16_Q(0.00980286),
  DSP16_Q(-0.04797069),
  DSP16_Q(0.41355584),
  DSP16_Q(0.15357258),
  DSP16_Q(-0.07606071),
  DSP16_Q(0.04997901),
  DSP16_Q(-0.03454085),
  DSP16_Q(0.02349347),
  DSP16_Q(-0.01514836),
  DSP16_Q(0.00891406),
  DSP16_Q(-0.00449138),
  DSP16_Q(0.00162503),
  DSP16_Q(-0.00002780),
  DSP16_Q(-0.00062567),
  DSP16_Q(0.00067371),
  DSP16_Q(-0.00043076),
  DSP16_Q(0.00015158),
  DSP16_Q(-0.00000529),
  DSP16_Q(-0.00002078),
  DSP16_Q(0.00020589),
  DSP16_Q(-0.00073616),
  DSP16_Q(0.00175453),
  DSP16_Q(-0.00332335),
  DSP16_Q(0.00538806),
  DSP16_Q(-0.00775204),
  DSP16_Q(0.01006330),
  DSP16_Q(-0.01180622),
  DSP16_Q(0.01227616),
  DSP16_Q(-0.01047446),
  DSP16_Q(0.00471632),
  DSP16_Q(0.00897635),
  DSP16_Q(-0.04665643),
  DSP16_Q(0.41475714),
  DSP16_Q(0.15106067),
  DSP16_Q(-0.07539749),
  DSP16_Q(0.04976264),
  DSP16_Q(-0.03451545),
  DSP16_Q(0.02355906),
  DSP16_Q(-0.01525203),
  DSP16_Q(0.00902449),
  DSP16_Q(-0.00459031),
  DSP16_Q(0.00170341),
  DSP16_Q(-0.00008324),
  DSP16_Q(-0.00059103),
  DSP16_Q(0.00065513),
  DSP16_Q(-0.00042270),
  DSP16_Q(0.00014910),
  DSP16_Q(-0.00000505),
  DSP16_Q(-0.00002012),
  DSP16_Q(0.00020249),
  DSP16_Q(-0.00072916),
  DSP16_Q(0.00174558),
  DSP16_Q(-0.00331770),
  DSP16_Q(0.00539532),
  DSP16_Q(-0.00778650),
  DSP16_Q(0.01014389),
  DSP16_Q(-0.01195628),
  DSP16_Q(0.01252374),
  DSP16_Q(-0.01085435),
  DSP16_Q(0.00527764),
  DSP16_Q(0.00814453),
  DSP16_Q(-0.04532397),
  DSP16_Q(0.41593594),
  DSP16_Q(0.14855218),
  DSP16_Q(-0.07472488),
  DSP16_Q(0.04953851),
  DSP16_Q(-0.03448417),
  DSP16_Q(0.02362038),
  DSP16_Q(-0.01535276),
  DSP16_Q(0.00913303),
  DSP16_Q(-0.00468813),
  DSP16_Q(0.00178121),
  DSP16_Q(-0.00013843),
  DSP16_Q(-0.00055645),
  DSP16_Q(0.00063654),
  DSP16_Q(-0.00041462),
  DSP16_Q(0.00014663),
  DSP16_Q(-0.00000482),
  DSP16_Q(-0.00001944),
  DSP16_Q(0.00019901),
  DSP16_Q(-0.00072197),
  DSP16_Q(0.00173626),
  DSP16_Q(-0.00331143),
  DSP16_Q(0.00540165),
  DSP16_Q(-0.00781971),
  DSP16_Q(0.01022295),
  DSP16_Q(-0.01210470),
  DSP16_Q(0.01276985),
  DSP16_Q(-0.01123351),
  DSP16_Q(0.00584000),
  DSP16_Q(0.00730752),
  DSP16_Q(-0.04397336),
  DSP16_Q(0.41709211),
  DSP16_Q(0.14604731),
  DSP16_Q(-0.07404304),
  DSP16_Q(0.04930668),
  DSP16_Q(-0.03444704),
  DSP16_Q(0.02367744),
  DSP16_Q(-0.01545055),
  DSP16_Q(0.00923966),
  DSP16_Q(-0.00478483),
  DSP16_Q(0.00185843),
  DSP16_Q(-0.00019338),
  DSP16_Q(-0.00052193),
  DSP16_Q(0.00061795),
  DSP16_Q(-0.00040653),
  DSP16_Q(0.00014416),
  DSP16_Q(-0.00000459),
  DSP16_Q(-0.00001873),
  DSP16_Q(0.00019546),
  DSP16_Q(-0.00071459),
  DSP16_Q(0.00172657),
  DSP16_Q(-0.00330454),
  DSP16_Q(0.00540705),
  DSP16_Q(-0.00785166),
  DSP16_Q(0.01030046),
  DSP16_Q(-0.01225144),
  DSP16_Q(0.01301447),
  DSP16_Q(-0.01161188),
  DSP16_Q(0.00640331),
  DSP16_Q(0.00646544),
  DSP16_Q(-0.04260467),
  DSP16_Q(0.41822555),
  DSP16_Q(0.14354630),
  DSP16_Q(-0.07335213),
  DSP16_Q(0.04906724),
  DSP16_Q(-0.03440407),
  DSP16_Q(0.02373024),
  DSP16_Q(-0.01554538),
  DSP16_Q(0.00934437),
  DSP16_Q(-0.00488038),
  DSP16_Q(0.00193505),
  DSP16_Q(-0.00024807),
  DSP16_Q(-0.00048749),
  DSP16_Q(0.00059936),
  DSP16_Q(-0.00039843),
  DSP16_Q(0.00014168),
  DSP16_Q(-0.00000437),
  DSP16_Q(-0.00001800),
  DSP16_Q(0.00019182),
  DSP16_Q(-0.00070702),
  DSP16_Q(0.00171652),
  DSP16_Q(-0.00329704),
  DSP16_Q(0.00541153),
  DSP16_Q(-0.00788234),
  DSP16_Q(0.01037642),
  DSP16_Q(-0.01239648),
  DSP16_Q(0.01325753),
  DSP16_Q(-0.01198939),
  DSP16_Q(0.00696747),
  DSP16_Q(0.00561839),
  DSP16_Q(-0.04121794),
  DSP16_Q(0.41933612),
  DSP16_Q(0.14104937),
  DSP16_Q(-0.07265230),
  DSP16_Q(0.04882024),
  DSP16_Q(-0.03435530),
  DSP16_Q(0.02377878),
  DSP16_Q(-0.01563724),
  DSP16_Q(0.00944714),
  DSP16_Q(-0.00497478),
  DSP16_Q(0.00201106),
  DSP16_Q(-0.00030249),
  DSP16_Q(-0.00045313),
  DSP16_Q(0.00058077),
  DSP16_Q(-0.00039032),
  DSP16_Q(0.00013921),
  DSP16_Q(-0.00000416),
  DSP16_Q(-0.00001724),
  DSP16_Q(0.00018810),
  DSP16_Q(-0.00069927),
  DSP16_Q(0.00170610),
  DSP16_Q(-0.00328891),
  DSP16_Q(0.00541506),
  DSP16_Q(-0.00791174),
  DSP16_Q(0.01045080),
  DSP16_Q(-0.01253979),
  DSP16_Q(0.01349899),
  DSP16_Q(-0.01236598),
  DSP16_Q(0.00753240),
  DSP16_Q(0.00476651),
  DSP16_Q(-0.03981325),
  DSP16_Q(0.42042372),
  DSP16_Q(0.13855675),
  DSP16_Q(-0.07194372),
  DSP16_Q(0.04856575),
  DSP16_Q(-0.03430075),
  DSP16_Q(0.02382307),
  DSP16_Q(-0.01572613),
  DSP16_Q(0.00954798),
  DSP16_Q(-0.00506802),
  DSP16_Q(0.00208646),
  DSP16_Q(-0.00035665),
  DSP16_Q(-0.00041886),
  DSP16_Q(0.00056220),
  DSP16_Q(-0.00038221),
  DSP16_Q(0.00013674),
  DSP16_Q(-0.00000395),
  DSP16_Q(-0.00001646),
  DSP16_Q(0.00018431),
  DSP16_Q(-0.00069133),
  DSP16_Q(0.00169532),
  DSP16_Q(-0.00328017),
  DSP16_Q(0.00541765),
  DSP16_Q(-0.00793986),
  DSP16_Q(0.01052359),
  DSP16_Q(-0.01268133),
  DSP16_Q(0.01373881),
  DSP16_Q(-0.01274157),
  DSP16_Q(0.00809801),
  DSP16_Q(0.00390990),
  DSP16_Q(-0.03839065),
  DSP16_Q(0.42148823),
  DSP16_Q(0.13606866),
  DSP16_Q(-0.07122655),
  DSP16_Q(0.04830386),
  DSP16_Q(-0.03424045),
  DSP16_Q(0.02386310),
  DSP16_Q(-0.01581204),
  DSP16_Q(0.00964685),
  DSP16_Q(-0.00516007),
  DSP16_Q(0.00216122),
  DSP16_Q(-0.00041052),
  DSP16_Q(-0.00038468),
  DSP16_Q(0.00054363),
  DSP16_Q(-0.00037409),
  DSP16_Q(0.00013428),
  DSP16_Q(-0.00000374),
  DSP16_Q(-0.00001566),
  DSP16_Q(0.00018043),
  DSP16_Q(-0.00068320),
  DSP16_Q(0.00168417),
  DSP16_Q(-0.00327080),
  DSP16_Q(0.00541930),
  DSP16_Q(-0.00796668),
  DSP16_Q(0.01059476),
  DSP16_Q(-0.01282107),
  DSP16_Q(0.01397694),
  DSP16_Q(-0.01311610),
  DSP16_Q(0.00866418),
  DSP16_Q(0.00304870),
  DSP16_Q(-0.03695022),
  DSP16_Q(0.42252954),
  DSP16_Q(0.13358532),
  DSP16_Q(-0.07050095),
  DSP16_Q(0.04803462),
  DSP16_Q(-0.03417443),
  DSP16_Q(0.02389890),
  DSP16_Q(-0.01589496),
  DSP16_Q(0.00974376),
  DSP16_Q(-0.00525093),
  DSP16_Q(0.00223534),
  DSP16_Q(-0.00046409),
  DSP16_Q(-0.00035059),
  DSP16_Q(0.00052508),
  DSP16_Q(-0.00036597),
  DSP16_Q(0.00013181),
  DSP16_Q(-0.00000354),
  DSP16_Q(-0.00001483),
  DSP16_Q(0.00017647),
  DSP16_Q(-0.00067489),
  DSP16_Q(0.00167266),
  DSP16_Q(-0.00326081),
  DSP16_Q(0.00542000),
  DSP16_Q(-0.00799219),
  DSP16_Q(0.01066430),
  DSP16_Q(-0.01295900),
  DSP16_Q(0.01421334),
  DSP16_Q(-0.01348950),
  DSP16_Q(0.00923084),
  DSP16_Q(0.00218301),
  DSP16_Q(-0.03549202),
  DSP16_Q(0.42354755),
  DSP16_Q(0.13110695),
  DSP16_Q(-0.06976708),
  DSP16_Q(0.04775812),
  DSP16_Q(-0.03410271),
  DSP16_Q(0.02393045),
  DSP16_Q(-0.01597489),
  DSP16_Q(0.00983869),
  DSP16_Q(-0.00534059),
  DSP16_Q(0.00230881),
  DSP16_Q(-0.00051738),
  DSP16_Q(-0.00031661),
  DSP16_Q(0.00050655),
  DSP16_Q(-0.00035785),
  DSP16_Q(0.00012936),
  DSP16_Q(-0.00000335),
  DSP16_Q(-0.00001397),
  DSP16_Q(0.00017244),
  DSP16_Q(-0.00066639),
  DSP16_Q(0.00166078),
  DSP16_Q(-0.00325019),
  DSP16_Q(0.00541975),
  DSP16_Q(-0.00801638),
  DSP16_Q(0.01073219),
  DSP16_Q(-0.01309507),
  DSP16_Q(0.01444795),
  DSP16_Q(-0.01386170),
  DSP16_Q(0.00979789),
  DSP16_Q(0.00131297),
  DSP16_Q(-0.03401612),
  DSP16_Q(0.42454214),
  DSP16_Q(0.12863377),
  DSP16_Q(-0.06902510),
  DSP16_Q(0.04747442),
  DSP16_Q(-0.03402533),
  DSP16_Q(0.02395778),
  DSP16_Q(-0.01605183),
  DSP16_Q(0.00993163),
  DSP16_Q(-0.00542904),
  DSP16_Q(0.00238161),
  DSP16_Q(-0.00057035),
  DSP16_Q(-0.00028274),
  DSP16_Q(0.00048804),
  DSP16_Q(-0.00034973),
  DSP16_Q(0.00012690),
  DSP16_Q(-0.00000316),
  DSP16_Q(-0.00001310),
  DSP16_Q(0.00016832),
  DSP16_Q(-0.00065770),
  DSP16_Q(0.00164854),
  DSP16_Q(-0.00323895),
  DSP16_Q(0.00541854),
  DSP16_Q(-0.00803926),
  DSP16_Q(0.01079842),
  DSP16_Q(-0.01322926),
  DSP16_Q(0.01468073),
  DSP16_Q(-0.01423264),
  DSP16_Q(0.01036523),
  DSP16_Q(0.00043869),
  DSP16_Q(-0.03252260),
  DSP16_Q(0.42551321),
  DSP16_Q(0.12616601),
  DSP16_Q(-0.06827517),
  DSP16_Q(0.04718360),
  DSP16_Q(-0.03394232),
  DSP16_Q(0.02398088),
  DSP16_Q(-0.01612576),
  DSP16_Q(0.01002256),
  DSP16_Q(-0.00551626),
  DSP16_Q(0.00245374),
  DSP16_Q(-0.00062300),
  DSP16_Q(-0.00024898),
  DSP16_Q(0.00046955),
  DSP16_Q(-0.00034161),
  DSP16_Q(0.00012446),
  DSP16_Q(-0.00000298),
  DSP16_Q(-0.00001219),
  DSP16_Q(0.00016413),
  DSP16_Q(-0.00064883),
  DSP16_Q(0.00163593),
  DSP16_Q(-0.00322708),
  DSP16_Q(0.00541637),
  DSP16_Q(-0.00806080),
  DSP16_Q(0.01086296),
  DSP16_Q(-0.01336154),
  DSP16_Q(0.01491164),
  DSP16_Q(-0.01460225),
  DSP16_Q(0.01093277),
  DSP16_Q(-0.00043970),
  DSP16_Q(-0.03101154),
  DSP16_Q(0.42646067),
  DSP16_Q(0.12370387),
  DSP16_Q(-0.06751746),
  DSP16_Q(0.04688574),
  DSP16_Q(-0.03385371),
  DSP16_Q(0.02399977),
  DSP16_Q(-0.01619668),
  DSP16_Q(0.01011149),
  DSP16_Q(-0.00560224),
  DSP16_Q(0.00252519),
  DSP16_Q(-0.00067534),
  DSP16_Q(-0.00021534),
  DSP16_Q(0.00045109),
  DSP16_Q(-0.00033349),
  DSP16_Q(0.00012201),
  DSP16_Q(-0.00000281),
  DSP16_Q(-0.00001127),
  DSP16_Q(0.00015986),
  DSP16_Q(-0.00063978),
  DSP16_Q(0.00162296),
  DSP16_Q(-0.00321459),
  DSP16_Q(0.00541324),
  DSP16_Q(-0.00808100),
  DSP16_Q(0.01092581),
  DSP16_Q(-0.01349187),
  DSP16_Q(0.01514063),
  DSP16_Q(-0.01497046),
  DSP16_Q(0.01150041),
  DSP16_Q(-0.00132207),
  DSP16_Q(-0.02948300),
  DSP16_Q(0.42738440),
  DSP16_Q(0.12124758),
  DSP16_Q(-0.06675214),
  DSP16_Q(0.04658092),
  DSP16_Q(-0.03375953),
  DSP16_Q(0.02401445),
  DSP16_Q(-0.01626460),
  DSP16_Q(0.01019840),
  DSP16_Q(-0.00568697),
  DSP16_Q(0.00259594),
  DSP16_Q(-0.00072734),
  DSP16_Q(-0.00018183),
  DSP16_Q(0.00043267),
  DSP16_Q(-0.00032538),
  DSP16_Q(0.00011958),
  DSP16_Q(-0.00000264),
  DSP16_Q(-0.00001031),
  DSP16_Q(0.00015550),
  DSP16_Q(-0.00063054),
  DSP16_Q(0.00160962),
  DSP16_Q(-0.00320147),
  DSP16_Q(0.00540914),
  DSP16_Q(-0.00809985),
  DSP16_Q(0.01098694),
  DSP16_Q(-0.01362025),
  DSP16_Q(0.01536766),
  DSP16_Q(-0.01533720),
  DSP16_Q(0.01206805),
  DSP16_Q(-0.00220829),
  DSP16_Q(-0.02793707),
  DSP16_Q(0.42828433),
  DSP16_Q(0.11879735),
  DSP16_Q(-0.06597936),
  DSP16_Q(0.04626921),
  DSP16_Q(-0.03365982),
  DSP16_Q(0.02402493),
  DSP16_Q(-0.01632951),
  DSP16_Q(0.01028328),
  DSP16_Q(-0.00577043),
  DSP16_Q(0.00266599),
  DSP16_Q(-0.00077900),
  DSP16_Q(-0.00014844),
  DSP16_Q(0.00041428),
  DSP16_Q(-0.00031728),
  DSP16_Q(0.00011715),
  DSP16_Q(-0.00000247),
  DSP16_Q(-0.00000933),
  DSP16_Q(0.00015107),
  DSP16_Q(-0.00062111),
  DSP16_Q(0.00159593),
  DSP16_Q(-0.00318772),
  DSP16_Q(0.00540408),
  DSP16_Q(-0.00811734),
  DSP16_Q(0.01104634),
  DSP16_Q(-0.01374662),
  DSP16_Q(0.01559267),
  DSP16_Q(-0.01570240),
  DSP16_Q(0.01263561),
  DSP16_Q(-0.00309824),
  DSP16_Q(-0.02637384),
  DSP16_Q(0.42916035),
  DSP16_Q(0.11635339),
  DSP16_Q(-0.06519929),
  DSP16_Q(0.04595068),
  DSP16_Q(-0.03355461),
  DSP16_Q(0.02403123),
  DSP16_Q(-0.01639139),
  DSP16_Q(0.01036612),
  DSP16_Q(-0.00585263),
  DSP16_Q(0.00273532),
  DSP16_Q(-0.00083031),
  DSP16_Q(-0.00011520),
  DSP16_Q(0.00039593),
  DSP16_Q(-0.00030919),
  DSP16_Q(0.00011473),
  DSP16_Q(-0.00000232),
  DSP16_Q(-0.00000833),
  DSP16_Q(0.00014657),
  DSP16_Q(-0.00061151),
  DSP16_Q(0.00158187),
  DSP16_Q(-0.00317335),
  DSP16_Q(0.00539804),
  DSP16_Q(-0.00813347),
  DSP16_Q(0.01110400),
  DSP16_Q(-0.01387097),
  DSP16_Q(0.01581563),
  DSP16_Q(-0.01606600),
  DSP16_Q(0.01320297),
  DSP16_Q(-0.00399178),
  DSP16_Q(-0.02479338),
  DSP16_Q(0.43001237),
  DSP16_Q(0.11391593),
  DSP16_Q(-0.06441209),
  DSP16_Q(0.04562543),
  DSP16_Q(-0.03344394),
  DSP16_Q(0.02403336),
  DSP16_Q(-0.01645027),
  DSP16_Q(0.01044692),
  DSP16_Q(-0.00593355),
  DSP16_Q(0.00280393),
  DSP16_Q(-0.00088127),
  DSP16_Q(-0.00008210),
  DSP16_Q(0.00037762),
  DSP16_Q(-0.00030110),
  DSP16_Q(0.00011232),
  DSP16_Q(-0.00000217),
  DSP16_Q(-0.00000730),
  DSP16_Q(0.00014198),
  DSP16_Q(-0.00060172),
  DSP16_Q(0.00156745),
  DSP16_Q(-0.00315835),
  DSP16_Q(0.00539103),
  DSP16_Q(-0.00814824),
  DSP16_Q(0.01115990),
  DSP16_Q(-0.01399327),
  DSP16_Q(0.01603650),
  DSP16_Q(-0.01642794),
  DSP16_Q(0.01377005),
  DSP16_Q(-0.00488879),
  DSP16_Q(-0.02319579),
  DSP16_Q(0.43084030),
  DSP16_Q(0.11148516),
  DSP16_Q(-0.06361793),
  DSP16_Q(0.04529352),
  DSP16_Q(-0.03332784),
  DSP16_Q(0.02403132),
  DSP16_Q(-0.01650612),
  DSP16_Q(0.01052566),
  DSP16_Q(-0.00601317),
  DSP16_Q(0.00287180),
  DSP16_Q(-0.00093186),
  DSP16_Q(-0.00004914),
  DSP16_Q(0.00035935),
  DSP16_Q(-0.00029303),
  DSP16_Q(0.00010992),
  DSP16_Q(-0.00000202),
  DSP16_Q(-0.00000625),
  DSP16_Q(0.00013732),
  DSP16_Q(-0.00059175),
  DSP16_Q(0.00155267),
  DSP16_Q(-0.00314272),
  DSP16_Q(0.00538305),
  DSP16_Q(-0.00816162),
  DSP16_Q(0.01121402),
  DSP16_Q(-0.01411350),
  DSP16_Q(0.01625522),
  DSP16_Q(-0.01678813),
  DSP16_Q(0.01433675),
  DSP16_Q(-0.00578914),
  DSP16_Q(-0.02158116),
  DSP16_Q(0.43164407),
  DSP16_Q(0.10906131),
  DSP16_Q(-0.06281697),
  DSP16_Q(0.04495505),
  DSP16_Q(-0.03320635),
  DSP16_Q(0.02402514),
  DSP16_Q(-0.01655895),
  DSP16_Q(0.01060234),
  DSP16_Q(-0.00609149),
  DSP16_Q(0.00293893),
  DSP16_Q(-0.00098209),
  DSP16_Q(-0.00001634),
  DSP16_Q(0.00034114),
  DSP16_Q(-0.00028498),
  DSP16_Q(0.00010753),
  DSP16_Q(-0.00000188),
  DSP16_Q(-0.00000517),
  DSP16_Q(0.00013258),
  DSP16_Q(-0.00058160),
  DSP16_Q(0.00153753),
  DSP16_Q(-0.00312647),
  DSP16_Q(0.00537409),
  DSP16_Q(-0.00817362),
  DSP16_Q(0.01126635),
  DSP16_Q(-0.01423161),
  DSP16_Q(0.01647175),
  DSP16_Q(-0.01714652),
  DSP16_Q(0.01490296),
  DSP16_Q(-0.00669268),
  DSP16_Q(-0.01994957),
  DSP16_Q(0.43242357),
  DSP16_Q(0.10664458),
  DSP16_Q(-0.06200938),
  DSP16_Q(0.04461009),
  DSP16_Q(-0.03307951),
  DSP16_Q(0.02401481),
  DSP16_Q(-0.01660876),
  DSP16_Q(0.01067695),
  DSP16_Q(-0.00616850),
  DSP16_Q(0.00300530),
  DSP16_Q(-0.00103193),
  DSP16_Q(0.00001630),
  DSP16_Q(0.00032297),
  DSP16_Q(-0.00027694),
  DSP16_Q(0.00010515),
  DSP16_Q(-0.00000174),
  DSP16_Q(-0.00000407),
  DSP16_Q(0.00012776),
  DSP16_Q(-0.00057127),
  DSP16_Q(0.00152203),
  DSP16_Q(-0.00310959),
  DSP16_Q(0.00536414),
  DSP16_Q(-0.00818423),
  DSP16_Q(0.01131687),
  DSP16_Q(-0.01434760),
  DSP16_Q(0.01668605),
  DSP16_Q(-0.01750304),
  DSP16_Q(0.01546860),
  DSP16_Q(-0.00759929),
  DSP16_Q(-0.01830112),
  DSP16_Q(0.43317874),
  DSP16_Q(0.10423518),
  DSP16_Q(-0.06119532),
  DSP16_Q(0.04425872),
  DSP16_Q(-0.03294735),
  DSP16_Q(0.02400037),
  DSP16_Q(-0.01665555),
  DSP16_Q(0.01074948),
  DSP16_Q(-0.00624419),
  DSP16_Q(0.00307092),
  DSP16_Q(-0.00108139),
  DSP16_Q(0.00004878),
  DSP16_Q(0.00030486),
  DSP16_Q(-0.00026891),
  DSP16_Q(0.00010277),
  DSP16_Q(-0.00000161),
  DSP16_Q(-0.00000294),
  DSP16_Q(0.00012286),
  DSP16_Q(-0.00056076),
  DSP16_Q(0.00150617),
  DSP16_Q(-0.00309209),
  DSP16_Q(0.00535322),
  DSP16_Q(-0.00819344),
  DSP16_Q(0.01136558),
  DSP16_Q(-0.01446143),
  DSP16_Q(0.01689808),
  DSP16_Q(-0.01785762),
  DSP16_Q(0.01603356),
  DSP16_Q(-0.00850882),
  DSP16_Q(-0.01663591),
  DSP16_Q(0.43390948),
  DSP16_Q(0.10183332),
  DSP16_Q(-0.06037496),
  DSP16_Q(0.04390102),
  DSP16_Q(-0.03280992),
  DSP16_Q(0.02398181),
  DSP16_Q(-0.01669932),
  DSP16_Q(0.01081993),
  DSP16_Q(-0.00631855),
  DSP16_Q(0.00313576),
  DSP16_Q(-0.00113045),
  DSP16_Q(0.00008109),
  DSP16_Q(0.00028681),
  DSP16_Q(-0.00026091),
  DSP16_Q(0.00010041),
  DSP16_Q(-0.00000149),
  DSP16_Q(-0.00000178),
  DSP16_Q(0.00011789),
  DSP16_Q(-0.00055007),
  DSP16_Q(0.00148996),
  DSP16_Q(-0.00307395),
  DSP16_Q(0.00534131),
  DSP16_Q(-0.00820124),
  DSP16_Q(0.01141245),
  DSP16_Q(-0.01457307),
  DSP16_Q(0.01710779),
  DSP16_Q(-0.01821020),
  DSP16_Q(0.01659775),
  DSP16_Q(-0.00942115),
  DSP16_Q(-0.01495403),
  DSP16_Q(0.43461574),
  DSP16_Q(0.09943919),
  DSP16_Q(-0.05954846),
  DSP16_Q(0.04353709),
  DSP16_Q(-0.03266726),
  DSP16_Q(0.02395916),
  DSP16_Q(-0.01674007),
  DSP16_Q(0.01088830),
  DSP16_Q(-0.00639157),
  DSP16_Q(0.00319983),
  DSP16_Q(-0.00117912),
  DSP16_Q(0.00011323),
  DSP16_Q(0.00026882),
  DSP16_Q(-0.00025292),
  DSP16_Q(0.00009807),
  DSP16_Q(-0.00000137),
  DSP16_Q(-0.00000060),
  DSP16_Q(0.00011284),
  DSP16_Q(-0.00053920),
  DSP16_Q(0.00147339),
  DSP16_Q(-0.00305520),
  DSP16_Q(0.00532842),
  DSP16_Q(-0.00820764),
  DSP16_Q(0.01145747),
  DSP16_Q(-0.01468251),
  DSP16_Q(0.01731514),
  DSP16_Q(-0.01856070),
  DSP16_Q(0.01716106),
  DSP16_Q(-0.01033614),
  DSP16_Q(-0.01325559),
  DSP16_Q(0.43529743),
  DSP16_Q(0.09705302),
  DSP16_Q(-0.05871599),
  DSP16_Q(0.04316701),
  DSP16_Q(-0.03251940),
  DSP16_Q(0.02393243),
  DSP16_Q(-0.01677781),
  DSP16_Q(0.01095457),
  DSP16_Q(-0.00646325),
  DSP16_Q(0.00326310),
  DSP16_Q(-0.00122737),
  DSP16_Q(0.00014519),
  DSP16_Q(0.00025090),
  DSP16_Q(-0.00024496),
  DSP16_Q(0.00009573),
  DSP16_Q(-0.00000126),
  DSP16_Q(0.00000061),
  DSP16_Q(0.00010772),
  DSP16_Q(-0.00052816),
  DSP16_Q(0.00145647),
  DSP16_Q(-0.00303582),
  DSP16_Q(0.00531454),
  DSP16_Q(-0.00821262),
  DSP16_Q(0.01150063),
  DSP16_Q(-0.01478970),
  DSP16_Q(0.01752009),
  DSP16_Q(-0.01890906),
  DSP16_Q(0.01772340),
  DSP16_Q(-0.01125365),
  DSP16_Q(-0.01154068),
  DSP16_Q(0.43595448),
  DSP16_Q(0.09467500),
  DSP16_Q(-0.05787771),
  DSP16_Q(0.04279086),
  DSP16_Q(-0.03236639),
  DSP16_Q(0.02390165),
  DSP16_Q(-0.01681252),
  DSP16_Q(0.01101874),
  DSP16_Q(-0.00653357),
  DSP16_Q(0.00332558),
  DSP16_Q(-0.00127521),
  DSP16_Q(0.00017696),
  DSP16_Q(0.00023304),
  DSP16_Q(-0.00023701),
  DSP16_Q(0.00009341),
  DSP16_Q(-0.00000115),
  DSP16_Q(0.00000184),
  DSP16_Q(0.00010252),
  DSP16_Q(-0.00051694),
  DSP16_Q(0.00143919),
  DSP16_Q(-0.00301581),
  DSP16_Q(0.00529968),
  DSP16_Q(-0.00821618),
  DSP16_Q(0.01154192),
  DSP16_Q(-0.01489464),
  DSP16_Q(0.01772259),
  DSP16_Q(-0.01925522),
  DSP16_Q(0.01828466),
  DSP16_Q(-0.01217353),
  DSP16_Q(-0.00980942),
  DSP16_Q(0.43658682),
  DSP16_Q(0.09230533),
  DSP16_Q(-0.05703379),
  DSP16_Q(0.04240872),
  DSP16_Q(-0.03220827),
  DSP16_Q(0.02386681),
  DSP16_Q(-0.01684423),
  DSP16_Q(0.01108080),
  DSP16_Q(-0.00660252),
  DSP16_Q(0.00338726),
  DSP16_Q(-0.00132263),
  DSP16_Q(0.00020855),
  DSP16_Q(0.00021525),
  DSP16_Q(-0.00022910),
  DSP16_Q(0.00009110),
  DSP16_Q(-0.00000105),
  DSP16_Q(0.00000310),
  DSP16_Q(0.00009725),
  DSP16_Q(-0.00050555),
  DSP16_Q(0.00142157),
  DSP16_Q(-0.00299519),
  DSP16_Q(0.00528383),
  DSP16_Q(-0.00821831),
  DSP16_Q(0.01158132),
  DSP16_Q(-0.01499729),
  DSP16_Q(0.01792260),
  DSP16_Q(-0.01959911),
  DSP16_Q(0.01884476),
  DSP16_Q(-0.01309565),
  DSP16_Q(-0.00806191),
  DSP16_Q(0.43719439),
  DSP16_Q(0.08994421),
  DSP16_Q(-0.05618439),
  DSP16_Q(0.04202069),
  DSP16_Q(-0.03204508),
  DSP16_Q(0.02382795),
  DSP16_Q(-0.01687293),
  DSP16_Q(0.01114076),
  DSP16_Q(-0.00667010),
  DSP16_Q(0.00344812),
  DSP16_Q(-0.00136962),
  DSP16_Q(0.00023994),
  DSP16_Q(0.00019754),
  DSP16_Q(-0.00022121),
  DSP16_Q(0.00008880),
  DSP16_Q(-0.00000096),
  DSP16_Q(0.00000438),
  DSP16_Q(0.00009191),
  DSP16_Q(-0.00049399),
  DSP16_Q(0.00140359),
  DSP16_Q(-0.00297394),
  DSP16_Q(0.00526698),
  DSP16_Q(-0.00821901),
  DSP16_Q(0.01161882),
  DSP16_Q(-0.01509764),
  DSP16_Q(0.01812008),
  DSP16_Q(-0.01994065),
  DSP16_Q(0.01940359),
  DSP16_Q(-0.01401987),
  DSP16_Q(-0.00629826),
  DSP16_Q(0.43777712),
  DSP16_Q(0.08759184),
  DSP16_Q(-0.05532969),
  DSP16_Q(0.04162684),
  DSP16_Q(-0.03187687),
  DSP16_Q(0.02378509),
  DSP16_Q(-0.01689862),
  DSP16_Q(0.01119860),
  DSP16_Q(-0.00673631),
  DSP16_Q(0.00350816),
  DSP16_Q(-0.00141618),
  DSP16_Q(0.00027113),
  DSP16_Q(0.00017990),
  DSP16_Q(-0.00021334),
  DSP16_Q(0.00008652),
  DSP16_Q(-0.00000087),
  DSP16_Q(0.00000569),
  DSP16_Q(0.00008649),
  DSP16_Q(-0.00048225),
  DSP16_Q(0.00138527),
  DSP16_Q(-0.00295207),
  DSP16_Q(0.00524915),
  DSP16_Q(-0.00821828),
  DSP16_Q(0.01165441),
  DSP16_Q(-0.01519565),
  DSP16_Q(0.01831499),
  DSP16_Q(-0.02027980),
  DSP16_Q(0.01996104),
  DSP16_Q(-0.01494604),
  DSP16_Q(-0.00451858),
  DSP16_Q(0.43833496),
  DSP16_Q(0.08524842),
  DSP16_Q(-0.05446984),
  DSP16_Q(0.04122728),
  DSP16_Q(-0.03170368),
  DSP16_Q(0.02373823),
  DSP16_Q(-0.01692131),
  DSP16_Q(0.01125433),
  DSP16_Q(-0.00680113),
  DSP16_Q(0.00356737),
  DSP16_Q(-0.00146230),
  DSP16_Q(0.00030212),
  DSP16_Q(0.00016234),
  DSP16_Q(-0.00020551),
  DSP16_Q(0.00008425),
  DSP16_Q(-0.00000078),
  DSP16_Q(0.00000702),
  DSP16_Q(0.00008099),
  DSP16_Q(-0.00047034),
  DSP16_Q(0.00136660),
  DSP16_Q(-0.00292959),
  DSP16_Q(0.00523033),
  DSP16_Q(-0.00821610),
  DSP16_Q(0.01168807),
  DSP16_Q(-0.01529130),
  DSP16_Q(0.01850729),
  DSP16_Q(-0.02061647),
  DSP16_Q(0.02051703),
  DSP16_Q(-0.01587402),
  DSP16_Q(-0.00272298),
  DSP16_Q(0.43886784),
  DSP16_Q(0.08291414),
  DSP16_Q(-0.05360501),
  DSP16_Q(0.04082208),
  DSP16_Q(-0.03152556),
  DSP16_Q(0.02368741),
  DSP16_Q(-0.01694100),
  DSP16_Q(0.01130793),
  DSP16_Q(-0.00686455),
  DSP16_Q(0.00362575),
  DSP16_Q(-0.00150796),
  DSP16_Q(0.00033290),
  DSP16_Q(0.00014486),
  DSP16_Q(-0.00019771),
  DSP16_Q(0.00008200),
  DSP16_Q(-0.00000070),
  DSP16_Q(0.00000838),
  DSP16_Q(0.00007543),
  DSP16_Q(-0.00045827),
  DSP16_Q(0.00134758),
  DSP16_Q(-0.00290649),
  DSP16_Q(0.00521052),
  DSP16_Q(-0.00821248),
  DSP16_Q(0.01171980),
  DSP16_Q(-0.01538457),
  DSP16_Q(0.01869694),
  DSP16_Q(-0.02095061),
  DSP16_Q(0.02107145),
  DSP16_Q(-0.01680367),
  DSP16_Q(-0.00091159),
  DSP16_Q(0.43937571),
  DSP16_Q(0.08058921),
  DSP16_Q(-0.05273537),
  DSP16_Q(0.04041135),
  DSP16_Q(-0.03134255),
  DSP16_Q(0.02363263),
  DSP16_Q(-0.01695770),
  DSP16_Q(0.01135941),
  DSP16_Q(-0.00692658),
  DSP16_Q(0.00368328),
  DSP16_Q(-0.00155317),
  DSP16_Q(0.00036347),
  DSP16_Q(0.00012747),
  DSP16_Q(-0.00018994),
  DSP16_Q(0.00007976),
  DSP16_Q(-0.00000062),
  DSP16_Q(0.00000976),
  DSP16_Q(0.00006979),
  DSP16_Q(-0.00044602),
  DSP16_Q(0.00132822),
  DSP16_Q(-0.00288277),
  DSP16_Q(0.00518972),
  DSP16_Q(-0.00820741),
  DSP16_Q(0.01174959),
  DSP16_Q(-0.01547543),
  DSP16_Q(0.01888389),
  DSP16_Q(-0.02128215),
  DSP16_Q(0.02162420),
  DSP16_Q(-0.01773484),
  DSP16_Q(0.00091549),
  DSP16_Q(0.43985851),
  DSP16_Q(0.07827380),
  DSP16_Q(-0.05186108),
  DSP16_Q(0.03999515),
  DSP16_Q(-0.03115470),
  DSP16_Q(0.02357393),
  DSP16_Q(-0.01697141),
  DSP16_Q(0.01140877),
  DSP16_Q(-0.00698720),
  DSP16_Q(0.00373996),
  DSP16_Q(-0.00159793),
  DSP16_Q(0.00039382),
  DSP16_Q(0.00011016),
  DSP16_Q(-0.00018220),
  DSP16_Q(0.00007754),
  DSP16_Q(-0.00000055),
  DSP16_Q(0.00001117),
  DSP16_Q(0.00006408),
  DSP16_Q(-0.00043361),
  DSP16_Q(0.00130853),
  DSP16_Q(-0.00285844),
  DSP16_Q(0.00516793),
  DSP16_Q(-0.00820089),
  DSP16_Q(0.01177741),
  DSP16_Q(-0.01556387),
  DSP16_Q(0.01906810),
  DSP16_Q(-0.02161102),
  DSP16_Q(0.02217518),
  DSP16_Q(-0.01866738),
  DSP16_Q(0.00275813),
  DSP16_Q(0.44031620),
  DSP16_Q(0.07596812),
  DSP16_Q(-0.05098231),
  DSP16_Q(0.03957360),
  DSP16_Q(-0.03096206),
  DSP16_Q(0.02351132),
  DSP16_Q(-0.01698215),
  DSP16_Q(0.01145599),
  DSP16_Q(-0.00704641),
  DSP16_Q(0.00379579),
  DSP16_Q(-0.00164221),
  DSP16_Q(0.00042395),
  DSP16_Q(0.00009294),
  DSP16_Q(-0.00017449),
  DSP16_Q(0.00007534),
  DSP16_Q(-0.00000049),
  DSP16_Q(0.00001261),
  DSP16_Q(0.00005830),
  DSP16_Q(-0.00042103),
  DSP16_Q(0.00128849),
  DSP16_Q(-0.00283349),
  DSP16_Q(0.00514515),
  DSP16_Q(-0.00819291),
  DSP16_Q(0.01180327),
  DSP16_Q(-0.01564986),
  DSP16_Q(0.01924955),
  DSP16_Q(-0.02193716),
  DSP16_Q(0.02272429),
  DSP16_Q(-0.01960115),
  DSP16_Q(0.00461620),
  DSP16_Q(0.44074873),
  DSP16_Q(0.07367236),
  DSP16_Q(-0.05009922),
  DSP16_Q(0.03914677),
  DSP16_Q(-0.03076467),
  DSP16_Q(0.02344483),
  DSP16_Q(-0.01698991),
  DSP16_Q(0.01150109),
  DSP16_Q(-0.00710420),
  DSP16_Q(0.00385074),
  DSP16_Q(-0.00168602),
  DSP16_Q(0.00045386),
  DSP16_Q(0.00007582),
  DSP16_Q(-0.00016683),
  DSP16_Q(0.00007315),
  DSP16_Q(-0.00000043),
  DSP16_Q(0.00001407),
  DSP16_Q(0.00005245),
  DSP16_Q(-0.00040829),
  DSP16_Q(0.00126811),
  DSP16_Q(-0.00280794),
  DSP16_Q(0.00512138),
  DSP16_Q(-0.00818347),
  DSP16_Q(0.01182714),
  DSP16_Q(-0.01573338),
  DSP16_Q(0.01942818),
  DSP16_Q(-0.02226051),
  DSP16_Q(0.02327144),
  DSP16_Q(-0.02053600),
  DSP16_Q(0.00648959),
  DSP16_Q(0.44115605),
  DSP16_Q(0.07138669),
  DSP16_Q(-0.04921198),
  DSP16_Q(0.03871476),
  DSP16_Q(-0.03056258),
  DSP16_Q(0.02337447),
  DSP16_Q(-0.01699470),
  DSP16_Q(0.01154405),
  DSP16_Q(-0.00716056),
  DSP16_Q(0.00390483),
  DSP16_Q(-0.00172935),
  DSP16_Q(0.00048353),
  DSP16_Q(0.00005880),
  DSP16_Q(-0.00015920),
  DSP16_Q(0.00007098),
  DSP16_Q(-0.00000037),
  DSP16_Q(0.00001555),
  DSP16_Q(0.00004653),
  DSP16_Q(-0.00039538),
  DSP16_Q(0.00124740),
  DSP16_Q(-0.00278178),
  DSP16_Q(0.00509662),
  DSP16_Q(-0.00817257),
  DSP16_Q(0.01184903),
  DSP16_Q(-0.01581440),
  DSP16_Q(0.01960395),
  DSP16_Q(-0.02258100),
  DSP16_Q(0.02381651),
  DSP16_Q(-0.02147178),
  DSP16_Q(0.00837817),
  DSP16_Q(0.44153812),
  DSP16_Q(0.06911131),
  DSP16_Q(-0.04832076),
  DSP16_Q(0.03827766),
  DSP16_Q(-0.03035585),
  DSP16_Q(0.02330028),
  DSP16_Q(-0.01699654),
  DSP16_Q(0.01158488),
  DSP16_Q(-0.00721550),
  DSP16_Q(0.00395804),
  DSP16_Q(-0.00177220),
  DSP16_Q(0.00051297),
  DSP16_Q(0.00004187),
  DSP16_Q(-0.00015160),
  DSP16_Q(0.00006883),
  DSP16_Q(-0.00000032),
  DSP16_Q(0.00001707),
  DSP16_Q(0.00004055),
  DSP16_Q(-0.00038231),
  DSP16_Q(0.00122636),
  DSP16_Q(-0.00275501),
  DSP16_Q(0.00507087),
  DSP16_Q(-0.00816020),
  DSP16_Q(0.01186892),
  DSP16_Q(-0.01589291),
  DSP16_Q(0.01977684),
  DSP16_Q(-0.02289857),
  DSP16_Q(0.02435942),
  DSP16_Q(-0.02240835),
  DSP16_Q(0.01028180),
  DSP16_Q(0.44189490),
  DSP16_Q(0.06684641),
  DSP16_Q(-0.04742571),
  DSP16_Q(0.03783557),
  DSP16_Q(-0.03014452),
  DSP16_Q(0.02322227),
  DSP16_Q(-0.01699542),
  DSP16_Q(0.01162357),
  DSP16_Q(-0.00726900),
  DSP16_Q(0.00401037),
  DSP16_Q(-0.00181456),
  DSP16_Q(0.00054217),
  DSP16_Q(0.00002504),
  DSP16_Q(-0.00014405),
  DSP16_Q(0.00006670),
  DSP16_Q(-0.00000027),
  DSP16_Q(0.00001860),
  DSP16_Q(0.00003449),
  DSP16_Q(-0.00036909),
  DSP16_Q(0.00120498),
  DSP16_Q(-0.00272764),
  DSP16_Q(0.00504414),
  DSP16_Q(-0.00814637),
  DSP16_Q(0.01188680),
  DSP16_Q(-0.01596889),
  DSP16_Q(0.01994680),
  DSP16_Q(-0.02321315),
  DSP16_Q(0.02490006),
  DSP16_Q(-0.02334554),
  DSP16_Q(0.01220036),
  DSP16_Q(0.44222635),
  DSP16_Q(0.06459216),
  DSP16_Q(-0.04652701),
  DSP16_Q(0.03738857),
  DSP16_Q(-0.02992864),
  DSP16_Q(0.02314047),
  DSP16_Q(-0.01699136),
  DSP16_Q(0.01166014),
  DSP16_Q(-0.00732107),
  DSP16_Q(0.00406180),
  DSP16_Q(-0.00185642),
  DSP16_Q(0.00057112),
  DSP16_Q(0.00000832),
  DSP16_Q(-0.00013654),
  DSP16_Q(0.00006458),
  DSP16_Q(-0.00000023),
  DSP16_Q(0.00002016),
  DSP16_Q(0.00002837),
  DSP16_Q(-0.00035570),
  DSP16_Q(0.00118328),
  DSP16_Q(-0.00269966),
  DSP16_Q(0.00501642),
  DSP16_Q(-0.00813106),
  DSP16_Q(0.01190266),
  DSP16_Q(-0.01604231),
  DSP16_Q(0.02011378),
  DSP16_Q(-0.02352468),
  DSP16_Q(0.02543833),
  DSP16_Q(-0.02428322),
  DSP16_Q(0.01413372),
  DSP16_Q(0.44253243),
  DSP16_Q(0.06234875),
  DSP16_Q(-0.04562481),
  DSP16_Q(0.03693676),
  DSP16_Q(-0.02970827),
  DSP16_Q(0.02305491),
  DSP16_Q(-0.01698438),
  DSP16_Q(0.01169456),
  DSP16_Q(-0.00737169),
  DSP16_Q(0.00411234),
  DSP16_Q(-0.00189778),
  DSP16_Q(0.00059983),
  DSP16_Q(-0.00000829),
  DSP16_Q(-0.00012907),
  DSP16_Q(0.00006248),
  DSP16_Q(-0.00000019),
  DSP16_Q(0.00002175),
  DSP16_Q(0.00002218),
  DSP16_Q(-0.00034216),
  DSP16_Q(0.00116125),
  DSP16_Q(-0.00267109),
  DSP16_Q(0.00498772),
  DSP16_Q(-0.00811428),
  DSP16_Q(0.01191649),
  DSP16_Q(-0.01611315),
  DSP16_Q(0.02027777),
  DSP16_Q(-0.02383310),
  DSP16_Q(0.02597413),
  DSP16_Q(-0.02522123),
  DSP16_Q(0.01608174),
  DSP16_Q(0.44281313),
  DSP16_Q(0.06011636),
  DSP16_Q(-0.04471928),
  DSP16_Q(0.03648024),
  DSP16_Q(-0.02948345),
  DSP16_Q(0.02296561),
  DSP16_Q(-0.01697446),
  DSP16_Q(0.01172685),
  DSP16_Q(-0.00742086),
  DSP16_Q(0.00416198),
  DSP16_Q(-0.00193863),
  DSP16_Q(0.00062829),
  DSP16_Q(-0.00002480),
  DSP16_Q(-0.00012165),
  DSP16_Q(0.00006041),
  DSP16_Q(-0.00000015),
  DSP16_Q(0.00002335),
  DSP16_Q(0.00001592),
  DSP16_Q(-0.00032846),
  DSP16_Q(0.00113890),
  DSP16_Q(-0.00264193),
  DSP16_Q(0.00495803),
  DSP16_Q(-0.00809603),
  DSP16_Q(0.01192829),
  DSP16_Q(-0.01618140),
  DSP16_Q(0.02043871),
  DSP16_Q(-0.02413834),
  DSP16_Q(0.02650737),
  DSP16_Q(-0.02615941),
  DSP16_Q(0.01804428),
  DSP16_Q(0.44306840),
  DSP16_Q(0.05789517),
  DSP16_Q(-0.04381059),
  DSP16_Q(0.03601910),
  DSP16_Q(-0.02925424),
  DSP16_Q(0.02287260),
  DSP16_Q(-0.01696164),
  DSP16_Q(0.01175701),
  DSP16_Q(-0.00746858),
  DSP16_Q(0.00421071),
  DSP16_Q(-0.00197897),
  DSP16_Q(0.00065649),
  DSP16_Q(-0.00004120),
  DSP16_Q(-0.00011427),
  DSP16_Q(0.00005835),
  DSP16_Q(-0.00000012),
  DSP16_Q(0.00002499),
  DSP16_Q(0.00000960),
  DSP16_Q(-0.00031461),
  DSP16_Q(0.00111622),
  DSP16_Q(-0.00261217),
  DSP16_Q(0.00492737),
  DSP16_Q(-0.00807630),
  DSP16_Q(0.01193805),
  DSP16_Q(-0.01624703),
  DSP16_Q(0.02059658),
  DSP16_Q(-0.02444035),
  DSP16_Q(0.02703793),
  DSP16_Q(-0.02709761),
  DSP16_Q(0.02002120),
  DSP16_Q(0.44329821),
  DSP16_Q(0.05568535),
  DSP16_Q(-0.04289890),
  DSP16_Q(0.03555342),
  DSP16_Q(-0.02902069),
  DSP16_Q(0.02277589),
  DSP16_Q(-0.01694591),
  DSP16_Q(0.01178504),
  DSP16_Q(-0.00751484),
  DSP16_Q(0.00425853),
  DSP16_Q(-0.00201879),
  DSP16_Q(0.00068443),
  DSP16_Q(-0.00005748),
  DSP16_Q(-0.00010694),
  DSP16_Q(0.00005631),
  DSP16_Q(-0.00000010),
  DSP16_Q(0.00002665),
  DSP16_Q(0.00000322),
  DSP16_Q(-0.00030061),
  DSP16_Q(0.00109323),
  DSP16_Q(-0.00258182),
  DSP16_Q(0.00489572),
  DSP16_Q(-0.00805509),
  DSP16_Q(0.01194576),
  DSP16_Q(-0.01631003),
  DSP16_Q(0.02075133),
  DSP16_Q(-0.02473905),
  DSP16_Q(0.02756573),
  DSP16_Q(-0.02803568),
  DSP16_Q(0.02201237),
  DSP16_Q(0.44350256),
  DSP16_Q(0.05348707),
  DSP16_Q(-0.04198437),
  DSP16_Q(0.03508332),
  DSP16_Q(-0.02878286),
  DSP16_Q(0.02267553),
  DSP16_Q(-0.01692730),
  DSP16_Q(0.01181093),
  DSP16_Q(-0.00755965),
  DSP16_Q(0.00430542),
  DSP16_Q(-0.00205809),
  DSP16_Q(0.00071211),
  DSP16_Q(-0.00007364),
  DSP16_Q(-0.00009965),
  DSP16_Q(0.00005429),
  DSP16_Q(-0.00000007),
  DSP16_Q(0.00002833),
  DSP16_Q(-0.00000323),
  DSP16_Q(-0.00028645),
  DSP16_Q(0.00106992),
  DSP16_Q(-0.00255088),
  DSP16_Q(0.00486310),
  DSP16_Q(-0.00803241),
  DSP16_Q(0.01195140),
  DSP16_Q(-0.01637037),
  DSP16_Q(0.02090292),
  DSP16_Q(-0.02503440),
  DSP16_Q(0.02809066),
  DSP16_Q(-0.02897347),
  DSP16_Q(0.02401764),
  DSP16_Q(0.44368140),
  DSP16_Q(0.05130052),
  DSP16_Q(-0.04106717),
  DSP16_Q(0.03460888),
  DSP16_Q(-0.02854079),
  DSP16_Q(0.02257154),
  DSP16_Q(-0.01690580),
  DSP16_Q(0.01183470),
  DSP16_Q(-0.00760299),
  DSP16_Q(0.00435140),
  DSP16_Q(-0.00209686),
  DSP16_Q(0.00073952),
  DSP16_Q(-0.00008969),
  DSP16_Q(-0.00009242),
  DSP16_Q(0.00005230),
  DSP16_Q(-0.00000005),
  DSP16_Q(0.00003003),
  DSP16_Q(-0.00000974),
  DSP16_Q(-0.00027215),
  DSP16_Q(0.00104630),
  DSP16_Q(-0.00251936),
  DSP16_Q(0.00482950),
  DSP16_Q(-0.00800824),
  DSP16_Q(0.01195499),
  DSP16_Q(-0.01642805),
  DSP16_Q(0.02105134),
  DSP16_Q(-0.02532632),
  DSP16_Q(0.02861263),
  DSP16_Q(-0.02991081),
  DSP16_Q(0.02603686),
  DSP16_Q(0.44383474),
  DSP16_Q(0.04912587),
  DSP16_Q(-0.04014745),
  DSP16_Q(0.03413020),
  DSP16_Q(-0.02829455),
  DSP16_Q(0.02246395),
  DSP16_Q(-0.01688143),
  DSP16_Q(0.01185634),
  DSP16_Q(-0.00764487),
  DSP16_Q(0.00439645),
  DSP16_Q(-0.00213510),
  DSP16_Q(0.00076666),
  DSP16_Q(-0.00010561),
  DSP16_Q(-0.00008523),
  DSP16_Q(0.00005032),
  DSP16_Q(-0.00000004),
  DSP16_Q(0.00003176),
  DSP16_Q(-0.00001632),
  DSP16_Q(-0.00025771),
  DSP16_Q(0.00102237),
  DSP16_Q(-0.00248726),
  DSP16_Q(0.00479493),
  DSP16_Q(-0.00798260),
  DSP16_Q(0.01195649),
  DSP16_Q(-0.01648304),
  DSP16_Q(0.02119653),
  DSP16_Q(-0.02561476),
  DSP16_Q(0.02913153),
  DSP16_Q(-0.03084756),
  DSP16_Q(0.02806989),
  DSP16_Q(0.44396254),
  DSP16_Q(0.04696328),
  DSP16_Q(-0.03922538),
  DSP16_Q(0.03364738),
  DSP16_Q(-0.02804418),
  DSP16_Q(0.02235279),
  DSP16_Q(-0.01685421),
  DSP16_Q(0.01187585),
  DSP16_Q(-0.00768528),
  DSP16_Q(0.00444056),
  DSP16_Q(-0.00217281),
  DSP16_Q(0.00079352),
  DSP16_Q(-0.00012141),
  DSP16_Q(-0.00007809),
  DSP16_Q(0.00004837),
  DSP16_Q(-0.00000002),
  DSP16_Q(0.00003352),
  DSP16_Q(-0.00002295),
  DSP16_Q(-0.00024311),
  DSP16_Q(0.00099813),
  DSP16_Q(-0.00245458),
  DSP16_Q(0.00475939),
  DSP16_Q(-0.00795548),
  DSP16_Q(0.01195592),
  DSP16_Q(-0.01653532),
  DSP16_Q(0.02133847),
  DSP16_Q(-0.02589966),
  DSP16_Q(0.02964726),
  DSP16_Q(-0.03178356),
  DSP16_Q(0.03011658),
  DSP16_Q(0.44406480),
  DSP16_Q(0.04481292),
  DSP16_Q(-0.03830113),
  DSP16_Q(0.03316050),
  DSP16_Q(-0.02778975),
  DSP16_Q(0.02223808),
  DSP16_Q(-0.01682415),
  DSP16_Q(0.01189325),
  DSP16_Q(-0.00772422),
  DSP16_Q(0.00448374),
  DSP16_Q(-0.00220997),
  DSP16_Q(0.00082011),
  DSP16_Q(-0.00013709),
  DSP16_Q(-0.00007101),
  DSP16_Q(0.00004643),
  DSP16_Q(-0.00000001),
  DSP16_Q(0.00003529),
  DSP16_Q(-0.00002964),
  DSP16_Q(-0.00022838),
  DSP16_Q(0.00097359),
  DSP16_Q(-0.00242132),
  DSP16_Q(0.00472289),
  DSP16_Q(-0.00792688),
  DSP16_Q(0.01195327),
  DSP16_Q(-0.01658487),
  DSP16_Q(0.02147711),
  DSP16_Q(-0.02618095),
  DSP16_Q(0.03015973),
  DSP16_Q(-0.03271864),
  DSP16_Q(0.03217677),
  DSP16_Q(0.44414150),
  DSP16_Q(0.04267495),
  DSP16_Q(-0.03737485),
  DSP16_Q(0.03266968),
  DSP16_Q(-0.02753131),
  DSP16_Q(0.02211985),
  DSP16_Q(-0.01679126),
  DSP16_Q(0.01190852),
  DSP16_Q(-0.00776168),
  DSP16_Q(0.00452597),
  DSP16_Q(-0.00224658),
  DSP16_Q(0.00084641),
  DSP16_Q(-0.00015264),
  DSP16_Q(-0.00006397),
  DSP16_Q(0.00004452),
  DSP16_Q(-0.00000001),
  DSP16_Q(0.00003709),
  DSP16_Q(-0.00003639),
  DSP16_Q(-0.00021350),
  DSP16_Q(0.00094874),
  DSP16_Q(-0.00238750),
  DSP16_Q(0.00468542),
  DSP16_Q(-0.00789679),
  DSP16_Q(0.01194852),
  DSP16_Q(-0.01663169),
  DSP16_Q(0.02161244),
  DSP16_Q(-0.02645858),
  DSP16_Q(0.03066884),
  DSP16_Q(-0.03365265),
  DSP16_Q(0.03425033),
  DSP16_Q(0.44419264),
  DSP16_Q(0.04054955),
  DSP16_Q(-0.03644670),
  DSP16_Q(0.03217501),
  DSP16_Q(-0.02726891),
  DSP16_Q(0.02199814),
  DSP16_Q(-0.01675556),
  DSP16_Q(0.01192168),
  DSP16_Q(-0.00779768),
  DSP16_Q(0.00456726),
  DSP16_Q(-0.00228265),
  DSP16_Q(0.00087243),
  DSP16_Q(-0.00016805),
  DSP16_Q(-0.00005699),
  DSP16_Q(0.00004263),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00003892),
  DSP16_Q(-0.00004320),
  DSP16_Q(-0.00019849),
  DSP16_Q(0.00092360),
  DSP16_Q(-0.00235311),
  DSP16_Q(0.00464699),
  DSP16_Q(-0.00786523),
  DSP16_Q(0.01194168),
  DSP16_Q(-0.01667576),
  DSP16_Q(0.02174441),
  DSP16_Q(-0.02673249),
  DSP16_Q(0.03117449),
  DSP16_Q(-0.03458544),
  DSP16_Q(0.03633708),
  DSP16_Q(0.44421821),
  DSP16_Q(0.03843687),
  DSP16_Q(-0.03551684),
  DSP16_Q(0.03167658),
  DSP16_Q(-0.02700262),
  DSP16_Q(0.02187299),
  DSP16_Q(-0.01671705),
  DSP16_Q(0.01193273),
  DSP16_Q(-0.00783219),
  DSP16_Q(0.00460760),
  DSP16_Q(-0.00231816),
  DSP16_Q(0.00089816),
  DSP16_Q(-0.00018334),
  DSP16_Q(-0.00005007),
  DSP16_Q(0.00004076),
  DSP16_Q(-0.00000000)
};
